/*
 * Copyright (c) Highsoft AS. All rights reserved.
 */

import * as globals from "./globals";
/**
 * Options for crosshairs on axes.
 */
export type AxisCrosshairOptions = (XAxisCrosshairOptions|YAxisCrosshairOptions);
export type AxisEventCallbackFunction = (this: Axis) => void;
/**
 * Options for axes.
 */
export type AxisOptions = (XAxisOptions|YAxisOptions|ZAxisOptions);
/**
 * Options for plot band labels on axes.
 */
export type AxisPlotBandsLabelOptions = (XAxisPlotBandsLabelOptions|YAxisPlotBandsLabelOptions|ZAxisPlotBandsLabelOptions);
/**
 * Options for plot bands on axes.
 */
export type AxisPlotBandsOptions = (XAxisPlotBandsOptions|YAxisPlotBandsOptions|ZAxisPlotBandsOptions);
/**
 * Options for plot line labels on axes.
 */
export type AxisPlotLinesLabelOptions = (XAxisPlotLinesLabelOptions|YAxisPlotLinesLabelOptions|ZAxisPlotLinesLabelOptions);
/**
 * Options for plot lines on axes.
 */
export type AxisPlotLinesOptions = (XAxisPlotLinesOptions|YAxisPlotLinesOptions|ZAxisPlotLinesOptions);
/**
 *
 */
export type AxisPointBreakEventCallbackFunction = (this: Axis, event: AxisPointBreakEventObject) => void;
/**
 *
 */
export type AxisSetExtremesEventCallbackFunction = (this: Axis, event: AxisSetExtremesEventObject) => void;
export type AxisTickPositionerCallbackFunction = (this: Axis) => Array<number>;
/**
 * Callback for chart constructors.
 *
 * @param chart
 *        Created chart.
 */
export type ChartCallbackFunction = (chart: Chart) => void;
/**
 * Gets fired when an area of the chart has been selected. The default action
 * for the selection event is to zoom the chart to the selected area. It can be
 * prevented by calling `event.preventDefault()` or return false.
 *
 * @param event
 *        Event informations
 *
 * @return Return false to prevent the default action, usually zoom.
 */
export type ChartSelectionCallbackFunction = (event: Event) => (boolean|undefined);
/**
 * A clipping rectangle that can be applied to one or more SVGElement instances.
 * It is instanciated with the SVGRenderer#clipRect function and applied with
 * the SVGElement#clip function.
 */
export type ClipRectElement = SVGElement;
/**
 * A valid color to be parsed and handled by Highcharts. Highcharts internally
 * supports hex colors like `#ffffff`, rgb colors like `rgb(255,255,255)` and
 * rgba colors like `rgba(255,255,255,1)`. Other colors may be supported by the
 * browsers and displayed correctly, but Highcharts is not able to process them
 * and apply concepts like opacity and brightening.
 */
export type ColorString = string;
/**
 * All possible cursor styles.
 */
export type CursorType = ("alias"|"all-scroll"|"auto"|"cell"|"col-resize"|"context-menu"|"copy"|"crosshair"|"default"|"e-resize"|"ew-resize"|"grab"|"grabbing"|"help"|"move"|"n-resize"|"ne-resize"|
"nesw-resize"|"no-drop"|"none"|"not-allowed"|"ns-resize"|"nw-resize"|"nwse-resize"|"pointer"|"progress"|"row-resize"|"s-resize"|"se-resize"|"sw-resize"|"text"|"vertical-text"|"w-resize"|"wait"|
"zoom-in"|"zoom-out");
/**
 * Callback function to modify the CSV before parsing it by the data module.
 *
 * @param csv
 *        The CSV to modify.
 *
 * @return The CSV to parse.
 */
export type DataBeforeParseCallbackFunction = (csv: string) => string;
/**
 * Callback function that gets called after parsing data.
 *
 * @param chartOptions
 *        The chart options that were used.
 */
export type DataCompleteCallbackFunction = (chartOptions: ChartOptions) => void;
/**
 * Callback function to parse string representations of dates into JavaScript
 * timestamps (milliseconds since 1.1.1970).
 *
 * @return Timestamp (milliseconds since 1.1.1970) as integer for Date class.
 */
export type DataParseDateCallbackFunction = (dateValue: string) => number;
/**
 * Callback function to access the parsed columns, the two-dimentional input
 * data array directly, before they are interpreted into series data and
 * categories.
 *
 * @param columns
 *        The parsed columns by the data module.
 *
 * @return Return `false` to stop completion, or call `this.complete()` to
 *         continue async.
 */
export type DataParsedCallbackFunction = (columns: Array<Array<any>>) => (boolean|undefined);
/**
 * Gets fired when a drilldown point is clicked, before the new series is added.
 * Note that when clicking a category label to trigger multiple series
 * drilldown, one `drilldown` event is triggered per point in the category.
 *
 * @param this
 *        The chart where the event occurs.
 *
 * @param e
 *        The drilldown event.
 */
export type DrilldownCallbackFunction = (this: Chart, e: DrilldownEventObject) => void;
/**
 * This gets fired after all the series have been drilled up. This is especially
 * usefull in a chart with multiple drilldown series.
 *
 * @param this
 *        The chart where the event occurs.
 *
 * @param e
 *        The final drillup event.
 */
export type DrillupAllCallbackFunction = (this: Chart, e: DrillupAllEventObject) => void;
/**
 * Gets fired when drilling up from a drilldown series.
 *
 * @param this
 *        The chart where the event occurs.
 *
 * @param e
 *        The drillup event.
 */
export type DrillupCallbackFunction = (this: Chart, e: DrillupEventObject) => void;
/**
 * The function callback to execute when the event is fired. The `this` context
 * contains the instance, that fired the event.
 *
 *
 * @param eventArguments
 *        Event arguments.
 */
export type EventCallbackFunction<T> = (this: T, eventArguments?: Dictionary<any>) => void;
/**
 * Function to call if the offline-exporting module fails to export a chart on
 * the client side.
 *
 * @param options
 *        The exporting options.
 *
 * @param err
 *        The error from the module.
 */
export type ExportingErrorCallbackFunction = (options: ExportingOptions, err: Error) => void;
/**
 * Formats data as a string. Usually the data is accessible throught the `this`
 * keyword.
 */
export type FormatterCallbackFunction<T> = (this: T) => string;
/**
 * An object of key-value pairs for HTML attributes.
 */
export type HTMLAttributes = Dictionary<(boolean|number|string)>;
/**
 * An HTML DOM element. The type is a reference to the regular HTMLElement in
 * the global scope.
 */
export type HTMLDOMElement = HTMLElement;
/**
 * The iterator callback.
 *
 * @param value
 *        The property value.
 *
 * @param key
 *        The property key.
 *
 * @param obj
 *        The object that objectEach is being applied to.
 */
export type ObjectEachCallbackFunction = (value: any, key: string, obj: any) => void;
/**
 * Callback function to react on button clicks.
 *
 * @param e
 *        Event arguments.
 *
 * @param Return
 *        false to cancel the default button event.
 */
export type RangeSelectorClickCallbackFunction = (e: Event, Return: (boolean|undefined)) => void;
/**
 * Callback function to parse values entered in the input boxes and return a
 * valid JavaScript time as milliseconds since 1970.
 *
 * @param value
 *        Input value to parse.
 *
 * @return Parsed JavaScript time value.
 */
export type RangeSelectorParseCallbackFunction = (value: string) => number;
/**
 * If a number is given, it defines the pixel length. If a percentage string is
 * given, like for example `'50%'`, the setting defines a length relative to a
 * base size, for example the size of a container.
 */
export type RelativeSize = (number|string);
/**
 * A callback function to gain complete control on when the responsive rule
 * applies.
 *
 * @return Return `true` if it applies.
 */
export type ResponsiveCallbackFunction = () => boolean;
/**
 * Function callback when a series has been animated.
 *
 * @param e
 *        Event arguments.
 */
export type SeriesAfterAnimateCallbackFunction = (e: SeriesAfterAnimateEventObject) => void;
/**
 * Function callback when the checkbox next to the series' name in the legend is
 * clicked.
 *
 * @param e
 *        Event arguments.
 */
export type SeriesCheckboxClickCallbackFunction = (e: SeriesCheckboxClickEventObject) => void;
/**
 * Function callback when a series is clicked. Return false to cancel toogle
 * actions.
 *
 * @param e
 *        Event arguments.
 */
export type SeriesClickCallbackFunction = (e: SeriesClickEventObject) => void;
/**
 * The possible types of series options.
 */
export type SeriesOptionsType = (SeriesAbandsOptions|SeriesAdOptions|SeriesAoOptions|SeriesApoOptions|SeriesAreaOptions|SeriesArearangeOptions|SeriesAreasplineOptions|SeriesAreasplinerangeOptions|
SeriesAroonOptions|SeriesAroonoscillatorOptions|SeriesAtrOptions|SeriesBarOptions|SeriesBbOptions|SeriesBellcurveOptions|SeriesBoxplotOptions|SeriesBubbleOptions|SeriesBulletOptions|
SeriesCandlestickOptions|SeriesCciOptions|SeriesChaikinOptions|SeriesCmfOptions|SeriesColumnOptions|SeriesColumnpyramidOptions|SeriesColumnrangeOptions|SeriesCylinderOptions|SeriesDemaOptions|
SeriesDpoOptions|SeriesEmaOptions|SeriesErrorbarOptions|SeriesFlagsOptions|SeriesFunnelOptions|SeriesGanttOptions|SeriesGaugeOptions|SeriesHeatmapOptions|SeriesHistogramOptions|SeriesIkhOptions|
SeriesKeltnerchannelsOptions|SeriesLinearregressionangleOptions|SeriesLinearregressioninterceptOptions|SeriesLinearregressionOptions|SeriesLinearregressionslopeOptions|SeriesLineOptions|
SeriesMacdOptions|SeriesMapbubbleOptions|SeriesMaplineOptions|SeriesMapOptions|SeriesMappointOptions|SeriesMfiOptions|SeriesMomentumOptions|SeriesNatrOptions|SeriesNetworkgraphOptions|
SeriesOhlcOptions|SeriesPackedbubbleOptions|SeriesParetoOptions|SeriesPcOptions|SeriesPieOptions|SeriesPivotpointsOptions|SeriesPolygonOptions|SeriesPpoOptions|SeriesPriceenvelopesOptions|
SeriesPsarOptions|SeriesPyramidOptions|SeriesRocOptions|SeriesRsiOptions|SeriesSankeyOptions|SeriesScatter3dOptions|SeriesScatterOptions|SeriesSmaOptions|SeriesSolidgaugeOptions|SeriesSplineOptions|
SeriesStochasticOptions|SeriesStreamgraphOptions|SeriesSunburstOptions|SeriesSupertrendOptions|SeriesTemaOptions|SeriesTilemapOptions|SeriesTreemapOptions|SeriesTrixOptions|SeriesVariablepieOptions|
SeriesVariwideOptions|SeriesVbpOptions|SeriesVectorOptions|SeriesVennOptions|SeriesVwapOptions|SeriesWaterfallOptions|SeriesWilliamsrOptions|SeriesWindbarbOptions|SeriesWmaOptions|
SeriesWordcloudOptions|SeriesXrangeOptions|SeriesZigzagOptions);
/**
 * Function callback when a series point is clicked. Return false to cancel the
 * action.
 *
 * @param e
 *        Event arguments.
 */
export type SeriesPointClickCallbackFunction = (e: SeriesPointClickEventObject) => void;
/**
 * Function callback to execute while series points are dragged.
 *
 * @param e
 *        Event arguments.
 *
 * @return Return false to stop the default drag action.
 */
export type SeriesPointDragCallbackFunction = (e: SeriesPointDragEventObject) => boolean;
/**
 * Function callback to execute when a series point is dragged.
 *
 * @param e
 *        Event arguments.
 */
export type SeriesPointDragStartCallbackFunction = (e: SeriesPointDragStartEventObject) => void;
/**
 * Function callback to execute when series points are dropped.
 *
 * @param e
 *        Event arguments.
 */
export type SeriesPointDropCallbackFunction = (e: SeriesPointDropEventObject) => void;
/**
 * An SVG DOM element. The type is a reference to the regular SVGElement in the
 * global scope.
 */
export type SVGDOMElement = globals.GlobalSVGElement;
/**
 * Array of path commands, that will go into the `d` attribute of an SVG
 * element.
 */
export type SVGPathArray = Array<(number|SVGPathCommand)>;
/**
 * Possible path commands in a SVG path array.
 */
export type SVGPathCommand = ("a"|"c"|"h"|"l"|"m"|"q"|"s"|"t"|"v"|"z"|"A"|"C"|"H"|"L"|"M"|"Q"|"S"|"T"|"V"|"Z");
/**
 * An extendable collection of functions for defining symbol paths.
 */
export type SymbolDictionary = {
    [key in SymbolKey]: (() => void|undefined);
};
/**
 * Can be one of `arc`, `callout`, `circle`, `diamond`, `square`, `triangle`,
 * `triangle-down`. Symbols are used internally for point markers, button and
 * label borders and backgrounds, or custom shapes. Extendable by adding to
 * SVGRenderer#symbols.
 */
export type SymbolKey = ("arc"|"callout"|"circle"|"diamond"|"square"|"triangle"|"triangle-down");
/**
 * Function of an additional date format specifier.
 *
 * @param timestamp
 *        The time to format.
 *
 * @return The formatted portion of the date.
 */
export type TimeFormatCallbackFunction = (timestamp: number) => string;
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the focus border drawn
 * around elements while navigating through them.
 *
 * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation.focusBorder
 * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation.focusBorder
 * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation.focusBorder
 * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation.focusBorder
 */
export interface AccessibilityKeyboardNavigationFocusBorderOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable/disable focus border for
     * chart.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation.focusBorder.enabled
     * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation.focusBorder.enabled
     * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation.focusBorder.enabled
     * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation.focusBorder.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Hide the browser's default focus
     * indicator.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation.focusBorder.hideBrowserFocusOutline
     * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation.focusBorder.hideBrowserFocusOutline
     * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation.focusBorder.hideBrowserFocusOutline
     * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation.focusBorder.hideBrowserFocusOutline
     */
    hideBrowserFocusOutline?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Focus border margin around the
     * elements.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation.focusBorder.margin
     * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation.focusBorder.margin
     * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation.focusBorder.margin
     * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation.focusBorder.margin
     */
    margin?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the focus
     * border drawn around elements while navigating through them. Note that
     * some browsers in addition draw their own borders for focused elements.
     * These automatic borders can not be styled by Highcharts.
     *
     * In styled mode, the border is given the `.highcharts-focus-border` class.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation.focusBorder.style
     * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation.focusBorder.style
     * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation.focusBorder.style
     * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation.focusBorder.style
     */
    style?: CSSObject;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for keyboard navigation.
 *
 * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation
 * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation
 * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation
 * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation
 */
export interface AccessibilityKeyboardNavigationOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable keyboard navigation for
     * the chart.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation.enabled
     * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation.enabled
     * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation.enabled
     * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the focus border
     * drawn around elements while navigating through them.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation.focusBorder
     * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation.focusBorder
     * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation.focusBorder
     * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation.focusBorder
     */
    focusBorder?: AccessibilityKeyboardNavigationFocusBorderOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the keyboard navigation mode
     * for the chart. Can be "normal" or "serialize". In normal mode, left/right
     * arrow keys move between points in a series, while up/down arrow keys move
     * between series. Up/down navigation acts intelligently to figure out which
     * series makes sense to move to from any given point.
     *
     * In "serialize" mode, points are instead navigated as a single list.
     * Left/right behaves as in "normal" mode. Up/down arrow keys will behave
     * like left/right. This is useful for unifying navigation behavior
     * with/without screen readers enabled.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation.mode
     * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation.mode
     * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation.mode
     * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation.mode
     */
    mode?: ("normal"|"serialize");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Skip null points when navigating
     * through points with the keyboard.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation.skipNullPoints
     * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation.skipNullPoints
     * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation.skipNullPoints
     * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation.skipNullPoints
     */
    skipNullPoints?: boolean;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for configuring
 * accessibility for the chart. Requires the accessibility module to be loaded.
 * For a description of the module and information on its features, see
 * Highcharts Accessibility.
 *
 * @see https://api.highcharts.com/highcharts/accessibility
 * @see https://api.highcharts.com/highstock/accessibility
 * @see https://api.highcharts.com/highmaps/accessibility
 * @see https://api.highcharts.com/gantt/accessibility
 */
export interface AccessibilityOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether or not to add series
     * descriptions to charts with a single series.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.describeSingleSeries
     * @see https://api.highcharts.com/highstock/accessibility.describeSingleSeries
     * @see https://api.highcharts.com/highmaps/accessibility.describeSingleSeries
     * @see https://api.highcharts.com/gantt/accessibility.describeSingleSeries
     */
    describeSingleSeries?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable accessibility features
     * for the chart.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.enabled
     * @see https://api.highcharts.com/highstock/accessibility.enabled
     * @see https://api.highcharts.com/highmaps/accessibility.enabled
     * @see https://api.highcharts.com/gantt/accessibility.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.keyboardNavigation
     * @see https://api.highcharts.com/highstock/accessibility.keyboardNavigation
     * @see https://api.highcharts.com/highmaps/accessibility.keyboardNavigation
     * @see https://api.highcharts.com/gantt/accessibility.keyboardNavigation
     */
    keyboardNavigation?: AccessibilityKeyboardNavigationOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to run upon clicking
     * the "View as Data Table" link in the screen reader region.
     *
     * By default Highcharts will insert and set focus to a data table
     * representation of the chart.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.onTableAnchorClick
     * @see https://api.highcharts.com/highstock/accessibility.onTableAnchorClick
     * @see https://api.highcharts.com/highmaps/accessibility.onTableAnchorClick
     * @see https://api.highcharts.com/gantt/accessibility.onTableAnchorClick
     */
    onTableAnchorClick?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Date format to use for points on
     * datetime axes when describing them to screen reader users.
     *
     * Defaults to the same format as in tooltip.
     *
     * For an overview of the replacement codes, see dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.pointDateFormat
     * @see https://api.highcharts.com/highstock/accessibility.pointDateFormat
     * @see https://api.highcharts.com/highmaps/accessibility.pointDateFormat
     * @see https://api.highcharts.com/gantt/accessibility.pointDateFormat
     */
    pointDateFormat?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Formatter function to determine
     * the date/time format used with points on datetime axes when describing
     * them to screen reader users. Receives one argument, `point`, referring to
     * the point to describe. Should return a date format string compatible with
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.pointDateFormatter
     * @see https://api.highcharts.com/highstock/accessibility.pointDateFormatter
     * @see https://api.highcharts.com/highmaps/accessibility.pointDateFormatter
     * @see https://api.highcharts.com/gantt/accessibility.pointDateFormatter
     */
    pointDateFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Formatter function to use
     * instead of the default for point descriptions. Receives one argument,
     * `point`, referring to the point to describe. Should return a String with
     * the description of the point for a screen reader user.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/accessibility.pointDescriptionFormatter
     * @see https://api.highcharts.com/highmaps/accessibility.pointDescriptionFormatter
     * @see https://api.highcharts.com/gantt/accessibility.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When a series contains more
     * points than this, we no longer expose information about individual points
     * to screen readers.
     *
     * Set to `false` to disable.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.pointDescriptionThreshold
     * @see https://api.highcharts.com/highstock/accessibility.pointDescriptionThreshold
     * @see https://api.highcharts.com/highmaps/accessibility.pointDescriptionThreshold
     * @see https://api.highcharts.com/gantt/accessibility.pointDescriptionThreshold
     */
    pointDescriptionThreshold?: (false|number);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A formatter function to create
     * the HTML contents of the hidden screen reader information region.
     * Receives one argument, `chart`, referring to the chart object. Should
     * return a String with the HTML content of the region.
     *
     * The link to view the chart as a data table will be added automatically
     * after the custom HTML content.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.screenReaderSectionFormatter
     * @see https://api.highcharts.com/highstock/accessibility.screenReaderSectionFormatter
     * @see https://api.highcharts.com/highmaps/accessibility.screenReaderSectionFormatter
     * @see https://api.highcharts.com/gantt/accessibility.screenReaderSectionFormatter
     */
    screenReaderSectionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Formatter function to use
     * instead of the default for series descriptions. Receives one argument,
     * `series`, referring to the series to describe. Should return a String
     * with the description of the series for a screen reader user.
     *
     * @see https://api.highcharts.com/highcharts/accessibility.seriesDescriptionFormatter
     * @see https://api.highcharts.com/highstock/accessibility.seriesDescriptionFormatter
     * @see https://api.highcharts.com/highmaps/accessibility.seriesDescriptionFormatter
     * @see https://api.highcharts.com/gantt/accessibility.seriesDescriptionFormatter
     */
    seriesDescriptionFormatter?: () => void;
}
/**
 * Options to align the element relative to the chart or another box.
 */
export interface AlignObject {
    /**
     * Horizontal alignment. Can be one of `left`, `center` and `right`.
     */
    align?: string;
    /**
     * Use the `transform` attribute with translateX and translateY custom
     * attributes to align this elements rather than `x` and `y` attributes.
     */
    alignByTranslate?: boolean;
    /**
     * Vertical alignment. Can be one of `top`, `middle` and `bottom`.
     */
    verticalAlign?: string;
    /**
     * Horizontal pixel offset from alignment.
     */
    x?: number;
    /**
     * Vertical pixel offset from alignment.
     */
    y?: number;
}
/**
 * An animation configuration. Animation configurations can also be defined as
 * booleans, where `false` turns off animation and `true` defaults to a duration
 * of 500ms.
 */
export interface AnimationOptionsObject {
    /**
     * A callback function to exectute when the animation finishes.
     */
    complete?: () => void;
    /**
     * The animation duration in milliseconds.
     */
    duration: number;
    /**
     * The name of an easing function as defined on the `Math` object.
     */
    easing?: string;
    /**
     * A callback function to execute on each step of each attribute or CSS
     * property that's being animated. The first argument contains information
     * about the animation and progress.
     */
    step?: () => void;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for annotation's labels.
 * Each label inherits options from the labelOptions object. An option from the
 * labelOptions can be overwritten by config for a specific label.
 *
 * @see https://api.highcharts.com/highcharts/annotations.labelOptions
 * @see https://api.highcharts.com/highstock/annotations.labelOptions
 * @see https://api.highcharts.com/highmaps/annotations.labelOptions
 * @see https://api.highcharts.com/gantt/annotations.labelOptions
 */
export interface AnnotationsLabelOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The alignment of the
     * annotation's label. If right, the right side of the label should be
     * touching the point.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.align
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.align
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.align
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to allow the
     * annotation's labels to overlap. To make the labels less sensitive for
     * overlapping, the can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.allowOverlap
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.allowOverlap
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.allowOverlap
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The background color or gradient
     * for the annotation's label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.backgroundColor
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.backgroundColor
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.backgroundColor
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border color for the
     * annotation's label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.borderColor
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.borderColor
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.borderColor
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border radius in pixels for
     * the annotaiton's label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.borderRadius
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.borderRadius
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.borderRadius
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border width in pixels for
     * the annotation's label
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.borderWidth
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.borderWidth
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.borderWidth
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A class name for styling by CSS.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.className
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.className
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.className
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to hide the annotation's
     * label that is outside the plot area.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.crop
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.crop
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.crop
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The label's pixel distance from
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.distance
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.distance
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.distance
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.distance
     */
    distance?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A format string for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.format
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.format
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.format
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback JavaScript function to
     * format the annotation's label. Note that if a `format` or `text` are
     * defined, the format or text take precedence and the formatter is ignored.
     * `This` refers to a point object.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.formatter
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.formatter
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.formatter
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.formatter
     */
    formatter?: FormatterCallbackFunction<Point>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) How to handle the annotation's
     * label that flow outside the plot area. The justify option aligns the
     * label inside the plot area.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.overflow
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.overflow
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.overflow
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When either the borderWidth or
     * the backgroundColor is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.padding
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.padding
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.padding
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The shadow of the box. The
     * shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.shadow
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.shadow
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.shadow
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The name of a symbol to use for
     * the border around the label. Symbols are predefined functions on the
     * Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.shape
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.shape
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.shape
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Styles for the annotation's
     * label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.style
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.style
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.style
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Alias for the format option.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.text
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.text
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.text
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render
     * the annotation's label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.useHTML
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.useHTML
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.useHTML
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical alignment of the
     * annotation's label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.verticalAlign
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.verticalAlign
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.verticalAlign
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position offset of the
     * label relative to the point. Note that if a `distance` is defined, the
     * distance takes precedence over `x` and `y` options.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.x
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.x
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.x
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position offset of the
     * label relative to the point. Note that if a `distance` is defined, the
     * distance takes precedence over `x` and `y` options.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions.y
     * @see https://api.highcharts.com/highstock/annotations.labelOptions.y
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions.y
     * @see https://api.highcharts.com/gantt/annotations.labelOptions.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) An array of labels for the
 * annotation. For options that apply to multiple labels, they can be added to
 * the labelOptions.
 *
 * @see https://api.highcharts.com/highcharts/annotations.labels
 * @see https://api.highcharts.com/highstock/annotations.labels
 * @see https://api.highcharts.com/highmaps/annotations.labels
 * @see https://api.highcharts.com/gantt/annotations.labels
 */
export interface AnnotationsLabelsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The alignment of the
     * annotation's label. If right, the right side of the label should be
     * touching the point.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.align
     * @see https://api.highcharts.com/highstock/annotations.labels.align
     * @see https://api.highcharts.com/highmaps/annotations.labels.align
     * @see https://api.highcharts.com/gantt/annotations.labels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to allow the
     * annotation's labels to overlap. To make the labels less sensitive for
     * overlapping, the can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.allowOverlap
     * @see https://api.highcharts.com/highstock/annotations.labels.allowOverlap
     * @see https://api.highcharts.com/highmaps/annotations.labels.allowOverlap
     * @see https://api.highcharts.com/gantt/annotations.labels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The background color or gradient
     * for the annotation's label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.backgroundColor
     * @see https://api.highcharts.com/highstock/annotations.labels.backgroundColor
     * @see https://api.highcharts.com/highmaps/annotations.labels.backgroundColor
     * @see https://api.highcharts.com/gantt/annotations.labels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border color for the
     * annotation's label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.borderColor
     * @see https://api.highcharts.com/highstock/annotations.labels.borderColor
     * @see https://api.highcharts.com/highmaps/annotations.labels.borderColor
     * @see https://api.highcharts.com/gantt/annotations.labels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border radius in pixels for
     * the annotaiton's label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.borderRadius
     * @see https://api.highcharts.com/highstock/annotations.labels.borderRadius
     * @see https://api.highcharts.com/highmaps/annotations.labels.borderRadius
     * @see https://api.highcharts.com/gantt/annotations.labels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border width in pixels for
     * the annotation's label
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.borderWidth
     * @see https://api.highcharts.com/highstock/annotations.labels.borderWidth
     * @see https://api.highcharts.com/highmaps/annotations.labels.borderWidth
     * @see https://api.highcharts.com/gantt/annotations.labels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A class name for styling by CSS.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.className
     * @see https://api.highcharts.com/highstock/annotations.labels.className
     * @see https://api.highcharts.com/highmaps/annotations.labels.className
     * @see https://api.highcharts.com/gantt/annotations.labels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to hide the annotation's
     * label that is outside the plot area.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.crop
     * @see https://api.highcharts.com/highstock/annotations.labels.crop
     * @see https://api.highcharts.com/highmaps/annotations.labels.crop
     * @see https://api.highcharts.com/gantt/annotations.labels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The label's pixel distance from
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.distance
     * @see https://api.highcharts.com/highstock/annotations.labels.distance
     * @see https://api.highcharts.com/highmaps/annotations.labels.distance
     * @see https://api.highcharts.com/gantt/annotations.labels.distance
     */
    distance?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A format string for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.format
     * @see https://api.highcharts.com/highstock/annotations.labels.format
     * @see https://api.highcharts.com/highmaps/annotations.labels.format
     * @see https://api.highcharts.com/gantt/annotations.labels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback JavaScript function to
     * format the annotation's label. Note that if a `format` or `text` are
     * defined, the format or text take precedence and the formatter is ignored.
     * `This` refers to a point object.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.formatter
     * @see https://api.highcharts.com/highstock/annotations.labels.formatter
     * @see https://api.highcharts.com/highmaps/annotations.labels.formatter
     * @see https://api.highcharts.com/gantt/annotations.labels.formatter
     */
    formatter?: FormatterCallbackFunction<Point>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) How to handle the annotation's
     * label that flow outside the plot area. The justify option aligns the
     * label inside the plot area.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.overflow
     * @see https://api.highcharts.com/highstock/annotations.labels.overflow
     * @see https://api.highcharts.com/highmaps/annotations.labels.overflow
     * @see https://api.highcharts.com/gantt/annotations.labels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When either the borderWidth or
     * the backgroundColor is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.padding
     * @see https://api.highcharts.com/highstock/annotations.labels.padding
     * @see https://api.highcharts.com/highmaps/annotations.labels.padding
     * @see https://api.highcharts.com/gantt/annotations.labels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This option defines the point to
     * which the label will be connected. It can be either the point which
     * exists in the series - it is referenced by the point's id - or a new
     * point with defined x, y properies and optionally axes.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.point
     * @see https://api.highcharts.com/highstock/annotations.labels.point
     * @see https://api.highcharts.com/highmaps/annotations.labels.point
     * @see https://api.highcharts.com/gantt/annotations.labels.point
     */
    point?: (string|AnnotationsLabelsPointOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The shadow of the box. The
     * shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.shadow
     * @see https://api.highcharts.com/highstock/annotations.labels.shadow
     * @see https://api.highcharts.com/highmaps/annotations.labels.shadow
     * @see https://api.highcharts.com/gantt/annotations.labels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The name of a symbol to use for
     * the border around the label. Symbols are predefined functions on the
     * Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.shape
     * @see https://api.highcharts.com/highstock/annotations.labels.shape
     * @see https://api.highcharts.com/highmaps/annotations.labels.shape
     * @see https://api.highcharts.com/gantt/annotations.labels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Styles for the annotation's
     * label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.style
     * @see https://api.highcharts.com/highstock/annotations.labels.style
     * @see https://api.highcharts.com/highmaps/annotations.labels.style
     * @see https://api.highcharts.com/gantt/annotations.labels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Alias for the format option.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.text
     * @see https://api.highcharts.com/highstock/annotations.labels.text
     * @see https://api.highcharts.com/highmaps/annotations.labels.text
     * @see https://api.highcharts.com/gantt/annotations.labels.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render
     * the annotation's label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.useHTML
     * @see https://api.highcharts.com/highstock/annotations.labels.useHTML
     * @see https://api.highcharts.com/highmaps/annotations.labels.useHTML
     * @see https://api.highcharts.com/gantt/annotations.labels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical alignment of the
     * annotation's label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.verticalAlign
     * @see https://api.highcharts.com/highstock/annotations.labels.verticalAlign
     * @see https://api.highcharts.com/highmaps/annotations.labels.verticalAlign
     * @see https://api.highcharts.com/gantt/annotations.labels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position offset of the
     * label relative to the point. Note that if a `distance` is defined, the
     * distance takes precedence over `x` and `y` options.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.x
     * @see https://api.highcharts.com/highstock/annotations.labels.x
     * @see https://api.highcharts.com/highmaps/annotations.labels.x
     * @see https://api.highcharts.com/gantt/annotations.labels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position offset of the
     * label relative to the point. Note that if a `distance` is defined, the
     * distance takes precedence over `x` and `y` options.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.y
     * @see https://api.highcharts.com/highstock/annotations.labels.y
     * @see https://api.highcharts.com/highmaps/annotations.labels.y
     * @see https://api.highcharts.com/gantt/annotations.labels.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) This option defines the point to
 * which the label will be connected. It can be either the point which exists in
 * the series - it is referenced by the point's id - or a new point with defined
 * x, y properies and optionally axes.
 *
 * @see https://api.highcharts.com/highcharts/annotations.labels.point
 * @see https://api.highcharts.com/highstock/annotations.labels.point
 * @see https://api.highcharts.com/highmaps/annotations.labels.point
 * @see https://api.highcharts.com/gantt/annotations.labels.point
 */
export interface AnnotationsLabelsPointOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position of the point.
     * Units can be either in axis or chart pixel coordinates.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.point.x
     * @see https://api.highcharts.com/highstock/annotations.labels.point.x
     * @see https://api.highcharts.com/highmaps/annotations.labels.point.x
     * @see https://api.highcharts.com/gantt/annotations.labels.point.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This number defines which xAxis
     * the point is connected to. It refers to either the axis id or the index
     * of the axis in the xAxis array. If the option is not configured or the
     * axis is not found the point's x coordinate refers to the chart pixels.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.point.xAxis
     * @see https://api.highcharts.com/highstock/annotations.labels.point.xAxis
     * @see https://api.highcharts.com/highmaps/annotations.labels.point.xAxis
     * @see https://api.highcharts.com/gantt/annotations.labels.point.xAxis
     */
    xAxis?: (number|string);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position of the point.
     * Units can be either in axis or chart pixel coordinates.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.point.y
     * @see https://api.highcharts.com/highstock/annotations.labels.point.y
     * @see https://api.highcharts.com/highmaps/annotations.labels.point.y
     * @see https://api.highcharts.com/gantt/annotations.labels.point.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This number defines which yAxis
     * the point is connected to. It refers to either the axis id or the index
     * of the axis in the yAxis array. If the option is not configured or the
     * axis is not found the point's y coordinate refers to the chart pixels.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels.point.yAxis
     * @see https://api.highcharts.com/highstock/annotations.labels.point.yAxis
     * @see https://api.highcharts.com/highmaps/annotations.labels.point.yAxis
     * @see https://api.highcharts.com/gantt/annotations.labels.point.yAxis
     */
    yAxis?: (number|string);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for configuring annotations,
 * for example labels, arrows or shapes. Annotations can be tied to points, axis
 * coordinates or chart pixel coordinates.
 *
 * @see https://api.highcharts.com/highcharts/annotations
 * @see https://api.highcharts.com/highstock/annotations
 * @see https://api.highcharts.com/highmaps/annotations
 * @see https://api.highcharts.com/gantt/annotations
 */
export interface AnnotationsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Sets an ID for an annotation.
     * Can be user later when removing an annotation in
     * Chart.removeAnnotation(id) method.
     *
     * @see https://api.highcharts.com/highcharts/annotations.id
     * @see https://api.highcharts.com/highstock/annotations.id
     * @see https://api.highcharts.com/highmaps/annotations.id
     * @see https://api.highcharts.com/gantt/annotations.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for annotation's labels.
     * Each label inherits options from the labelOptions object. An option from
     * the labelOptions can be overwritten by config for a specific label.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labelOptions
     * @see https://api.highcharts.com/highstock/annotations.labelOptions
     * @see https://api.highcharts.com/highmaps/annotations.labelOptions
     * @see https://api.highcharts.com/gantt/annotations.labelOptions
     */
    labelOptions?: AnnotationsLabelOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array of labels for the
     * annotation. For options that apply to multiple labels, they can be added
     * to the labelOptions.
     *
     * @see https://api.highcharts.com/highcharts/annotations.labels
     * @see https://api.highcharts.com/highstock/annotations.labels
     * @see https://api.highcharts.com/highmaps/annotations.labels
     * @see https://api.highcharts.com/gantt/annotations.labels
     */
    labels?: Array<AnnotationsLabelsOptions>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for annotation's shapes.
     * Each shape inherits options from the shapeOptions object. An option from
     * the shapeOptions can be overwritten by config for a specific shape.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapeOptions
     * @see https://api.highcharts.com/highstock/annotations.shapeOptions
     * @see https://api.highcharts.com/highmaps/annotations.shapeOptions
     * @see https://api.highcharts.com/gantt/annotations.shapeOptions
     */
    shapeOptions?: AnnotationsShapeOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array of shapes for the
     * annotation. For options that apply to multiple shapes, then can be added
     * to the shapeOptions.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes
     * @see https://api.highcharts.com/highstock/annotations.shapes
     * @see https://api.highcharts.com/highmaps/annotations.shapes
     * @see https://api.highcharts.com/gantt/annotations.shapes
     */
    shapes?: Array<AnnotationsShapesOptions>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether the annotation is
     * visible.
     *
     * @see https://api.highcharts.com/highcharts/annotations.visible
     * @see https://api.highcharts.com/highstock/annotations.visible
     * @see https://api.highcharts.com/highmaps/annotations.visible
     * @see https://api.highcharts.com/gantt/annotations.visible
     */
    visible?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Z index of the annotation.
     *
     * @see https://api.highcharts.com/highcharts/annotations.zIndex
     * @see https://api.highcharts.com/highstock/annotations.zIndex
     * @see https://api.highcharts.com/highmaps/annotations.zIndex
     * @see https://api.highcharts.com/gantt/annotations.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for annotation's shapes.
 * Each shape inherits options from the shapeOptions object. An option from the
 * shapeOptions can be overwritten by config for a specific shape.
 *
 * @see https://api.highcharts.com/highcharts/annotations.shapeOptions
 * @see https://api.highcharts.com/highstock/annotations.shapeOptions
 * @see https://api.highcharts.com/highmaps/annotations.shapeOptions
 * @see https://api.highcharts.com/gantt/annotations.shapeOptions
 */
export interface AnnotationsShapeOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the shape's fill.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapeOptions.fill
     * @see https://api.highcharts.com/highstock/annotations.shapeOptions.fill
     * @see https://api.highcharts.com/highmaps/annotations.shapeOptions.fill
     * @see https://api.highcharts.com/gantt/annotations.shapeOptions.fill
     */
    fill?: (ColorString|GradientColorObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The height of the shape.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapeOptions.height
     * @see https://api.highcharts.com/highstock/annotations.shapeOptions.height
     * @see https://api.highcharts.com/highmaps/annotations.shapeOptions.height
     * @see https://api.highcharts.com/gantt/annotations.shapeOptions.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the shape.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapeOptions.r
     * @see https://api.highcharts.com/highstock/annotations.shapeOptions.r
     * @see https://api.highcharts.com/highmaps/annotations.shapeOptions.r
     * @see https://api.highcharts.com/gantt/annotations.shapeOptions.r
     */
    r?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the shape's stroke.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapeOptions.stroke
     * @see https://api.highcharts.com/highstock/annotations.shapeOptions.stroke
     * @see https://api.highcharts.com/highmaps/annotations.shapeOptions.stroke
     * @see https://api.highcharts.com/gantt/annotations.shapeOptions.stroke
     */
    stroke?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel stroke width of the
     * shape.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapeOptions.strokeWidth
     * @see https://api.highcharts.com/highstock/annotations.shapeOptions.strokeWidth
     * @see https://api.highcharts.com/highmaps/annotations.shapeOptions.strokeWidth
     * @see https://api.highcharts.com/gantt/annotations.shapeOptions.strokeWidth
     */
    strokeWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The type of the shape, e.g.
     * circle or rectangle.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapeOptions.type
     * @see https://api.highcharts.com/highstock/annotations.shapeOptions.type
     * @see https://api.highcharts.com/highmaps/annotations.shapeOptions.type
     * @see https://api.highcharts.com/gantt/annotations.shapeOptions.type
     */
    type?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the shape.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapeOptions.width
     * @see https://api.highcharts.com/highstock/annotations.shapeOptions.width
     * @see https://api.highcharts.com/highmaps/annotations.shapeOptions.width
     * @see https://api.highcharts.com/gantt/annotations.shapeOptions.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) An array of shapes for the
 * annotation. For options that apply to multiple shapes, then can be added to
 * the shapeOptions.
 *
 * @see https://api.highcharts.com/highcharts/annotations.shapes
 * @see https://api.highcharts.com/highstock/annotations.shapes
 * @see https://api.highcharts.com/highmaps/annotations.shapes
 * @see https://api.highcharts.com/gantt/annotations.shapes
 */
export interface AnnotationsShapesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the shape's fill.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.fill
     * @see https://api.highcharts.com/highstock/annotations.shapes.fill
     * @see https://api.highcharts.com/highmaps/annotations.shapes.fill
     * @see https://api.highcharts.com/gantt/annotations.shapes.fill
     */
    fill?: (ColorString|GradientColorObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The height of the shape.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.height
     * @see https://api.highcharts.com/highstock/annotations.shapes.height
     * @see https://api.highcharts.com/highmaps/annotations.shapes.height
     * @see https://api.highcharts.com/gantt/annotations.shapes.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Id of the marker which will be
     * drawn at the final vertex of the path. Custom markers can be defined in
     * defs property.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.markerEnd
     * @see https://api.highcharts.com/highstock/annotations.shapes.markerEnd
     * @see https://api.highcharts.com/highmaps/annotations.shapes.markerEnd
     * @see https://api.highcharts.com/gantt/annotations.shapes.markerEnd
     */
    markerEnd?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Id of the marker which will be
     * drawn at the first vertex of the path. Custom markers can be defined in
     * defs property.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.markerStart
     * @see https://api.highcharts.com/highstock/annotations.shapes.markerStart
     * @see https://api.highcharts.com/highmaps/annotations.shapes.markerStart
     * @see https://api.highcharts.com/gantt/annotations.shapes.markerStart
     */
    markerStart?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This option defines the point to
     * which the shape will be connected. It can be either the point which
     * exists in the series - it is referenced by the point's id - or a new
     * point with defined x, y properties and optionally axes.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.point
     * @see https://api.highcharts.com/highstock/annotations.shapes.point
     * @see https://api.highcharts.com/highmaps/annotations.shapes.point
     * @see https://api.highcharts.com/gantt/annotations.shapes.point
     */
    point?: (string|AnnotationsShapesPointOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array of points for the
     * shape. This option is available for shapes which can use multiple points
     * such as path. A point can be either a point object or a point's id.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.points
     * @see https://api.highcharts.com/highstock/annotations.shapes.points
     * @see https://api.highcharts.com/highmaps/annotations.shapes.points
     * @see https://api.highcharts.com/gantt/annotations.shapes.points
     */
    points?: Array<AnnotationsShapesPointsOptions>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the shape.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.r
     * @see https://api.highcharts.com/highstock/annotations.shapes.r
     * @see https://api.highcharts.com/highmaps/annotations.shapes.r
     * @see https://api.highcharts.com/gantt/annotations.shapes.r
     */
    r?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the shape's stroke.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.stroke
     * @see https://api.highcharts.com/highstock/annotations.shapes.stroke
     * @see https://api.highcharts.com/highmaps/annotations.shapes.stroke
     * @see https://api.highcharts.com/gantt/annotations.shapes.stroke
     */
    stroke?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel stroke width of the
     * shape.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.strokeWidth
     * @see https://api.highcharts.com/highstock/annotations.shapes.strokeWidth
     * @see https://api.highcharts.com/highmaps/annotations.shapes.strokeWidth
     * @see https://api.highcharts.com/gantt/annotations.shapes.strokeWidth
     */
    strokeWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The type of the shape, e.g.
     * circle or rectangle.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.type
     * @see https://api.highcharts.com/highstock/annotations.shapes.type
     * @see https://api.highcharts.com/highmaps/annotations.shapes.type
     * @see https://api.highcharts.com/gantt/annotations.shapes.type
     */
    type?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the shape.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.width
     * @see https://api.highcharts.com/highstock/annotations.shapes.width
     * @see https://api.highcharts.com/highmaps/annotations.shapes.width
     * @see https://api.highcharts.com/gantt/annotations.shapes.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) This option defines the point to
 * which the shape will be connected. It can be either the point which exists in
 * the series - it is referenced by the point's id - or a new point with defined
 * x, y properties and optionally axes.
 *
 * @see https://api.highcharts.com/highcharts/annotations.shapes.point
 * @see https://api.highcharts.com/highstock/annotations.shapes.point
 * @see https://api.highcharts.com/highmaps/annotations.shapes.point
 * @see https://api.highcharts.com/gantt/annotations.shapes.point
 */
export interface AnnotationsShapesPointOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position of the point.
     * Units can be either in axis or chart pixel coordinates.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.point.x
     * @see https://api.highcharts.com/highstock/annotations.shapes.point.x
     * @see https://api.highcharts.com/highmaps/annotations.shapes.point.x
     * @see https://api.highcharts.com/gantt/annotations.shapes.point.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This number defines which xAxis
     * the point is connected to. It refers to either the axis id or the index
     * of the axis in the xAxis array. If the option is not configured or the
     * axis is not found the point's x coordinate refers to the chart pixels.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.point.xAxis
     * @see https://api.highcharts.com/highstock/annotations.shapes.point.xAxis
     * @see https://api.highcharts.com/highmaps/annotations.shapes.point.xAxis
     * @see https://api.highcharts.com/gantt/annotations.shapes.point.xAxis
     */
    xAxis?: (number|string);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position of the point.
     * Units can be either in axis or chart pixel coordinates.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.point.y
     * @see https://api.highcharts.com/highstock/annotations.shapes.point.y
     * @see https://api.highcharts.com/highmaps/annotations.shapes.point.y
     * @see https://api.highcharts.com/gantt/annotations.shapes.point.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This number defines which yAxis
     * the point is connected to. It refers to either the axis id or the index
     * of the axis in the yAxis array. If the option is not configured or the
     * axis is not found the point's y coordinate refers to the chart pixels.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.point.yAxis
     * @see https://api.highcharts.com/highstock/annotations.shapes.point.yAxis
     * @see https://api.highcharts.com/highmaps/annotations.shapes.point.yAxis
     * @see https://api.highcharts.com/gantt/annotations.shapes.point.yAxis
     */
    yAxis?: (number|string);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) An array of points for the shape.
 * This option is available for shapes which can use multiple points such as
 * path. A point can be either a point object or a point's id.
 *
 * @see https://api.highcharts.com/highcharts/annotations.shapes.points
 * @see https://api.highcharts.com/highstock/annotations.shapes.points
 * @see https://api.highcharts.com/highmaps/annotations.shapes.points
 * @see https://api.highcharts.com/gantt/annotations.shapes.points
 */
export interface AnnotationsShapesPointsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position of the point.
     * Units can be either in axis or chart pixel coordinates.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.points.x
     * @see https://api.highcharts.com/highstock/annotations.shapes.points.x
     * @see https://api.highcharts.com/highmaps/annotations.shapes.points.x
     * @see https://api.highcharts.com/gantt/annotations.shapes.points.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This number defines which xAxis
     * the point is connected to. It refers to either the axis id or the index
     * of the axis in the xAxis array. If the option is not configured or the
     * axis is not found the point's x coordinate refers to the chart pixels.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.points.xAxis
     * @see https://api.highcharts.com/highstock/annotations.shapes.points.xAxis
     * @see https://api.highcharts.com/highmaps/annotations.shapes.points.xAxis
     * @see https://api.highcharts.com/gantt/annotations.shapes.points.xAxis
     */
    xAxis?: (number|string);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position of the point.
     * Units can be either in axis or chart pixel coordinates.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.points.y
     * @see https://api.highcharts.com/highstock/annotations.shapes.points.y
     * @see https://api.highcharts.com/highmaps/annotations.shapes.points.y
     * @see https://api.highcharts.com/gantt/annotations.shapes.points.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This number defines which yAxis
     * the point is connected to. It refers to either the axis id or the index
     * of the axis in the yAxis array. If the option is not configured or the
     * axis is not found the point's y coordinate refers to the chart pixels.
     *
     * @see https://api.highcharts.com/highcharts/annotations.shapes.points.yAxis
     * @see https://api.highcharts.com/highstock/annotations.shapes.points.yAxis
     * @see https://api.highcharts.com/highmaps/annotations.shapes.points.yAxis
     * @see https://api.highcharts.com/gantt/annotations.shapes.points.yAxis
     */
    yAxis?: (number|string);
}
export interface AxisLabelsFormatterContextObject {
    axis: Axis;
    chart: Chart;
    isFirst: boolean;
    isLast: boolean;
    value: number;
}
export interface AxisPointBreakEventObject {
    brk: Dictionary<number>;
    point: Point;
    preventDefault: () => void;
    target: SVGElement;
    type: ("pointBreak"|"pointInBreak");
}
export interface AxisSetExtremesEventObject {
    dataMax: number;
    dataMin: number;
    max: number;
    min: number;
    preventDefault: () => void;
    target: SVGElement;
    trigger: string;
    type: "setExtremes";
    userMax: number;
    userMin: number;
}
/**
 * Bounding box of an element.
 */
export interface BBoxObject {
    /**
     * Height of the bounding box.
     */
    height: number;
    /**
     * Width of the bounding box.
     */
    width: number;
    /**
     * Horizontal position of the bounding box.
     */
    x: number;
    /**
     * Vertical position of the bounding box.
     */
    y: number;
}
/**
 * (Highcharts, Highstock) Debugging options for boost. Useful for benchmarking,
 * and general timing.
 *
 * @see https://api.highcharts.com/highcharts/boost.debug
 * @see https://api.highcharts.com/highstock/boost.debug
 */
export interface BoostDebugOptions {
    /**
     * (Highcharts, Highstock) Show the number of points skipped through
     * culling.
     *
     * When set to true, the number of points skipped in series processing is
     * outputted. Points are skipped if they are closer than 1 pixel from each
     * other.
     *
     * @see https://api.highcharts.com/highcharts/boost.debug.showSkipSummary
     * @see https://api.highcharts.com/highstock/boost.debug.showSkipSummary
     */
    showSkipSummary?: boolean;
    /**
     * (Highcharts, Highstock) Time the WebGL to SVG buffer copy
     *
     * After rendering, the result is copied to an image which is injected into
     * the SVG.
     *
     * If this property is set to true, the time it takes for the buffer copy to
     * complete is outputted.
     *
     * @see https://api.highcharts.com/highcharts/boost.debug.timeBufferCopy
     * @see https://api.highcharts.com/highstock/boost.debug.timeBufferCopy
     */
    timeBufferCopy?: boolean;
    /**
     * (Highcharts, Highstock) Time the building of the k-d tree.
     *
     * This outputs the time spent building the k-d tree used for markers etc.
     *
     * Note that the k-d tree is built async, and runs post-rendering.
     * Following, it does not affect the performance of the rendering itself.
     *
     * @see https://api.highcharts.com/highcharts/boost.debug.timeKDTree
     * @see https://api.highcharts.com/highstock/boost.debug.timeKDTree
     */
    timeKDTree?: boolean;
    /**
     * (Highcharts, Highstock) Time the series rendering.
     *
     * This outputs the time spent on actual rendering in the console when set
     * to true.
     *
     * @see https://api.highcharts.com/highcharts/boost.debug.timeRendering
     * @see https://api.highcharts.com/highstock/boost.debug.timeRendering
     */
    timeRendering?: boolean;
    /**
     * (Highcharts, Highstock) Time the series processing.
     *
     * This outputs the time spent on transforming the series data to vertex
     * buffers when set to true.
     *
     * @see https://api.highcharts.com/highcharts/boost.debug.timeSeriesProcessing
     * @see https://api.highcharts.com/highstock/boost.debug.timeSeriesProcessing
     */
    timeSeriesProcessing?: boolean;
    /**
     * (Highcharts, Highstock) Time the the WebGL setup.
     *
     * This outputs the time spent on setting up the WebGL context, creating
     * shaders, and textures.
     *
     * @see https://api.highcharts.com/highcharts/boost.debug.timeSetup
     * @see https://api.highcharts.com/highstock/boost.debug.timeSetup
     */
    timeSetup?: boolean;
}
/**
 * (Highcharts, Highstock) Options for the Boost module. The Boost module allows
 * certain series types to be rendered by WebGL instead of the default SVG. This
 * allows hundreds of thousands of data points to be rendered in milliseconds.
 * In addition to the WebGL rendering it saves time by skipping processing and
 * inspection of the data wherever possible. This introduces some limitations to
 * what features are available in Boost mode. See the docs for details.
 *
 * In addition to the global `boost` option, each series has a boostThreshold
 * that defines when the boost should kick in.
 *
 * Requires the `modules/boost.js` module.
 *
 * @see https://api.highcharts.com/highcharts/boost
 * @see https://api.highcharts.com/highstock/boost
 */
export interface BoostOptions {
    /**
     * (Highcharts, Highstock) If set to true, the whole chart will be boosted
     * if one of the series crosses its threshold, and all the series can be
     * boosted.
     *
     * @see https://api.highcharts.com/highcharts/boost.allowForce
     * @see https://api.highcharts.com/highstock/boost.allowForce
     */
    allowForce?: boolean;
    /**
     * (Highcharts, Highstock) Debugging options for boost. Useful for
     * benchmarking, and general timing.
     *
     * @see https://api.highcharts.com/highcharts/boost.debug
     * @see https://api.highcharts.com/highstock/boost.debug
     */
    debug?: BoostDebugOptions;
    /**
     * (Highcharts, Highstock) Enable or disable boost on a chart.
     *
     * @see https://api.highcharts.com/highcharts/boost.enabled
     * @see https://api.highcharts.com/highstock/boost.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Set the series threshold for when the boost
     * should kick in globally.
     *
     * Setting to e.g. 20 will cause the whole chart to enter boost mode if
     * there are 20 or more series active. When the chart is in boost mode,
     * every series in it will be rendered to a common canvas. This offers a
     * significant speed improvment in charts with a very high amount of series.
     *
     * @see https://api.highcharts.com/highcharts/boost.seriesThreshold
     * @see https://api.highcharts.com/highstock/boost.seriesThreshold
     */
    seriesThreshold?: (number|null);
    /**
     * (Highcharts, Highstock) Enable or disable GPU translations. GPU
     * translations are faster than doing the translation in JavaScript.
     *
     * This option may cause rendering issues with certain datasets. Namely, if
     * your dataset has large numbers with small increments (such as
     * timestamps), it won't work correctly. This is due to floating point
     * precission.
     *
     * @see https://api.highcharts.com/highcharts/boost.useGPUTranslations
     * @see https://api.highcharts.com/highstock/boost.useGPUTranslations
     */
    useGPUTranslations?: boolean;
}
/**
 * (Highcharts) The back side of the frame around a 3D chart.
 *
 * @see https://api.highcharts.com/highcharts/chart.options3d.frame.back
 */
export interface Chart3dFrameBackOptions {
    /**
     * (Highcharts) The color of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.back.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The thickness of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.back.size
     */
    size?: number;
    /**
     * (Highcharts) Whether to display the frame. Possible values are `true`,
     * `false`, `"auto"` to display only the frames behind the data, and
     * `"default"` to display faces behind the data based on the axis layout,
     * ignoring the point of view.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.back.visible
     */
    visible?: ("auto"|"default"|boolean);
}
/**
 * (Highcharts) The bottom of the frame around a 3D chart.
 *
 * @see https://api.highcharts.com/highcharts/chart.options3d.frame.bottom
 */
export interface Chart3dFrameBottomOptions {
    /**
     * (Highcharts) The color of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.bottom.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The thickness of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.bottom.size
     */
    size?: number;
    /**
     * (Highcharts) Whether to display the frame. Possible values are `true`,
     * `false`, `"auto"` to display only the frames behind the data, and
     * `"default"` to display faces behind the data based on the axis layout,
     * ignoring the point of view.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.bottom.visible
     */
    visible?: ("auto"|"default"|boolean);
}
/**
 * (Highcharts) The front of the frame around a 3D chart.
 *
 * @see https://api.highcharts.com/highcharts/chart.options3d.frame.front
 */
export interface Chart3dFrameFrontOptions {
    /**
     * (Highcharts) The color of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.front.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The thickness of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.front.size
     */
    size?: number;
    /**
     * (Highcharts) Whether to display the frame. Possible values are `true`,
     * `false`, `"auto"` to display only the frames behind the data, and
     * `"default"` to display faces behind the data based on the axis layout,
     * ignoring the point of view.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.front.visible
     */
    visible?: ("auto"|"default"|boolean);
}
/**
 * (Highcharts) The left side of the frame around a 3D chart.
 *
 * @see https://api.highcharts.com/highcharts/chart.options3d.frame.left
 */
export interface Chart3dFrameLeftOptions {
    /**
     * (Highcharts) The color of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.left.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The thickness of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.left.size
     */
    size?: number;
    /**
     * (Highcharts) Whether to display the frame. Possible values are `true`,
     * `false`, `"auto"` to display only the frames behind the data, and
     * `"default"` to display faces behind the data based on the axis layout,
     * ignoring the point of view.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.left.visible
     */
    visible?: ("auto"|"default"|boolean);
}
/**
 * (Highcharts) Provides the option to draw a frame around the charts by
 * defining a bottom, front and back panel.
 *
 * @see https://api.highcharts.com/highcharts/chart.options3d.frame
 */
export interface Chart3dFrameOptions {
    /**
     * (Highcharts) The back side of the frame around a 3D chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.back
     */
    back?: Chart3dFrameBackOptions;
    /**
     * (Highcharts) The bottom of the frame around a 3D chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.bottom
     */
    bottom?: Chart3dFrameBottomOptions;
    /**
     * (Highcharts) The front of the frame around a 3D chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.front
     */
    front?: Chart3dFrameFrontOptions;
    /**
     * (Highcharts) The left side of the frame around a 3D chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.left
     */
    left?: Chart3dFrameLeftOptions;
    /**
     * (Highcharts) The right of the frame around a 3D chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.right
     */
    right?: Chart3dFrameRightOptions;
    /**
     * (Highcharts) Note: As of v5.0.12, `frame.left` or `frame.right` should be
     * used instead.
     *
     * The side for the frame around a 3D chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.side
     */
    side?: Chart3dFrameSideOptions;
    /**
     * (Highcharts) General pixel thickness for the frame faces.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.size
     */
    size?: number;
    /**
     * (Highcharts) The top of the frame around a 3D chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.top
     */
    top?: Chart3dFrameTopOptions;
    /**
     * (Highcharts) Whether the frames are visible.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.visible
     */
    visible?: string;
}
/**
 * (Highcharts) The right of the frame around a 3D chart.
 *
 * @see https://api.highcharts.com/highcharts/chart.options3d.frame.right
 */
export interface Chart3dFrameRightOptions {
    /**
     * (Highcharts) The color of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.right.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The thickness of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.right.size
     */
    size?: number;
    /**
     * (Highcharts) Whether to display the frame. Possible values are `true`,
     * `false`, `"auto"` to display only the frames behind the data, and
     * `"default"` to display faces behind the data based on the axis layout,
     * ignoring the point of view.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.right.visible
     */
    visible?: ("auto"|"default"|boolean);
}
/**
 * (Highcharts) Note: As of v5.0.12, `frame.left` or `frame.right` should be
 * used instead.
 *
 * The side for the frame around a 3D chart.
 *
 * @see https://api.highcharts.com/highcharts/chart.options3d.frame.side
 */
export interface Chart3dFrameSideOptions {
    /**
     * (Highcharts) The color of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.side.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The thickness of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.side.size
     */
    size?: number;
}
/**
 * (Highcharts) The top of the frame around a 3D chart.
 *
 * @see https://api.highcharts.com/highcharts/chart.options3d.frame.top
 */
export interface Chart3dFrameTopOptions {
    /**
     * (Highcharts) The color of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.top.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The thickness of the panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.top.size
     */
    size?: number;
    /**
     * (Highcharts) Whether to display the frame. Possible values are `true`,
     * `false`, `"auto"` to display only the frames behind the data, and
     * `"default"` to display faces behind the data based on the axis layout,
     * ignoring the point of view.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame.top.visible
     */
    visible?: ("auto"|"default"|boolean);
}
/**
 * (Highcharts) Options to render charts in 3 dimensions. This feature requires
 * `highcharts-3d.js`, found in the download package or online at
 * code.highcharts.com/highcharts-3d.js.
 *
 * @see https://api.highcharts.com/highcharts/chart.options3d
 */
export interface Chart3dOptions {
    /**
     * (Highcharts) One of the two rotation angles for the chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.alpha
     */
    alpha?: number;
    /**
     * (Highcharts) Set it to `"auto"` to automatically move the labels to the
     * best edge.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.axisLabelPosition
     */
    axisLabelPosition?: ("auto"|null);
    /**
     * (Highcharts) One of the two rotation angles for the chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.beta
     */
    beta?: number;
    /**
     * (Highcharts) The total depth of the chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.depth
     */
    depth?: number;
    /**
     * (Highcharts) Wether to render the chart using the 3D functionality.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) Whether the 3d box should automatically adjust to the chart
     * plot area.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.fitToPlot
     */
    fitToPlot?: boolean;
    /**
     * (Highcharts) Provides the option to draw a frame around the charts by
     * defining a bottom, front and back panel.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.frame
     */
    frame?: Chart3dFrameOptions;
    /**
     * (Highcharts) Defines the distance the viewer is standing in front of the
     * chart, this setting is important to calculate the perspective effect in
     * column and scatter charts. It is not used for 3D pie charts.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d.viewDistance
     */
    viewDistance?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Event listeners for the chart.
 *
 * @see https://api.highcharts.com/highcharts/chart.events
 * @see https://api.highcharts.com/highstock/chart.events
 * @see https://api.highcharts.com/highmaps/chart.events
 * @see https://api.highcharts.com/gantt/chart.events
 */
export interface ChartEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a series is added to
     * the chart after load time, using the `addSeries` method. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Through `event.options` you can access the series options that was passed
     * to the `addSeries` method. Returning false prevents the series from being
     * added.
     *
     * @see https://api.highcharts.com/highcharts/chart.events.addSeries
     * @see https://api.highcharts.com/highstock/chart.events.addSeries
     * @see https://api.highcharts.com/highmaps/chart.events.addSeries
     * @see https://api.highcharts.com/gantt/chart.events.addSeries
     */
    addSeries?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires after a chart is printed
     * through the context menu item or the `Chart.print` method. Requires the
     * exporting module.
     *
     * @see https://api.highcharts.com/highcharts/chart.events.afterPrint
     * @see https://api.highcharts.com/highstock/chart.events.afterPrint
     * @see https://api.highcharts.com/highmaps/chart.events.afterPrint
     * @see https://api.highcharts.com/gantt/chart.events.afterPrint
     */
    afterPrint?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires before a chart is printed
     * through the context menu item or the `Chart.print` method. Requires the
     * exporting module.
     *
     * @see https://api.highcharts.com/highcharts/chart.events.beforePrint
     * @see https://api.highcharts.com/highstock/chart.events.beforePrint
     * @see https://api.highcharts.com/highmaps/chart.events.beforePrint
     * @see https://api.highcharts.com/gantt/chart.events.beforePrint
     */
    beforePrint?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when clicking on the plot
     * background. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * Information on the clicked spot can be found through `event.xAxis` and
     * `event.yAxis`, which are arrays containing the axes of each dimension and
     * each axis' value at the clicked spot. The primary axes are
     * `event.xAxis[0]` and `event.yAxis[0]`. Remember the unit of a datetime
     * axis is milliseconds since 1970-01-01 00:00:00.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/chart.events.click
     * @see https://api.highcharts.com/highstock/chart.events.click
     * @see https://api.highcharts.com/highmaps/chart.events.click
     * @see https://api.highcharts.com/gantt/chart.events.click
     */
    click?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when a drilldown point is clicked, before
     * the new series is added. This event is also utilized for async drilldown,
     * where the seriesOptions are not added by option, but rather loaded async.
     * Note that when clicking a category label to trigger multiple series
     * drilldown, one `drilldown` event is triggered per point in the category.
     *
     * Event arguments:
     *
     * - `category`: If a category label was clicked, which index.</dd>
     *
     * - `originalEvent`: The original browser event (usually click) that
     * triggered the drilldown.
     *
     * - `point`: The originating point.
     *
     * - `points`: If a category label was clicked, this array holds all points
     * corresponing to the category.</dd>
     *
     * - `seriesOptions`: Options for the new series.
     *
     * @see https://api.highcharts.com/highcharts/chart.events.drilldown
     * @see https://api.highcharts.com/highmaps/chart.events.drilldown
     */
    drilldown?: DrilldownCallbackFunction;
    /**
     * (Highcharts, Highmaps) Fires when drilling up from a drilldown series.
     *
     * @see https://api.highcharts.com/highcharts/chart.events.drillup
     * @see https://api.highcharts.com/highmaps/chart.events.drillup
     */
    drillup?: DrillupCallbackFunction;
    /**
     * (Highcharts, Highmaps) In a chart with multiple drilldown series, this
     * event fires after all the series have been drilled up.
     *
     * @see https://api.highcharts.com/highcharts/chart.events.drillupall
     * @see https://api.highcharts.com/highmaps/chart.events.drillupall
     */
    drillupall?: DrillupAllCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the chart is finished
     * loading. Since v4.2.2, it also waits for images to be loaded, for example
     * from point markers. One parameter, `event`, is passed to the function,
     * containing common event information.
     *
     * There is also a second parameter to the chart constructor where a
     * callback function can be passed to be executed on chart.load.
     *
     * @see https://api.highcharts.com/highcharts/chart.events.load
     * @see https://api.highcharts.com/highstock/chart.events.load
     * @see https://api.highcharts.com/highmaps/chart.events.load
     * @see https://api.highcharts.com/gantt/chart.events.load
     */
    load?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the chart is redrawn,
     * either after a call to `chart.redraw()` or after an axis, series or point
     * is modified with the `redraw` option set to true. One parameter, `event`,
     * is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/chart.events.redraw
     * @see https://api.highcharts.com/highstock/chart.events.redraw
     * @see https://api.highcharts.com/highmaps/chart.events.redraw
     * @see https://api.highcharts.com/gantt/chart.events.redraw
     */
    redraw?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires after initial load of the
     * chart (directly after the `load` event), and after each redraw (directly
     * after the `redraw` event).
     *
     * @see https://api.highcharts.com/highcharts/chart.events.render
     * @see https://api.highcharts.com/highstock/chart.events.render
     * @see https://api.highcharts.com/highmaps/chart.events.render
     * @see https://api.highcharts.com/gantt/chart.events.render
     */
    render?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when an area of the chart
     * has been selected. Selection is enabled by setting the chart's zoomType.
     * One parameter, `event`, is passed to the function, containing common
     * event information. The default action for the selection event is to zoom
     * the chart to the selected area. It can be prevented by calling
     * `event.preventDefault()` or return false.
     *
     * Information on the selected area can be found through `event.xAxis` and
     * `event.yAxis`, which are arrays containing the axes of each dimension and
     * each axis' min and max values. The primary axes are `event.xAxis[0]` and
     * `event.yAxis[0]`. Remember the unit of a datetime axis is milliseconds
     * since 1970-01-01 00:00:00.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/chart.events.selection
     * @see https://api.highcharts.com/highstock/chart.events.selection
     * @see https://api.highcharts.com/highmaps/chart.events.selection
     * @see https://api.highcharts.com/gantt/chart.events.selection
     */
    selection?: ChartSelectionCallbackFunction;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) General options for the chart.
 *
 * @see https://api.highcharts.com/highcharts/chart
 * @see https://api.highcharts.com/highstock/chart
 * @see https://api.highcharts.com/highmaps/chart
 * @see https://api.highcharts.com/gantt/chart
 */
export interface ChartOptions {
    /**
     * (Highcharts, Highstock, Gantt) When using multiple axis, the ticks of two
     * or more opposite axes will automatically be aligned by adding ticks to
     * the axis or axes with the least ticks, as if `tickAmount` were specified.
     *
     * This can be prevented by setting `alignTicks` to false. If the grid lines
     * look messy, it's a good idea to hide them for the secondary axis by
     * setting `gridLineWidth` to 0.
     *
     * If `startOnTick` or `endOnTick` in an Axis options are set to false, then
     * the `alignTicks ` will be disabled for the Axis.
     *
     * Disabled for logarithmic axes.
     *
     * @see https://api.highcharts.com/highcharts/chart.alignTicks
     * @see https://api.highcharts.com/highstock/chart.alignTicks
     * @see https://api.highcharts.com/gantt/chart.alignTicks
     */
    alignTicks?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the overall animation for
     * all chart updating. Animation can be disabled throughout the chart by
     * setting it to false here. It can be overridden for each individual API
     * method as a function parameter. The only animation not affected by this
     * option is the initial series animation, see plotOptions.series.animation.
     *
     * The animation can either be set as a boolean or a configuration object.
     * If `true`, it will use the 'swing' jQuery easing and a duration of 500
     * ms. If used as a configuration object, the following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/chart.animation
     * @see https://api.highcharts.com/highstock/chart.animation
     * @see https://api.highcharts.com/highmaps/chart.animation
     * @see https://api.highcharts.com/gantt/chart.animation
     */
    animation?: (boolean|AnimationOptionsObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The background color or gradient
     * for the outer chart area.
     *
     * @see https://api.highcharts.com/highcharts/chart.backgroundColor
     * @see https://api.highcharts.com/highstock/chart.backgroundColor
     * @see https://api.highcharts.com/highmaps/chart.backgroundColor
     * @see https://api.highcharts.com/gantt/chart.backgroundColor
     */
    backgroundColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the outer chart
     * border.
     *
     * @see https://api.highcharts.com/highcharts/chart.borderColor
     * @see https://api.highcharts.com/highstock/chart.borderColor
     * @see https://api.highcharts.com/highmaps/chart.borderColor
     * @see https://api.highcharts.com/gantt/chart.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The corner radius of the outer
     * chart border.
     *
     * @see https://api.highcharts.com/highcharts/chart.borderRadius
     * @see https://api.highcharts.com/highstock/chart.borderRadius
     * @see https://api.highcharts.com/highmaps/chart.borderRadius
     * @see https://api.highcharts.com/gantt/chart.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the outer
     * chart border.
     *
     * @see https://api.highcharts.com/highcharts/chart.borderWidth
     * @see https://api.highcharts.com/highstock/chart.borderWidth
     * @see https://api.highcharts.com/highmaps/chart.borderWidth
     * @see https://api.highcharts.com/gantt/chart.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A CSS class name to apply to the
     * charts container `div`, allowing unique CSS styling for each chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.className
     * @see https://api.highcharts.com/highstock/chart.className
     * @see https://api.highcharts.com/highmaps/chart.className
     * @see https://api.highcharts.com/gantt/chart.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) In styled mode, this sets how
     * many colors the class names should rotate between. With ten colors,
     * series (or points) are given class names like `highcharts-color-0`,
     * `highcharts-color-0` [...] `highcharts-color-9`. The equivalent in
     * non-styled mode is to set colors using the colors setting.
     *
     * @see https://api.highcharts.com/highcharts/chart.colorCount
     * @see https://api.highcharts.com/highstock/chart.colorCount
     * @see https://api.highcharts.com/highmaps/chart.colorCount
     * @see https://api.highcharts.com/gantt/chart.colorCount
     */
    colorCount?: number;
    /**
     * (Highcharts) Alias of `type`.
     *
     * @see https://api.highcharts.com/highcharts/chart.defaultSeriesType
     */
    defaultSeriesType?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A text description of the chart.
     *
     * If the Accessibility module is loaded, this is included by default as a
     * long description of the chart and its contents in the hidden screen
     * reader information region.
     *
     * @see https://api.highcharts.com/highcharts/chart.description
     * @see https://api.highcharts.com/highstock/chart.description
     * @see https://api.highcharts.com/highmaps/chart.description
     * @see https://api.highcharts.com/gantt/chart.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to display errors on the
     * chart. When `false`, the errors will be shown only in the console.
     *
     * Requires `debugger.js` module.
     *
     * @see https://api.highcharts.com/highcharts/chart.displayErrors
     * @see https://api.highcharts.com/highstock/chart.displayErrors
     * @see https://api.highcharts.com/highmaps/chart.displayErrors
     * @see https://api.highcharts.com/gantt/chart.displayErrors
     */
    displayErrors?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Event listeners for the chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.events
     * @see https://api.highcharts.com/highstock/chart.events
     * @see https://api.highcharts.com/highmaps/chart.events
     * @see https://api.highcharts.com/gantt/chart.events
     */
    events?: ChartEventsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An explicit height for the
     * chart. If a _number_, the height is given in pixels. If given a
     * _percentage string_ (for example `'56%'`), the height is given as the
     * percentage of the actual chart width. This allows for preserving the
     * aspect ratio across responsive sizes.
     *
     * By default (when `null`) the height is calculated from the offset height
     * of the containing element, or 400 pixels if the containing element's
     * height is 0.
     *
     * @see https://api.highcharts.com/highcharts/chart.height
     * @see https://api.highcharts.com/highstock/chart.height
     * @see https://api.highcharts.com/highmaps/chart.height
     * @see https://api.highcharts.com/gantt/chart.height
     */
    height?: (number|string|null);
    /**
     * (Highcharts, Highstock, Gantt) If true, the axes will scale to the
     * remaining visible series once one series is hidden. If false, hiding and
     * showing a series will not affect the axes or the other series. For
     * stacks, once one series within the stack is hidden, the rest of the stack
     * will close in around it even if the axis is not affected.
     *
     * @see https://api.highcharts.com/highcharts/chart.ignoreHiddenSeries
     * @see https://api.highcharts.com/highstock/chart.ignoreHiddenSeries
     * @see https://api.highcharts.com/gantt/chart.ignoreHiddenSeries
     */
    ignoreHiddenSeries?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to invert the axes so that the x
     * axis is vertical and y axis is horizontal. When `true`, the x axis is
     * reversed by default.
     *
     * @see https://api.highcharts.com/highcharts/chart.inverted
     * @see https://api.highcharts.com/highstock/chart.inverted
     * @see https://api.highcharts.com/gantt/chart.inverted
     */
    inverted?: boolean;
    /**
     * (Highmaps) Default `mapData` for all series. If set to a string, it
     * functions as an index into the `Highcharts.maps` array. Otherwise it is
     * interpreted s map data.
     *
     * @see https://api.highcharts.com/highmaps/chart.map
     */
    map?: (string|Array<any>);
    /**
     * (Highmaps) Set lat/lon transformation definitions for the chart. If not
     * defined, these are extracted from the map data.
     *
     * @see https://api.highcharts.com/highmaps/chart.mapTransforms
     */
    mapTransforms?: any;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The margin between the outer
     * edge of the chart and the plot area. The numbers in the array designate
     * top, right, bottom and left respectively. Use the options `marginTop`,
     * `marginRight`, `marginBottom` and `marginLeft` for shorthand setting of
     * one option.
     *
     * By default there is no margin. The actual space is dynamically calculated
     * from the offset of axis labels, axis title, title, subtitle and legend in
     * addition to the `spacingTop`, `spacingRight`, `spacingBottom` and
     * `spacingLeft` options.
     *
     * @see https://api.highcharts.com/highcharts/chart.margin
     * @see https://api.highcharts.com/highstock/chart.margin
     * @see https://api.highcharts.com/highmaps/chart.margin
     * @see https://api.highcharts.com/gantt/chart.margin
     */
    margin?: (number|Array<number>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The margin between the bottom
     * outer edge of the chart and the plot area. Use this to set a fixed pixel
     * value for the margin as opposed to the default dynamic margin. See also
     * `spacingBottom`.
     *
     * @see https://api.highcharts.com/highcharts/chart.marginBottom
     * @see https://api.highcharts.com/highstock/chart.marginBottom
     * @see https://api.highcharts.com/highmaps/chart.marginBottom
     * @see https://api.highcharts.com/gantt/chart.marginBottom
     */
    marginBottom?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The margin between the left
     * outer edge of the chart and the plot area. Use this to set a fixed pixel
     * value for the margin as opposed to the default dynamic margin. See also
     * `spacingLeft`.
     *
     * @see https://api.highcharts.com/highcharts/chart.marginLeft
     * @see https://api.highcharts.com/highstock/chart.marginLeft
     * @see https://api.highcharts.com/highmaps/chart.marginLeft
     * @see https://api.highcharts.com/gantt/chart.marginLeft
     */
    marginLeft?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The margin between the right
     * outer edge of the chart and the plot area. Use this to set a fixed pixel
     * value for the margin as opposed to the default dynamic margin. See also
     * `spacingRight`.
     *
     * @see https://api.highcharts.com/highcharts/chart.marginRight
     * @see https://api.highcharts.com/highstock/chart.marginRight
     * @see https://api.highcharts.com/highmaps/chart.marginRight
     * @see https://api.highcharts.com/gantt/chart.marginRight
     */
    marginRight?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The margin between the top outer
     * edge of the chart and the plot area. Use this to set a fixed pixel value
     * for the margin as opposed to the default dynamic margin. See also
     * `spacingTop`.
     *
     * @see https://api.highcharts.com/highcharts/chart.marginTop
     * @see https://api.highcharts.com/highstock/chart.marginTop
     * @see https://api.highcharts.com/highmaps/chart.marginTop
     * @see https://api.highcharts.com/gantt/chart.marginTop
     */
    marginTop?: number;
    /**
     * (Highcharts) Options to render charts in 3 dimensions. This feature
     * requires `highcharts-3d.js`, found in the download package or online at
     * code.highcharts.com/highcharts-3d.js.
     *
     * @see https://api.highcharts.com/highcharts/chart.options3d
     */
    options3d?: Chart3dOptions;
    /**
     * (Highcharts, Gantt) Allows setting a key to switch between zooming and
     * panning. Can be one of `alt`, `ctrl`, `meta` (the command key on Mac and
     * Windows key on Windows) or `shift`. The keys are mapped directly to the
     * key properties of the click event argument (`event.altKey`,
     * `event.ctrlKey`, `event.metaKey` and `event.shiftKey`).
     *
     * @see https://api.highcharts.com/highcharts/chart.panKey
     * @see https://api.highcharts.com/gantt/chart.panKey
     */
    panKey?: ("alt"|"ctrl"|"meta"|"shift");
    /**
     * (Highcharts, Highstock, Gantt) Allow panning in a chart. Best used with
     * panKey to combine zooming and panning.
     *
     * On touch devices, when the tooltip.followTouchMove option is `true`
     * (default), panning requires two fingers. To allow panning with one
     * finger, set `followTouchMove` to `false`.
     *
     * @see https://api.highcharts.com/highcharts/chart.panning
     * @see https://api.highcharts.com/highstock/chart.panning
     * @see https://api.highcharts.com/gantt/chart.panning
     */
    panning?: boolean;
    /**
     * (Highcharts) Common options for all yAxes rendered in a parallel
     * coordinates plot. This feature requires
     * `modules/parallel-coordinates.js`.
     *
     * The default options are: (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes
     */
    parallelAxes?: ChartParallelAxesOptions;
    /**
     * (Highcharts) Flag to render charts as a parallel coordinates plot. In a
     * parallel coordinates plot (||-coords) by default all required yAxes are
     * generated and the legend is disabled. This feature requires
     * `modules/parallel-coordinates.js`.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelCoordinates
     */
    parallelCoordinates?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Equivalent to zoomType, but for multitouch
     * gestures only. By default, the `pinchType` is the same as the `zoomType`
     * setting. However, pinching can be enabled separately in some cases, for
     * example in stock charts where a mouse drag pans the chart, while pinching
     * is enabled. When tooltip.followTouchMove is true, pinchType only applies
     * to two-finger touches.
     *
     * @see https://api.highcharts.com/highcharts/chart.pinchType
     * @see https://api.highcharts.com/highstock/chart.pinchType
     * @see https://api.highcharts.com/gantt/chart.pinchType
     */
    pinchType?: ("x"|"xy"|"y");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The background color or gradient
     * for the plot area.
     *
     * @see https://api.highcharts.com/highcharts/chart.plotBackgroundColor
     * @see https://api.highcharts.com/highstock/chart.plotBackgroundColor
     * @see https://api.highcharts.com/highmaps/chart.plotBackgroundColor
     * @see https://api.highcharts.com/gantt/chart.plotBackgroundColor
     */
    plotBackgroundColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The URL for an image to use as
     * the plot background. To set an image as the background for the entire
     * chart, set a CSS background image to the container element. Note that for
     * the image to be applied to exported charts, its URL needs to be
     * accessible by the export server.
     *
     * @see https://api.highcharts.com/highcharts/chart.plotBackgroundImage
     * @see https://api.highcharts.com/highstock/chart.plotBackgroundImage
     * @see https://api.highcharts.com/highmaps/chart.plotBackgroundImage
     * @see https://api.highcharts.com/gantt/chart.plotBackgroundImage
     */
    plotBackgroundImage?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the inner chart or
     * plot area border.
     *
     * @see https://api.highcharts.com/highcharts/chart.plotBorderColor
     * @see https://api.highcharts.com/highstock/chart.plotBorderColor
     * @see https://api.highcharts.com/highmaps/chart.plotBorderColor
     * @see https://api.highcharts.com/gantt/chart.plotBorderColor
     */
    plotBorderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the plot area
     * border.
     *
     * @see https://api.highcharts.com/highcharts/chart.plotBorderWidth
     * @see https://api.highcharts.com/highstock/chart.plotBorderWidth
     * @see https://api.highcharts.com/highmaps/chart.plotBorderWidth
     * @see https://api.highcharts.com/gantt/chart.plotBorderWidth
     */
    plotBorderWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to apply a drop shadow
     * to the plot area. Requires that plotBackgroundColor be set. The shadow
     * can be an object configuration containing `color`, `offsetX`, `offsetY`,
     * `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/chart.plotShadow
     * @see https://api.highcharts.com/highstock/chart.plotShadow
     * @see https://api.highcharts.com/highmaps/chart.plotShadow
     * @see https://api.highcharts.com/gantt/chart.plotShadow
     */
    plotShadow?: (boolean|CSSObject);
    /**
     * (Highcharts) When true, cartesian charts like line, spline, area and
     * column are transformed into the polar coordinate system. This produces
     * _polar charts_, also known as _radar charts_. Requires
     * `highcharts-more.js`.
     *
     * @see https://api.highcharts.com/highcharts/chart.polar
     */
    polar?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to reflow the chart to
     * fit the width of the container div on resizing the window.
     *
     * @see https://api.highcharts.com/highcharts/chart.reflow
     * @see https://api.highcharts.com/highstock/chart.reflow
     * @see https://api.highcharts.com/highmaps/chart.reflow
     * @see https://api.highcharts.com/gantt/chart.reflow
     */
    reflow?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The HTML element where the chart
     * will be rendered. If it is a string, the element by that id is used. The
     * HTML element can also be passed by direct reference, or as the first
     * argument of the chart constructor, in which case the option is not
     * needed.
     *
     * @see https://api.highcharts.com/highcharts/chart.renderTo
     * @see https://api.highcharts.com/highstock/chart.renderTo
     * @see https://api.highcharts.com/highmaps/chart.renderTo
     * @see https://api.highcharts.com/gantt/chart.renderTo
     */
    renderTo?: (string|HTMLDOMElement);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The button that appears after a
     * selection zoom, allowing the user to reset zoom.
     *
     * @see https://api.highcharts.com/highcharts/chart.resetZoomButton
     * @see https://api.highcharts.com/highstock/chart.resetZoomButton
     * @see https://api.highcharts.com/highmaps/chart.resetZoomButton
     * @see https://api.highcharts.com/gantt/chart.resetZoomButton
     */
    resetZoomButton?: ChartResetZoomButtonOptions;
    /**
     * (Highcharts, Gantt) Options for a scrollable plot area. This feature
     * provides a minimum width for the plot area of the chart. If the width
     * gets smaller than this, typically on mobile devices, a native browser
     * scrollbar is presented below the chart. This scrollbar provides smooth
     * scrolling for the contents of the plot area, whereas the title, legend
     * and axes are fixed.
     *
     * @see https://api.highcharts.com/highcharts/chart.scrollablePlotArea
     * @see https://api.highcharts.com/gantt/chart.scrollablePlotArea
     */
    scrollablePlotArea?: ChartScrollablePlotAreaOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The background color of the
     * marker square when selecting (zooming in on) an area of the chart.
     *
     * @see https://api.highcharts.com/highcharts/chart.selectionMarkerFill
     * @see https://api.highcharts.com/highstock/chart.selectionMarkerFill
     * @see https://api.highcharts.com/highmaps/chart.selectionMarkerFill
     * @see https://api.highcharts.com/gantt/chart.selectionMarkerFill
     */
    selectionMarkerFill?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to apply a drop shadow
     * to the outer chart area. Requires that backgroundColor be set. The shadow
     * can be an object configuration containing `color`, `offsetX`, `offsetY`,
     * `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/chart.shadow
     * @see https://api.highcharts.com/highstock/chart.shadow
     * @see https://api.highcharts.com/highmaps/chart.shadow
     * @see https://api.highcharts.com/gantt/chart.shadow
     */
    shadow?: (boolean|CSSObject);
    /**
     * (Highcharts, Gantt) Whether to show the axes initially. This only applies
     * to empty charts where series are added dynamically, as axes are
     * automatically added to cartesian series.
     *
     * @see https://api.highcharts.com/highcharts/chart.showAxes
     * @see https://api.highcharts.com/gantt/chart.showAxes
     */
    showAxes?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The distance between the outer
     * edge of the chart and the content, like title or legend, or axis title
     * and labels if present. The numbers in the array designate top, right,
     * bottom and left respectively. Use the options spacingTop, spacingRight,
     * spacingBottom and spacingLeft options for shorthand setting of one
     * option.
     *
     * @see https://api.highcharts.com/highcharts/chart.spacing
     * @see https://api.highcharts.com/highstock/chart.spacing
     * @see https://api.highcharts.com/highmaps/chart.spacing
     * @see https://api.highcharts.com/gantt/chart.spacing
     */
    spacing?: Array<number>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The space between the bottom
     * edge of the chart and the content (plot area, axis title and labels,
     * title, subtitle or legend in top position).
     *
     * @see https://api.highcharts.com/highcharts/chart.spacingBottom
     * @see https://api.highcharts.com/highstock/chart.spacingBottom
     * @see https://api.highcharts.com/highmaps/chart.spacingBottom
     * @see https://api.highcharts.com/gantt/chart.spacingBottom
     */
    spacingBottom?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The space between the left edge
     * of the chart and the content (plot area, axis title and labels, title,
     * subtitle or legend in top position).
     *
     * @see https://api.highcharts.com/highcharts/chart.spacingLeft
     * @see https://api.highcharts.com/highstock/chart.spacingLeft
     * @see https://api.highcharts.com/highmaps/chart.spacingLeft
     * @see https://api.highcharts.com/gantt/chart.spacingLeft
     */
    spacingLeft?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The space between the right edge
     * of the chart and the content (plot area, axis title and labels, title,
     * subtitle or legend in top position).
     *
     * @see https://api.highcharts.com/highcharts/chart.spacingRight
     * @see https://api.highcharts.com/highstock/chart.spacingRight
     * @see https://api.highcharts.com/highmaps/chart.spacingRight
     * @see https://api.highcharts.com/gantt/chart.spacingRight
     */
    spacingRight?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The space between the top edge
     * of the chart and the content (plot area, axis title and labels, title,
     * subtitle or legend in top position).
     *
     * @see https://api.highcharts.com/highcharts/chart.spacingTop
     * @see https://api.highcharts.com/highstock/chart.spacingTop
     * @see https://api.highcharts.com/highmaps/chart.spacingTop
     * @see https://api.highcharts.com/gantt/chart.spacingTop
     */
    spacingTop?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Additional CSS styles to apply
     * inline to the container `div`. Note that since the default font styles
     * are applied in the renderer, it is ignorant of the individual chart
     * options and must be set globally.
     *
     * @see https://api.highcharts.com/highcharts/chart.style
     * @see https://api.highcharts.com/highstock/chart.style
     * @see https://api.highcharts.com/highmaps/chart.style
     * @see https://api.highcharts.com/gantt/chart.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to apply styled mode.
     * When in styled mode, no presentational attributes or CSS are applied to
     * the chart SVG. Instead, CSS rules are required to style the chart. The
     * default style sheet is available from
     * `https://code.highcharts.com/css/highcharts.css`.
     *
     * @see https://api.highcharts.com/highcharts/chart.styledMode
     * @see https://api.highcharts.com/highstock/chart.styledMode
     * @see https://api.highcharts.com/highmaps/chart.styledMode
     * @see https://api.highcharts.com/gantt/chart.styledMode
     */
    styledMode?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The default series type for the
     * chart. Can be any of the chart types listed under plotOptions.
     *
     * @see https://api.highcharts.com/highcharts/chart.type
     * @see https://api.highcharts.com/highstock/chart.type
     * @see https://api.highcharts.com/highmaps/chart.type
     * @see https://api.highcharts.com/gantt/chart.type
     */
    type?: ("area"|"arearange"|"areaspline"|"areasplinerange"|"bar"|"boxplot"|"bubble"|"column"|"columnrange"|"errorbar"|"funnel"|"gauge"|"heatmap"|"line"|"pie"|"polygon"|"pyramid"|"scatter"|
"solidgauge"|"spline"|"treemap"|"waterfall");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A text description of the chart
     * type.
     *
     * If the Accessibility module is loaded, this will be included in the
     * description of the chart in the screen reader information region.
     *
     * Highcharts will by default attempt to guess the chart type, but for more
     * complex charts it is recommended to specify this property for clarity.
     *
     * @see https://api.highcharts.com/highcharts/chart.typeDescription
     * @see https://api.highcharts.com/highstock/chart.typeDescription
     * @see https://api.highcharts.com/highmaps/chart.typeDescription
     * @see https://api.highcharts.com/gantt/chart.typeDescription
     */
    typeDescription?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An explicit width for the chart.
     * By default (when `null`) the width is calculated from the offset width of
     * the containing element.
     *
     * @see https://api.highcharts.com/highcharts/chart.width
     * @see https://api.highcharts.com/highstock/chart.width
     * @see https://api.highcharts.com/highmaps/chart.width
     * @see https://api.highcharts.com/gantt/chart.width
     */
    width?: (number|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set a key to hold when dragging
     * to zoom the chart. Requires the draggable-points module. This is useful
     * to avoid zooming while moving points. Should be set different than
     * chart.panKey.
     *
     * @see https://api.highcharts.com/highcharts/chart.zoomKey
     * @see https://api.highcharts.com/highstock/chart.zoomKey
     * @see https://api.highcharts.com/highmaps/chart.zoomKey
     * @see https://api.highcharts.com/gantt/chart.zoomKey
     */
    zoomKey?: ("alt"|"ctrl"|"meta"|"shift");
    /**
     * (Highcharts, Highstock, Gantt) Decides in what dimensions the user can
     * zoom by dragging the mouse. Can be one of `x`, `y` or `xy`.
     *
     * @see https://api.highcharts.com/highcharts/chart.zoomType
     * @see https://api.highcharts.com/highstock/chart.zoomType
     * @see https://api.highcharts.com/gantt/chart.zoomType
     */
    zoomType?: ("x"|"xy"|"y");
}
/**
 * (Highstock) A label on the axis next to the crosshair.
 *
 * In styled mode, the label is styled with the `.highcharts-crosshair-label`
 * class.
 *
 * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label
 */
export interface ChartParallelAxesCrosshairLabelOptions {
    /**
     * (Highstock) Alignment of the label compared to the axis. Defaults to
     * `left` for right-side axes, `right` for left-side axes and `center` for
     * horizontal axes.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label.align
     */
    align?: string;
    /**
     * (Highstock) The background color for the label. Defaults to the related
     * series color, or `#666666` if that is not available.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the crosshair label
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border corner radius of the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width for the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A format string for the crosshair label. Defaults to
     * `{value}` for numeric axes and `{value:%b %d, %Y}` for datetime axes.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label.format
     */
    format?: string;
    /**
     * (Highstock) Formatter function for the label text.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label.formatter
     */
    formatter?: FormatterCallbackFunction<object>;
    /**
     * (Highstock) Padding inside the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label.padding
     */
    padding?: number;
    /**
     * (Highstock) The shape to use for the label box.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label.shape
     */
    shape?: string;
    /**
     * (Highstock) Text styles for the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label.style
     */
    style?: CSSObject;
}
/**
 * (Highcharts) Configure a crosshair that follows either the mouse pointer or
 * the hovered point.
 *
 * In styled mode, the crosshairs are styled in the `.highcharts-crosshair`,
 * `.highcharts-crosshair-thin` or `.highcharts-xaxis-category` classes.
 *
 * @see https://api.highcharts.com/highcharts/chart.parallelAxes.crosshair
 */
export interface ChartParallelAxesCrosshairOptions {
    /**
     * (Highcharts) A class name for the crosshair, especially as a hook for
     * styling.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.crosshair.className
     */
    className?: string;
    /**
     * (Highcharts) The color of the crosshair. Defaults to `#cccccc` for
     * numeric and datetime axes, and `rgba(204,214,235,0.25)` for category
     * axes, where the crosshair by default highlights the whole category.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.crosshair.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The dash style for the crosshair. See series.dashStyle for
     * possible values.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.crosshair.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) A label on the axis next to the crosshair.
     *
     * In styled mode, the label is styled with the
     * `.highcharts-crosshair-label` class.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.crosshair.label
     */
    label?: ChartParallelAxesCrosshairLabelOptions;
    /**
     * (Highcharts) Whether the crosshair should snap to the point or follow the
     * pointer independent of points.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.crosshair.snap
     */
    snap?: boolean;
    /**
     * (Highcharts) The pixel width of the crosshair. Defaults to 1 for numeric
     * or datetime axes, and for one category width for category axes.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.crosshair.width
     */
    width?: number;
    /**
     * (Highcharts) The Z index of the crosshair. Higher Z indices allow drawing
     * the crosshair on top of the series or behind the grid lines.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.crosshair.zIndex
     */
    zIndex?: number;
}
export interface ChartParallelAxesDateTimeLabelFormatsDayOptions {
    main?: string;
}
export interface ChartParallelAxesDateTimeLabelFormatsHourOptions {
    main?: string;
    range?: boolean;
}
export interface ChartParallelAxesDateTimeLabelFormatsMillisecondOptions {
    main?: string;
    range?: boolean;
}
export interface ChartParallelAxesDateTimeLabelFormatsMinuteOptions {
    main?: string;
    range?: boolean;
}
export interface ChartParallelAxesDateTimeLabelFormatsMonthOptions {
    main?: string;
}
/**
 * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
 * automatically adjust to the appropriate unit. This member gives the default
 * string representations used for each unit. For intermediate values, different
 * units may be used, for example the `day` unit can be used on midnight and
 * `hour` unit be used for intermediate values on the same axis. For an overview
 * of the replacement codes, see dateFormat. Defaults to:
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/chart.parallelAxes.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/chart.parallelAxes.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/chart.parallelAxes.dateTimeLabelFormats
 */
export interface ChartParallelAxesDateTimeLabelFormatsOptions {
    day?: ChartParallelAxesDateTimeLabelFormatsDayOptions;
    hour?: ChartParallelAxesDateTimeLabelFormatsHourOptions;
    millisecond?: ChartParallelAxesDateTimeLabelFormatsMillisecondOptions;
    minute?: ChartParallelAxesDateTimeLabelFormatsMinuteOptions;
    month?: ChartParallelAxesDateTimeLabelFormatsMonthOptions;
    second?: ChartParallelAxesDateTimeLabelFormatsSecondOptions;
    week?: ChartParallelAxesDateTimeLabelFormatsWeekOptions;
    year?: ChartParallelAxesDateTimeLabelFormatsYearOptions;
}
export interface ChartParallelAxesDateTimeLabelFormatsSecondOptions {
    main?: string;
    range?: boolean;
}
export interface ChartParallelAxesDateTimeLabelFormatsWeekOptions {
    main?: string;
}
export interface ChartParallelAxesDateTimeLabelFormatsYearOptions {
    main?: string;
}
/**
 * (Highcharts) Event handlers for the axis.
 *
 * @see https://api.highcharts.com/highcharts/chart.parallelAxes.events
 */
export interface ChartParallelAxesEventsOptions {
    /**
     * (Highcharts, Gantt) An event fired after the breaks have rendered.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.events.afterBreaks
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.events.afterBreaks
     */
    afterBreaks?: AxisEventCallbackFunction;
    /**
     * (Highcharts) As opposed to the `setExtremes` event, this event fires
     * after the final min and max values are computed and corrected for
     * `minRange`.
     *
     * Fires when the minimum and maximum is set for the axis, either by calling
     * the `.setExtremes()` method or by selecting an area in the chart. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in axis
     * values. The actual data extremes are found in `event.dataMin` and
     * `event.dataMax`.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.events.afterSetExtremes
     */
    afterSetExtremes?: AxisEventCallbackFunction;
    /**
     * (Highcharts, Gantt) An event fired when a break from this axis occurs on
     * a point.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.events.pointBreak
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.events.pointBreak
     */
    pointBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) An event fired when a point falls inside a
     * break from this axis.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.events.pointInBreak
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.events.pointInBreak
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.events.pointInBreak
     */
    pointInBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highcharts) Fires when the minimum and maximum is set for the axis,
     * either by calling the `.setExtremes()` method or by selecting an area in
     * the chart. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in data
     * values. When an axis is zoomed all the way out from the "Reset zoom"
     * button, `event.min` and `event.max` are null, and the new extremes are
     * set based on `this.dataMin` and `this.dataMax`.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.events.setExtremes
     */
    setExtremes?: AxisSetExtremesEventCallbackFunction;
}
/**
 * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
 *
 * @see https://api.highcharts.com/gantt/chart.parallelAxes.grid
 */
export interface ChartParallelAxesGridOptions {
    /**
     * (Gantt) Set border color for the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.grid.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Gantt) Set border width of the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.grid.borderWidth
     */
    borderWidth?: number;
    /**
     * (Gantt) Set cell height for grid axis labels. By default this is
     * calculated from font size.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.grid.cellHeight
     */
    cellHeight?: number;
    /**
     * (Gantt) Set specific options for each column (or row for horizontal axes)
     * in the grid. Each extra column/row is its own axis, and the axis options
     * can be set here.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.grid.columns
     */
    columns?: Array<XAxisOptions>;
    /**
     * (Gantt) Enable grid on the axis labels. Defaults to true for Gantt
     * charts.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.grid.enabled
     */
    enabled?: boolean;
}
/**
 * (Gantt) Set options on specific levels in a tree grid axis. Takes precedence
 * over labels options.
 *
 * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.levels
 */
export interface ChartParallelAxesLabelsLevelsOptions {
    /**
     * (Gantt) Specify the level which the options within this object applies
     * to.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.levels.level
     */
    level?: number;
    style?: CSSObject;
}
/**
 * (Highcharts) The axis labels show the number or category for each tick.
 *
 * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels
 */
export interface ChartParallelAxesLabelsOptions {
    /**
     * (Highcharts) What part of the string the given position is anchored to.
     * Can be one of `"left"`, `"center"` or `"right"`. The exact position also
     * depends on the `labels.x` setting.
     *
     * Angular gauges and solid gauges defaults to `center`.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) For horizontal axes, the allowed degrees
     * of label rotation to prevent overlapping labels. If there is enough
     * space, labels are not rotated. As the chart gets narrower, it will start
     * rotating the labels -45 degrees, then remove every second label and try
     * again with rotations 0 and -45 etc. Set it to `false` to disable
     * rotation, which will cause the labels to word-wrap if possible.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.autoRotation
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.labels.autoRotation
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.autoRotation
     */
    autoRotation?: Array<number>;
    /**
     * (Highcharts, Gantt) When each category width is more than this many
     * pixels, we don't apply auto rotation. Instead, we lay out the axis label
     * with word wrap. A lower limit makes sense when the label contains
     * multiple short words that don't extend the available horizontal space for
     * each label.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.autoRotationLimit
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.autoRotationLimit
     */
    autoRotationLimit?: number;
    /**
     * (Highcharts) Angular gauges and solid gauges only. The label's pixel
     * distance from the perimeter of the plot area.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.distance
     */
    distance?: number;
    /**
     * (Highcharts) Enable or disable the axis labels.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A format string for the axis label.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the label. The value
     * is given by `this.value`. Additional properties for `this` are `axis`,
     * `chart`, `isFirst` and `isLast`. The value of the default label formatter
     * can be retrieved by calling `this.axis.defaultLabelFormatter.call(this)`
     * within the function.
     *
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.formatter
     */
    formatter?: FormatterCallbackFunction<AxisLabelsFormatterContextObject>;
    /**
     * (Gantt) The number of pixels to indent the labels per level in a treegrid
     * axis.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.indentation
     */
    indentation?: number;
    /**
     * (Gantt) Set options on specific levels in a tree grid axis. Takes
     * precedence over labels options.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.levels
     */
    levels?: Array<ChartParallelAxesLabelsLevelsOptions>;
    /**
     * (Highcharts) Horizontal axis only. When `staggerLines` is not set,
     * `maxStaggerLines` defines how many lines the axis is allowed to add to
     * automatically avoid overlapping X labels. Set to `1` to disable overlap
     * detection.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.maxStaggerLines
     */
    maxStaggerLines?: number;
    /**
     * (Highcharts) How to handle overflowing labels on horizontal axis. If set
     * to `"allow"`, it will not be aligned at all. By default it `"justify"`
     * labels inside the chart area. If there is room to move it, it will be
     * aligned to the edge, else it will be removed.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Gantt) The pixel padding for axis labels, to ensure white
     * space between them.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.padding
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Defines how the labels are be repositioned according to the
     * 3D chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho");
    /**
     * (Highcharts, Gantt) Whether to reserve space for the labels. By default,
     * space is reserved for the labels in these cases:
     *
     * * On all horizontal axes.
     *
     * * On vertical axes if `label.align` is `right` on a left-side axis or
     * `left` on a right-side axis.
     *
     * * On vertical axes if `label.align` is `center`.
     *
     * This can be turned off when for example the labels are rendered inside
     * the plot area instead of outside.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.reserveSpace
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highcharts) Rotation of the labels in degrees.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis labels will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `labels.position3d`.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.skew3d
     */
    skew3d?: boolean;
    /**
     * (Highcharts) Horizontal axes only. The number of lines to spread the
     * labels over to make room or tighter labels.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.staggerLines
     */
    staggerLines?: number;
    /**
     * (Highcharts) To show only every _n_'th label on the axis, set the step to
     * _n_. Setting the step to 2 shows every other label.
     *
     * By default, the step is calculated automatically to avoid overlap. To
     * prevent this, set it to 1\. This usually only happens on a category axis,
     * and is often a sign that you have chosen the wrong axis type.
     *
     * Read more at Axis docs => What axis should I use?
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.step
     */
    step?: number;
    /**
     * (Highcharts) CSS styles for the label. Use `whiteSpace: 'nowrap'` to
     * prevent wrapping of category labels. Use `textOverflow: 'none'` to
     * prevent ellipsis (dots).
     *
     * In styled mode, the labels are styled with the `.highcharts-axis-labels`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.style
     */
    style?: CSSObject;
    /**
     * (Gantt) The symbol for the collapse and expand icon in a treegrid.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.symbol
     */
    symbol?: ChartParallelAxesLabelsSymbolOptions;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The x position offset of the label relative to the tick
     * position on the axis. Defaults to -15 for left axis, 15 for right axis.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the tick
     * position on the axis.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index for the axis labels.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels.zIndex
     */
    zIndex?: number;
}
/**
 * (Gantt) The symbol for the collapse and expand icon in a treegrid.
 *
 * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.symbol
 */
export interface ChartParallelAxesLabelsSymbolOptions {
    height?: number;
    padding?: number;
    /**
     * (Gantt) The symbol type. Points to a definition function in the
     * `Highcharts.Renderer.symbols` collection.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.labels.symbol.type
     */
    type?: ("arc"|"circle"|"diamond"|"square"|"triangle"|"triangle-down");
    width?: number;
    x?: number;
    y?: number;
}
/**
 * (Highcharts) Common options for all yAxes rendered in a parallel coordinates
 * plot. This feature requires `modules/parallel-coordinates.js`.
 *
 * The default options are: (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/chart.parallelAxes
 */
export interface ChartParallelAxesOptions {
    /**
     * (Highcharts, Highstock, Gantt) When using multiple axis, the ticks of two
     * or more opposite axes will automatically be aligned by adding ticks to
     * the axis or axes with the least ticks, as if `tickAmount` were specified.
     *
     * This can be prevented by setting `alignTicks` to false. If the grid lines
     * look messy, it's a good idea to hide them for the secondary axis by
     * setting `gridLineWidth` to 0.
     *
     * If `startOnTick` or `endOnTick` in an Axis options are set to false, then
     * the `alignTicks ` will be disabled for the Axis.
     *
     * Disabled for logarithmic axes.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.alignTicks
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.alignTicks
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.alignTicks
     */
    alignTicks?: boolean;
    /**
     * (Highcharts) Whether to allow decimals in this axis' ticks. When counting
     * integers, like persons or hits on a web page, decimals should be avoided
     * in the labels.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.allowDecimals
     */
    allowDecimals?: boolean;
    /**
     * (Highcharts, Gantt) If categories are present for the xAxis, names are
     * used instead of numbers for that axis. Since Highcharts 3.0, categories
     * can also be extracted by giving each point a name and setting axis type
     * to `category`. However, if you have multiple series, best practice
     * remains defining the `categories` array.
     *
     * Example:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.categories
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.categories
     */
    categories?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) The highest allowed value for
     * automatically computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.ceiling
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.ceiling
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.ceiling
     */
    ceiling?: number;
    /**
     * (Highcharts) A class name that opens for styling the axis by CSS,
     * especially in Highcharts styled mode. The class name is applied to group
     * elements for the grid, axis elements and labels.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.className
     */
    className?: string;
    /**
     * (Highcharts) Configure a crosshair that follows either the mouse pointer
     * or the hovered point.
     *
     * In styled mode, the crosshairs are styled in the `.highcharts-crosshair`,
     * `.highcharts-crosshair-thin` or `.highcharts-xaxis-category` classes.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.crosshair
     */
    crosshair?: (boolean|ChartParallelAxesCrosshairOptions);
    /**
     * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
     * automatically adjust to the appropriate unit. This member gives the
     * default string representations used for each unit. For intermediate
     * values, different units may be used, for example the `day` unit can be
     * used on midnight and `hour` unit be used for intermediate values on the
     * same axis. For an overview of the replacement codes, see dateFormat.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: ChartParallelAxesDateTimeLabelFormatsOptions;
    /**
     * (Highcharts) _Requires Accessibility module_
     *
     * Description of the axis to screen reader users.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.description
     */
    description?: string;
    /**
     * (Highcharts) Whether to force the axis to end on a tick. Use this option
     * with the `maxPadding` option to control the axis end.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.endOnTick
     */
    endOnTick?: boolean;
    /**
     * (Highcharts) Event handlers for the axis.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.events
     */
    events?: ChartParallelAxesEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) The lowest allowed value for automatically
     * computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.floor
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.floor
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.floor
     */
    floor?: number;
    /**
     * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.grid
     */
    grid?: ChartParallelAxesGridOptions;
    /**
     * (Highcharts, Highstock, Gantt) The Z index of the grid lines.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.gridZIndex
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.gridZIndex
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.gridZIndex
     */
    gridZIndex?: number;
    /**
     * (Highstock) The height of the Y axis. If it's a number, it is interpreted
     * as pixels.
     *
     * Since Highstock 2: If it's a percentage string, it is interpreted as
     * percentages of the total plot height.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.height
     */
    height?: (number|string);
    /**
     * (Highcharts) The axis labels show the number or category for each tick.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.labels
     */
    labels?: ChartParallelAxesLabelsOptions;
    /**
     * (Highcharts) The color of the line marking the axis itself.
     *
     * In styled mode, the line stroke is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the line marking the axis itself.
     *
     * In styled mode, the stroke width is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Index of another axis that this axis is
     * linked to. When an axis is linked to a master axis, it will take the same
     * extremes as the master, but as assigned by min or max or by setExtremes.
     * It can be used to show additional info, or to ease reading the chart by
     * duplicating the scales.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.linkedTo
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.linkedTo
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.linkedTo
     */
    linkedTo?: number;
    /**
     * (Highcharts) The maximum value of the axis. If `null`, the max value is
     * automatically calculated.
     *
     * If the endOnTick option is true, the `max` value might be rounded up.
     *
     * If a tickAmount is set, the axis may be extended beyond the set max in
     * order to reach the given number of ticks. The same may happen in a chart
     * with multiple axes, determined by chart. alignTicks, where a `tickAmount`
     * is applied internally.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.max
     */
    max?: number;
    /**
     * (Highstock) Maximal size of a resizable axis. Could be set as a percent
     * of plot area or pixel size.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.maxLength
     */
    maxLength?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) Padding of the max value relative to the
     * length of the axis. A padding of 0.05 will make a 100px axis 5px longer.
     * This is useful when you don't want the highest data value to appear on
     * the edge of the plot area. When the axis' `max` option is set or a max
     * extreme is set using `axis.setExtremes()`, the maxPadding will be
     * ignored.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.maxPadding
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.maxPadding
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.maxPadding
     */
    maxPadding?: number;
    /**
     * (Highstock) Maximum range which can be set using the navigator's handles.
     * Opposite of xAxis.minRange.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.maxRange
     */
    maxRange?: number;
    /**
     * (Highcharts) The minimum value of the axis. If `null` the min value is
     * automatically calculated.
     *
     * If the startOnTick option is true (default), the `min` value might be
     * rounded down.
     *
     * The automatically calculated minimum value is also affected by floor,
     * softMin, minPadding, minRange as well as series.threshold and
     * series.softThreshold.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.min
     */
    min?: number;
    /**
     * (Highstock) Minimal size of a resizable axis. Could be set as a percent
     * of plot area or pixel size.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.minLength
     */
    minLength?: (number|string);
    /**
     * (Highcharts) Color for the minor tick marks.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.minorTickColor
     */
    minorTickColor?: ColorString;
    /**
     * (Highcharts) Specific tick interval in axis units for the minor ticks. On
     * a linear axis, if `"auto"`, the minor tick interval is calculated as a
     * fifth of the tickInterval. If `null` or `undefined`, minor ticks are not
     * shown.
     *
     * On logarithmic axes, the unit is the power of the value. For example,
     * setting the minorTickInterval to 1 puts one tick on each of 0.1, 1, 10,
     * 100 etc. Setting the minorTickInterval to 0.1 produces 9 ticks between 1
     * and 10, 10 and 100 etc.
     *
     * If user settings dictate minor ticks to become too dense, they don't make
     * sense, and will be ignored to prevent performance problems.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.minorTickInterval
     */
    minorTickInterval?: (number|string|null);
    /**
     * (Highcharts) The pixel length of the minor tick marks.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.minorTickLength
     */
    minorTickLength?: number;
    /**
     * (Highcharts) The position of the minor tick marks relative to the axis
     * line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.minorTickPosition
     */
    minorTickPosition?: ("inside"|"outside");
    /**
     * (Highcharts) Enable or disable minor ticks. Unless minorTickInterval is
     * set, the tick interval is calculated as a fifth of the `tickInterval`.
     *
     * On a logarithmic axis, minor ticks are laid out based on a best guess,
     * attempting to enter approximately 5 minor ticks between each major tick.
     *
     * Prior to v6.0.0, ticks were unabled in auto layout by setting
     * `minorTickInterval` to `"auto"`.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.minorTicks
     */
    minorTicks?: boolean;
    /**
     * (Highcharts) The pixel width of the minor tick mark.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.minorTickWidth
     */
    minorTickWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Padding of the min value relative to the
     * length of the axis. A padding of 0.05 will make a 100px axis 5px longer.
     * This is useful when you don't want the lowest data value to appear on the
     * edge of the plot area. When the axis' `min` option is set or a max
     * extreme is set using `axis.setExtremes()`, the maxPadding will be
     * ignored.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.minPadding
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.minPadding
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.minPadding
     */
    minPadding?: number;
    /**
     * (Highcharts) The minimum range to display on this axis. The entire axis
     * will not be allowed to span over a smaller interval than this. For
     * example, for a datetime axis the main unit is milliseconds. If minRange
     * is set to 3600000, you can't zoom in more than to one hour.
     *
     * The default minRange for the x axis is five times the smallest interval
     * between any of the data points.
     *
     * On a logarithmic axis, the unit for the minimum range is the power. So a
     * minRange of 1 means that the axis can be zoomed to 10-100, 100-1000,
     * 1000-10000 etc.
     *
     * Note that the `minPadding`, `maxPadding`, `startOnTick` and `endOnTick`
     * settings also affect how the extremes of the axis are computed.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.minRange
     */
    minRange?: number;
    /**
     * (Highcharts) The minimum tick interval allowed in axis values. For
     * example on zooming in on an axis with daily data, this can be used to
     * prevent the axis from showing hours. Defaults to the closest distance
     * between two points on the axis.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.minTickInterval
     */
    minTickInterval?: number;
    /**
     * (Highcharts) The distance in pixels from the plot area to the axis line.
     * A positive offset moves the axis with it's line, labels and ticks away
     * from the plot area. This is typically used when two or more axes are
     * displayed on the same side of the plot. With multiple axes the offset is
     * dynamically adjusted to avoid collision, this can be overridden by
     * setting offset explicitly.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.offset
     */
    offset?: number;
    /**
     * (Highstock, Highcharts, Gantt) Whether to display the axis on the
     * opposite side of the normal. The normal is on the left side for vertical
     * axes and bottom for horizontal, so the opposite sides will be right and
     * top respectively. This is typically used with dual or multiple axes.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.opposite
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.opposite
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.opposite
     */
    opposite?: boolean;
    /**
     * (Highcharts) Refers to the index in the panes array. Used for circular
     * gauges and polar charts. When the option is not set then first pane will
     * be used.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.pane
     */
    pane?: number;
    /**
     * (Highstock) The zoomed range to display when only defining one or none of
     * `min` or `max`. For example, to show the latest month, a range of one
     * month can be set.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.range
     */
    range?: number;
    /**
     * (Highstock) Options for axis resizing. This feature requires the
     * `drag-panes.js` - classic or styled mode - module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize
     */
    resize?: ChartParallelAxesResizeOptions;
    /**
     * (Highcharts) Whether to reverse the axis so that the highest number is
     * closest to the origin.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.reversed
     */
    reversed?: boolean;
    /**
     * (Highcharts, Highstock) If `true`, the first series in a stack will be
     * drawn on top in a positive, non-reversed Y axis. If `false`, the first
     * series is in the base of the stack.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.reversedStacks
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.reversedStacks
     */
    reversedStacks?: boolean;
    /**
     * (Highcharts) Whether to show the axis line and title when the axis has no
     * data.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.showEmpty
     */
    showEmpty?: boolean;
    /**
     * (Highcharts) Whether to show the first tick label.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.showFirstLabel
     */
    showFirstLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to show the last tick label.
     * Defaults to `true` on cartesian charts, and `false` on polar charts.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.showLastLabel
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.showLastLabel
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.showLastLabel
     */
    showLastLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A soft maximum for the axis. If the series
     * data maximum is less than this, the axis will stay at this maximum, but
     * if the series data maximum is higher, the axis will flex to show all
     * data.
     *
     * **Note**: The series.softThreshold option takes precedence over this
     * option.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.softMax
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.softMax
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.softMax
     */
    softMax?: number;
    /**
     * (Highcharts, Highstock, Gantt) A soft minimum for the axis. If the series
     * data minimum is greater than this, the axis will stay at this minimum,
     * but if the series data minimum is lower, the axis will flex to show all
     * data.
     *
     * **Note**: The series.softThreshold option takes precedence over this
     * option.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.softMin
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.softMin
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.softMin
     */
    softMin?: number;
    /**
     * (Highcharts, Highstock, Gantt) For datetime axes, this decides where to
     * put the tick between weeks. 0 = Sunday, 1 = Monday.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.startOfWeek
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.startOfWeek
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.startOfWeek
     */
    startOfWeek?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether to force the axis to start on a
     * tick. Use this option with the `maxPadding` option to control the axis
     * start.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.startOnTick
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.startOnTick
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.startOnTick
     */
    startOnTick?: boolean;
    /**
     * (Gantt) For vertical axes only. Setting the static scale ensures that
     * each tick unit is translated into a fixed pixel height. For example,
     * setting the static scale to 24 results in each Y axis category taking up
     * 24 pixels, and the height of the chart adjusts. Adding or removing items
     * will make the chart resize.
     *
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.staticScale
     */
    staticScale?: number;
    /**
     * (Highcharts, Highstock, Gantt) The amount of ticks to draw on the axis.
     * This opens up for aligning the ticks of multiple charts or panes within a
     * chart. This option overrides the `tickPixelInterval` option.
     *
     * This option only has an effect on linear axes. Datetime, logarithmic or
     * category axes are not affected.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tickAmount
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.tickAmount
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.tickAmount
     */
    tickAmount?: number;
    /**
     * (Highcharts) Color for the main tick marks.
     *
     * In styled mode, the stroke is given in the `.highcharts-tick` class.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tickColor
     */
    tickColor?: ColorString;
    /**
     * (Highcharts) The interval of the tick marks in axis units. When
     * `undefined`, the tick interval is computed to approximately follow the
     * tickPixelInterval on linear and datetime axes. On categorized axes, a
     * `undefined` tickInterval will default to 1, one category. Note that
     * datetime axes are based on milliseconds, so for example an interval of
     * one day is expressed as `24 * 3600 * 1000`.
     *
     * On logarithmic axes, the tickInterval is based on powers, so a
     * tickInterval of 1 means one tick on each of 0.1, 1, 10, 100 etc. A
     * tickInterval of 2 means a tick of 0.1, 10, 1000 etc. A tickInterval of
     * 0.2 puts a tick on 0.1, 0.2, 0.4, 0.6, 0.8, 1, 2, 4, 6, 8, 10, 20, 40
     * etc.
     *
     * If the tickInterval is too dense for labels to be drawn, Highcharts may
     * remove ticks.
     *
     * If the chart has multiple axes, the alignTicks option may interfere with
     * the `tickInterval` setting.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tickInterval
     */
    tickInterval?: number;
    /**
     * (Highcharts) The pixel length of the main tick marks.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tickLength
     */
    tickLength?: number;
    /**
     * (Highcharts, Gantt) For categorized axes only. If `on` the tick mark is
     * placed in the center of the category, if `between` the tick mark is
     * placed between categories. The default is `between` if the `tickInterval`
     * is 1, else `on`.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tickmarkPlacement
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.tickmarkPlacement
     */
    tickmarkPlacement?: ("between"|"on");
    /**
     * (Highcharts) If tickInterval is `null` this option sets the approximate
     * pixel interval of the tick marks. Not applicable to categorized axis.
     *
     * The tick interval is also influenced by the minTickInterval option, that,
     * by default prevents ticks from being denser than the data points.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tickPixelInterval
     */
    tickPixelInterval?: number;
    /**
     * (Highcharts) The position of the major tick marks relative to the axis
     * line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tickPosition
     */
    tickPosition?: ("inside"|"outside");
    /**
     * (Highcharts) A callback function returning array defining where the ticks
     * are laid out on the axis. This overrides the default behaviour of
     * tickPixelInterval and tickInterval. The automatic tick positions are
     * accessible through `this.tickPositions` and can be modified by the
     * callback.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tickPositioner
     */
    tickPositioner?: AxisTickPositionerCallbackFunction;
    /**
     * (Highcharts) An array defining where the ticks are laid out on the axis.
     * This overrides the default behaviour of tickPixelInterval and
     * tickInterval.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tickPositions
     */
    tickPositions?: Array<number>;
    /**
     * (Highcharts, Highstock, Gantt) The pixel width of the major tick marks.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tickWidth
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.tickWidth
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.tickWidth
     */
    tickWidth?: number;
    /**
     * (Highcharts) Titles for yAxes are taken from xAxis.categories. All
     * options for `xAxis.labels` applies to parallel coordinates titles. For
     * example, to style categories, use xAxis.labels.style.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.title
     */
    title?: ChartParallelAxesTitleOptions;
    /**
     * (Highcharts) Parallel coordinates only. Format that will be used for
     * point.y and available in tooltip.pointFormat as `{point.formattedValue}`.
     * If not set, `{point.formattedValue}` will use other options, in this
     * order:
     *
     * 1. yAxis.labels.format will be used if set
     *
     * 2. If yAxis is a category, then category name will be displayed
     *
     * 3. If yAxis is a datetime, then value will use the same format as yAxis
     * labels
     *
     * 4. If yAxis is linear/logarithmic type, then simple value will be used
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.tooltipValueFormat
     */
    tooltipValueFormat?: string;
    /**
     * (Highstock) The top position of the Y axis. If it's a number, it is
     * interpreted as pixel position relative to the chart.
     *
     * Since Highstock 2: If it's a percentage string, it is interpreted as
     * percentages of the plot height, offset from plot area top.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.top
     */
    top?: (number|string);
    /**
     * (Highcharts, Gantt) The type of axis. Can be one of `linear`,
     * `logarithmic`, `datetime`, `category` or `treegrid`. Defaults to
     * `treegrid` for Gantt charts, `linear` for other chart types.
     *
     * In a datetime axis, the numbers are given in milliseconds, and tick marks
     * are placed on appropriate values, like full hours or days. In a category
     * or treegrid axis, the point names of the chart's series are used for
     * categories, if a categories array is not defined.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.type
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.type
     */
    type?: ("category"|"datetime"|"linear"|"logarithmic"|"treegrid");
    /**
     * (Highcharts, Gantt) Applies only when the axis `type` is `category`. When
     * `uniqueNames` is true, points are placed on the X axis according to their
     * names. If the same point name is repeated in the same or another series,
     * the point is placed on the same X position as other points of the same
     * name. When `uniqueNames` is false, the points are laid out in increasing
     * X positions regardless of their names, and the X axis category will take
     * the name of the last point in each position.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.uniqueNames
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.uniqueNames
     */
    uniqueNames?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Datetime axis only. An array determining
     * what time intervals the ticks are allowed to fall on. Each array item is
     * an array where the first value is the time unit and the second value
     * another array of allowed multiples. Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.units
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.units
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.units
     */
    units?: Array<[string, (Array<number>|null)]>;
    /**
     * (Highcharts, Highstock, Gantt) Whether axis, including axis title, line,
     * ticks and labels, should be visible.
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.visible
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.visible
     * @see https://api.highcharts.com/gantt/chart.parallelAxes.visible
     */
    visible?: boolean;
}
/**
 * (Highstock) Contains two arrays of axes that are controlled by control line
 * of the axis.
 *
 * This feature requires the `drag-panes.js` module.
 *
 * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.controlledAxis
 */
export interface ChartParallelAxesResizeControlledAxisOptions {
    /**
     * (Highstock) Array of axes that should move out of the way of resizing
     * being done for the current axis. If not set, the next axis will be used.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.controlledAxis.next
     */
    next?: Array<(string|number)>;
    /**
     * (Highstock) Array of axes that should move with the current axis while
     * resizing.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.controlledAxis.prev
     */
    prev?: Array<(string|number)>;
}
/**
 * (Highstock) Options for axis resizing. This feature requires the
 * `drag-panes.js` - classic or styled mode - module.
 *
 * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize
 */
export interface ChartParallelAxesResizeOptions {
    /**
     * (Highstock) Contains two arrays of axes that are controlled by control
     * line of the axis.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.controlledAxis
     */
    controlledAxis?: ChartParallelAxesResizeControlledAxisOptions;
    /**
     * (Highstock) Cursor style for the control line.
     *
     * In styled mode use class `highcharts-axis-resizer` instead.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Enable or disable resize by drag for the axis.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) Color of the control line.
     *
     * In styled mode use class `highcharts-axis-resizer` instead.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Dash style of the control line.
     *
     * In styled mode use class `highcharts-axis-resizer` instead.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.lineDashStyle
     */
    lineDashStyle?: string;
    /**
     * (Highstock) Width of the control line.
     *
     * In styled mode use class `highcharts-axis-resizer` instead.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Horizontal offset of the control line.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.x
     */
    x?: number;
    /**
     * (Highstock) Vertical offset of the control line.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/chart.parallelAxes.resize.y
     */
    y?: number;
}
/**
 * (Highcharts) Titles for yAxes are taken from xAxis.categories. All options
 * for `xAxis.labels` applies to parallel coordinates titles. For example, to
 * style categories, use xAxis.labels.style.
 *
 * @see https://api.highcharts.com/highcharts/chart.parallelAxes.title
 */
export interface ChartParallelAxesTitleOptions {
    reserveSpace?: boolean;
    text?: string;
    /**
     * (Highcharts) Alignment of the text, can be `"left"`, `"right"` or
     * `"center"`. Default alignment depends on the title.align:
     *
     * Horizontal axes:
     *
     * - for `align` = `"low"`, `textAlign` is set to `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"`, `textAlign` is set to `right`
     *
     * Vertical axes:
     *
     * - for `align` = `"low"` and `opposite` = `true`, `textAlign` is set to
     * `right`
     *
     * - for `align` = `"low"` and `opposite` = `false`, `textAlign` is set to
     * `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"` and `opposite` = `true` `textAlign` is set to
     * `left`
     *
     * - for `align` = `"high"` and `opposite` = `false` `textAlign` is set to
     * `right`
     *
     * @see https://api.highcharts.com/highcharts/chart.parallelAxes.title.textAlign
     */
    textAlign?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The button that appears after a
 * selection zoom, allowing the user to reset zoom.
 *
 * @see https://api.highcharts.com/highcharts/chart.resetZoomButton
 * @see https://api.highcharts.com/highstock/chart.resetZoomButton
 * @see https://api.highcharts.com/highmaps/chart.resetZoomButton
 * @see https://api.highcharts.com/gantt/chart.resetZoomButton
 */
export interface ChartResetZoomButtonOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The position of the button.
     *
     * @see https://api.highcharts.com/highcharts/chart.resetZoomButton.position
     * @see https://api.highcharts.com/highstock/chart.resetZoomButton.position
     * @see https://api.highcharts.com/highmaps/chart.resetZoomButton.position
     * @see https://api.highcharts.com/gantt/chart.resetZoomButton.position
     */
    position?: ChartResetZoomButtonPositionOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) What frame the button should be
     * placed related to. Can be either `plot` or `chart`
     *
     * @see https://api.highcharts.com/highcharts/chart.resetZoomButton.relativeTo
     * @see https://api.highcharts.com/highstock/chart.resetZoomButton.relativeTo
     * @see https://api.highcharts.com/highmaps/chart.resetZoomButton.relativeTo
     * @see https://api.highcharts.com/gantt/chart.resetZoomButton.relativeTo
     */
    relativeTo?: ("chart"|"plot");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A collection of attributes for
     * the button. The object takes SVG attributes like `fill`, `stroke`,
     * `stroke-width` or `r`, the border radius. The theme also supports
     * `style`, a collection of CSS properties for the text. Equivalent
     * attributes for the hover state are given in `theme.states.hover`.
     *
     * @see https://api.highcharts.com/highcharts/chart.resetZoomButton.theme
     * @see https://api.highcharts.com/highstock/chart.resetZoomButton.theme
     * @see https://api.highcharts.com/highmaps/chart.resetZoomButton.theme
     * @see https://api.highcharts.com/gantt/chart.resetZoomButton.theme
     */
    theme?: ChartResetZoomButtonThemeOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The position of the button.
 *
 * @see https://api.highcharts.com/highcharts/chart.resetZoomButton.position
 * @see https://api.highcharts.com/highstock/chart.resetZoomButton.position
 * @see https://api.highcharts.com/highmaps/chart.resetZoomButton.position
 * @see https://api.highcharts.com/gantt/chart.resetZoomButton.position
 */
export interface ChartResetZoomButtonPositionOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The horizontal alignment of the
     * button.
     *
     * @see https://api.highcharts.com/highcharts/chart.resetZoomButton.position.align
     * @see https://api.highcharts.com/highstock/chart.resetZoomButton.position.align
     * @see https://api.highcharts.com/highmaps/chart.resetZoomButton.position.align
     * @see https://api.highcharts.com/gantt/chart.resetZoomButton.position.align
     */
    align?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical alignment of the
     * button.
     *
     * @see https://api.highcharts.com/highcharts/chart.resetZoomButton.position.verticalAlign
     * @see https://api.highcharts.com/highstock/chart.resetZoomButton.position.verticalAlign
     * @see https://api.highcharts.com/highmaps/chart.resetZoomButton.position.verticalAlign
     * @see https://api.highcharts.com/gantt/chart.resetZoomButton.position.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The horizontal offset of the
     * button.
     *
     * @see https://api.highcharts.com/highcharts/chart.resetZoomButton.position.x
     * @see https://api.highcharts.com/highstock/chart.resetZoomButton.position.x
     * @see https://api.highcharts.com/highmaps/chart.resetZoomButton.position.x
     * @see https://api.highcharts.com/gantt/chart.resetZoomButton.position.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical offset of the
     * button.
     *
     * @see https://api.highcharts.com/highcharts/chart.resetZoomButton.position.y
     * @see https://api.highcharts.com/highstock/chart.resetZoomButton.position.y
     * @see https://api.highcharts.com/highmaps/chart.resetZoomButton.position.y
     * @see https://api.highcharts.com/gantt/chart.resetZoomButton.position.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) A collection of attributes for the
 * button. The object takes SVG attributes like `fill`, `stroke`, `stroke-width`
 * or `r`, the border radius. The theme also supports `style`, a collection of
 * CSS properties for the text. Equivalent attributes for the hover state are
 * given in `theme.states.hover`.
 *
 * @see https://api.highcharts.com/highcharts/chart.resetZoomButton.theme
 * @see https://api.highcharts.com/highstock/chart.resetZoomButton.theme
 * @see https://api.highcharts.com/highmaps/chart.resetZoomButton.theme
 * @see https://api.highcharts.com/gantt/chart.resetZoomButton.theme
 */
export interface ChartResetZoomButtonThemeOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Z index for the reset zoom
     * button. The default value places it below the tooltip that has Z index 7.
     *
     * @see https://api.highcharts.com/highcharts/chart.resetZoomButton.theme.zIndex
     * @see https://api.highcharts.com/highstock/chart.resetZoomButton.theme.zIndex
     * @see https://api.highcharts.com/highmaps/chart.resetZoomButton.theme.zIndex
     * @see https://api.highcharts.com/gantt/chart.resetZoomButton.theme.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Gantt) Options for a scrollable plot area. This feature provides
 * a minimum width for the plot area of the chart. If the width gets smaller
 * than this, typically on mobile devices, a native browser scrollbar is
 * presented below the chart. This scrollbar provides smooth scrolling for the
 * contents of the plot area, whereas the title, legend and axes are fixed.
 *
 * @see https://api.highcharts.com/highcharts/chart.scrollablePlotArea
 * @see https://api.highcharts.com/gantt/chart.scrollablePlotArea
 */
export interface ChartScrollablePlotAreaOptions {
    /**
     * (Highcharts, Gantt) The minimum width for the plot area. If it gets
     * smaller than this, the plot area will become scrollable.
     *
     * @see https://api.highcharts.com/highcharts/chart.scrollablePlotArea.minWidth
     * @see https://api.highcharts.com/gantt/chart.scrollablePlotArea.minWidth
     */
    minWidth?: number;
    /**
     * (Highcharts, Gantt) The initial scrolling position of the scrollable plot
     * area. Ranges from 0 to 1, where 0 aligns the plot area to the left and 1
     * aligns it to the right. Typically we would use 1 if the chart has right
     * aligned Y axes.
     *
     * @see https://api.highcharts.com/highcharts/chart.scrollablePlotArea.scrollPositionX
     * @see https://api.highcharts.com/gantt/chart.scrollablePlotArea.scrollPositionX
     */
    scrollPositionX?: number;
}
/**
 * (Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label
 */
export interface ColorAxisCurrentDateIndicatorLabelOptions {
    /**
     * (Gantt) Horizontal alignment of the label. Can be one of "left", "center"
     * or "right".
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Gantt) Rotation of the text label in degrees. Defaults to 0 for
     * horizontal plot lines and 90 for vertical lines.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label.rotation
     */
    rotation?: number;
    /**
     * (Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-line-label` class.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label.style
     */
    style?: CSSObject;
    /**
     * (Gantt) The text itself. A subset of HTML is supported.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label.text
     */
    text?: string;
    /**
     * (Gantt) The text alignment for the label. While `align` determines where
     * the texts anchor point is placed within the plot band, `textAlign`
     * determines how the text is aligned against its anchor point. Possible
     * values are "left", "center" and "right". Defaults to the same as the
     * `align` option.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label.textAlign
     */
    textAlign?: string;
    /**
     * (Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Gantt) Vertical alignment of the label relative to the plot line. Can be
     * one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Gantt) Horizontal position relative the alignment. Default varies by
     * orientation.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label.x
     */
    x?: number;
    /**
     * (Gantt) Vertical position of the text baseline relative to the alignment.
     * Default varies by orientation.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label.y
     */
    y?: number;
}
/**
 * (Gantt) Show an indicator on the axis for the current date and time. Can be a
 * boolean or a configuration object similar to xAxis.plotLines.
 *
 * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator
 */
export interface ColorAxisCurrentDateIndicatorOptions {
    /**
     * (Gantt) A custom class name, in addition to the default
     * `highcharts-plot-line`, to apply to each individual line.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.className
     */
    className?: string;
    /**
     * (Gantt) The color of the line.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.color
     */
    color?: ColorString;
    /**
     * (Gantt) The dashing or dot style for the plot line. For possible values
     * see this overview.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Gantt) An object defining mouse events for the plot line. Supported
     * properties are `click`, `mouseover`, `mouseout`, `mousemove`.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.events
     */
    events?: any;
    /**
     * (Gantt) An id used for identifying the plot line in Axis.removePlotLine.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.id
     */
    id?: string;
    /**
     * (Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.label
     */
    label?: ColorAxisCurrentDateIndicatorLabelOptions;
    /**
     * (Gantt) The width or thickness of the plot line.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.width
     */
    width?: number;
    /**
     * (Gantt) The z index of the plot line within the chart.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highmaps) An array of data classes or ranges for the choropleth
 * map. If none given, the color axis is scalar and values are distributed as a
 * gradient between the minimum and maximum colors.
 *
 * @see https://api.highcharts.com/highcharts/colorAxis.dataClasses
 * @see https://api.highcharts.com/highmaps/colorAxis.dataClasses
 */
export interface ColorAxisDataClassesOptions {
    /**
     * (Highcharts, Highmaps) The color of each data class. If not set, the
     * color is pulled from the global or chart-specific colors array. In styled
     * mode, this option is ignored. Instead, use colors defined in CSS.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.dataClasses.color
     * @see https://api.highcharts.com/highmaps/colorAxis.dataClasses.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highmaps) The start of the value range that the data class
     * represents, relating to the point value.
     *
     * The range of each `dataClass` is closed in both ends, but can be
     * overridden by the next `dataClass`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.dataClasses.from
     * @see https://api.highcharts.com/highmaps/colorAxis.dataClasses.from
     */
    from?: number;
    /**
     * (Highcharts, Highmaps) The name of the data class as it appears in the
     * legend. If no name is given, it is automatically created based on the
     * `from` and `to` values. For full programmatic control,
     * legend.labelFormatter can be used. In the formatter, `this.from` and
     * `this.to` can be accessed.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.dataClasses.name
     * @see https://api.highcharts.com/highmaps/colorAxis.dataClasses.name
     */
    name?: string;
    /**
     * (Highcharts, Highmaps) The end of the value range that the data class
     * represents, relating to the point value.
     *
     * The range of each `dataClass` is closed in both ends, but can be
     * overridden by the next `dataClass`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.dataClasses.to
     * @see https://api.highcharts.com/highmaps/colorAxis.dataClasses.to
     */
    to?: number;
}
/**
 * (Highcharts, Highmaps) Event handlers for the axis.
 *
 * @see https://api.highcharts.com/highcharts/colorAxis.events
 * @see https://api.highcharts.com/highmaps/colorAxis.events
 */
export interface ColorAxisEventsOptions {
    /**
     * (Highcharts, Highmaps) As opposed to the `setExtremes` event, this event
     * fires after the final min and max values are computed and corrected for
     * `minRange`.
     *
     * Fires when the minimum and maximum is set for the axis, either by calling
     * the `.setExtremes()` method or by selecting an area in the chart. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in axis
     * values. The actual data extremes are found in `event.dataMin` and
     * `event.dataMax`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.events.afterSetExtremes
     * @see https://api.highcharts.com/highmaps/colorAxis.events.afterSetExtremes
     */
    afterSetExtremes?: AxisEventCallbackFunction;
    /**
     * (Highcharts, Highmaps) Fires when the legend item belonging to the
     * colorAxis is clicked. One parameter, `event`, is passed to the function.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.events.legendItemClick
     * @see https://api.highcharts.com/highmaps/colorAxis.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the minimum and maximum is set for the
     * axis, either by calling the `.setExtremes()` method or by selecting an
     * area in the chart. One parameter, `event`, is passed to the function,
     * containing common event information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in data
     * values. When an axis is zoomed all the way out from the "Reset zoom"
     * button, `event.min` and `event.max` are null, and the new extremes are
     * set based on `this.dataMin` and `this.dataMax`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.events.setExtremes
     * @see https://api.highcharts.com/highmaps/colorAxis.events.setExtremes
     */
    setExtremes?: AxisSetExtremesEventCallbackFunction;
}
/**
 * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
 *
 * @see https://api.highcharts.com/gantt/colorAxis.grid
 */
export interface ColorAxisGridOptions {
    /**
     * (Gantt) Set border color for the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.grid.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Gantt) Set border width of the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.grid.borderWidth
     */
    borderWidth?: number;
    /**
     * (Gantt) Set cell height for grid axis labels. By default this is
     * calculated from font size.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.grid.cellHeight
     */
    cellHeight?: number;
    /**
     * (Gantt) Set specific options for each column (or row for horizontal axes)
     * in the grid. Each extra column/row is its own axis, and the axis options
     * can be set here.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.grid.columns
     */
    columns?: Array<XAxisOptions>;
    /**
     * (Gantt) Enable grid on the axis labels. Defaults to true for Gantt
     * charts.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.grid.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highmaps) The axis labels show the number for each tick.
 *
 * For more live examples on label options, see xAxis.labels in the Highcharts
 * API.
 *
 * @see https://api.highcharts.com/highcharts/colorAxis.labels
 * @see https://api.highcharts.com/highmaps/colorAxis.labels
 */
export interface ColorAxisLabelsOptions {
    /**
     * (Highcharts, Highmaps) What part of the string the given position is
     * anchored to. If `left`, the left side of the string is at the axis
     * position. Can be one of `"left"`, `"center"` or `"right"`. Defaults to an
     * intelligent guess based on which side of the chart the axis is on and the
     * rotation of the label.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.align
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) For horizontal axes, the allowed degrees
     * of label rotation to prevent overlapping labels. If there is enough
     * space, labels are not rotated. As the chart gets narrower, it will start
     * rotating the labels -45 degrees, then remove every second label and try
     * again with rotations 0 and -45 etc. Set it to `false` to disable
     * rotation, which will cause the labels to word-wrap if possible.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.autoRotation
     * @see https://api.highcharts.com/highstock/colorAxis.labels.autoRotation
     * @see https://api.highcharts.com/gantt/colorAxis.labels.autoRotation
     */
    autoRotation?: Array<number>;
    /**
     * (Highcharts, Gantt) When each category width is more than this many
     * pixels, we don't apply auto rotation. Instead, we lay out the axis label
     * with word wrap. A lower limit makes sense when the label contains
     * multiple short words that don't extend the available horizontal space for
     * each label.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.autoRotationLimit
     * @see https://api.highcharts.com/gantt/colorAxis.labels.autoRotationLimit
     */
    autoRotationLimit?: number;
    /**
     * (Highcharts, Gantt) Polar charts only. The label's pixel distance from
     * the perimeter of the plot area.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.distance
     * @see https://api.highcharts.com/gantt/colorAxis.labels.distance
     */
    distance?: number;
    /**
     * (Highcharts, Highmaps) Enable or disable the axis labels.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.enabled
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highmaps) A format string for the axis label.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.format
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.format
     */
    format?: string;
    /**
     * (Highcharts, Highmaps) Callback JavaScript function to format the label.
     * The value is given by `this.value`. Additional properties for `this` are
     * `axis`, `chart`, `isFirst` and `isLast`. The value of the default label
     * formatter can be retrieved by calling
     * `this.axis.defaultLabelFormatter.call(this)` within the function.
     *
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.formatter
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.formatter
     */
    formatter?: FormatterCallbackFunction<AxisLabelsFormatterContextObject>;
    /**
     * (Gantt) The number of pixels to indent the labels per level in a treegrid
     * axis.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.labels.indentation
     */
    indentation?: number;
    /**
     * (Highcharts, Highmaps) Horizontal axis only. When `staggerLines` is not
     * set, `maxStaggerLines` defines how many lines the axis is allowed to add
     * to automatically avoid overlapping X labels. Set to `1` to disable
     * overlap detection.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.maxStaggerLines
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.maxStaggerLines
     */
    maxStaggerLines?: number;
    /**
     * (Highcharts, Highmaps) How to handle overflowing labels on horizontal
     * color axis. Can be undefined or "justify". If "justify", labels will not
     * render outside the legend area. If there is room to move it, it will be
     * aligned to the edge, else it will be removed.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.overflow
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Gantt) The pixel padding for axis labels, to ensure white
     * space between them.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.padding
     * @see https://api.highcharts.com/gantt/colorAxis.labels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Defines how the labels are be repositioned according to the
     * 3D chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho");
    /**
     * (Highcharts, Gantt) Whether to reserve space for the labels. By default,
     * space is reserved for the labels in these cases:
     *
     * * On all horizontal axes.
     *
     * * On vertical axes if `label.align` is `right` on a left-side axis or
     * `left` on a right-side axis.
     *
     * * On vertical axes if `label.align` is `center`.
     *
     * This can be turned off when for example the labels are rendered inside
     * the plot area instead of outside.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.reserveSpace
     * @see https://api.highcharts.com/gantt/colorAxis.labels.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highcharts, Highmaps) Rotation of the labels in degrees.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.rotation
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis labels will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `labels.position3d`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.skew3d
     */
    skew3d?: boolean;
    /**
     * (Highcharts, Highmaps) Horizontal axes only. The number of lines to
     * spread the labels over to make room or tighter labels.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.staggerLines
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.staggerLines
     */
    staggerLines?: number;
    /**
     * (Highcharts, Highmaps) To show only every _n_'th label on the axis, set
     * the step to _n_. Setting the step to 2 shows every other label.
     *
     * By default, the step is calculated automatically to avoid overlap. To
     * prevent this, set it to 1\. This usually only happens on a category axis,
     * and is often a sign that you have chosen the wrong axis type.
     *
     * Read more at Axis docs => What axis should I use?
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.step
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.step
     */
    step?: number;
    /**
     * (Highcharts, Highmaps) CSS styles for the label. Use `whiteSpace:
     * 'nowrap'` to prevent wrapping of category labels. Use `textOverflow:
     * 'none'` to prevent ellipsis (dots).
     *
     * In styled mode, the labels are styled with the `.highcharts-axis-labels`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.style
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highmaps) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.useHTML
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highmaps) The x position offset of the label relative to the
     * tick position on the axis.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.x
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.x
     */
    x?: number;
    /**
     * (Highcharts, Highmaps) The y position offset of the label relative to the
     * tick position on the axis. The default makes it adapt to the font size on
     * bottom axis.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.y
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.y
     */
    y?: number;
    /**
     * (Highcharts, Highmaps) The Z index for the axis labels.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels.zIndex
     * @see https://api.highcharts.com/highmaps/colorAxis.labels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highmaps) The triangular marker on a scalar color axis that
 * points to the value of the hovered area. To disable the marker, set `marker:
 * null`.
 *
 * @see https://api.highcharts.com/highcharts/colorAxis.marker
 * @see https://api.highcharts.com/highmaps/colorAxis.marker
 */
export interface ColorAxisMarkerOptions {
    /**
     * (Highcharts, Highmaps) Animation for the marker as it moves between
     * values. Set to `false` to disable animation. Defaults to `{ duration: 50
     * }`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.marker.animation
     * @see https://api.highcharts.com/highmaps/colorAxis.marker.animation
     */
    animation?: (boolean|AnimationOptionsObject);
    /**
     * (Highcharts, Highmaps) The color of the marker.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.marker.color
     * @see https://api.highcharts.com/highmaps/colorAxis.marker.color
     */
    color?: ColorString;
}
/**
 * (Highcharts, Highmaps) A color axis for choropleth maps and heat maps.
 * Visually, the color axis will appear as a gradient or as separate items
 * inside the legend, depending on whether the axis is scalar or based on data
 * classes.
 *
 * For supported color formats, see the docs article about colors.
 *
 * A scalar color axis is represented by a gradient. The colors either range
 * between the minColor and the maxColor, or for more fine grained control the
 * colors can be defined in stops. Often times, the color axis needs to be
 * adjusted to get the right color spread for the data. In addition to stops,
 * consider using a logarithmic axis type, or setting min and max to avoid the
 * colors being determined by outliers.
 *
 * When dataClasses are used, the ranges are subdivided into separate classes
 * like categories based on their values. This can be used for ranges between
 * two values, but also for a true category. However, when your data is
 * categorized, it may be as convenient to add each category to a separate
 * series.
 *
 * See the Axis object for programmatic access to the axis.
 *
 * @see https://api.highcharts.com/highcharts/colorAxis
 * @see https://api.highcharts.com/highmaps/colorAxis
 */
export interface ColorAxisOptions {
    /**
     * (Highcharts, Highstock, Gantt) When using multiple axis, the ticks of two
     * or more opposite axes will automatically be aligned by adding ticks to
     * the axis or axes with the least ticks, as if `tickAmount` were specified.
     *
     * This can be prevented by setting `alignTicks` to false. If the grid lines
     * look messy, it's a good idea to hide them for the secondary axis by
     * setting `gridLineWidth` to 0.
     *
     * If `startOnTick` or `endOnTick` in an Axis options are set to false, then
     * the `alignTicks ` will be disabled for the Axis.
     *
     * Disabled for logarithmic axes.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.alignTicks
     * @see https://api.highcharts.com/highstock/colorAxis.alignTicks
     * @see https://api.highcharts.com/gantt/colorAxis.alignTicks
     */
    alignTicks?: boolean;
    /**
     * (Highcharts, Highmaps) Whether to allow decimals on the color axis.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.allowDecimals
     * @see https://api.highcharts.com/highmaps/colorAxis.allowDecimals
     */
    allowDecimals?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) The highest allowed value for
     * automatically computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.ceiling
     * @see https://api.highcharts.com/highstock/colorAxis.ceiling
     * @see https://api.highcharts.com/gantt/colorAxis.ceiling
     */
    ceiling?: number;
    /**
     * (Highcharts, Highmaps) A class name that opens for styling the axis by
     * CSS, especially in Highcharts styled mode. The class name is applied to
     * group elements for the grid, axis elements and labels.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.className
     * @see https://api.highcharts.com/highmaps/colorAxis.className
     */
    className?: string;
    /**
     * (Gantt) Show an indicator on the axis for the current date and time. Can
     * be a boolean or a configuration object similar to xAxis.plotLines.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.currentDateIndicator
     */
    currentDateIndicator?: (boolean|ColorAxisCurrentDateIndicatorOptions);
    /**
     * (Highcharts, Highmaps) Determines how to set each data class' color if no
     * individual color is set. The default value, `tween`, computes
     * intermediate colors between `minColor` and `maxColor`. The other possible
     * value, `category`, pulls colors from the global or chart specific colors
     * array.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.dataClassColor
     * @see https://api.highcharts.com/highmaps/colorAxis.dataClassColor
     */
    dataClassColor?: ("category"|"tween");
    /**
     * (Highcharts, Highmaps) An array of data classes or ranges for the
     * choropleth map. If none given, the color axis is scalar and values are
     * distributed as a gradient between the minimum and maximum colors.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.dataClasses
     * @see https://api.highcharts.com/highmaps/colorAxis.dataClasses
     */
    dataClasses?: Array<ColorAxisDataClassesOptions>;
    /**
     * (Highcharts, Highmaps) _Requires Accessibility module_
     *
     * Description of the axis to screen reader users.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.description
     * @see https://api.highcharts.com/highmaps/colorAxis.description
     */
    description?: string;
    /**
     * (Highcharts, Highmaps) Whether to force the axis to end on a tick. Use
     * this option with the maxPadding option to control the axis end.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.endOnTick
     * @see https://api.highcharts.com/highmaps/colorAxis.endOnTick
     */
    endOnTick?: boolean;
    /**
     * (Highcharts, Highmaps) Event handlers for the axis.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.events
     * @see https://api.highcharts.com/highmaps/colorAxis.events
     */
    events?: ColorAxisEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) The lowest allowed value for automatically
     * computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.floor
     * @see https://api.highcharts.com/highstock/colorAxis.floor
     * @see https://api.highcharts.com/gantt/colorAxis.floor
     */
    floor?: number;
    /**
     * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
     *
     * @see https://api.highcharts.com/gantt/colorAxis.grid
     */
    grid?: ColorAxisGridOptions;
    /**
     * (Highcharts, Highmaps) Color of the grid lines extending from the axis
     * across the gradient.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.gridLineColor
     * @see https://api.highcharts.com/highmaps/colorAxis.gridLineColor
     */
    gridLineColor?: ColorString;
    /**
     * (Highcharts, Highmaps) The dash or dot style of the grid lines. For
     * possible values, see this demonstration.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.gridLineDashStyle
     * @see https://api.highcharts.com/highmaps/colorAxis.gridLineDashStyle
     */
    gridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highmaps) The width of the grid lines extending from the
     * axis across the gradient of a scalar color axis.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.gridLineWidth
     * @see https://api.highcharts.com/highmaps/colorAxis.gridLineWidth
     */
    gridLineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The Z index of the grid lines.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.gridZIndex
     * @see https://api.highcharts.com/highstock/colorAxis.gridZIndex
     * @see https://api.highcharts.com/gantt/colorAxis.gridZIndex
     */
    gridZIndex?: number;
    /**
     * (Highcharts, Highmaps) An id for the axis. This can be used after render
     * time to get a pointer to the axis object through `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.id
     * @see https://api.highcharts.com/highmaps/colorAxis.id
     */
    id?: string;
    /**
     * (Highcharts, Highmaps) The axis labels show the number for each tick.
     *
     * For more live examples on label options, see xAxis.labels in the
     * Highcharts API.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.labels
     * @see https://api.highcharts.com/highmaps/colorAxis.labels
     */
    labels?: ColorAxisLabelsOptions;
    /**
     * (Highcharts, Highmaps) The color of the line marking the axis itself.
     *
     * In styled mode, the line stroke is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.lineColor
     * @see https://api.highcharts.com/highmaps/colorAxis.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highmaps) The triangular marker on a scalar color axis that
     * points to the value of the hovered area. To disable the marker, set
     * `marker: null`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.marker
     * @see https://api.highcharts.com/highmaps/colorAxis.marker
     */
    marker?: ColorAxisMarkerOptions;
    /**
     * (Highcharts, Highmaps) The maximum value of the axis in terms of map
     * point values. If `null`, the max value is automatically calculated. If
     * the `endOnTick` option is true, the max value might be rounded up.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.max
     * @see https://api.highcharts.com/highmaps/colorAxis.max
     */
    max?: number;
    /**
     * (Highcharts, Highmaps) The color to represent the maximum of the color
     * axis. Unless dataClasses or stops are set, the gradient ends at this
     * value.
     *
     * If dataClasses are set, the color is based on minColor and maxColor
     * unless a color is set for each data class, or the dataClassColor is set.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.maxColor
     * @see https://api.highcharts.com/highmaps/colorAxis.maxColor
     */
    maxColor?: ColorString;
    /**
     * (Highcharts, Highmaps) Padding of the max value relative to the length of
     * the axis. A padding of 0.05 will make a 100px axis 5px longer.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.maxPadding
     * @see https://api.highcharts.com/highmaps/colorAxis.maxPadding
     */
    maxPadding?: number;
    /**
     * (Highstock) Maximum range which can be set using the navigator's handles.
     * Opposite of xAxis.minRange.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.maxRange
     */
    maxRange?: number;
    /**
     * (Highcharts, Highmaps) The minimum value of the axis in terms of map
     * point values. If `null`, the min value is automatically calculated. If
     * the `startOnTick` option is true, the min value might be rounded down.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.min
     * @see https://api.highcharts.com/highmaps/colorAxis.min
     */
    min?: number;
    /**
     * (Highcharts, Highmaps) The color to represent the minimum of the color
     * axis. Unless dataClasses or stops are set, the gradient starts at this
     * value.
     *
     * If dataClasses are set, the color is based on minColor and maxColor
     * unless a color is set for each data class, or the dataClassColor is set.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minColor
     * @see https://api.highcharts.com/highmaps/colorAxis.minColor
     */
    minColor?: ColorString;
    /**
     * (Highcharts, Highmaps) Color of the minor, secondary grid lines.
     *
     * In styled mode, the stroke width is given in the
     * `.highcharts-minor-grid-line` class.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minorGridLineColor
     * @see https://api.highcharts.com/highmaps/colorAxis.minorGridLineColor
     */
    minorGridLineColor?: ColorString;
    /**
     * (Highcharts, Highmaps) The dash or dot style of the minor grid lines. For
     * possible values, see this demonstration.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minorGridLineDashStyle
     * @see https://api.highcharts.com/highmaps/colorAxis.minorGridLineDashStyle
     */
    minorGridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highmaps) Width of the minor, secondary grid lines.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minorGridLineWidth
     * @see https://api.highcharts.com/highmaps/colorAxis.minorGridLineWidth
     */
    minorGridLineWidth?: number;
    /**
     * (Highcharts, Highmaps) Color for the minor tick marks.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minorTickColor
     * @see https://api.highcharts.com/highmaps/colorAxis.minorTickColor
     */
    minorTickColor?: ColorString;
    /**
     * (Highcharts, Highmaps) Specific tick interval in axis units for the minor
     * ticks. On a linear axis, if `"auto"`, the minor tick interval is
     * calculated as a fifth of the tickInterval. If `null` or `undefined`,
     * minor ticks are not shown.
     *
     * On logarithmic axes, the unit is the power of the value. For example,
     * setting the minorTickInterval to 1 puts one tick on each of 0.1, 1, 10,
     * 100 etc. Setting the minorTickInterval to 0.1 produces 9 ticks between 1
     * and 10, 10 and 100 etc.
     *
     * If user settings dictate minor ticks to become too dense, they don't make
     * sense, and will be ignored to prevent performance problems.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minorTickInterval
     * @see https://api.highcharts.com/highmaps/colorAxis.minorTickInterval
     */
    minorTickInterval?: (number|string|null);
    /**
     * (Highcharts, Highmaps) The pixel length of the minor tick marks.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minorTickLength
     * @see https://api.highcharts.com/highmaps/colorAxis.minorTickLength
     */
    minorTickLength?: number;
    /**
     * (Highcharts, Highmaps) The position of the minor tick marks relative to
     * the axis line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minorTickPosition
     * @see https://api.highcharts.com/highmaps/colorAxis.minorTickPosition
     */
    minorTickPosition?: ("inside"|"outside");
    /**
     * (Highcharts, Highmaps) Enable or disable minor ticks. Unless
     * minorTickInterval is set, the tick interval is calculated as a fifth of
     * the `tickInterval`.
     *
     * On a logarithmic axis, minor ticks are laid out based on a best guess,
     * attempting to enter approximately 5 minor ticks between each major tick.
     *
     * Prior to v6.0.0, ticks were unabled in auto layout by setting
     * `minorTickInterval` to `"auto"`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minorTicks
     * @see https://api.highcharts.com/highmaps/colorAxis.minorTicks
     */
    minorTicks?: boolean;
    /**
     * (Highcharts, Highmaps) The pixel width of the minor tick mark.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minorTickWidth
     * @see https://api.highcharts.com/highmaps/colorAxis.minorTickWidth
     */
    minorTickWidth?: number;
    /**
     * (Highcharts, Highmaps) Padding of the min value relative to the length of
     * the axis. A padding of 0.05 will make a 100px axis 5px longer.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.minPadding
     * @see https://api.highcharts.com/highmaps/colorAxis.minPadding
     */
    minPadding?: number;
    /**
     * (Highstock) In an ordinal axis, the points are equally spaced in the
     * chart regardless of the actual time or x distance between them. This
     * means that missing data periods (e.g. nights or weekends for a stock
     * chart) will not take up space in the chart. Having `ordinal: false` will
     * show any gaps created by the `gapSize` setting proportionate to their
     * duration.
     *
     * In stock charts the X axis is ordinal by default, unless the boost module
     * is used and at least one of the series' data length exceeds the
     * boostThreshold.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.ordinal
     */
    ordinal?: boolean;
    /**
     * (Highstock) Additional range on the right side of the xAxis. Works
     * similar to `xAxis.maxPadding`, but value is set in milliseconds. Can be
     * set for both main `xAxis` and the navigator's `xAxis`.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.overscroll
     */
    overscroll?: number;
    /**
     * (Highcharts) Refers to the index in the panes array. Used for circular
     * gauges and polar charts. When the option is not set then first pane will
     * be used.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.pane
     */
    pane?: number;
    /**
     * (Highstock) The zoomed range to display when only defining one or none of
     * `min` or `max`. For example, to show the latest month, a range of one
     * month can be set.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.range
     */
    range?: number;
    /**
     * (Highcharts, Highmaps) Whether to reverse the axis so that the highest
     * number is closest to the origin. Defaults to `false` in a horizontal
     * legend and `true` in a vertical legend, where the smallest value starts
     * on top.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.reversed
     * @see https://api.highcharts.com/highmaps/colorAxis.reversed
     */
    reversed?: boolean;
    /**
     * (Highcharts, Highstock) This option determines how stacks should be
     * ordered within a group. For example reversed xAxis also reverses stacks,
     * so first series comes last in a group. To keep order like for
     * non-reversed xAxis enable this option.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.reversedStacks
     * @see https://api.highcharts.com/highstock/colorAxis.reversedStacks
     */
    reversedStacks?: boolean;
    /**
     * (Highstock) An optional scrollbar to display on the X axis in response to
     * limiting the minimum and maximum of the axis values.
     *
     * In styled mode, all the presentational options for the scrollbar are
     * replaced by the classes `.highcharts-scrollbar-thumb`,
     * `.highcharts-scrollbar-arrow`, `.highcharts-scrollbar-button`,
     * `.highcharts-scrollbar-rifles` and `.highcharts-scrollbar-track`.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar
     */
    scrollbar?: ColorAxisScrollbarOptions;
    /**
     * (Highcharts, Highmaps) Whether to show the first tick label.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.showFirstLabel
     * @see https://api.highcharts.com/highmaps/colorAxis.showFirstLabel
     */
    showFirstLabel?: boolean;
    /**
     * (Highcharts, Highmaps) Whether to display the colorAxis in the legend.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.showInLegend
     * @see https://api.highcharts.com/highmaps/colorAxis.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to show the last tick label.
     * Defaults to `true` on cartesian charts, and `false` on polar charts.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.showLastLabel
     * @see https://api.highcharts.com/highstock/colorAxis.showLastLabel
     * @see https://api.highcharts.com/gantt/colorAxis.showLastLabel
     */
    showLastLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A soft maximum for the axis. If the series
     * data maximum is less than this, the axis will stay at this maximum, but
     * if the series data maximum is higher, the axis will flex to show all
     * data.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.softMax
     * @see https://api.highcharts.com/highstock/colorAxis.softMax
     * @see https://api.highcharts.com/gantt/colorAxis.softMax
     */
    softMax?: number;
    /**
     * (Highcharts, Highstock, Gantt) A soft minimum for the axis. If the series
     * data minimum is greater than this, the axis will stay at this minimum,
     * but if the series data minimum is lower, the axis will flex to show all
     * data.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.softMin
     * @see https://api.highcharts.com/highstock/colorAxis.softMin
     * @see https://api.highcharts.com/gantt/colorAxis.softMin
     */
    softMin?: number;
    /**
     * (Highcharts, Highstock, Gantt) For datetime axes, this decides where to
     * put the tick between weeks. 0 = Sunday, 1 = Monday.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.startOfWeek
     * @see https://api.highcharts.com/highstock/colorAxis.startOfWeek
     * @see https://api.highcharts.com/gantt/colorAxis.startOfWeek
     */
    startOfWeek?: number;
    /**
     * (Highcharts, Highmaps) Whether to force the axis to start on a tick. Use
     * this option with the `maxPadding` option to control the axis start.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.startOnTick
     * @see https://api.highcharts.com/highmaps/colorAxis.startOnTick
     */
    startOnTick?: boolean;
    /**
     * (Highcharts, Highmaps) Color stops for the gradient of a scalar color
     * axis. Use this in cases where a linear gradient between a `minColor` and
     * `maxColor` is not sufficient. The stops is an array of tuples, where the
     * first item is a float between 0 and 1 assigning the relative position in
     * the gradient, and the second item is the color.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.stops
     * @see https://api.highcharts.com/highmaps/colorAxis.stops
     */
    stops?: Array<[number, ColorString]>;
    /**
     * (Highcharts, Highstock, Gantt) The amount of ticks to draw on the axis.
     * This opens up for aligning the ticks of multiple charts or panes within a
     * chart. This option overrides the `tickPixelInterval` option.
     *
     * This option only has an effect on linear axes. Datetime, logarithmic or
     * category axes are not affected.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.tickAmount
     * @see https://api.highcharts.com/highstock/colorAxis.tickAmount
     * @see https://api.highcharts.com/gantt/colorAxis.tickAmount
     */
    tickAmount?: number;
    /**
     * (Highcharts, Highmaps) Color for the main tick marks.
     *
     * In styled mode, the stroke is given in the `.highcharts-tick` class.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.tickColor
     * @see https://api.highcharts.com/highmaps/colorAxis.tickColor
     */
    tickColor?: ColorString;
    /**
     * (Highcharts, Highmaps) The interval of the tick marks in axis units. When
     * `null`, the tick interval is computed to approximately follow the
     * `tickPixelInterval`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.tickInterval
     * @see https://api.highcharts.com/highmaps/colorAxis.tickInterval
     */
    tickInterval?: number;
    /**
     * (Highcharts, Highmaps) The pixel length of the main tick marks on the
     * color axis.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.tickLength
     * @see https://api.highcharts.com/highmaps/colorAxis.tickLength
     */
    tickLength?: number;
    /**
     * (Highcharts, Gantt) For categorized axes only. If `on` the tick mark is
     * placed in the center of the category, if `between` the tick mark is
     * placed between categories. The default is `between` if the `tickInterval`
     * is 1, else `on`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.tickmarkPlacement
     * @see https://api.highcharts.com/gantt/colorAxis.tickmarkPlacement
     */
    tickmarkPlacement?: ("between"|"on");
    /**
     * (Highcharts, Highmaps) If tickInterval is `null` this option sets the
     * approximate pixel interval of the tick marks.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.tickPixelInterval
     * @see https://api.highcharts.com/highmaps/colorAxis.tickPixelInterval
     */
    tickPixelInterval?: number;
    /**
     * (Highcharts, Highmaps) The position of the major tick marks relative to
     * the axis line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.tickPosition
     * @see https://api.highcharts.com/highmaps/colorAxis.tickPosition
     */
    tickPosition?: ("inside"|"outside");
    /**
     * (Highcharts, Highmaps) A callback function returning array defining where
     * the ticks are laid out on the axis. This overrides the default behaviour
     * of tickPixelInterval and tickInterval. The automatic tick positions are
     * accessible through `this.tickPositions` and can be modified by the
     * callback.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.tickPositioner
     * @see https://api.highcharts.com/highmaps/colorAxis.tickPositioner
     */
    tickPositioner?: AxisTickPositionerCallbackFunction;
    /**
     * (Highcharts, Highmaps) An array defining where the ticks are laid out on
     * the axis. This overrides the default behaviour of tickPixelInterval and
     * tickInterval.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.tickPositions
     * @see https://api.highcharts.com/highmaps/colorAxis.tickPositions
     */
    tickPositions?: Array<number>;
    /**
     * (Highcharts, Highmaps) The pixel width of the major tick marks.
     *
     * In styled mode, the stroke width is given in the `.highcharts-tick`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.tickWidth
     * @see https://api.highcharts.com/highmaps/colorAxis.tickWidth
     */
    tickWidth?: number;
    /**
     * (Highcharts, Highmaps) The type of interpolation to use for the color
     * axis. Can be `linear` or `logarithmic`.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.type
     * @see https://api.highcharts.com/highmaps/colorAxis.type
     */
    type?: ("linear"|"logarithmic");
    /**
     * (Highcharts, Gantt) Applies only when the axis `type` is `category`. When
     * `uniqueNames` is true, points are placed on the X axis according to their
     * names. If the same point name is repeated in the same or another series,
     * the point is placed on the same X position as other points of the same
     * name. When `uniqueNames` is false, the points are laid out in increasing
     * X positions regardless of their names, and the X axis category will take
     * the name of the last point in each position.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.uniqueNames
     * @see https://api.highcharts.com/gantt/colorAxis.uniqueNames
     */
    uniqueNames?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Datetime axis only. An array determining
     * what time intervals the ticks are allowed to fall on. Each array item is
     * an array where the first value is the time unit and the second value
     * another array of allowed multiples. Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.units
     * @see https://api.highcharts.com/highstock/colorAxis.units
     * @see https://api.highcharts.com/gantt/colorAxis.units
     */
    units?: Array<[string, (Array<number>|null)]>;
    /**
     * (Highcharts, Highstock, Gantt) Whether axis, including axis title, line,
     * ticks and labels, should be visible.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis.visible
     * @see https://api.highcharts.com/highstock/colorAxis.visible
     * @see https://api.highcharts.com/gantt/colorAxis.visible
     */
    visible?: boolean;
}
/**
 * (Highstock) An optional scrollbar to display on the X axis in response to
 * limiting the minimum and maximum of the axis values.
 *
 * In styled mode, all the presentational options for the scrollbar are replaced
 * by the classes `.highcharts-scrollbar-thumb`, `.highcharts-scrollbar-arrow`,
 * `.highcharts-scrollbar-button`, `.highcharts-scrollbar-rifles` and
 * `.highcharts-scrollbar-track`.
 *
 * @see https://api.highcharts.com/highstock/colorAxis.scrollbar
 */
export interface ColorAxisScrollbarOptions {
    /**
     * (Highstock) The background color of the scrollbar itself.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.barBackgroundColor
     */
    barBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the scrollbar's border.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.barBorderColor
     */
    barBorderColor?: ColorString;
    /**
     * (Highstock) The border rounding radius of the bar.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.barBorderRadius
     */
    barBorderRadius?: number;
    /**
     * (Highstock) The width of the bar's border.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.barBorderWidth
     */
    barBorderWidth?: number;
    /**
     * (Highstock) The color of the small arrow inside the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.buttonArrowColor
     */
    buttonArrowColor?: ColorString;
    /**
     * (Highstock) The color of scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.buttonBackgroundColor
     */
    buttonBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the border of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.buttonBorderColor
     */
    buttonBorderColor?: ColorString;
    /**
     * (Highstock) The corner radius of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.buttonBorderRadius
     */
    buttonBorderRadius?: number;
    /**
     * (Highstock) The border width of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.buttonBorderWidth
     */
    buttonBorderWidth?: number;
    /**
     * (Highstock) Enable or disable the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The height of the scrollbar. The height also applies to the
     * width of the scroll arrows so that they are always squares. Defaults to
     * 20 for touch devices and 14 for mouse devices.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.height
     */
    height?: number;
    /**
     * (Highstock) Whether to redraw the main chart as the scrollbar or the
     * navigator zoomed window is moved. Defaults to `true` for modern browsers
     * and `false` for legacy IE browsers as well as mobile devices.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.liveRedraw
     */
    liveRedraw?: boolean;
    /**
     * (Highstock) The margin between the scrollbar and its axis when the
     * scrollbar is applied directly to an axis.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.margin
     */
    margin?: number;
    /**
     * (Highstock) The minimum width of the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.minWidth
     */
    minWidth?: number;
    /**
     * (Highstock) The color of the small rifles in the middle of the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.rifleColor
     */
    rifleColor?: ColorString;
    /**
     * (Highstock) Whether to show or hide the scrollbar when the scrolled
     * content is zoomed out to it full extent.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.showFull
     */
    showFull?: boolean;
    step?: number;
    /**
     * (Highstock) The color of the track background.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.trackBackgroundColor
     */
    trackBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.trackBorderColor
     */
    trackBorderColor?: ColorString;
    /**
     * (Highstock) The corner radius of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.trackBorderRadius
     */
    trackBorderRadius?: number;
    /**
     * (Highstock) The width of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.trackBorderWidth
     */
    trackBorderWidth?: number;
    /**
     * (Highstock) The z index of the scrollbar group.
     *
     * @see https://api.highcharts.com/highstock/colorAxis.scrollbar.zIndex
     */
    zIndex?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/connectors.endMarker
 */
export interface ConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/connectors.marker
 */
export interface ConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) The Pathfinder module allows you to define connections between any
 * two points, represented as lines - optionally with markers for the start
 * and/or end points. Multiple algorithms are available for calculating how the
 * connecting lines are drawn.
 *
 * Connector functionality requires Highcharts Gantt to be loaded. In Gantt
 * charts, the connectors are used to draw dependencies between tasks.
 *
 * @see https://api.highcharts.com/gantt/connectors
 */
export interface ConnectorsOptions {
    /**
     * (Gantt) Set the default pathfinder margin to use, in pixels. Some
     * Pathfinder algorithms attempt to avoid obstacles, such as other points in
     * the chart. These algorithms use this margin to determine how close lines
     * can be to an obstacle. The default is to compute this automatically from
     * the size of the obstacles in the chart.
     *
     * To draw connecting lines close to existing points, set this to a low
     * number. For more space around existing points, set this number higher.
     *
     * @see https://api.highcharts.com/gantt/connectors.algorithmMargin
     */
    algorithmMargin?: number;
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Enable connectors for this chart. Requires Highcharts Gantt.
     *
     * @see https://api.highcharts.com/gantt/connectors.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/connectors.endMarker
     */
    endMarker?: ConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/connectors.marker
     */
    marker?: ConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker
     */
    startMarker?: ConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/connectors.startMarker
 */
export interface ConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Highchart by default puts a credits
 * label in the lower right corner of the chart. This can be changed using these
 * options.
 *
 * @see https://api.highcharts.com/highcharts/credits
 * @see https://api.highcharts.com/highstock/credits
 * @see https://api.highcharts.com/highmaps/credits
 * @see https://api.highcharts.com/gantt/credits
 */
export interface CreditsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to show the credits
     * text.
     *
     * @see https://api.highcharts.com/highcharts/credits.enabled
     * @see https://api.highcharts.com/highstock/credits.enabled
     * @see https://api.highcharts.com/highmaps/credits.enabled
     * @see https://api.highcharts.com/gantt/credits.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The URL for the credits label.
     *
     * @see https://api.highcharts.com/highcharts/credits.href
     * @see https://api.highcharts.com/highstock/credits.href
     * @see https://api.highcharts.com/highmaps/credits.href
     * @see https://api.highcharts.com/gantt/credits.href
     */
    href?: string;
    /**
     * (Highmaps) Credits for map source to be concatenated with conventional
     * credit text. By default this is a format string that collects copyright
     * information from the map if available.
     *
     * @see https://api.highcharts.com/highmaps/credits.mapText
     */
    mapText?: string;
    /**
     * (Highmaps) Detailed credits for map source to be displayed on hover of
     * credits text. By default this is a format string that collects copyright
     * information from the map if available.
     *
     * @see https://api.highcharts.com/highmaps/credits.mapTextFull
     */
    mapTextFull?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Position configuration for the
     * credits label.
     *
     * @see https://api.highcharts.com/highcharts/credits.position
     * @see https://api.highcharts.com/highstock/credits.position
     * @see https://api.highcharts.com/highmaps/credits.position
     * @see https://api.highcharts.com/gantt/credits.position
     */
    position?: CreditsPositionOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the credits
     * label.
     *
     * @see https://api.highcharts.com/highcharts/credits.style
     * @see https://api.highcharts.com/highstock/credits.style
     * @see https://api.highcharts.com/highmaps/credits.style
     * @see https://api.highcharts.com/gantt/credits.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The text for the credits label.
     *
     * @see https://api.highcharts.com/highcharts/credits.text
     * @see https://api.highcharts.com/highstock/credits.text
     * @see https://api.highcharts.com/highmaps/credits.text
     * @see https://api.highcharts.com/gantt/credits.text
     */
    text?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Position configuration for the
 * credits label.
 *
 * @see https://api.highcharts.com/highcharts/credits.position
 * @see https://api.highcharts.com/highstock/credits.position
 * @see https://api.highcharts.com/highmaps/credits.position
 * @see https://api.highcharts.com/gantt/credits.position
 */
export interface CreditsPositionOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Horizontal alignment of the
     * credits.
     *
     * @see https://api.highcharts.com/highcharts/credits.position.align
     * @see https://api.highcharts.com/highstock/credits.position.align
     * @see https://api.highcharts.com/highmaps/credits.position.align
     * @see https://api.highcharts.com/gantt/credits.position.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Vertical alignment of the
     * credits.
     *
     * @see https://api.highcharts.com/highcharts/credits.position.verticalAlign
     * @see https://api.highcharts.com/highstock/credits.position.verticalAlign
     * @see https://api.highcharts.com/highmaps/credits.position.verticalAlign
     * @see https://api.highcharts.com/gantt/credits.position.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Horizontal pixel offset of the
     * credits.
     *
     * @see https://api.highcharts.com/highcharts/credits.position.x
     * @see https://api.highcharts.com/highstock/credits.position.x
     * @see https://api.highcharts.com/highmaps/credits.position.x
     * @see https://api.highcharts.com/gantt/credits.position.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Vertical pixel offset of the
     * credits.
     *
     * @see https://api.highcharts.com/highcharts/credits.position.y
     * @see https://api.highcharts.com/highstock/credits.position.y
     * @see https://api.highcharts.com/highmaps/credits.position.y
     * @see https://api.highcharts.com/gantt/credits.position.y
     */
    y?: number;
}
/**
 * A style object with camel case property names to define visual appearance of
 * a SVG element or HTML element. The properties can be whatever styles are
 * supported on the given SVG or HTML element.
 */
export interface CSSObject {
    [key: string]: (boolean|number|string|undefined);
    /**
     * Background style for the element.
     */
    background?: string;
    /**
     * Background color of the element.
     */
    backgroundColor?: ColorString;
    /**
     * Border style for the element.
     */
    border?: string;
    /**
     * Radius of the element border.
     */
    borderRadius?: number;
    /**
     * Color used in the element. The "contrast" option is a Highcharts custom
     * property that results in black or white, depending on the background of
     * the element.
     */
    color?: ("contrast"|ColorString);
    /**
     * Style of the mouse cursor when resting over the element.
     */
    cursor?: CursorType;
    /**
     * Font family of the element text. Multiple values have to be in decreasing
     * preference order and separated by comma.
     */
    fontFamily?: string;
    /**
     * Font size of the element text.
     */
    fontSize?: string;
    /**
     * Font weight of the element text.
     */
    fontWeight?: string;
    /**
     * Height of the element.
     */
    height?: number;
    /**
     * Width of the element border.
     */
    lineWidth?: number;
    /**
     * Opacity of the element.
     */
    opacity?: number;
    /**
     * Space around the element content.
     */
    padding?: string;
    /**
     * Behaviour of the element when the mouse cursor rests over it.
     */
    pointerEvents?: string;
    /**
     * Positioning of the element.
     */
    position?: string;
    /**
     * Alignment of the element text.
     */
    textAlign?: string;
    /**
     * Additional decoration of the element text.
     */
    textDecoration?: string;
    /**
     * Outline style of the element text.
     */
    textOutline?: string;
    /**
     * Line break style of the element text. Highcharts SVG elements support
     * `ellipsis` when a `width` is set.
     */
    textOverflow?: string;
    /**
     * Top spacing of the element relative to the parent element.
     */
    top?: string;
    /**
     * Animated transition of selected element properties.
     */
    transition?: string;
    /**
     * Line break style of the element text.
     */
    whiteSpace?: string;
    /**
     * Width of the element.
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The Data module provides a
 * simplified interface for adding data to a chart from sources like CVS, HTML
 * tables or grid views. See also the tutorial article on the Data module.
 *
 * It requires the `modules/data.js` file to be loaded.
 *
 * Please note that the default way of adding data in Highcharts, without the
 * need of a module, is through the series.data option.
 *
 * @see https://api.highcharts.com/highcharts/data
 * @see https://api.highcharts.com/highstock/data
 * @see https://api.highcharts.com/highmaps/data
 * @see https://api.highcharts.com/gantt/data
 */
export interface DataOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A callback function to modify
     * the CSV before parsing it. Return the modified string.
     *
     * @see https://api.highcharts.com/highcharts/data.beforeParse
     * @see https://api.highcharts.com/highstock/data.beforeParse
     * @see https://api.highcharts.com/highmaps/data.beforeParse
     * @see https://api.highcharts.com/gantt/data.beforeParse
     */
    beforeParse?: DataBeforeParseCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A two-dimensional array
     * representing the input data on tabular form. This input can be used when
     * the data is already parsed, for example from a grid view component. Each
     * cell can be a string or number. If not switchRowsAndColumns is set, the
     * columns are interpreted as series.
     *
     * @see https://api.highcharts.com/highcharts/data.columns
     * @see https://api.highcharts.com/highstock/data.columns
     * @see https://api.highcharts.com/highmaps/data.columns
     * @see https://api.highcharts.com/gantt/data.columns
     */
    columns?: Array<Array<any>>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A URL to a remote JSON dataset,
     * structured as a column array. Will be fetched when the chart is created
     * using Ajax.
     *
     * @see https://api.highcharts.com/highcharts/data.columnsURL
     * @see https://api.highcharts.com/highstock/data.columnsURL
     * @see https://api.highcharts.com/highmaps/data.columnsURL
     * @see https://api.highcharts.com/gantt/data.columnsURL
     */
    columnsURL?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The callback that is evaluated
     * when the data is finished loading, optionally from an external source,
     * and parsed. The first argument passed is a finished chart options object,
     * containing the series. These options can be extended with additional
     * options and passed directly to the chart constructor.
     *
     * @see https://api.highcharts.com/highcharts/data.complete
     * @see https://api.highcharts.com/highstock/data.complete
     * @see https://api.highcharts.com/highmaps/data.complete
     * @see https://api.highcharts.com/gantt/data.complete
     */
    complete?: DataCompleteCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A comma delimited string to be
     * parsed. Related options are startRow, endRow, startColumn and endColumn
     * to delimit what part of the table is used. The lineDelimiter and
     * itemDelimiter options define the CSV delimiter formats.
     *
     * The built-in CSV parser doesn't support all flavours of CSV, so in some
     * cases it may be necessary to use an external CSV parser. See this example
     * of parsing CSV through the MIT licensed Papa Parse library.
     *
     * @see https://api.highcharts.com/highcharts/data.csv
     * @see https://api.highcharts.com/highstock/data.csv
     * @see https://api.highcharts.com/highmaps/data.csv
     * @see https://api.highcharts.com/gantt/data.csv
     */
    csv?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An URL to a remote CSV dataset.
     * Will be fetched when the chart is created using Ajax.
     *
     * @see https://api.highcharts.com/highcharts/data.csvURL
     * @see https://api.highcharts.com/highstock/data.csvURL
     * @see https://api.highcharts.com/highmaps/data.csvURL
     * @see https://api.highcharts.com/gantt/data.csvURL
     */
    csvURL?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Sets the refresh rate for data
     * polling when importing remote dataset by setting data.csvURL,
     * data.rowsURL, data.columnsURL, or data.googleSpreadsheetKey.
     *
     * Note that polling must be enabled by setting data.enablePolling to true.
     *
     * The value is the number of seconds between pollings. It cannot be set to
     * less than 1 second.
     *
     * @see https://api.highcharts.com/highcharts/data.dataRefreshRate
     * @see https://api.highcharts.com/highstock/data.dataRefreshRate
     * @see https://api.highcharts.com/highmaps/data.dataRefreshRate
     * @see https://api.highcharts.com/gantt/data.dataRefreshRate
     */
    dataRefreshRate?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Which of the predefined date
     * formats in Date.prototype.dateFormats to use to parse date values.
     * Defaults to a best guess based on what format gives valid and ordered
     * dates. Valid options include: `YYYY/mm/dd`, `dd/mm/YYYY`, `mm/dd/YYYY`,
     * `dd/mm/YY`, `mm/dd/YY`.
     *
     * @see https://api.highcharts.com/highcharts/data.dateFormat
     * @see https://api.highcharts.com/highstock/data.dateFormat
     * @see https://api.highcharts.com/highmaps/data.dateFormat
     * @see https://api.highcharts.com/gantt/data.dateFormat
     */
    dateFormat?: ("dd/mm/YY"|"dd/mm/YYYY"|"dd/mm/YYYY"|"mm/dd/YY"|"mm/dd/YYYY"|"YYYY/mm/dd");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The decimal point used for
     * parsing numbers in the CSV.
     *
     * If both this and data.delimiter is set to `undefined`, the parser will
     * attempt to deduce the decimal point automatically.
     *
     * @see https://api.highcharts.com/highcharts/data.decimalPoint
     * @see https://api.highcharts.com/highstock/data.decimalPoint
     * @see https://api.highcharts.com/highmaps/data.decimalPoint
     * @see https://api.highcharts.com/gantt/data.decimalPoint
     */
    decimalPoint?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enables automatic refetching of
     * remote datasets every _n_ seconds (defined by setting
     * data.dataRefreshRate).
     *
     * Only works when either data.csvURL, data.rowsURL, data.columnsURL, or
     * data.googleSpreadsheetKey.
     *
     * @see https://api.highcharts.com/highcharts/data.enablePolling
     * @see https://api.highcharts.com/highstock/data.enablePolling
     * @see https://api.highcharts.com/highmaps/data.enablePolling
     * @see https://api.highcharts.com/gantt/data.enablePolling
     */
    enablePolling?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) In tabular input data, the last
     * column (indexed by 0) to use. Defaults to the last column containing
     * data.
     *
     * @see https://api.highcharts.com/highcharts/data.endColumn
     * @see https://api.highcharts.com/highstock/data.endColumn
     * @see https://api.highcharts.com/highmaps/data.endColumn
     * @see https://api.highcharts.com/gantt/data.endColumn
     */
    endColumn?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) In tabular input data, the last
     * row (indexed by 0) to use. Defaults to the last row containing data.
     *
     * @see https://api.highcharts.com/highcharts/data.endRow
     * @see https://api.highcharts.com/highstock/data.endRow
     * @see https://api.highcharts.com/highmaps/data.endRow
     * @see https://api.highcharts.com/gantt/data.endRow
     */
    endRow?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the first row in the data
     * set as series names.
     *
     * @see https://api.highcharts.com/highcharts/data.firstRowAsNames
     * @see https://api.highcharts.com/highstock/data.firstRowAsNames
     * @see https://api.highcharts.com/gantt/data.firstRowAsNames
     */
    firstRowAsNames?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The key for a Google Spreadsheet
     * to load. See general information on GS.
     *
     * @see https://api.highcharts.com/highcharts/data.googleSpreadsheetKey
     * @see https://api.highcharts.com/highstock/data.googleSpreadsheetKey
     * @see https://api.highcharts.com/highmaps/data.googleSpreadsheetKey
     * @see https://api.highcharts.com/gantt/data.googleSpreadsheetKey
     */
    googleSpreadsheetKey?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Google Spreadsheet worksheet
     * to use in combination with googleSpreadsheetKey. The available id's from
     * your sheet can be read from
     * `https://spreadsheets.google.com/feeds/worksheets/{key}/public/basic`.
     *
     * @see https://api.highcharts.com/highcharts/data.googleSpreadsheetWorksheet
     * @see https://api.highcharts.com/highstock/data.googleSpreadsheetWorksheet
     * @see https://api.highcharts.com/highmaps/data.googleSpreadsheetWorksheet
     * @see https://api.highcharts.com/gantt/data.googleSpreadsheetWorksheet
     */
    googleSpreadsheetWorksheet?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Item or cell delimiter for
     * parsing CSV. Defaults to the tab character `\t` if a tab character is
     * found in the CSV string, if not it defaults to `,`.
     *
     * If this is set to false or undefined, the parser will attempt to deduce
     * the delimiter automatically.
     *
     * @see https://api.highcharts.com/highcharts/data.itemDelimiter
     * @see https://api.highcharts.com/highstock/data.itemDelimiter
     * @see https://api.highcharts.com/highmaps/data.itemDelimiter
     * @see https://api.highcharts.com/gantt/data.itemDelimiter
     */
    itemDelimiter?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Line delimiter for parsing CSV.
     *
     * @see https://api.highcharts.com/highcharts/data.lineDelimiter
     * @see https://api.highcharts.com/highstock/data.lineDelimiter
     * @see https://api.highcharts.com/highmaps/data.lineDelimiter
     * @see https://api.highcharts.com/gantt/data.lineDelimiter
     */
    lineDelimiter?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A callback function to access
     * the parsed columns, the two-dimentional input data array directly, before
     * they are interpreted into series data and categories. Return `false` to
     * stop completion, or call `this.complete()` to continue async.
     *
     * @see https://api.highcharts.com/highcharts/data.parsed
     * @see https://api.highcharts.com/highstock/data.parsed
     * @see https://api.highcharts.com/highmaps/data.parsed
     * @see https://api.highcharts.com/gantt/data.parsed
     */
    parsed?: DataParsedCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A callback function to parse
     * string representations of dates into JavaScript timestamps. Should return
     * an integer timestamp on success.
     *
     * @see https://api.highcharts.com/highcharts/data.parseDate
     * @see https://api.highcharts.com/highstock/data.parseDate
     * @see https://api.highcharts.com/highmaps/data.parseDate
     * @see https://api.highcharts.com/gantt/data.parseDate
     */
    parseDate?: DataParseDateCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The same as the columns input
     * option, but defining rows intead of columns.
     *
     * @see https://api.highcharts.com/highcharts/data.rows
     * @see https://api.highcharts.com/highstock/data.rows
     * @see https://api.highcharts.com/highmaps/data.rows
     * @see https://api.highcharts.com/gantt/data.rows
     */
    rows?: Array<Array<any>>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A URL to a remote JSON dataset,
     * structured as a row array. Will be fetched when the chart is created
     * using Ajax.
     *
     * @see https://api.highcharts.com/highcharts/data.rowsURL
     * @see https://api.highcharts.com/highstock/data.rowsURL
     * @see https://api.highcharts.com/highmaps/data.rowsURL
     * @see https://api.highcharts.com/gantt/data.rowsURL
     */
    rowsURL?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array containing dictionaries
     * for each series. A dictionary exists of Point property names as the key
     * and the CSV column index as the value.
     *
     * @see https://api.highcharts.com/highcharts/data.seriesMapping
     * @see https://api.highcharts.com/highstock/data.seriesMapping
     * @see https://api.highcharts.com/highmaps/data.seriesMapping
     * @see https://api.highcharts.com/gantt/data.seriesMapping
     */
    seriesMapping?: Array<Dictionary<number>>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) In tabular input data, the first
     * column (indexed by 0) to use.
     *
     * @see https://api.highcharts.com/highcharts/data.startColumn
     * @see https://api.highcharts.com/highstock/data.startColumn
     * @see https://api.highcharts.com/highmaps/data.startColumn
     * @see https://api.highcharts.com/gantt/data.startColumn
     */
    startColumn?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) In tabular input data, the first
     * row (indexed by 0) to use.
     *
     * @see https://api.highcharts.com/highcharts/data.startRow
     * @see https://api.highcharts.com/highstock/data.startRow
     * @see https://api.highcharts.com/highmaps/data.startRow
     * @see https://api.highcharts.com/gantt/data.startRow
     */
    startRow?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Switch rows and columns of the
     * input data, so that `this.columns` effectively becomes the rows of the
     * data set, and the rows are interpreted as series.
     *
     * @see https://api.highcharts.com/highcharts/data.switchRowsAndColumns
     * @see https://api.highcharts.com/highstock/data.switchRowsAndColumns
     * @see https://api.highcharts.com/highmaps/data.switchRowsAndColumns
     * @see https://api.highcharts.com/gantt/data.switchRowsAndColumns
     */
    switchRowsAndColumns?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An HTML table or the id of such
     * to be parsed as input data. Related options are `startRow`, `endRow`,
     * `startColumn` and `endColumn` to delimit what part of the table is used.
     *
     * @see https://api.highcharts.com/highcharts/data.table
     * @see https://api.highcharts.com/highstock/data.table
     * @see https://api.highcharts.com/highmaps/data.table
     * @see https://api.highcharts.com/gantt/data.table
     */
    table?: (string|HTMLElement);
}
/**
 * Generic dictionary in TypeScript notation.
 */
export interface Dictionary<T> {
    [key: string]: T;
}
/**
 * (Highcharts, Highmaps) Additional styles to apply to the data label of a
 * point that has drilldown data. By default it is underlined and blue to invite
 * to interaction.
 *
 * In styled mode, active data label styles can be applied with the
 * `.highcharts-drilldown-data-label` class.
 *
 * @see https://api.highcharts.com/highcharts/drilldown.activeDataLabelStyle
 * @see https://api.highcharts.com/highmaps/drilldown.activeDataLabelStyle
 */
export interface DrilldownActiveDataLabelStyleOptions {
    color?: string;
    cursor?: string;
    fontWeight?: string;
    textDecoration?: string;
}
/**
 * (Highcharts, Highmaps) Options for the drill up button that appears when
 * drilling down on a series. The text for the button is defined in
 * lang.drillUpText.
 *
 * @see https://api.highcharts.com/highcharts/drilldown.drillUpButton
 * @see https://api.highcharts.com/highmaps/drilldown.drillUpButton
 */
export interface DrilldownDrillUpButtonOptions {
    /**
     * (Highcharts, Highmaps) Positioning options for the button within the
     * `relativeTo` box. Available properties are `x`, `y`, `align` and
     * `verticalAlign`.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.drillUpButton.position
     * @see https://api.highcharts.com/highmaps/drilldown.drillUpButton.position
     */
    position?: DrilldownDrillUpButtonPositionOptions;
    /**
     * (Highcharts, Highmaps) What box to align the button to. Can be either
     * `plotBox` or `spacingBox`.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.drillUpButton.relativeTo
     * @see https://api.highcharts.com/highmaps/drilldown.drillUpButton.relativeTo
     */
    relativeTo?: ("plotBox"|"spacingBox");
    /**
     * (Highcharts, Highmaps) A collection of attributes for the button. The
     * object takes SVG attributes like `fill`, `stroke`, `stroke-width` or `r`,
     * the border radius. The theme also supports `style`, a collection of CSS
     * properties for the text. Equivalent attributes for the hover state are
     * given in `theme.states.hover`.
     *
     * In styled mode, drill-up button styles can be applied with the
     * `.highcharts-drillup-button` class.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.drillUpButton.theme
     * @see https://api.highcharts.com/highmaps/drilldown.drillUpButton.theme
     */
    theme?: object;
}
/**
 * (Highcharts, Highmaps) Positioning options for the button within the
 * `relativeTo` box. Available properties are `x`, `y`, `align` and
 * `verticalAlign`.
 *
 * @see https://api.highcharts.com/highcharts/drilldown.drillUpButton.position
 * @see https://api.highcharts.com/highmaps/drilldown.drillUpButton.position
 */
export interface DrilldownDrillUpButtonPositionOptions {
    /**
     * (Highcharts, Highmaps) Horizontal alignment.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.drillUpButton.position.align
     * @see https://api.highcharts.com/highmaps/drilldown.drillUpButton.position.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highmaps) Vertical alignment of the button.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.drillUpButton.position.verticalAlign
     * @see https://api.highcharts.com/highmaps/drilldown.drillUpButton.position.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highmaps) The X offset of the button.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.drillUpButton.position.x
     * @see https://api.highcharts.com/highmaps/drilldown.drillUpButton.position.x
     */
    x?: number;
    /**
     * (Highcharts, Highmaps) The Y offset of the button.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.drillUpButton.position.y
     * @see https://api.highcharts.com/highmaps/drilldown.drillUpButton.position.y
     */
    y?: number;
}
/**
 * The event arguments when a drilldown point is clicked.
 */
export interface DrilldownEventObject {
    /**
     * If a category label was clicked, which index.
     */
    category?: number;
    /**
     * The original browser event (usually click) that triggered the drilldown.
     */
    originalEvent?: Event;
    /**
     * The originating point.
     */
    point: Point;
    /**
     * If a category label was clicked, this array holds all points corresponing
     * to the category. Otherwise it is set to false.
     */
    points?: (boolean|Array<Point>);
    /**
     * Prevents the default behaviour of the event.
     */
    preventDefault: () => void;
    /**
     * Options for the new series. If the event is utilized for async drilldown,
     * the seriesOptions are not added, but rather loaded async.
     */
    seriesOptions?: SeriesOptionsType;
    /**
     * The event target.
     */
    target: Chart;
    /**
     * The event type.
     */
    type: "drilldown";
}
/**
 * (Highcharts, Highstock, Highmaps) Options for drill down, the concept of
 * inspecting increasingly high resolution data through clicking on chart items
 * like columns or pie slices.
 *
 * The drilldown feature requires the drilldown.js file to be loaded, found in
 * the modules directory of the download package, or online at
 * code.highcharts.com/modules/drilldown.js.
 *
 * @see https://api.highcharts.com/highcharts/drilldown
 * @see https://api.highcharts.com/highstock/drilldown
 * @see https://api.highcharts.com/highmaps/drilldown
 */
export interface DrilldownOptions {
    /**
     * (Highcharts, Highmaps) Additional styles to apply to the X axis label for
     * a point that has drilldown data. By default it is underlined and blue to
     * invite to interaction.
     *
     * In styled mode, active label styles can be set with the
     * `.highcharts-drilldown-axis-label` class.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.activeAxisLabelStyle
     * @see https://api.highcharts.com/highmaps/drilldown.activeAxisLabelStyle
     */
    activeAxisLabelStyle?: CSSObject;
    /**
     * (Highcharts, Highmaps) Additional styles to apply to the data label of a
     * point that has drilldown data. By default it is underlined and blue to
     * invite to interaction.
     *
     * In styled mode, active data label styles can be applied with the
     * `.highcharts-drilldown-data-label` class.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.activeDataLabelStyle
     * @see https://api.highcharts.com/highmaps/drilldown.activeDataLabelStyle
     */
    activeDataLabelStyle?: (CSSObject|DrilldownActiveDataLabelStyleOptions);
    /**
     * (Highcharts) When this option is false, clicking a single point will
     * drill down all points in the same category, equivalent to clicking the X
     * axis label.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.allowPointDrilldown
     */
    allowPointDrilldown?: boolean;
    /**
     * (Highcharts, Highmaps) Set the animation for all drilldown animations.
     * Animation of a drilldown occurs when drilling between a column point and
     * a column series, or a pie slice and a full pie series. Drilldown can
     * still be used between series and points of different types, but animation
     * will not occur.
     *
     * The animation can either be set as a boolean or a configuration object.
     * If `true`, it will use the 'swing' jQuery easing and a duration of 500
     * ms. If used as a configuration object, the following properties are
     * supported:
     *
     * - `duration`: The duration of the animation in milliseconds.
     *
     * - `easing`: A string reference to an easing function set on the `Math`
     * object. See the easing demo.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.animation
     * @see https://api.highcharts.com/highmaps/drilldown.animation
     */
    animation?: (boolean|AnimationOptionsObject);
    /**
     * (Highcharts, Highmaps) Options for the drill up button that appears when
     * drilling down on a series. The text for the button is defined in
     * lang.drillUpText.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.drillUpButton
     * @see https://api.highcharts.com/highmaps/drilldown.drillUpButton
     */
    drillUpButton?: DrilldownDrillUpButtonOptions;
    /**
     * (Highcharts, Highmaps) An array of series configurations for the drill
     * down. Each series configuration uses the same syntax as the series option
     * set. These drilldown series are hidden by default. The drilldown series
     * is linked to the parent series' point by its `id`.
     *
     * @see https://api.highcharts.com/highcharts/drilldown.series
     * @see https://api.highcharts.com/highmaps/drilldown.series
     */
    series?: Array<SeriesOptionsType>;
}
/**
 * The event arguments when all the series have been drilled up.
 */
export interface DrillupAllEventObject {
    /**
     * Prevents the default behaviour of the event.
     */
    preventDefault: () => void;
    /**
     * The event target.
     */
    target: Chart;
    /**
     * The event type.
     */
    type: "drillupall";
}
/**
 * The event arguments when drilling up from a drilldown series.
 */
export interface DrillupEventObject {
    /**
     * Prevents the default behaviour of the event.
     */
    preventDefault: () => void;
    /**
     * Options for the new series.
     */
    seriesOptions?: SeriesOptionsType;
    /**
     * The event target.
     */
    target: Chart;
    /**
     * The event type.
     */
    type: "drillup";
}
/**
 * The event options for adding function callback.
 */
export interface EventOptionsObject {
    /**
     * The order the event handler should be called. This opens for having one
     * handler be called before another, independent of in which order they were
     * added.
     */
    order: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the export button.
 *
 * In styled mode, export button styles can be applied with the
 * `.highcharts-contextbutton` class.
 *
 * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton
 * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton
 * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton
 * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton
 */
export interface ExportingButtonsContextButtonOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This option is deprecated, use
     * titleKey instead.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton._titleKey
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton._titleKey
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton._titleKey
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton._titleKey
     */
    _titleKey?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the context
     * button.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.className
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.className
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.className
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to enable buttons.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.enabled
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.enabled
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.enabled
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the menu
     * appearing from the button.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.menuClassName
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.menuClassName
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.menuClassName
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.menuClassName
     */
    menuClassName?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A collection of strings pointing
     * to config options for the menu items. The config options are defined in
     * the `menuItemDefinitions` option.
     *
     * By default, there is the "Print" menu item plus one menu item for each of
     * the available export types.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.menuItems
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.menuItems
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.menuItems
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.menuItems
     */
    menuItems?: Array<string>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A click handler callback to use
     * on the button directly instead of the popup menu.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.onclick
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.onclick
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.onclick
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.onclick
     */
    onclick?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The symbol for the button.
     * Points to a definition function in the `Highcharts.Renderer.symbols`
     * collection. The default `exportIcon` function is part of the exporting
     * module. Possible values are "circle", "square", "diamond", "triangle",
     * "triangle-down", "menu", "menuball" or custom shape.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.symbol
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.symbol
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.symbol
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.symbol
     */
    symbol?: ("circle"|"diamond"|"menu"|"menuball"|"square"|"triangle"|"triangle-down"|"exportIcon");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) See
     * navigation.buttonOptions.symbolFill.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.symbolFill
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.symbolFill
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.symbolFill
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.symbolFill
     */
    symbolFill?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the symbol's stroke
     * or line.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.symbolStroke
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.symbolStroke
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.symbolStroke
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.symbolStroke
     */
    symbolStroke?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel stroke width of the
     * symbol on the button.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.symbolStrokeWidth
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.symbolStrokeWidth
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.symbolStrokeWidth
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.symbolStrokeWidth
     */
    symbolStrokeWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A text string to add to the
     * individual button.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.text
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.text
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.text
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A configuration object for the
     * button theme. The object accepts SVG properties like `stroke-width`,
     * `stroke` and `fill`. Tri-state button styles are supported by the
     * `states.hover` and `states.select` objects.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.theme
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.theme
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.theme
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.theme
     */
    theme?: ExportingButtonsContextButtonThemeOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The key to a lang option setting
     * that is used for the button's title tooltip. When the key is
     * `contextButtonTitle`, it refers to lang.contextButtonTitle that defaults
     * to "Chart context menu".
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.titleKey
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.titleKey
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.titleKey
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.titleKey
     */
    titleKey?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The horizontal position of the
     * button relative to the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.x
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.x
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.x
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical offset of the
     * button's position relative to its `verticalAlign`.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.y
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.y
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.y
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) A configuration object for the
 * button theme. The object accepts SVG properties like `stroke-width`, `stroke`
 * and `fill`. Tri-state button styles are supported by the `states.hover` and
 * `states.select` objects.
 *
 * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.theme
 * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.theme
 * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.theme
 * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.theme
 */
export interface ExportingButtonsContextButtonThemeOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The default fill exists only to
     * capture hover events.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.theme.fill
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.theme.fill
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.theme.fill
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.theme.fill
     */
    fill?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Padding for the button.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.theme.padding
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.theme.padding
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.theme.padding
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.theme.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Default stroke for the buttons.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton.theme.stroke
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton.theme.stroke
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton.theme.stroke
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton.theme.stroke
     */
    stroke?: ColorString;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the export related
 * buttons, print and export. In addition to the default buttons listed here,
 * custom buttons can be added. See navigation.buttonOptions for general
 * options.
 *
 * @see https://api.highcharts.com/highcharts/exporting.buttons
 * @see https://api.highcharts.com/highstock/exporting.buttons
 * @see https://api.highcharts.com/highmaps/exporting.buttons
 * @see https://api.highcharts.com/gantt/exporting.buttons
 */
export interface ExportingButtonsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the export button.
     *
     * In styled mode, export button styles can be applied with the
     * `.highcharts-contextbutton` class.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons.contextButton
     * @see https://api.highcharts.com/highstock/exporting.buttons.contextButton
     * @see https://api.highcharts.com/highmaps/exporting.buttons.contextButton
     * @see https://api.highcharts.com/gantt/exporting.buttons.contextButton
     */
    contextButton?: ExportingButtonsContextButtonOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for exporting data to CSV or
 * ExCel, or displaying the data in a HTML table or a JavaScript structure.
 * Requires the `export-data.js` module. This module adds data export options to
 * the export menu and provides functions like `Chart.getCSV`, `Chart.getTable`,
 * `Chart.getDataRows` and `Chart.viewData`.
 *
 * The XLS converter is limited and only creates a HTML string that is passed
 * for download, which works but creates a warning before opening. The
 * workaround for this is to use a third party XLSX converter, as demonstrated
 * in the sample below.
 *
 * @see https://api.highcharts.com/highcharts/exporting.csv
 * @see https://api.highcharts.com/highstock/exporting.csv
 * @see https://api.highcharts.com/highmaps/exporting.csv
 * @see https://api.highcharts.com/gantt/exporting.csv
 */
export interface ExportingCsvOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Formatter callback for the
     * column headers. Parameters are:
     *
     * - `item` - The series or axis object)
     *
     * - `key` - The point key, for example y or z
     *
     * - `keyLength` - The amount of value keys for this item, for example a
     * range series has the keys `low` and `high` so the key length is 2.
     *
     * If useMultiLevelHeaders is true, columnHeaderFormatter by default returns
     * an object with columnTitle and topLevelColumnTitle for each key. Columns
     * with the same topLevelColumnTitle have their titles merged into a single
     * cell with colspan for table/Excel export.
     *
     * If `useMultiLevelHeaders` is false, or for CSV export, it returns the
     * series name, followed by the key if there is more than one key.
     *
     * For the axis it returns the axis title or "Category" or "DateTime" by
     * default.
     *
     * Return `false` to use Highcharts' proposed header.
     *
     * @see https://api.highcharts.com/highcharts/exporting.csv.columnHeaderFormatter
     * @see https://api.highcharts.com/highstock/exporting.csv.columnHeaderFormatter
     * @see https://api.highcharts.com/highmaps/exporting.csv.columnHeaderFormatter
     * @see https://api.highcharts.com/gantt/exporting.csv.columnHeaderFormatter
     */
    columnHeaderFormatter?: (() => void|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Which date format to use for
     * exported dates on a datetime X axis. See `Highcharts.dateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/exporting.csv.dateFormat
     * @see https://api.highcharts.com/highstock/exporting.csv.dateFormat
     * @see https://api.highcharts.com/highmaps/exporting.csv.dateFormat
     * @see https://api.highcharts.com/gantt/exporting.csv.dateFormat
     */
    dateFormat?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Which decimal point to use for
     * exported CSV. Defaults to the same as the browser locale, typically `.`
     * (English) or `,` (German, French etc).
     *
     * @see https://api.highcharts.com/highcharts/exporting.csv.decimalPoint
     * @see https://api.highcharts.com/highstock/exporting.csv.decimalPoint
     * @see https://api.highcharts.com/highmaps/exporting.csv.decimalPoint
     * @see https://api.highcharts.com/gantt/exporting.csv.decimalPoint
     */
    decimalPoint?: (string|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The item delimiter in the
     * exported data. Use `;` for direct exporting to Excel. Defaults to a best
     * guess based on the browser locale. If the locale _decimal point_ is `,`,
     * the `itemDelimiter` defaults to `;`, otherwise the `itemDelimiter`
     * defaults to `,`.
     *
     * @see https://api.highcharts.com/highcharts/exporting.csv.itemDelimiter
     * @see https://api.highcharts.com/highstock/exporting.csv.itemDelimiter
     * @see https://api.highcharts.com/highmaps/exporting.csv.itemDelimiter
     * @see https://api.highcharts.com/gantt/exporting.csv.itemDelimiter
     */
    itemDelimiter?: (string|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line delimiter in the
     * exported data, defaults to a newline.
     *
     * @see https://api.highcharts.com/highcharts/exporting.csv.lineDelimiter
     * @see https://api.highcharts.com/highstock/exporting.csv.lineDelimiter
     * @see https://api.highcharts.com/highmaps/exporting.csv.lineDelimiter
     * @see https://api.highcharts.com/gantt/exporting.csv.lineDelimiter
     */
    lineDelimiter?: string;
}
/**
 * Definition for a menu item in the context menu.
 */
export interface ExportingMenuObject {
    /**
     * The click handler for the menu item.
     */
    onclick?: () => void;
    /**
     * Indicates a separator line instead of an item.
     */
    separator?: boolean;
    /**
     * The text for the menu item.
     */
    text?: string;
    /**
     * If internationalization is required, the key to a language string.
     */
    textKey?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the exporting module.
 * For an overview on the matter, see the docs.
 *
 * @see https://api.highcharts.com/highcharts/exporting
 * @see https://api.highcharts.com/highstock/exporting
 * @see https://api.highcharts.com/highmaps/exporting
 * @see https://api.highcharts.com/gantt/exporting
 */
export interface ExportingOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Experimental setting to allow
     * HTML inside the chart (added through the `useHTML` options), directly in
     * the exported image. This allows you to preserve complicated HTML
     * structures like tables or bi-directional text in exported charts.
     *
     * Disclaimer: The HTML is rendered in a `foreignObject` tag in the
     * generated SVG. The official export server is based on PhantomJS, which
     * supports this, but other SVG clients, like Batik, does not support it.
     * This also applies to downloaded SVG that you want to open in a desktop
     * client.
     *
     * @see https://api.highcharts.com/highcharts/exporting.allowHTML
     * @see https://api.highcharts.com/highstock/exporting.allowHTML
     * @see https://api.highcharts.com/highmaps/exporting.allowHTML
     * @see https://api.highcharts.com/gantt/exporting.allowHTML
     */
    allowHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the export related
     * buttons, print and export. In addition to the default buttons listed
     * here, custom buttons can be added. See navigation.buttonOptions for
     * general options.
     *
     * @see https://api.highcharts.com/highcharts/exporting.buttons
     * @see https://api.highcharts.com/highstock/exporting.buttons
     * @see https://api.highcharts.com/highmaps/exporting.buttons
     * @see https://api.highcharts.com/gantt/exporting.buttons
     */
    buttons?: (ExportingButtonsOptions|Dictionary<ExportingButtonsContextButtonOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Additional chart options to be
     * merged into an exported chart. For example, a common use case is to add
     * data labels to improve readability of the exported chart, or to add a
     * printer-friendly color scheme.
     *
     * @see https://api.highcharts.com/highcharts/exporting.chartOptions
     * @see https://api.highcharts.com/highstock/exporting.chartOptions
     * @see https://api.highcharts.com/highmaps/exporting.chartOptions
     * @see https://api.highcharts.com/gantt/exporting.chartOptions
     */
    chartOptions?: Options;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for exporting data to
     * CSV or ExCel, or displaying the data in a HTML table or a JavaScript
     * structure. Requires the `export-data.js` module. This module adds data
     * export options to the export menu and provides functions like
     * `Chart.getCSV`, `Chart.getTable`, `Chart.getDataRows` and
     * `Chart.viewData`.
     *
     * The XLS converter is limited and only creates a HTML string that is
     * passed for download, which works but creates a warning before opening.
     * The workaround for this is to use a third party XLSX converter, as
     * demonstrated in the sample below.
     *
     * @see https://api.highcharts.com/highcharts/exporting.csv
     * @see https://api.highcharts.com/highstock/exporting.csv
     * @see https://api.highcharts.com/highmaps/exporting.csv
     * @see https://api.highcharts.com/gantt/exporting.csv
     */
    csv?: ExportingCsvOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to enable the exporting
     * module. Disabling the module will hide the context button, but API
     * methods will still be available.
     *
     * @see https://api.highcharts.com/highcharts/exporting.enabled
     * @see https://api.highcharts.com/highstock/exporting.enabled
     * @see https://api.highcharts.com/highmaps/exporting.enabled
     * @see https://api.highcharts.com/gantt/exporting.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to call if the
     * offline-exporting module fails to export a chart on the client side, and
     * fallbackToExportServer is disabled. If left undefined, an exception is
     * thrown instead. Receives two parameters, the exporting options, and the
     * error from the module.
     *
     * @see https://api.highcharts.com/highcharts/exporting.error
     * @see https://api.highcharts.com/highstock/exporting.error
     * @see https://api.highcharts.com/highmaps/exporting.error
     * @see https://api.highcharts.com/gantt/exporting.error
     */
    error?: ExportingErrorCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether or not to fall back to
     * the export server if the offline-exporting module is unable to export the
     * chart on the client side. This happens for certain browsers, and certain
     * features (e.g. allowHTML), depending on the image type exporting to. For
     * very complex charts, it is possible that export can fail in browsers that
     * don't support Blob objects, due to data URL length limits. It is
     * recommended to define the exporting.error handler if disabling fallback,
     * in order to notify users in case export fails.
     *
     * @see https://api.highcharts.com/highcharts/exporting.fallbackToExportServer
     * @see https://api.highcharts.com/highstock/exporting.fallbackToExportServer
     * @see https://api.highcharts.com/highmaps/exporting.fallbackToExportServer
     * @see https://api.highcharts.com/gantt/exporting.fallbackToExportServer
     */
    fallbackToExportServer?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The filename, without extension,
     * to use for the exported chart.
     *
     * @see https://api.highcharts.com/highcharts/exporting.filename
     * @see https://api.highcharts.com/highstock/exporting.filename
     * @see https://api.highcharts.com/highmaps/exporting.filename
     * @see https://api.highcharts.com/gantt/exporting.filename
     */
    filename?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An object containing additional
     * key value data for the POST form that sends the SVG to the export server.
     * For example, a `target` can be set to make sure the generated image is
     * received in another frame, or a custom `enctype` or `encoding` can be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/exporting.formAttributes
     * @see https://api.highcharts.com/highstock/exporting.formAttributes
     * @see https://api.highcharts.com/highmaps/exporting.formAttributes
     * @see https://api.highcharts.com/gantt/exporting.formAttributes
     */
    formAttributes?: any;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Path where Highcharts will look
     * for export module dependencies to load on demand if they don't already
     * exist on `window`. Should currently point to location of CanVG library,
     * RGBColor.js, jsPDF and svg2pdf.js, required for client side export in
     * certain browsers.
     *
     * @see https://api.highcharts.com/highcharts/exporting.libURL
     * @see https://api.highcharts.com/highstock/exporting.libURL
     * @see https://api.highcharts.com/highmaps/exporting.libURL
     * @see https://api.highcharts.com/gantt/exporting.libURL
     */
    libURL?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An object consisting of
     * definitions for the menu items in the context menu. Each key value pair
     * has a `key` that is referenced in the menuItems setting, and a `value`,
     * which is an object with the following properties:
     *
     * - **onclick:** The click handler for the menu item
     *
     * - **text:** The text for the menu item
     *
     * - **textKey:** If internationalization is required, the key to a language
     * string
     *
     * @see https://api.highcharts.com/highcharts/exporting.menuItemDefinitions
     * @see https://api.highcharts.com/highstock/exporting.menuItemDefinitions
     * @see https://api.highcharts.com/highmaps/exporting.menuItemDefinitions
     * @see https://api.highcharts.com/gantt/exporting.menuItemDefinitions
     */
    menuItemDefinitions?: Dictionary<ExportingMenuObject>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When printing the chart from the
     * menu item in the burger menu, if the on-screen chart exceeds this width,
     * it is resized. After printing or cancelled, it is restored. The default
     * width makes the chart fit into typical paper format. Note that this does
     * not affect the chart when printing the web page as a whole.
     *
     * @see https://api.highcharts.com/highcharts/exporting.printMaxWidth
     * @see https://api.highcharts.com/highstock/exporting.printMaxWidth
     * @see https://api.highcharts.com/highmaps/exporting.printMaxWidth
     * @see https://api.highcharts.com/gantt/exporting.printMaxWidth
     */
    printMaxWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Defines the scale or zoom factor
     * for the exported image compared to the on-screen display. While for
     * instance a 600px wide chart may look good on a website, it will look bad
     * in print. The default scale of 2 makes this chart export to a 1200px PNG
     * or JPG.
     *
     * @see https://api.highcharts.com/highcharts/exporting.scale
     * @see https://api.highcharts.com/highstock/exporting.scale
     * @see https://api.highcharts.com/highmaps/exporting.scale
     * @see https://api.highcharts.com/gantt/exporting.scale
     */
    scale?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Export-data module required.
     * Show a HTML table below the chart with the chart's current data.
     *
     * @see https://api.highcharts.com/highcharts/exporting.showTable
     * @see https://api.highcharts.com/highstock/exporting.showTable
     * @see https://api.highcharts.com/highmaps/exporting.showTable
     * @see https://api.highcharts.com/gantt/exporting.showTable
     */
    showTable?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Analogous to sourceWidth.
     *
     * @see https://api.highcharts.com/highcharts/exporting.sourceHeight
     * @see https://api.highcharts.com/highstock/exporting.sourceHeight
     * @see https://api.highcharts.com/highmaps/exporting.sourceHeight
     * @see https://api.highcharts.com/gantt/exporting.sourceHeight
     */
    sourceHeight?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the original chart
     * when exported, unless an explicit chart.width is set, or a pixel width is
     * set on the container. The width exported raster image is then multiplied
     * by scale.
     *
     * @see https://api.highcharts.com/highcharts/exporting.sourceWidth
     * @see https://api.highcharts.com/highstock/exporting.sourceWidth
     * @see https://api.highcharts.com/highmaps/exporting.sourceWidth
     * @see https://api.highcharts.com/gantt/exporting.sourceWidth
     */
    sourceWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Export-data module required.
     * Caption for the data table. Same as chart title by default. Set to
     * `false` to disable.
     *
     * @see https://api.highcharts.com/highcharts/exporting.tableCaption
     * @see https://api.highcharts.com/highstock/exporting.tableCaption
     * @see https://api.highcharts.com/highmaps/exporting.tableCaption
     * @see https://api.highcharts.com/gantt/exporting.tableCaption
     */
    tableCaption?: (boolean|string);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Default MIME type for exporting
     * if `chart.exportChart()` is called without specifying a `type` option.
     * Possible values are `image/png`, `image/jpeg`, `application/pdf` and
     * `image/svg+xml`.
     *
     * @see https://api.highcharts.com/highcharts/exporting.type
     * @see https://api.highcharts.com/highstock/exporting.type
     * @see https://api.highcharts.com/highmaps/exporting.type
     * @see https://api.highcharts.com/gantt/exporting.type
     */
    type?: ("application/pdf"|"image/jpeg"|"image/png"|"image/svg+xml");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The URL for the server module
     * converting the SVG string to an image format. By default this points to
     * Highchart's free web service.
     *
     * @see https://api.highcharts.com/highcharts/exporting.url
     * @see https://api.highcharts.com/highstock/exporting.url
     * @see https://api.highcharts.com/highmaps/exporting.url
     * @see https://api.highcharts.com/gantt/exporting.url
     */
    url?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Export-data module required. Use
     * multi level headers in data table. If csv.columnHeaderFormatter is
     * defined, it has to return objects in order for multi level headers to
     * work.
     *
     * @see https://api.highcharts.com/highcharts/exporting.useMultiLevelHeaders
     * @see https://api.highcharts.com/highstock/exporting.useMultiLevelHeaders
     * @see https://api.highcharts.com/highmaps/exporting.useMultiLevelHeaders
     * @see https://api.highcharts.com/gantt/exporting.useMultiLevelHeaders
     */
    useMultiLevelHeaders?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Export-data module required. If
     * using multi level table headers, use rowspans for headers that have only
     * one level.
     *
     * @see https://api.highcharts.com/highcharts/exporting.useRowspanHeaders
     * @see https://api.highcharts.com/highstock/exporting.useRowspanHeaders
     * @see https://api.highcharts.com/highmaps/exporting.useRowspanHeaders
     * @see https://api.highcharts.com/gantt/exporting.useRowspanHeaders
     */
    useRowspanHeaders?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of charts
     * exported to PNG or JPG. As of Highcharts 3.0, the default pixel width is
     * a function of the chart.width or exporting.sourceWidth and the
     * exporting.scale.
     *
     * @see https://api.highcharts.com/highcharts/exporting.width
     * @see https://api.highcharts.com/highstock/exporting.width
     * @see https://api.highcharts.com/highmaps/exporting.width
     * @see https://api.highcharts.com/gantt/exporting.width
     */
    width?: number;
}
/**
 * The returned object literal from the Highcharts.Axis#getExtremes function.
 */
export interface ExtremesObject {
    /**
     * The maximum value of the axis' associated series.
     */
    dataMax: number;
    /**
     * The minimum value of the axis' associated series.
     */
    dataMin: number;
    /**
     * The maximum axis value, either automatic or set manually. If the `max`
     * option is not set, `maxPadding` is 0 and `endOnTick` is false, this value
     * will be the same as `dataMax`.
     */
    max: number;
    /**
     * The minimum axis value, either automatic or set manually. If the `min`
     * option is not set, `minPadding` is 0 and `startOnTick` is false, this
     * value will be the same as `dataMin`.
     */
    min: number;
    /**
     * The user defined maximum, either from the `max` option or from a zoom or
     * `setExtremes` action.
     */
    userMax: number;
    /**
     * The user defined minimum, either from the `min` option or from a zoom or
     * `setExtremes` action.
     */
    userMin: number;
}
/**
 * The font metrics.
 */
export interface FontMetricsObject {
    /**
     * The baseline relative to the top of the box.
     */
    b: number;
    /**
     * The font size.
     */
    f: number;
    /**
     * The line height.
     */
    h: number;
}
export interface GlobalOptions {
    /**
     * (Highcharts, Highmaps) _Canvg rendering for Android 2.x is removed as of
     * Highcharts 5.0\. Use the libURL option to configure exporting._
     *
     * The URL to the additional file to lazy load for Android 2.x devices.
     * These devices don't support SVG, so we download a helper file that
     * contains canvg, its dependency rbcolor, and our own CanVG Renderer class.
     * To avoid hotlinking to our site, you can install canvas-tools.js on your
     * own server and change this option accordingly.
     *
     * @see https://api.highcharts.com/highcharts/global.canvasToolsURL
     * @see https://api.highcharts.com/highmaps/global.canvasToolsURL
     */
    canvasToolsURL?: string;
    /**
     * (Highcharts, Highstock) This option is deprecated since v6.0.5. Instead,
     * use time.Date that supports individual time settings per chart.
     *
     * @see https://api.highcharts.com/highcharts/global.Date
     * @see https://api.highcharts.com/highstock/global.Date
     */
    Date?: () => void;
    /**
     * (Highcharts, Highstock) This option is deprecated since v6.0.5. Instead,
     * use time.getTimezoneOffset that supports individual time settings per
     * chart.
     *
     * @see https://api.highcharts.com/highcharts/global.getTimezoneOffset
     * @see https://api.highcharts.com/highstock/global.getTimezoneOffset
     */
    getTimezoneOffset?: () => void;
    /**
     * (Highcharts, Highstock) This option is deprecated since v6.0.5. Instead,
     * use time.timezone that supports individual time settings per chart.
     *
     * @see https://api.highcharts.com/highcharts/global.timezone
     * @see https://api.highcharts.com/highstock/global.timezone
     */
    timezone?: string;
    /**
     * (Highcharts, Highstock) This option is deprecated since v6.0.5. Instead,
     * use time.timezoneOffset that supports individual time settings per chart.
     *
     * @see https://api.highcharts.com/highcharts/global.timezoneOffset
     * @see https://api.highcharts.com/highstock/global.timezoneOffset
     */
    timezoneOffset?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This option is deprecated since
     * v6.0.5. Instead, use time.useUTC that supports individual time settings
     * per chart.
     *
     * @see https://api.highcharts.com/highcharts/global.useUTC
     * @see https://api.highcharts.com/highstock/global.useUTC
     * @see https://api.highcharts.com/highmaps/global.useUTC
     * @see https://api.highcharts.com/gantt/global.useUTC
     */
    useUTC?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Path to the pattern image
     * required by VML browsers in order to draw radial gradients.
     *
     * @see https://api.highcharts.com/highcharts/global.VMLRadialGradientURL
     * @see https://api.highcharts.com/highstock/global.VMLRadialGradientURL
     * @see https://api.highcharts.com/highmaps/global.VMLRadialGradientURL
     * @see https://api.highcharts.com/gantt/global.VMLRadialGradientURL
     */
    VMLRadialGradientURL?: string;
}
/**
 * Gradient options instead of a solid color.
 */
export interface GradientColorObject {
    /**
     * Holds an object that defines the start position and the end position
     * relative to the shape.
     */
    linearGradient?: LinearGradientColorObject;
    /**
     * Holds an object that defines the center position and the radius.
     */
    radialGradient?: RadialGradientColorObject;
    /**
     * The first item in each tuple is the position in the gradient, where 0 is
     * the start of the gradient and 1 is the end of the gradient. Multiple
     * stops can be applied. The second item is the color for each stop. This
     * color can also be given in the rgba format.
     */
    stops?: Array<[number, ColorString]>;
}
/**
 * Containing the position of a box that should be avoided by labels.
 */
export interface LabelIntersectBoxObject {
    bottom: number;
    left: number;
    right: number;
    top: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) An HTML label that can be positioned
 * anywhere in the chart area.
 *
 * @see https://api.highcharts.com/highcharts/labels.items
 * @see https://api.highcharts.com/highstock/labels.items
 * @see https://api.highcharts.com/highmaps/labels.items
 * @see https://api.highcharts.com/gantt/labels.items
 */
export interface LabelsItemsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Inner HTML or text for the
     * label.
     *
     * @see https://api.highcharts.com/highcharts/labels.items.html
     * @see https://api.highcharts.com/highstock/labels.items.html
     * @see https://api.highcharts.com/highmaps/labels.items.html
     * @see https://api.highcharts.com/gantt/labels.items.html
     */
    html?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for each label. To
     * position the label, use left and top like this:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/labels.items.style
     * @see https://api.highcharts.com/highstock/labels.items.style
     * @see https://api.highcharts.com/highmaps/labels.items.style
     * @see https://api.highcharts.com/gantt/labels.items.style
     */
    style?: CSSObject;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) HTML labels that can be positioned
 * anywhere in the chart area.
 *
 * @see https://api.highcharts.com/highcharts/labels
 * @see https://api.highcharts.com/highstock/labels
 * @see https://api.highcharts.com/highmaps/labels
 * @see https://api.highcharts.com/gantt/labels
 */
export interface LabelsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An HTML label that can be
     * positioned anywhere in the chart area.
     *
     * @see https://api.highcharts.com/highcharts/labels.items
     * @see https://api.highcharts.com/highstock/labels.items
     * @see https://api.highcharts.com/highmaps/labels.items
     * @see https://api.highcharts.com/gantt/labels.items
     */
    items?: Array<LabelsItemsOptions>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Shared CSS styles for all
     * labels.
     *
     * @see https://api.highcharts.com/highcharts/labels.style
     * @see https://api.highcharts.com/highstock/labels.style
     * @see https://api.highcharts.com/highmaps/labels.style
     * @see https://api.highcharts.com/gantt/labels.style
     */
    style?: CSSObject;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Axis description format strings.
 *
 * @see https://api.highcharts.com/highcharts/lang.accessibility.axis
 * @see https://api.highcharts.com/highstock/lang.accessibility.axis
 * @see https://api.highcharts.com/highmaps/lang.accessibility.axis
 * @see https://api.highcharts.com/gantt/lang.accessibility.axis
 */
export interface LangAccessibilityAxisOptions {
    xAxisDescriptionPlural?: string;
    xAxisDescriptionSingular?: string;
    yAxisDescriptionPlural?: string;
    yAxisDescriptionSingular?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Chart type description strings. This
 * is added to the chart information region.
 *
 * If there is only a single series type used in the chart, we use the format
 * string for the series type, or default if missing. There is one format string
 * for cases where there is only a single series in the chart, and one for
 * multiple series of the same type.
 *
 * @see https://api.highcharts.com/highcharts/lang.accessibility.chartTypes
 * @see https://api.highcharts.com/highstock/lang.accessibility.chartTypes
 * @see https://api.highcharts.com/highmaps/lang.accessibility.chartTypes
 * @see https://api.highcharts.com/gantt/lang.accessibility.chartTypes
 */
export interface LangAccessibilityChartTypesOptions {
    barMultiple?: string;
    barSingle?: string;
    boxplotMultiple?: string;
    boxplotSingle?: string;
    bubbleMultiple?: string;
    bubbleSingle?: string;
    columnMultiple?: string;
    columnSingle?: string;
    combinationChart?: string;
    defaultMultiple?: string;
    defaultSingle?: string;
    emptyChart?: string;
    lineMultiple?: string;
    lineSingle?: string;
    mapTypeDescription?: string;
    pieMultiple?: string;
    pieSingle?: string;
    scatterMultiple?: string;
    scatterSingle?: string;
    splineMultiple?: string;
    splineSingle?: string;
    unknownMap?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Exporting menu format strings for
 * accessibility module.
 *
 * @see https://api.highcharts.com/highcharts/lang.accessibility.exporting
 * @see https://api.highcharts.com/highstock/lang.accessibility.exporting
 * @see https://api.highcharts.com/highmaps/lang.accessibility.exporting
 * @see https://api.highcharts.com/gantt/lang.accessibility.exporting
 */
export interface LangAccessibilityExportingOptions {
    chartMenuLabel?: string;
    exportRegionLabel?: string;
    menuButtonLabel?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Configure the accessibility strings
 * in the chart. Requires the accessibility module to be loaded. For a
 * description of the module and information on its features, see Highcharts
 * Accessibility.
 *
 * For more dynamic control over the accessibility functionality, see
 * accessibility.pointDescriptionFormatter,
 * accessibility.seriesDescriptionFormatter, and
 * accessibility.screenReaderSectionFormatter.
 *
 * @see https://api.highcharts.com/highcharts/lang.accessibility
 * @see https://api.highcharts.com/highstock/lang.accessibility
 * @see https://api.highcharts.com/highmaps/lang.accessibility
 * @see https://api.highcharts.com/gantt/lang.accessibility
 */
export interface LangAccessibilityOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Axis description format strings.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility.axis
     * @see https://api.highcharts.com/highstock/lang.accessibility.axis
     * @see https://api.highcharts.com/highmaps/lang.accessibility.axis
     * @see https://api.highcharts.com/gantt/lang.accessibility.axis
     */
    axis?: LangAccessibilityAxisOptions;
    chartContainerLabel?: string;
    chartHeading?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Chart type description strings.
     * This is added to the chart information region.
     *
     * If there is only a single series type used in the chart, we use the
     * format string for the series type, or default if missing. There is one
     * format string for cases where there is only a single series in the chart,
     * and one for multiple series of the same type.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility.chartTypes
     * @see https://api.highcharts.com/highstock/lang.accessibility.chartTypes
     * @see https://api.highcharts.com/highmaps/lang.accessibility.chartTypes
     * @see https://api.highcharts.com/gantt/lang.accessibility.chartTypes
     */
    chartTypes?: LangAccessibilityChartTypesOptions;
    defaultChartTitle?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Exporting menu format strings
     * for accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility.exporting
     * @see https://api.highcharts.com/highstock/lang.accessibility.exporting
     * @see https://api.highcharts.com/highmaps/lang.accessibility.exporting
     * @see https://api.highcharts.com/gantt/lang.accessibility.exporting
     */
    exporting?: LangAccessibilityExportingOptions;
    legendItem?: string;
    longDescriptionHeading?: string;
    mapZoomIn?: string;
    mapZoomOut?: string;
    navigationHint?: string;
    noDescription?: string;
    rangeSelectorButton?: string;
    rangeSelectorMaxInput?: string;
    rangeSelectorMinInput?: string;
    screenReaderRegionLabel?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Lang configuration for different
     * series types. For more dynamic control over the series element
     * descriptions, see accessibility.seriesDescriptionFormatter.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility.series
     * @see https://api.highcharts.com/highstock/lang.accessibility.series
     * @see https://api.highcharts.com/highmaps/lang.accessibility.series
     * @see https://api.highcharts.com/gantt/lang.accessibility.series
     */
    series?: LangAccessibilitySeriesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Descriptions of lesser known
     * series types. The relevant description is added to the screen reader
     * information region when these series types are used.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility.seriesTypeDescriptions
     * @see https://api.highcharts.com/highstock/lang.accessibility.seriesTypeDescriptions
     * @see https://api.highcharts.com/highmaps/lang.accessibility.seriesTypeDescriptions
     * @see https://api.highcharts.com/gantt/lang.accessibility.seriesTypeDescriptions
     */
    seriesTypeDescriptions?: LangAccessibilitySeriesTypeDescriptionsOptions;
    structureHeading?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Title element text for the chart
     * SVG element. Leave this empty to disable adding the title element.
     * Browsers will display this content when hovering over elements in the
     * chart. Assistive technology may use this element to label the chart.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility.svgContainerTitle
     * @see https://api.highcharts.com/highstock/lang.accessibility.svgContainerTitle
     * @see https://api.highcharts.com/highmaps/lang.accessibility.svgContainerTitle
     * @see https://api.highcharts.com/gantt/lang.accessibility.svgContainerTitle
     */
    svgContainerTitle?: string;
    tableSummary?: string;
    viewAsDataTable?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Lang configuration for different
 * series types. For more dynamic control over the series element descriptions,
 * see accessibility.seriesDescriptionFormatter.
 *
 * @see https://api.highcharts.com/highcharts/lang.accessibility.series
 * @see https://api.highcharts.com/highstock/lang.accessibility.series
 * @see https://api.highcharts.com/highmaps/lang.accessibility.series
 * @see https://api.highcharts.com/gantt/lang.accessibility.series
 */
export interface LangAccessibilitySeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) User supplied description text.
     * This is added after the main summary if present.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility.series.description
     * @see https://api.highcharts.com/highstock/lang.accessibility.series.description
     * @see https://api.highcharts.com/highmaps/lang.accessibility.series.description
     * @see https://api.highcharts.com/gantt/lang.accessibility.series.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Lang configuration for the
     * series main summary. Each series type has two modes:
     *
     * 1. This series type is the only series type used in the chart
     *
     * 2. This is a combination chart with multiple series types
     *
     * If a definition does not exist for the specific series type and mode, the
     * 'default' lang definitions are used.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility.series.summary
     * @see https://api.highcharts.com/highstock/lang.accessibility.series.summary
     * @see https://api.highcharts.com/highmaps/lang.accessibility.series.summary
     * @see https://api.highcharts.com/gantt/lang.accessibility.series.summary
     */
    summary?: LangAccessibilitySeriesSummaryOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) xAxis description for series if
     * there are multiple xAxes in the chart.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility.series.xAxisDescription
     * @see https://api.highcharts.com/highstock/lang.accessibility.series.xAxisDescription
     * @see https://api.highcharts.com/highmaps/lang.accessibility.series.xAxisDescription
     * @see https://api.highcharts.com/gantt/lang.accessibility.series.xAxisDescription
     */
    xAxisDescription?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) yAxis description for series if
     * there are multiple yAxes in the chart.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility.series.yAxisDescription
     * @see https://api.highcharts.com/highstock/lang.accessibility.series.yAxisDescription
     * @see https://api.highcharts.com/highmaps/lang.accessibility.series.yAxisDescription
     * @see https://api.highcharts.com/gantt/lang.accessibility.series.yAxisDescription
     */
    yAxisDescription?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Lang configuration for the series
 * main summary. Each series type has two modes:
 *
 * 1. This series type is the only series type used in the chart
 *
 * 2. This is a combination chart with multiple series types
 *
 * If a definition does not exist for the specific series type and mode, the
 * 'default' lang definitions are used.
 *
 * @see https://api.highcharts.com/highcharts/lang.accessibility.series.summary
 * @see https://api.highcharts.com/highstock/lang.accessibility.series.summary
 * @see https://api.highcharts.com/highmaps/lang.accessibility.series.summary
 * @see https://api.highcharts.com/gantt/lang.accessibility.series.summary
 */
export interface LangAccessibilitySeriesSummaryOptions {
    bar?: string;
    barCombination?: string;
    boxplot?: string;
    boxplotCombination?: string;
    bubble?: string;
    bubbleCombination?: string;
    column?: string;
    columnCombination?: string;
    default?: string;
    defaultCombination?: string;
    line?: string;
    lineCombination?: string;
    map?: string;
    mapbubble?: string;
    mapbubbleCombination?: string;
    mapCombination?: string;
    mapline?: string;
    maplineCombination?: string;
    pie?: string;
    pieCombination?: string;
    scatter?: string;
    scatterCombination?: string;
    spline?: string;
    splineCombination?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Descriptions of lesser known series
 * types. The relevant description is added to the screen reader information
 * region when these series types are used.
 *
 * @see https://api.highcharts.com/highcharts/lang.accessibility.seriesTypeDescriptions
 * @see https://api.highcharts.com/highstock/lang.accessibility.seriesTypeDescriptions
 * @see https://api.highcharts.com/highmaps/lang.accessibility.seriesTypeDescriptions
 * @see https://api.highcharts.com/gantt/lang.accessibility.seriesTypeDescriptions
 */
export interface LangAccessibilitySeriesTypeDescriptionsOptions {
    arearange?: string;
    areasplinerange?: string;
    boxplot?: string;
    bubble?: string;
    columnrange?: string;
    errorbar?: string;
    funnel?: string;
    pyramid?: string;
    waterfall?: string;
}
/**
 * (Highcharts, Highstock) Configure the Popup strings in the chart. Requires
 * the `annotations.js` or `annotations-advanced.src.js` module to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/lang.navigation
 * @see https://api.highcharts.com/highstock/lang.navigation
 */
export interface LangNavigationOptions {
    /**
     * (Highcharts, Highstock) Translations for all field names used in popup.
     *
     * @see https://api.highcharts.com/highcharts/lang.navigation.popup
     * @see https://api.highcharts.com/highstock/lang.navigation.popup
     */
    popup?: (object|LangNavigationPopupOptions);
}
/**
 * (Highcharts, Highstock) Translations for all field names used in popup.
 *
 * @see https://api.highcharts.com/highcharts/lang.navigation.popup
 * @see https://api.highcharts.com/highstock/lang.navigation.popup
 */
export interface LangNavigationPopupOptions {
    addButton?: string;
    arrowLine?: string;
    arrowRay?: string;
    arrowSegment?: string;
    background?: string;
    backgroundColor?: string;
    backgroundColors?: string;
    borderColor?: string;
    borderRadius?: string;
    borderWidth?: string;
    circle?: string;
    color?: string;
    connector?: string;
    crooked3?: string;
    crooked5?: string;
    crosshairX?: string;
    crosshairY?: string;
    editButton?: string;
    elliott3?: string;
    elliott5?: string;
    fibonacci?: string;
    fill?: string;
    flags?: string;
    fontSize?: string;
    format?: string;
    height?: string;
    horizontalLine?: string;
    infinityLine?: string;
    innerBackground?: string;
    label?: string;
    labelOptions?: string;
    labels?: string;
    line?: string;
    lines?: string;
    measure?: string;
    measureX?: string;
    measureXY?: string;
    measureY?: string;
    name?: string;
    outerBackground?: string;
    padding?: string;
    parallelChannel?: string;
    pitchfork?: string;
    ray?: string;
    rectangle?: string;
    removeButton?: string;
    saveButton?: string;
    segment?: string;
    series?: string;
    shapeOptions?: string;
    shapes?: string;
    simpleShapes?: string;
    stroke?: string;
    strokeWidth?: string;
    style?: string;
    title?: string;
    tunnel?: string;
    typeOptions?: string;
    verticalArrow?: string;
    verticalCounter?: string;
    verticalLabel?: string;
    verticalLine?: string;
    volume?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Language object. The language object
 * is global and it can't be set on each chart initiation. Instead, use
 * `Highcharts.setOptions` to set it before any chart is initialized.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/lang
 * @see https://api.highcharts.com/highstock/lang
 * @see https://api.highcharts.com/highmaps/lang
 * @see https://api.highcharts.com/gantt/lang
 */
export interface LangOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Configure the accessibility
     * strings in the chart. Requires the accessibility module to be loaded. For
     * a description of the module and information on its features, see
     * Highcharts Accessibility.
     *
     * For more dynamic control over the accessibility functionality, see
     * accessibility.pointDescriptionFormatter,
     * accessibility.seriesDescriptionFormatter, and
     * accessibility.screenReaderSectionFormatter.
     *
     * @see https://api.highcharts.com/highcharts/lang.accessibility
     * @see https://api.highcharts.com/highstock/lang.accessibility
     * @see https://api.highcharts.com/highmaps/lang.accessibility
     * @see https://api.highcharts.com/gantt/lang.accessibility
     */
    accessibility?: LangAccessibilityOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Exporting module menu. The
     * tooltip title for the context menu holding print and export menu items.
     *
     * @see https://api.highcharts.com/highcharts/lang.contextButtonTitle
     * @see https://api.highcharts.com/highstock/lang.contextButtonTitle
     * @see https://api.highcharts.com/highmaps/lang.contextButtonTitle
     * @see https://api.highcharts.com/gantt/lang.contextButtonTitle
     */
    contextButtonTitle?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The default decimal point used
     * in the `Highcharts.numberFormat` method unless otherwise specified in the
     * function arguments.
     *
     * @see https://api.highcharts.com/highcharts/lang.decimalPoint
     * @see https://api.highcharts.com/highstock/lang.decimalPoint
     * @see https://api.highcharts.com/highmaps/lang.decimalPoint
     * @see https://api.highcharts.com/gantt/lang.decimalPoint
     */
    decimalPoint?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Export-data module only. The
     * text for the menu item.
     *
     * @see https://api.highcharts.com/highcharts/lang.downloadCSV
     * @see https://api.highcharts.com/highstock/lang.downloadCSV
     * @see https://api.highcharts.com/highmaps/lang.downloadCSV
     * @see https://api.highcharts.com/gantt/lang.downloadCSV
     */
    downloadCSV?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Exporting module only. The text
     * for the JPEG download menu item.
     *
     * @see https://api.highcharts.com/highcharts/lang.downloadJPEG
     * @see https://api.highcharts.com/highstock/lang.downloadJPEG
     * @see https://api.highcharts.com/highmaps/lang.downloadJPEG
     * @see https://api.highcharts.com/gantt/lang.downloadJPEG
     */
    downloadJPEG?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Exporting module only. The text
     * for the PDF download menu item.
     *
     * @see https://api.highcharts.com/highcharts/lang.downloadPDF
     * @see https://api.highcharts.com/highstock/lang.downloadPDF
     * @see https://api.highcharts.com/highmaps/lang.downloadPDF
     * @see https://api.highcharts.com/gantt/lang.downloadPDF
     */
    downloadPDF?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Exporting module only. The text
     * for the PNG download menu item.
     *
     * @see https://api.highcharts.com/highcharts/lang.downloadPNG
     * @see https://api.highcharts.com/highstock/lang.downloadPNG
     * @see https://api.highcharts.com/highmaps/lang.downloadPNG
     * @see https://api.highcharts.com/gantt/lang.downloadPNG
     */
    downloadPNG?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Exporting module only. The text
     * for the SVG download menu item.
     *
     * @see https://api.highcharts.com/highcharts/lang.downloadSVG
     * @see https://api.highcharts.com/highstock/lang.downloadSVG
     * @see https://api.highcharts.com/highmaps/lang.downloadSVG
     * @see https://api.highcharts.com/gantt/lang.downloadSVG
     */
    downloadSVG?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Export-data module only. The
     * text for the menu item.
     *
     * @see https://api.highcharts.com/highcharts/lang.downloadXLS
     * @see https://api.highcharts.com/highstock/lang.downloadXLS
     * @see https://api.highcharts.com/highmaps/lang.downloadXLS
     * @see https://api.highcharts.com/gantt/lang.downloadXLS
     */
    downloadXLS?: string;
    /**
     * (Highcharts, Highmaps) The text for the button that appears when drilling
     * down, linking back to the parent series. The parent series' name is
     * inserted for `{series.name}`.
     *
     * @see https://api.highcharts.com/highcharts/lang.drillUpText
     * @see https://api.highcharts.com/highmaps/lang.drillUpText
     */
    drillUpText?: string;
    /**
     * (Highcharts, Highstock) What to show in a date field for invalid dates.
     * Defaults to an empty string.
     *
     * @see https://api.highcharts.com/highcharts/lang.invalidDate
     * @see https://api.highcharts.com/highstock/lang.invalidDate
     */
    invalidDate?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The loading text that appears
     * when the chart is set into the loading state following a call to
     * `chart.showLoading`.
     *
     * @see https://api.highcharts.com/highcharts/lang.loading
     * @see https://api.highcharts.com/highstock/lang.loading
     * @see https://api.highcharts.com/highmaps/lang.loading
     * @see https://api.highcharts.com/gantt/lang.loading
     */
    loading?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array containing the months
     * names. Corresponds to the `%B` format in `Highcharts.dateFormat()`.
     *
     * @see https://api.highcharts.com/highcharts/lang.months
     * @see https://api.highcharts.com/highstock/lang.months
     * @see https://api.highcharts.com/highmaps/lang.months
     * @see https://api.highcharts.com/gantt/lang.months
     */
    months?: Array<string>;
    /**
     * (Highcharts, Highstock) Configure the Popup strings in the chart.
     * Requires the `annotations.js` or `annotations-advanced.src.js` module to
     * be loaded.
     *
     * @see https://api.highcharts.com/highcharts/lang.navigation
     * @see https://api.highcharts.com/highstock/lang.navigation
     */
    navigation?: (object|LangNavigationOptions);
    /**
     * (Highcharts, Highstock) The text to display when the chart contains no
     * data. Requires the no-data module, see noData.
     *
     * @see https://api.highcharts.com/highcharts/lang.noData
     * @see https://api.highcharts.com/highstock/lang.noData
     */
    noData?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The magnitude of numericSymbols
     * replacements. Use 10000 for Japanese, Korean and various Chinese locales,
     * which use symbols for 10^4, 10^8 and 10^12.
     *
     * @see https://api.highcharts.com/highcharts/lang.numericSymbolMagnitude
     * @see https://api.highcharts.com/highstock/lang.numericSymbolMagnitude
     * @see https://api.highcharts.com/highmaps/lang.numericSymbolMagnitude
     * @see https://api.highcharts.com/gantt/lang.numericSymbolMagnitude
     */
    numericSymbolMagnitude?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Metric prefixes used to shorten
     * high numbers in axis labels. Replacing any of the positions with `null`
     * causes the full number to be written. Setting `numericSymbols` to `null`
     * disables shortening altogether.
     *
     * @see https://api.highcharts.com/highcharts/lang.numericSymbols
     * @see https://api.highcharts.com/highstock/lang.numericSymbols
     * @see https://api.highcharts.com/highmaps/lang.numericSymbols
     * @see https://api.highcharts.com/gantt/lang.numericSymbols
     */
    numericSymbols?: Array<string>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Export-data module only. The
     * text for the menu item.
     *
     * @see https://api.highcharts.com/highcharts/lang.openInCloud
     * @see https://api.highcharts.com/highstock/lang.openInCloud
     * @see https://api.highcharts.com/highmaps/lang.openInCloud
     * @see https://api.highcharts.com/gantt/lang.openInCloud
     */
    openInCloud?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Exporting module only. The text
     * for the menu item to print the chart.
     *
     * @see https://api.highcharts.com/highcharts/lang.printChart
     * @see https://api.highcharts.com/highstock/lang.printChart
     * @see https://api.highcharts.com/highmaps/lang.printChart
     * @see https://api.highcharts.com/gantt/lang.printChart
     */
    printChart?: string;
    /**
     * (Highstock) The text for the label for the "from" input box in the range
     * selector.
     *
     * @see https://api.highcharts.com/highstock/lang.rangeSelectorFrom
     */
    rangeSelectorFrom?: string;
    /**
     * (Highstock) The text for the label for the "to" input box in the range
     * selector.
     *
     * @see https://api.highcharts.com/highstock/lang.rangeSelectorTo
     */
    rangeSelectorTo?: string;
    /**
     * (Highstock) The text for the label for the range selector buttons.
     *
     * @see https://api.highcharts.com/highstock/lang.rangeSelectorZoom
     */
    rangeSelectorZoom?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The text for the label appearing
     * when a chart is zoomed.
     *
     * @see https://api.highcharts.com/highcharts/lang.resetZoom
     * @see https://api.highcharts.com/highstock/lang.resetZoom
     * @see https://api.highcharts.com/highmaps/lang.resetZoom
     * @see https://api.highcharts.com/gantt/lang.resetZoom
     */
    resetZoom?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The tooltip title for the label
     * appearing when a chart is zoomed.
     *
     * @see https://api.highcharts.com/highcharts/lang.resetZoomTitle
     * @see https://api.highcharts.com/highstock/lang.resetZoomTitle
     * @see https://api.highcharts.com/highmaps/lang.resetZoomTitle
     * @see https://api.highcharts.com/gantt/lang.resetZoomTitle
     */
    resetZoomTitle?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array containing the months
     * names in abbreviated form. Corresponds to the `%b` format in
     * `Highcharts.dateFormat()`.
     *
     * @see https://api.highcharts.com/highcharts/lang.shortMonths
     * @see https://api.highcharts.com/highstock/lang.shortMonths
     * @see https://api.highcharts.com/highmaps/lang.shortMonths
     * @see https://api.highcharts.com/gantt/lang.shortMonths
     */
    shortMonths?: Array<string>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Short week days, starting
     * Sunday. If not specified, Highcharts uses the first three letters of the
     * `lang.weekdays` option.
     *
     * @see https://api.highcharts.com/highcharts/lang.shortWeekdays
     * @see https://api.highcharts.com/highstock/lang.shortWeekdays
     * @see https://api.highcharts.com/highmaps/lang.shortWeekdays
     * @see https://api.highcharts.com/gantt/lang.shortWeekdays
     */
    shortWeekdays?: Array<string>;
    /**
     * (Highstock) Configure the stockTools GUI titles(hints) in the chart.
     * Requires the `stock-tools.js` module to be loaded.
     *
     * @see https://api.highcharts.com/highstock/lang.stockTools
     */
    stockTools?: (object|LangStockToolsOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The default thousands separator
     * used in the `Highcharts.numberFormat` method unless otherwise specified
     * in the function arguments. Defaults to a single space character, which is
     * recommended in ISO 31-0 and works across Anglo-American and continental
     * European languages.
     *
     * @see https://api.highcharts.com/highcharts/lang.thousandsSep
     * @see https://api.highcharts.com/highstock/lang.thousandsSep
     * @see https://api.highcharts.com/highmaps/lang.thousandsSep
     * @see https://api.highcharts.com/gantt/lang.thousandsSep
     */
    thousandsSep?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Export-data module only. The
     * text for the menu item.
     *
     * @see https://api.highcharts.com/highcharts/lang.viewData
     * @see https://api.highcharts.com/highstock/lang.viewData
     * @see https://api.highcharts.com/highmaps/lang.viewData
     * @see https://api.highcharts.com/gantt/lang.viewData
     */
    viewData?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array containing the weekday
     * names.
     *
     * @see https://api.highcharts.com/highcharts/lang.weekdays
     * @see https://api.highcharts.com/highstock/lang.weekdays
     * @see https://api.highcharts.com/highmaps/lang.weekdays
     * @see https://api.highcharts.com/gantt/lang.weekdays
     */
    weekdays?: Array<string>;
    /**
     * (Highmaps) The title appearing on hovering the zoom in button. The text
     * itself defaults to "+" and can be changed in the button options.
     *
     * @see https://api.highcharts.com/highmaps/lang.zoomIn
     */
    zoomIn?: string;
    /**
     * (Highmaps) The title appearing on hovering the zoom out button. The text
     * itself defaults to "-" and can be changed in the button options.
     *
     * @see https://api.highcharts.com/highmaps/lang.zoomOut
     */
    zoomOut?: string;
}
export interface LangStockToolsGuiOptions {
    advanced?: string;
    arrowLine?: string;
    arrowRay?: string;
    arrowSegment?: string;
    circle?: string;
    crooked3?: string;
    crooked5?: string;
    crookedLines?: string;
    currentPriceIndicator?: string;
    elliott3?: string;
    elliott5?: string;
    fibonacci?: string;
    flagCirclepin?: string;
    flagDiamondpin?: string;
    flags?: string;
    flagSimplepin?: string;
    flagSquarepin?: string;
    fullScreen?: string;
    horizontalLine?: string;
    indicators?: string;
    infinityLine?: string;
    label?: string;
    line?: string;
    lines?: string;
    measure?: string;
    measureX?: string;
    measureXY?: string;
    measureY?: string;
    parallelChannel?: string;
    pitchfork?: string;
    ray?: string;
    rectangle?: string;
    saveChart?: string;
    segment?: string;
    simpleShapes?: string;
    toggleAnnotations?: string;
    typeCandlestick?: string;
    typeChange?: string;
    typeLine?: string;
    typeOHLC?: string;
    verticalArrow?: string;
    verticalCounter?: string;
    verticalLabel?: string;
    verticalLabels?: string;
    verticalLine?: string;
    zoomChange?: string;
    zoomX?: string;
    zoomXY?: string;
    zoomY?: string;
}
/**
 * (Highstock) Configure the stockTools GUI titles(hints) in the chart. Requires
 * the `stock-tools.js` module to be loaded.
 *
 * @see https://api.highcharts.com/highstock/lang.stockTools
 */
export interface LangStockToolsOptions {
    gui?: LangStockToolsGuiOptions;
}
export interface LegendBubbleLegendFormatterContextObject {
    /**
     * The center y position of the range.
     */
    center: number;
    /**
     * The radius of the bubble range.
     */
    radius: number;
    /**
     * The bubble value.
     */
    value: number;
}
/**
 * (Highcharts, Highstock, Highmaps) Options for the bubble legend labels.
 *
 * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.labels
 * @see https://api.highcharts.com/highstock/legend.bubbleLegend.labels
 * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.labels
 */
export interface LegendBubbleLegendLabelsOptions {
    /**
     * (Highcharts, Highstock, Highmaps) The alignment of the labels compared to
     * the bubble legend. Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.labels.align
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.labels.align
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.labels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Highmaps) Whether to allow data labels to
     * overlap.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.labels.allowOverlap
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.labels.allowOverlap
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.labels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps) An additional class name to apply to
     * the bubble legend label graphical elements. This option does not replace
     * default class names of the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.labels.className
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.labels.className
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.labels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps) A format string for the bubble legend
     * labels. Available variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.labels.format
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.labels.format
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.labels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock, Highmaps) Available `this` properties are:
     *
     * - `this.value`: The bubble value.
     *
     * - `this.radius`: The radius of the bubble range.
     *
     * - `this.center`: The center y position of the range.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.labels.formatter
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.labels.formatter
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.labels.formatter
     */
    formatter?: FormatterCallbackFunction<LegendBubbleLegendFormatterContextObject>;
    /**
     * (Highcharts, Highstock, Highmaps) CSS styles for the labels.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.labels.style
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.labels.style
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.labels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps) The x position offset of the label
     * relative to the connector.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.labels.x
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.labels.x
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.labels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps) The y position offset of the label
     * relative to the connector.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.labels.y
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.labels.y
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.labels.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Highmaps) The bubble legend is an additional element
 * in legend which presents the scale of the bubble series. Individual bubble
 * ranges can be defined by user or calculated from series. In the case of
 * automatically calculated ranges, a 1px margin of error is permitted. Requires
 * `highcharts-more.js`.
 *
 * @see https://api.highcharts.com/highcharts/legend.bubbleLegend
 * @see https://api.highcharts.com/highstock/legend.bubbleLegend
 * @see https://api.highcharts.com/highmaps/legend.bubbleLegend
 */
export interface LegendBubbleLegendOptions {
    /**
     * (Highcharts, Highstock, Highmaps) The color of the ranges borders, can be
     * also defined for an individual range.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.borderColor
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.borderColor
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps) The width of the ranges borders in
     * pixels, can be also defined for an individual range.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.borderWidth
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.borderWidth
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps) An additional class name to apply to
     * the bubble legend' circle graphical elements. This option does not
     * replace default class names of the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.className
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.className
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps) The main color of the bubble legend.
     * Applies to ranges, if individual color is not defined.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.color
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.color
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps) An additional class name to apply to
     * the bubble legend's connector graphical elements. This option does not
     * replace default class names of the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.connectorClassName
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.connectorClassName
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.connectorClassName
     */
    connectorClassName?: string;
    /**
     * (Highcharts, Highstock, Highmaps) The color of the connector, can be also
     * defined for an individual range.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.connectorColor
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.connectorColor
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.connectorColor
     */
    connectorColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps) The length of the connectors in pixels.
     * If labels are centered, the distance is reduced to 0.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.connectorDistance
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.connectorDistance
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.connectorDistance
     */
    connectorDistance?: number;
    /**
     * (Highcharts, Highstock, Highmaps) The width of the connectors in pixels.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.connectorWidth
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.connectorWidth
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.connectorWidth
     */
    connectorWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps) Enable or disable the bubble legend.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.enabled
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.enabled
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps) Options for the bubble legend labels.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.labels
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.labels
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.labels
     */
    labels?: LegendBubbleLegendLabelsOptions;
    /**
     * (Highcharts, Highstock, Highmaps) The position of the bubble legend in
     * the legend.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.legendIndex
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.legendIndex
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.legendIndex
     */
    legendIndex?: number;
    /**
     * (Highcharts, Highstock, Highmaps) Miximum bubble legend range size. If
     * values for ranges are not specified, the `minSize` and the `maxSize` are
     * calculated from bubble series.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.maxSize
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.maxSize
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.maxSize
     */
    maxSize?: number;
    /**
     * (Highcharts, Highstock, Highmaps) Minimum bubble legend range size. If
     * values for ranges are not specified, the `minSize` and the `maxSize` are
     * calculated from bubble series.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.minSize
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.minSize
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.minSize
     */
    minSize?: number;
    /**
     * (Highcharts, Highstock, Highmaps) Options for specific range. One range
     * consists of bubble, label and connector.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.ranges
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.ranges
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.ranges
     */
    ranges?: Array<LegendBubbleLegendRangesOptions>;
    /**
     * (Highcharts, Highstock, Highmaps) Whether the bubble legend range value
     * should be represented by the area or the width of the bubble. The
     * default, area, corresponds best to the human perception of the size of
     * each bubble.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.sizeBy
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.sizeBy
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.sizeBy
     */
    sizeBy?: ("area"|"width");
    /**
     * (Highcharts, Highstock, Highmaps) When this is true, the absolute value
     * of z determines the size of the bubble. This means that with the default
     * zThreshold of 0, a bubble of value -1 will have the same size as a bubble
     * of value 1, while a bubble of value 0 will have a smaller size according
     * to minSize.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.sizeByAbsoluteValue
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.sizeByAbsoluteValue
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.sizeByAbsoluteValue
     */
    sizeByAbsoluteValue?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps) Define the visual z index of the bubble
     * legend.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.zIndex
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.zIndex
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock, Highmaps) Ranges with with lower value than
     * zThreshold, are skipped.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.zThreshold
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.zThreshold
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.zThreshold
     */
    zThreshold?: number;
}
/**
 * (Highcharts, Highstock, Highmaps) Options for specific range. One range
 * consists of bubble, label and connector.
 *
 * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.ranges
 * @see https://api.highcharts.com/highstock/legend.bubbleLegend.ranges
 * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.ranges
 */
export interface LegendBubbleLegendRangesOptions {
    /**
     * (Highcharts, Highstock, Highmaps) The color of the border for individual
     * range.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.ranges.borderColor
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.ranges.borderColor
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.ranges.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps) The color of the bubble for individual
     * range.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.ranges.color
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.ranges.color
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.ranges.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps) The color of the connector for
     * individual range.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.ranges.connectorColor
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.ranges.connectorColor
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.ranges.connectorColor
     */
    connectorColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps) Range size value, similar to bubble Z
     * data.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend.ranges.value
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend.ranges.value
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend.ranges.value
     */
    value?: object;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Default styling for the checkbox
 * next to a legend item when `showCheckbox` is true.
 *
 * @see https://api.highcharts.com/highcharts/legend.itemCheckboxStyle
 * @see https://api.highcharts.com/highstock/legend.itemCheckboxStyle
 * @see https://api.highcharts.com/highmaps/legend.itemCheckboxStyle
 * @see https://api.highcharts.com/gantt/legend.itemCheckboxStyle
 */
export interface LegendItemCheckboxStyleOptions {
    height?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Keyboard navigation for the legend.
 * Requires the Accessibility module.
 *
 * @see https://api.highcharts.com/highcharts/legend.keyboardNavigation
 * @see https://api.highcharts.com/highstock/legend.keyboardNavigation
 * @see https://api.highcharts.com/highmaps/legend.keyboardNavigation
 * @see https://api.highcharts.com/gantt/legend.keyboardNavigation
 */
export interface LegendKeyboardNavigationOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable/disable keyboard
     * navigation for the legend. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/legend.keyboardNavigation.enabled
     * @see https://api.highcharts.com/highstock/legend.keyboardNavigation.enabled
     * @see https://api.highcharts.com/highmaps/legend.keyboardNavigation.enabled
     * @see https://api.highcharts.com/gantt/legend.keyboardNavigation.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the paging or navigation
 * appearing when the legend is overflown. Navigation works well on screen, but
 * not in static exported images. One way of working around that is to increase
 * the chart height in export.
 *
 * @see https://api.highcharts.com/highcharts/legend.navigation
 * @see https://api.highcharts.com/highstock/legend.navigation
 * @see https://api.highcharts.com/highmaps/legend.navigation
 * @see https://api.highcharts.com/gantt/legend.navigation
 */
export interface LegendNavigationOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color for the active up or
     * down arrow in the legend page navigation.
     *
     * @see https://api.highcharts.com/highcharts/legend.navigation.activeColor
     * @see https://api.highcharts.com/highstock/legend.navigation.activeColor
     * @see https://api.highcharts.com/highmaps/legend.navigation.activeColor
     * @see https://api.highcharts.com/gantt/legend.navigation.activeColor
     */
    activeColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) How to animate the pages when
     * navigating up or down. A value of `true` applies the default navigation
     * given in the `chart.animation` option. Additional options can be given as
     * an object containing values for easing and duration.
     *
     * @see https://api.highcharts.com/highcharts/legend.navigation.animation
     * @see https://api.highcharts.com/highstock/legend.navigation.animation
     * @see https://api.highcharts.com/highmaps/legend.navigation.animation
     * @see https://api.highcharts.com/gantt/legend.navigation.animation
     */
    animation?: (boolean|AnimationOptionsObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel size of the up and
     * down arrows in the legend paging navigation.
     *
     * @see https://api.highcharts.com/highcharts/legend.navigation.arrowSize
     * @see https://api.highcharts.com/highstock/legend.navigation.arrowSize
     * @see https://api.highcharts.com/highmaps/legend.navigation.arrowSize
     * @see https://api.highcharts.com/gantt/legend.navigation.arrowSize
     */
    arrowSize?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to enable the legend
     * navigation. In most cases, disabling the navigation results in an
     * unwanted overflow.
     *
     * See also the adapt chart to legend plugin for a solution to extend the
     * chart height to make room for the legend, optionally in exported charts
     * only.
     *
     * @see https://api.highcharts.com/highcharts/legend.navigation.enabled
     * @see https://api.highcharts.com/highstock/legend.navigation.enabled
     * @see https://api.highcharts.com/highmaps/legend.navigation.enabled
     * @see https://api.highcharts.com/gantt/legend.navigation.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the inactive up or
     * down arrow in the legend page navigation. .
     *
     * @see https://api.highcharts.com/highcharts/legend.navigation.inactiveColor
     * @see https://api.highcharts.com/highstock/legend.navigation.inactiveColor
     * @see https://api.highcharts.com/highmaps/legend.navigation.inactiveColor
     * @see https://api.highcharts.com/gantt/legend.navigation.inactiveColor
     */
    inactiveColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Text styles for the legend page
     * navigation.
     *
     * @see https://api.highcharts.com/highcharts/legend.navigation.style
     * @see https://api.highcharts.com/highstock/legend.navigation.style
     * @see https://api.highcharts.com/highmaps/legend.navigation.style
     * @see https://api.highcharts.com/gantt/legend.navigation.style
     */
    style?: CSSObject;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The legend is a box containing a
 * symbol and name for each series item or point item in the chart. Each series
 * (or points in case of pie charts) is represented by a symbol and its name in
 * the legend.
 *
 * It is possible to override the symbol creator function and create custom
 * legend symbols.
 *
 * @see https://api.highcharts.com/highcharts/legend
 * @see https://api.highcharts.com/highstock/legend
 * @see https://api.highcharts.com/highmaps/legend
 * @see https://api.highcharts.com/gantt/legend
 */
export interface LegendOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The horizontal alignment of the
     * legend box within the chart area. Valid values are `left`, `center` and
     * `right`.
     *
     * In the case that the legend is aligned in a corner position, the `layout`
     * option will determine whether to place it above/below or on the side of
     * the plot area.
     *
     * @see https://api.highcharts.com/highcharts/legend.align
     * @see https://api.highcharts.com/highstock/legend.align
     * @see https://api.highcharts.com/highmaps/legend.align
     * @see https://api.highcharts.com/gantt/legend.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) If the layout is `horizontal`
     * and the legend items span over two lines or more, whether to align the
     * items into vertical columns. Setting this to `false` makes room for more
     * items, but will look more messy.
     *
     * @see https://api.highcharts.com/highcharts/legend.alignColumns
     * @see https://api.highcharts.com/highstock/legend.alignColumns
     * @see https://api.highcharts.com/highmaps/legend.alignColumns
     * @see https://api.highcharts.com/gantt/legend.alignColumns
     */
    alignColumns?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The background color of the
     * legend.
     *
     * @see https://api.highcharts.com/highcharts/legend.backgroundColor
     * @see https://api.highcharts.com/highstock/legend.backgroundColor
     * @see https://api.highcharts.com/highmaps/legend.backgroundColor
     * @see https://api.highcharts.com/gantt/legend.backgroundColor
     */
    backgroundColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the drawn border
     * around the legend.
     *
     * @see https://api.highcharts.com/highcharts/legend.borderColor
     * @see https://api.highcharts.com/highstock/legend.borderColor
     * @see https://api.highcharts.com/highmaps/legend.borderColor
     * @see https://api.highcharts.com/gantt/legend.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border corner radius of the
     * legend.
     *
     * @see https://api.highcharts.com/highcharts/legend.borderRadius
     * @see https://api.highcharts.com/highstock/legend.borderRadius
     * @see https://api.highcharts.com/highmaps/legend.borderRadius
     * @see https://api.highcharts.com/gantt/legend.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the drawn border
     * around the legend.
     *
     * @see https://api.highcharts.com/highcharts/legend.borderWidth
     * @see https://api.highcharts.com/highstock/legend.borderWidth
     * @see https://api.highcharts.com/highmaps/legend.borderWidth
     * @see https://api.highcharts.com/gantt/legend.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps) The bubble legend is an additional
     * element in legend which presents the scale of the bubble series.
     * Individual bubble ranges can be defined by user or calculated from
     * series. In the case of automatically calculated ranges, a 1px margin of
     * error is permitted. Requires `highcharts-more.js`.
     *
     * @see https://api.highcharts.com/highcharts/legend.bubbleLegend
     * @see https://api.highcharts.com/highstock/legend.bubbleLegend
     * @see https://api.highcharts.com/highmaps/legend.bubbleLegend
     */
    bubbleLegend?: LegendBubbleLegendOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the legend.
     * There is also a series-specific option, showInLegend, that can hide the
     * series from the legend. In some series types this is `false` by default,
     * so it must set to `true` in order to show the legend for the series.
     *
     * @see https://api.highcharts.com/highcharts/legend.enabled
     * @see https://api.highcharts.com/highstock/legend.enabled
     * @see https://api.highcharts.com/highmaps/legend.enabled
     * @see https://api.highcharts.com/gantt/legend.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When the legend is floating, the
     * plot area ignores it and is allowed to be placed below it.
     *
     * @see https://api.highcharts.com/highcharts/legend.floating
     * @see https://api.highcharts.com/highstock/legend.floating
     * @see https://api.highcharts.com/highmaps/legend.floating
     * @see https://api.highcharts.com/gantt/legend.floating
     */
    floating?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Default styling for the checkbox
     * next to a legend item when `showCheckbox` is true.
     *
     * @see https://api.highcharts.com/highcharts/legend.itemCheckboxStyle
     * @see https://api.highcharts.com/highstock/legend.itemCheckboxStyle
     * @see https://api.highcharts.com/highmaps/legend.itemCheckboxStyle
     * @see https://api.highcharts.com/gantt/legend.itemCheckboxStyle
     */
    itemCheckboxStyle?: (CSSObject|LegendItemCheckboxStyleOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) In a legend with horizontal
     * layout, the itemDistance defines the pixel distance between each item.
     *
     * @see https://api.highcharts.com/highcharts/legend.itemDistance
     * @see https://api.highcharts.com/highstock/legend.itemDistance
     * @see https://api.highcharts.com/highmaps/legend.itemDistance
     * @see https://api.highcharts.com/gantt/legend.itemDistance
     */
    itemDistance?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for each legend item
     * when the corresponding series or point is hidden. Only a subset of CSS is
     * supported, notably those options related to text. Properties are
     * inherited from `style` unless overridden here.
     *
     * @see https://api.highcharts.com/highcharts/legend.itemHiddenStyle
     * @see https://api.highcharts.com/highstock/legend.itemHiddenStyle
     * @see https://api.highcharts.com/highmaps/legend.itemHiddenStyle
     * @see https://api.highcharts.com/gantt/legend.itemHiddenStyle
     */
    itemHiddenStyle?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for each legend item
     * in hover mode. Only a subset of CSS is supported, notably those options
     * related to text. Properties are inherited from `style` unless overridden
     * here.
     *
     * @see https://api.highcharts.com/highcharts/legend.itemHoverStyle
     * @see https://api.highcharts.com/highstock/legend.itemHoverStyle
     * @see https://api.highcharts.com/highmaps/legend.itemHoverStyle
     * @see https://api.highcharts.com/gantt/legend.itemHoverStyle
     */
    itemHoverStyle?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel bottom margin for each
     * legend item.
     *
     * @see https://api.highcharts.com/highcharts/legend.itemMarginBottom
     * @see https://api.highcharts.com/highstock/legend.itemMarginBottom
     * @see https://api.highcharts.com/highmaps/legend.itemMarginBottom
     * @see https://api.highcharts.com/gantt/legend.itemMarginBottom
     */
    itemMarginBottom?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel top margin for each
     * legend item.
     *
     * @see https://api.highcharts.com/highcharts/legend.itemMarginTop
     * @see https://api.highcharts.com/highstock/legend.itemMarginTop
     * @see https://api.highcharts.com/highmaps/legend.itemMarginTop
     * @see https://api.highcharts.com/gantt/legend.itemMarginTop
     */
    itemMarginTop?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for each legend item.
     * Only a subset of CSS is supported, notably those options related to text.
     * The default `textOverflow` property makes long texts truncate. Set it to
     * `undefined` to wrap text instead. A `width` property can be added to
     * control the text width.
     *
     * @see https://api.highcharts.com/highcharts/legend.itemStyle
     * @see https://api.highcharts.com/highstock/legend.itemStyle
     * @see https://api.highcharts.com/highmaps/legend.itemStyle
     * @see https://api.highcharts.com/gantt/legend.itemStyle
     */
    itemStyle?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width for each legend item.
     * By default the items are laid out successively. In a horizontal layout,
     * if the items are laid out across two rows or more, they will be
     * vertically aligned depending on the legend.alignColumns option.
     *
     * @see https://api.highcharts.com/highcharts/legend.itemWidth
     * @see https://api.highcharts.com/highstock/legend.itemWidth
     * @see https://api.highcharts.com/highmaps/legend.itemWidth
     * @see https://api.highcharts.com/gantt/legend.itemWidth
     */
    itemWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Keyboard navigation for the
     * legend. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/legend.keyboardNavigation
     * @see https://api.highcharts.com/highstock/legend.keyboardNavigation
     * @see https://api.highcharts.com/highmaps/legend.keyboardNavigation
     * @see https://api.highcharts.com/gantt/legend.keyboardNavigation
     */
    keyboardNavigation?: LegendKeyboardNavigationOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A format string for each legend
     * label. Available variables relates to properties on the series, or the
     * point in case of pies.
     *
     * @see https://api.highcharts.com/highcharts/legend.labelFormat
     * @see https://api.highcharts.com/highstock/legend.labelFormat
     * @see https://api.highcharts.com/highmaps/legend.labelFormat
     * @see https://api.highcharts.com/gantt/legend.labelFormat
     */
    labelFormat?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback function to format each
     * of the series' labels. The `this` keyword refers to the series object, or
     * the point object in case of pie charts. By default the series or point
     * name is printed.
     *
     * @see https://api.highcharts.com/highcharts/legend.labelFormatter
     * @see https://api.highcharts.com/highstock/legend.labelFormatter
     * @see https://api.highcharts.com/highmaps/legend.labelFormatter
     * @see https://api.highcharts.com/gantt/legend.labelFormatter
     */
    labelFormatter?: object;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The layout of the legend items.
     * Can be one of `horizontal` or `vertical` or `proximate`. When
     * `proximate`, the legend items will be placed as close as possible to the
     * graphs they're representing, except in inverted charts or when the legend
     * position doesn't allow it.
     *
     * @see https://api.highcharts.com/highcharts/legend.layout
     * @see https://api.highcharts.com/highstock/legend.layout
     * @see https://api.highcharts.com/highmaps/legend.layout
     * @see https://api.highcharts.com/gantt/legend.layout
     */
    layout?: ("horizontal"|"proximate"|"vertical");
    /**
     * (Highcharts, Gantt) Line height for the legend items. Deprecated as of
     * 2.1\. Instead, the line height for each item can be set using
     * itemStyle.lineHeight, and the padding between items using `itemMarginTop`
     * and `itemMarginBottom`.
     *
     * @see https://api.highcharts.com/highcharts/legend.lineHeight
     * @see https://api.highcharts.com/gantt/legend.lineHeight
     */
    lineHeight?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) If the plot area sized is
     * calculated automatically and the legend is not floating, the legend
     * margin is the space between the legend and the axis labels or plot area.
     *
     * @see https://api.highcharts.com/highcharts/legend.margin
     * @see https://api.highcharts.com/highstock/legend.margin
     * @see https://api.highcharts.com/highmaps/legend.margin
     * @see https://api.highcharts.com/gantt/legend.margin
     */
    margin?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Maximum pixel height for the
     * legend. When the maximum height is extended, navigation will show.
     *
     * @see https://api.highcharts.com/highcharts/legend.maxHeight
     * @see https://api.highcharts.com/highstock/legend.maxHeight
     * @see https://api.highcharts.com/highmaps/legend.maxHeight
     * @see https://api.highcharts.com/gantt/legend.maxHeight
     */
    maxHeight?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the paging or
     * navigation appearing when the legend is overflown. Navigation works well
     * on screen, but not in static exported images. One way of working around
     * that is to increase the chart height in export.
     *
     * @see https://api.highcharts.com/highcharts/legend.navigation
     * @see https://api.highcharts.com/highstock/legend.navigation
     * @see https://api.highcharts.com/highmaps/legend.navigation
     * @see https://api.highcharts.com/gantt/legend.navigation
     */
    navigation?: LegendNavigationOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The inner padding of the legend
     * box.
     *
     * @see https://api.highcharts.com/highcharts/legend.padding
     * @see https://api.highcharts.com/highstock/legend.padding
     * @see https://api.highcharts.com/highmaps/legend.padding
     * @see https://api.highcharts.com/gantt/legend.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to reverse the order of
     * the legend items compared to the order of the series or points as defined
     * in the configuration object.
     *
     * @see https://api.highcharts.com/highcharts/legend.reversed
     * @see https://api.highcharts.com/highstock/legend.reversed
     * @see https://api.highcharts.com/highmaps/legend.reversed
     * @see https://api.highcharts.com/gantt/legend.reversed
     */
    reversed?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to show the symbol on
     * the right side of the text rather than the left side. This is common in
     * Arabic and Hebraic.
     *
     * @see https://api.highcharts.com/highcharts/legend.rtl
     * @see https://api.highcharts.com/highstock/legend.rtl
     * @see https://api.highcharts.com/highmaps/legend.rtl
     * @see https://api.highcharts.com/gantt/legend.rtl
     */
    rtl?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to apply a drop shadow
     * to the legend. A `backgroundColor` also needs to be applied for this to
     * take effect. The shadow can be an object configuration containing
     * `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/legend.shadow
     * @see https://api.highcharts.com/highstock/legend.shadow
     * @see https://api.highcharts.com/highmaps/legend.shadow
     * @see https://api.highcharts.com/gantt/legend.shadow
     */
    shadow?: (boolean|CSSObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When this is true, the legend
     * symbol width will be the same as the symbol height, which in turn
     * defaults to the font size of the legend items.
     *
     * @see https://api.highcharts.com/highcharts/legend.squareSymbol
     * @see https://api.highcharts.com/highstock/legend.squareSymbol
     * @see https://api.highcharts.com/highmaps/legend.squareSymbol
     * @see https://api.highcharts.com/gantt/legend.squareSymbol
     */
    squareSymbol?: boolean;
    /**
     * (Highcharts, Highstock) CSS styles for the legend area. In the 1.x
     * versions the position of the legend area was determined by CSS. In 2.x,
     * the position is determined by properties like `align`, `verticalAlign`,
     * `x` and `y`, but the styles are still parsed for backwards compatibility.
     *
     * @see https://api.highcharts.com/highcharts/legend.style
     * @see https://api.highcharts.com/highstock/legend.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel height of the symbol
     * for series types that use a rectangle in the legend. Defaults to the font
     * size of legend items.
     *
     * @see https://api.highcharts.com/highcharts/legend.symbolHeight
     * @see https://api.highcharts.com/highstock/legend.symbolHeight
     * @see https://api.highcharts.com/highmaps/legend.symbolHeight
     * @see https://api.highcharts.com/gantt/legend.symbolHeight
     */
    symbolHeight?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel padding between the
     * legend item symbol and the legend item text.
     *
     * @see https://api.highcharts.com/highcharts/legend.symbolPadding
     * @see https://api.highcharts.com/highstock/legend.symbolPadding
     * @see https://api.highcharts.com/highmaps/legend.symbolPadding
     * @see https://api.highcharts.com/gantt/legend.symbolPadding
     */
    symbolPadding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border radius of the symbol
     * for series types that use a rectangle in the legend. Defaults to half the
     * `symbolHeight`.
     *
     * @see https://api.highcharts.com/highcharts/legend.symbolRadius
     * @see https://api.highcharts.com/highstock/legend.symbolRadius
     * @see https://api.highcharts.com/highmaps/legend.symbolRadius
     * @see https://api.highcharts.com/gantt/legend.symbolRadius
     */
    symbolRadius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the legend
     * item symbol. When the `squareSymbol` option is set, this defaults to the
     * `symbolHeight`, otherwise 16.
     *
     * @see https://api.highcharts.com/highcharts/legend.symbolWidth
     * @see https://api.highcharts.com/highstock/legend.symbolWidth
     * @see https://api.highcharts.com/highmaps/legend.symbolWidth
     * @see https://api.highcharts.com/gantt/legend.symbolWidth
     */
    symbolWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A title to be added on top of
     * the legend.
     *
     * @see https://api.highcharts.com/highcharts/legend.title
     * @see https://api.highcharts.com/highstock/legend.title
     * @see https://api.highcharts.com/highmaps/legend.title
     * @see https://api.highcharts.com/gantt/legend.title
     */
    title?: LegendTitleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render
     * the legend item texts.
     *
     * Prior to 4.1.7, when using HTML, legend.navigation was disabled.
     *
     * @see https://api.highcharts.com/highcharts/legend.useHTML
     * @see https://api.highcharts.com/highstock/legend.useHTML
     * @see https://api.highcharts.com/highmaps/legend.useHTML
     * @see https://api.highcharts.com/gantt/legend.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical alignment of the
     * legend box. Can be one of `top`, `middle` or `bottom`. Vertical position
     * can be further determined by the `y` option.
     *
     * In the case that the legend is aligned in a corner position, the `layout`
     * option will determine whether to place it above/below or on the side of
     * the plot area.
     *
     * When the layout option is `proximate`, the `verticalAlign` option doesn't
     * apply.
     *
     * @see https://api.highcharts.com/highcharts/legend.verticalAlign
     * @see https://api.highcharts.com/highstock/legend.verticalAlign
     * @see https://api.highcharts.com/highmaps/legend.verticalAlign
     * @see https://api.highcharts.com/gantt/legend.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the legend box.
     *
     * @see https://api.highcharts.com/highcharts/legend.width
     * @see https://api.highcharts.com/highstock/legend.width
     * @see https://api.highcharts.com/highmaps/legend.width
     * @see https://api.highcharts.com/gantt/legend.width
     */
    width?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x offset of the legend
     * relative to its horizontal alignment `align` within chart.spacingLeft and
     * chart.spacingRight. Negative x moves it to the left, positive x moves it
     * to the right.
     *
     * @see https://api.highcharts.com/highcharts/legend.x
     * @see https://api.highcharts.com/highstock/legend.x
     * @see https://api.highcharts.com/highmaps/legend.x
     * @see https://api.highcharts.com/gantt/legend.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical offset of the
     * legend relative to it's vertical alignment `verticalAlign` within
     * chart.spacingTop and chart.spacingBottom. Negative y moves it up,
     * positive y moves it down.
     *
     * @see https://api.highcharts.com/highcharts/legend.y
     * @see https://api.highcharts.com/highstock/legend.y
     * @see https://api.highcharts.com/highmaps/legend.y
     * @see https://api.highcharts.com/gantt/legend.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) A title to be added on top of the
 * legend.
 *
 * @see https://api.highcharts.com/highcharts/legend.title
 * @see https://api.highcharts.com/highstock/legend.title
 * @see https://api.highcharts.com/highmaps/legend.title
 * @see https://api.highcharts.com/gantt/legend.title
 */
export interface LegendTitleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Generic CSS styles for the
     * legend title.
     *
     * @see https://api.highcharts.com/highcharts/legend.title.style
     * @see https://api.highcharts.com/highstock/legend.title.style
     * @see https://api.highcharts.com/highmaps/legend.title.style
     * @see https://api.highcharts.com/gantt/legend.title.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A text or HTML string for the
     * title.
     *
     * @see https://api.highcharts.com/highcharts/legend.title.text
     * @see https://api.highcharts.com/highstock/legend.title.text
     * @see https://api.highcharts.com/highmaps/legend.title.text
     * @see https://api.highcharts.com/gantt/legend.title.text
     */
    text?: string;
}
/**
 * Defines the start position and the end position for a gradient relative to
 * the shape. Start position (x1, y1) and end position (x2, y2) are relative to
 * the shape, where 0 means top/left and 1 is bottom/right.
 */
export interface LinearGradientColorObject {
    /**
     * Start horizontal position of the gradient. Float ranges 0-1.
     */
    x1: number;
    /**
     * End horizontal position of the gradient. Float ranges 0-1.
     */
    x2: number;
    /**
     * Start vertical position of the gradient. Float ranges 0-1.
     */
    y1: number;
    /**
     * End vertical position of the gradient. Float ranges 0-1.
     */
    y2: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The loading options control the
 * appearance of the loading screen that covers the plot area on chart
 * operations. This screen only appears after an explicit call to
 * `chart.showLoading()`. It is a utility for developers to communicate to the
 * end user that something is going on, for example while retrieving new data
 * via an XHR connection. The "Loading..." text itself is not part of this
 * configuration object, but part of the `lang` object.
 *
 * @see https://api.highcharts.com/highcharts/loading
 * @see https://api.highcharts.com/highstock/loading
 * @see https://api.highcharts.com/highmaps/loading
 * @see https://api.highcharts.com/gantt/loading
 */
export interface LoadingOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The duration in milliseconds of
     * the fade out effect.
     *
     * @see https://api.highcharts.com/highcharts/loading.hideDuration
     * @see https://api.highcharts.com/highstock/loading.hideDuration
     * @see https://api.highcharts.com/highmaps/loading.hideDuration
     * @see https://api.highcharts.com/gantt/loading.hideDuration
     */
    hideDuration?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the loading label
     * `span`.
     *
     * @see https://api.highcharts.com/highcharts/loading.labelStyle
     * @see https://api.highcharts.com/highstock/loading.labelStyle
     * @see https://api.highcharts.com/highmaps/loading.labelStyle
     * @see https://api.highcharts.com/gantt/loading.labelStyle
     */
    labelStyle?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The duration in milliseconds of
     * the fade in effect.
     *
     * @see https://api.highcharts.com/highcharts/loading.showDuration
     * @see https://api.highcharts.com/highstock/loading.showDuration
     * @see https://api.highcharts.com/highmaps/loading.showDuration
     * @see https://api.highcharts.com/gantt/loading.showDuration
     */
    showDuration?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the loading
     * screen that covers the plot area.
     *
     * In styled mode, the loading label is styled with the
     * `.highcharts-loading` class.
     *
     * @see https://api.highcharts.com/highcharts/loading.style
     * @see https://api.highcharts.com/highstock/loading.style
     * @see https://api.highcharts.com/highmaps/loading.style
     * @see https://api.highcharts.com/gantt/loading.style
     */
    style?: CSSObject;
}
/**
 * Map data object.
 */
export interface MapDataObject {
    /**
     * The name of the data.
     */
    name?: string;
    /**
     * The SVG path.
     */
    path: SVGPathArray;
    /**
     * The GeoJSON meta data.
     */
    properties?: object;
}
/**
 * (Highmaps) General options for the map navigation buttons. Individual options
 * can be given from the mapNavigation.buttons option set.
 *
 * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions
 */
export interface MapNavigationButtonOptions {
    /**
     * (Highmaps) The alignment of the navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highmaps) What box to align the buttons to. Possible values are
     * `plotBox` and `spacingBox`.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions.alignTo
     */
    alignTo?: ("plotBox"|"spacingBox");
    /**
     * (Highmaps) The pixel height of the map navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions.height
     */
    height?: number;
    /**
     * (Highmaps) Padding for the navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions.padding
     */
    padding?: number;
    /**
     * (Highmaps) Text styles for the map navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions.style
     */
    style?: CSSObject;
    /**
     * (Highmaps) A configuration object for the button theme. The object
     * accepts SVG properties like `stroke-width`, `stroke` and `fill`.
     * Tri-state button styles are supported by the `states.hover` and
     * `states.select` objects.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions.theme
     */
    theme?: SVGAttributes;
    /**
     * (Highmaps) The vertical alignment of the buttons. Individual alignment
     * can be adjusted by each button's `y` offset.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highmaps) The width of the map navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions.width
     */
    width?: number;
    /**
     * (Highmaps) The X offset of the buttons relative to its `align` setting.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions.x
     */
    x?: number;
}
/**
 * (Highmaps) The individual buttons for the map navigation. This usually
 * includes the zoom in and zoom out buttons. Properties for each button is
 * inherited from mapNavigation.buttonOptions, while individual options can be
 * overridden. But default, the `onclick`, `text` and `y` options are
 * individual.
 *
 * @see https://api.highcharts.com/highmaps/mapNavigation.buttons
 */
export interface MapNavigationButtonsOptions {
    /**
     * (Highmaps) Options for the zoom in button. Properties for the zoom in and
     * zoom out buttons are inherited from mapNavigation.buttonOptions, while
     * individual options can be overridden. By default, the `onclick`, `text`
     * and `y` options are individual.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn
     */
    zoomIn?: MapNavigationButtonsZoomInOptions;
    /**
     * (Highmaps) Options for the zoom out button. Properties for the zoom in
     * and zoom out buttons are inherited from mapNavigation.buttonOptions,
     * while individual options can be overridden. By default, the `onclick`,
     * `text` and `y` options are individual.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut
     */
    zoomOut?: MapNavigationButtonsZoomOutOptions;
}
/**
 * (Highmaps) Options for the zoom in button. Properties for the zoom in and
 * zoom out buttons are inherited from mapNavigation.buttonOptions, while
 * individual options can be overridden. By default, the `onclick`, `text` and
 * `y` options are individual.
 *
 * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn
 */
export interface MapNavigationButtonsZoomInOptions {
    /**
     * (Highmaps) The alignment of the navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highmaps) What box to align the buttons to. Possible values are
     * `plotBox` and `spacingBox`.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.alignTo
     */
    alignTo?: ("plotBox"|"spacingBox");
    /**
     * (Highmaps) The pixel height of the map navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.height
     */
    height?: number;
    /**
     * (Highmaps) Click handler for the button.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.onclick
     */
    onclick?: () => void;
    /**
     * (Highmaps) Padding for the navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.padding
     */
    padding?: number;
    /**
     * (Highmaps) Text styles for the map navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.style
     */
    style?: CSSObject;
    /**
     * (Highmaps) The text for the button. The tooltip (title) is a language
     * option given by lang.zoomIn.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.text
     */
    text?: string;
    /**
     * (Highmaps) A configuration object for the button theme. The object
     * accepts SVG properties like `stroke-width`, `stroke` and `fill`.
     * Tri-state button styles are supported by the `states.hover` and
     * `states.select` objects.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.theme
     */
    theme?: SVGAttributes;
    /**
     * (Highmaps) The vertical alignment of the buttons. Individual alignment
     * can be adjusted by each button's `y` offset.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highmaps) The width of the map navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.width
     */
    width?: number;
    /**
     * (Highmaps) The X offset of the buttons relative to its `align` setting.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.x
     */
    x?: number;
    /**
     * (Highmaps) The position of the zoomIn button relative to the vertical
     * alignment.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomIn.y
     */
    y?: number;
}
/**
 * (Highmaps) Options for the zoom out button. Properties for the zoom in and
 * zoom out buttons are inherited from mapNavigation.buttonOptions, while
 * individual options can be overridden. By default, the `onclick`, `text` and
 * `y` options are individual.
 *
 * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut
 */
export interface MapNavigationButtonsZoomOutOptions {
    /**
     * (Highmaps) The alignment of the navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highmaps) What box to align the buttons to. Possible values are
     * `plotBox` and `spacingBox`.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.alignTo
     */
    alignTo?: ("plotBox"|"spacingBox");
    /**
     * (Highmaps) The pixel height of the map navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.height
     */
    height?: number;
    /**
     * (Highmaps) Click handler for the button.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.onclick
     */
    onclick?: () => void;
    /**
     * (Highmaps) Padding for the navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.padding
     */
    padding?: number;
    /**
     * (Highmaps) Text styles for the map navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.style
     */
    style?: CSSObject;
    /**
     * (Highmaps) The text for the button. The tooltip (title) is a language
     * option given by lang.zoomOut.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.text
     */
    text?: string;
    /**
     * (Highmaps) A configuration object for the button theme. The object
     * accepts SVG properties like `stroke-width`, `stroke` and `fill`.
     * Tri-state button styles are supported by the `states.hover` and
     * `states.select` objects.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.theme
     */
    theme?: SVGAttributes;
    /**
     * (Highmaps) The vertical alignment of the buttons. Individual alignment
     * can be adjusted by each button's `y` offset.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highmaps) The width of the map navigation buttons.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.width
     */
    width?: number;
    /**
     * (Highmaps) The X offset of the buttons relative to its `align` setting.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.x
     */
    x?: number;
    /**
     * (Highmaps) The position of the zoomOut button relative to the vertical
     * alignment.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons.zoomOut.y
     */
    y?: number;
}
export interface MapNavigationOptions {
    /**
     * (Highmaps) General options for the map navigation buttons. Individual
     * options can be given from the mapNavigation.buttons option set.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttonOptions
     */
    buttonOptions?: MapNavigationButtonOptions;
    /**
     * (Highmaps) The individual buttons for the map navigation. This usually
     * includes the zoom in and zoom out buttons. Properties for each button is
     * inherited from mapNavigation.buttonOptions, while individual options can
     * be overridden. But default, the `onclick`, `text` and `y` options are
     * individual.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.buttons
     */
    buttons?: MapNavigationButtonsOptions;
    /**
     * (Highmaps) Whether to enable navigation buttons. By default it inherits
     * the enabled setting.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.enableButtons
     */
    enableButtons?: boolean;
    /**
     * (Highmaps) Whether to enable map navigation. The default is not to enable
     * navigation, as many choropleth maps are simple and don't need it.
     * Additionally, when touch zoom and mousewheel zoom is enabled, it breaks
     * the default behaviour of these interactions in the website, and the
     * implementer should be aware of this.
     *
     * Individual interactions can be enabled separately, namely buttons,
     * multitouch zoom, double click zoom, double click zoom to element and
     * mousewheel zoom.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.enabled
     */
    enabled?: boolean;
    /**
     * (Highmaps) Enables zooming in on an area on double clicking in the map.
     * By default it inherits the enabled setting.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.enableDoubleClickZoom
     */
    enableDoubleClickZoom?: boolean;
    /**
     * (Highmaps) Whether to zoom in on an area when that area is double
     * clicked.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.enableDoubleClickZoomTo
     */
    enableDoubleClickZoomTo?: boolean;
    /**
     * (Highmaps) Enables zooming by mouse wheel. By default it inherits the
     * enabled setting.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.enableMouseWheelZoom
     */
    enableMouseWheelZoom?: boolean;
    /**
     * (Highmaps) Whether to enable multitouch zooming. Note that if the chart
     * covers the viewport, this prevents the user from using multitouch and
     * touchdrag on the web page, so you should make sure the user is not
     * trapped inside the chart. By default it inherits the enabled setting.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.enableTouchZoom
     */
    enableTouchZoom?: boolean;
    /**
     * (Highmaps) Sensitivity of mouse wheel or trackpad scrolling. 1 is no
     * sensitivity, while with 2, one mousewheel delta will zoom in 50%.
     *
     * @see https://api.highcharts.com/highmaps/mapNavigation.mouseWheelSensitivity
     */
    mouseWheelSensitivity?: number;
}
/**
 * (Highcharts, Highstock) Bindings definitions for custom HTML buttons. Each
 * binding implements simple event-driven interface:
 *
 * - `className`: classname used to bind event to
 *
 * - `init`: initial event, fired on button click
 *
 * - `start`: fired on first click on a chart
 *
 * - `steps`: array of sequential events fired one after another on each of
 * users clicks
 *
 * - `end`: last event to be called after last step event
 *
 * @see https://api.highcharts.com/highcharts/navigation.bindings
 * @see https://api.highcharts.com/highstock/navigation.bindings
 */
export interface NavigationBindingsOptions {
    /**
     * (Highstock) A line with arrow annotation. Includes `start` and one event
     * in `steps` array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.arrowInfinityLine
     */
    arrowInfinityLine?: StockToolsBindingsObject;
    /**
     * (Highstock) A ray with an arrow annotation bindings. Includes `start` and
     * one event in `steps` array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.arrowRay
     */
    arrowRay?: StockToolsBindingsObject;
    /**
     * (Highstock) A segment with an arrow annotation bindings. Includes `start`
     * and one event in `steps` array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.arrowSegment
     */
    arrowSegment?: StockToolsBindingsObject;
    /**
     * (Highcharts, Highstock) A circle annotation bindings. Includes `start`
     * and one event in `steps` array.
     *
     * @see https://api.highcharts.com/highcharts/navigation.bindings.circleAnnotation
     * @see https://api.highcharts.com/highstock/navigation.bindings.circleAnnotation
     */
    circleAnnotation?: StockToolsBindingsObject;
    /**
     * (Highstock) Crooked line (three points) annotation bindings. Includes
     * `start` and two events in `steps` (for second and third points in crooked
     * line) array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.crooked3
     */
    crooked3?: StockToolsBindingsObject;
    /**
     * (Highstock) Crooked line (five points) annotation bindings. Includes
     * `start` and four events in `steps` (for all consequent points in crooked
     * line) array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.crooked5
     */
    crooked5?: StockToolsBindingsObject;
    /**
     * (Highstock) Hides/shows two price indicators:
     *
     * - last price in the dataset
     *
     * - last price in the selected range
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.currentPriceIndicator
     */
    currentPriceIndicator?: StockToolsBindingsObject;
    /**
     * (Highstock) Elliott wave (three points) annotation bindings. Includes
     * `start` and two events in `steps` (for second and third points) array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.elliott3
     */
    elliott3?: StockToolsBindingsObject;
    /**
     * (Highstock) Elliott wave (five points) annotation bindings. Includes
     * `start` and four event in `steps` (for all consequent points in Elliott
     * wave) array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.elliott5
     */
    elliott5?: StockToolsBindingsObject;
    /**
     * (Highstock) A fibonacci annotation bindings. Includes `start` and two
     * events in `steps` array (updates second point, then height).
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.fibonacci
     */
    fibonacci?: StockToolsBindingsObject;
    /**
     * (Highstock) A flag series bindings. Includes `start` event. On click,
     * finds the closest point and marks it with a flag with `'circlepin'`
     * shape.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.flagCirclepin
     */
    flagCirclepin?: StockToolsBindingsObject;
    /**
     * (Highstock) A flag series bindings. Includes `start` event. On click,
     * finds the closest point and marks it with a flag with `'diamondpin'`
     * shape.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.flagDiamondpin
     */
    flagDiamondpin?: StockToolsBindingsObject;
    /**
     * (Highstock) A flag series bindings. Includes `start` event. On click,
     * finds the closest point and marks it with a flag without pin shape.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.flagSimplepin
     */
    flagSimplepin?: StockToolsBindingsObject;
    /**
     * (Highstock) A flag series bindings. Includes `start` event. On click,
     * finds the closest point and marks it with a flag with `'squarepin'`
     * shape.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.flagSquarepin
     */
    flagSquarepin?: StockToolsBindingsObject;
    /**
     * (Highstock) Displays chart in fullscreen.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.fullScreen
     */
    fullScreen?: StockToolsBindingsObject;
    /**
     * (Highstock) A horizontal line annotation. Includes `start` event.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.horizontalLine
     */
    horizontalLine?: StockToolsBindingsObject;
    /**
     * (Highstock) Indicators bindings. Includes `init` event to show a popup.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.indicators
     */
    indicators?: StockToolsBindingsObject;
    /**
     * (Highstock) A line annotation. Includes `start` and one event in `steps`
     * array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.infinityLine
     */
    infinityLine?: StockToolsBindingsObject;
    /**
     * (Highcharts, Highstock) A label annotation bindings. Includes `start`
     * event only.
     *
     * @see https://api.highcharts.com/highcharts/navigation.bindings.labelAnnotation
     * @see https://api.highcharts.com/highstock/navigation.bindings.labelAnnotation
     */
    labelAnnotation?: StockToolsBindingsObject;
    /**
     * (Highstock) A measure (x-dimension) annotation bindings. Includes `start`
     * and one event in `steps` array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.measureX
     */
    measureX?: StockToolsBindingsObject;
    /**
     * (Highstock) A measure (xy-dimension) annotation bindings. Includes
     * `start` and one event in `steps` array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.measureXY
     */
    measureXY?: StockToolsBindingsObject;
    /**
     * (Highstock) A measure (y-dimension) annotation bindings. Includes `start`
     * and one event in `steps` array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.measureY
     */
    measureY?: StockToolsBindingsObject;
    /**
     * (Highstock) A parallel channel (tunnel) annotation bindings. Includes
     * `start` and two events in `steps` array (updates second point, then
     * height).
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.parallelChannel
     */
    parallelChannel?: StockToolsBindingsObject;
    /**
     * (Highstock) An Andrew's pitchfork annotation bindings. Includes `start`
     * and two events in `steps` array (sets second and third control points).
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.pitchfork
     */
    pitchfork?: StockToolsBindingsObject;
    /**
     * (Highstock) A ray annotation bindings. Includes `start` and one event in
     * `steps` array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.ray
     */
    ray?: StockToolsBindingsObject;
    /**
     * (Highcharts, Highstock) A rectangle annotation bindings. Includes `start`
     * and one event in `steps` array.
     *
     * @see https://api.highcharts.com/highcharts/navigation.bindings.rectangleAnnotation
     * @see https://api.highcharts.com/highstock/navigation.bindings.rectangleAnnotation
     */
    rectangleAnnotation?: StockToolsBindingsObject;
    /**
     * (Highstock) Save a chart in localStorage under `highcharts-chart` key.
     * Stored items:
     *
     * - annotations
     *
     * - indicators (with yAxes)
     *
     * - flags
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.saveChart
     */
    saveChart?: StockToolsBindingsObject;
    /**
     * (Highstock) A segment annotation bindings. Includes `start` and one event
     * in `steps` array.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.segment
     */
    segment?: StockToolsBindingsObject;
    /**
     * (Highstock) Changes main series to `'candlestick'` type.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.seriesTypeCandlestick
     */
    seriesTypeCandlestick?: StockToolsBindingsObject;
    /**
     * (Highstock) Changes main series to `'line'` type.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.seriesTypeLine
     */
    seriesTypeLine?: StockToolsBindingsObject;
    /**
     * (Highstock) Changes main series to `'ohlc'` type.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.seriesTypeOhlc
     */
    seriesTypeOhlc?: StockToolsBindingsObject;
    /**
     * (Highstock) Hides/shows all annotations on a chart.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.toggleAnnotations
     */
    toggleAnnotations?: StockToolsBindingsObject;
    /**
     * (Highstock) A vertical arrow annotation bindings. Includes `start` event.
     * On click, finds the closest point and marks it with an arrow. Green arrow
     * when pointing from above, red when pointing from below the point.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.verticalArrow
     */
    verticalArrow?: StockToolsBindingsObject;
    /**
     * (Highstock) A vertical counter annotation bindings. Includes `start`
     * event. On click, finds the closest point and marks it with a numeric
     * annotation - incrementing counter on each add.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.verticalCounter
     */
    verticalCounter?: StockToolsBindingsObject;
    /**
     * (Highstock) A vertical arrow annotation bindings. Includes `start` event.
     * On click, finds the closest point and marks it with an arrow and a label
     * with value.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.verticalLabel
     */
    verticalLabel?: StockToolsBindingsObject;
    /**
     * (Highstock) A vertical line annotation. Includes `start` event.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.verticalLine
     */
    verticalLine?: StockToolsBindingsObject;
    /**
     * (Highstock) Enables zooming in xAxis on a chart. Includes `start` event
     * which changes chart.zoomType.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.zoomX
     */
    zoomX?: StockToolsBindingsObject;
    /**
     * (Highstock) Enables zooming in xAxis and yAxis on a chart. Includes
     * `start` event which changes chart.zoomType.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.zoomXY
     */
    zoomXY?: StockToolsBindingsObject;
    /**
     * (Highstock) Enables zooming in yAxis on a chart. Includes `start` event
     * which changes chart.zoomType.
     *
     * @see https://api.highcharts.com/highstock/navigation.bindings.zoomY
     */
    zoomY?: StockToolsBindingsObject;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) A collection of options for buttons
 * appearing in the exporting module.
 *
 * In styled mode, the buttons are styled with the `.highcharts-contextbutton`
 * and `.highcharts-button-symbol` classes.
 *
 * @see https://api.highcharts.com/highcharts/navigation.buttonOptions
 * @see https://api.highcharts.com/highstock/navigation.buttonOptions
 * @see https://api.highcharts.com/highmaps/navigation.buttonOptions
 * @see https://api.highcharts.com/gantt/navigation.buttonOptions
 */
export interface NavigationButtonOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to enable buttons.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.enabled
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions.enabled
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.enabled
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fill color for the symbol within
     * the button.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.symbolFill
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions.symbolFill
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.symbolFill
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions.symbolFill
     */
    symbolFill?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the symbol's stroke
     * or line.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.symbolStroke
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions.symbolStroke
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.symbolStroke
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions.symbolStroke
     */
    symbolStroke?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel stroke width of the
     * symbol on the button.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.symbolStrokeWidth
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions.symbolStrokeWidth
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.symbolStrokeWidth
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions.symbolStrokeWidth
     */
    symbolStrokeWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A text string to add to the
     * individual button.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.text
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions.text
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.text
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A configuration object for the
     * button theme. The object accepts SVG properties like `stroke-width`,
     * `stroke` and `fill`. Tri-state button styles are supported by the
     * `states.hover` and `states.select` objects.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.theme
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions.theme
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.theme
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions.theme
     */
    theme?: NavigationButtonThemeOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical offset of the
     * button's position relative to its `verticalAlign`.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.y
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions.y
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.y
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) A configuration object for the
 * button theme. The object accepts SVG properties like `stroke-width`, `stroke`
 * and `fill`. Tri-state button styles are supported by the `states.hover` and
 * `states.select` objects.
 *
 * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.theme
 * @see https://api.highcharts.com/highstock/navigation.buttonOptions.theme
 * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.theme
 * @see https://api.highcharts.com/gantt/navigation.buttonOptions.theme
 */
export interface NavigationButtonThemeOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The default fill exists only to
     * capture hover events.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.theme.fill
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions.theme.fill
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.theme.fill
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions.theme.fill
     */
    fill?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Padding for the button.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.theme.padding
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions.theme.padding
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.theme.padding
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions.theme.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Default stroke for the buttons.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions.theme.stroke
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions.theme.stroke
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions.theme.stroke
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions.theme.stroke
     */
    stroke?: ColorString;
}
/**
 * (Highcharts, Highstock) Events to communicate between Stock Tools and custom
 * GUI.
 *
 * @see https://api.highcharts.com/highcharts/navigation.events
 * @see https://api.highcharts.com/highstock/navigation.events
 */
export interface NavigationEventsOptions {
    /**
     * (Highcharts, Highstock) Event fired when button state should change, for
     * example after adding an annotation.
     *
     * @see https://api.highcharts.com/highcharts/navigation.events.deselectButton
     * @see https://api.highcharts.com/highstock/navigation.events.deselectButton
     */
    deselectButton?: () => void;
    /**
     * (Highcharts, Highstock) A `hidePopop` event. Fired when Popup should be
     * hidden, for exampole when clicking on an annotation again.
     *
     * @see https://api.highcharts.com/highcharts/navigation.events.hidePopup
     * @see https://api.highcharts.com/highstock/navigation.events.hidePopup
     */
    hidePopup?: () => void;
    /**
     * (Highcharts, Highstock) Event fired on a button click.
     *
     * @see https://api.highcharts.com/highcharts/navigation.events.selectButton
     * @see https://api.highcharts.com/highstock/navigation.events.selectButton
     */
    selectButton?: () => void;
    /**
     * (Highcharts, Highstock) A `showPopup` event. Fired when selecting for
     * example an annotation.
     *
     * @see https://api.highcharts.com/highcharts/navigation.events.showPopup
     * @see https://api.highcharts.com/highstock/navigation.events.showPopup
     */
    showPopup?: () => void;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) A collection of options for buttons
 * and menus appearing in the exporting module.
 *
 * @see https://api.highcharts.com/highcharts/navigation
 * @see https://api.highcharts.com/highstock/navigation
 * @see https://api.highcharts.com/highmaps/navigation
 * @see https://api.highcharts.com/gantt/navigation
 */
export interface NavigationOptions {
    /**
     * (Highcharts, Highstock) Bindings definitions for custom HTML buttons.
     * Each binding implements simple event-driven interface:
     *
     * - `className`: classname used to bind event to
     *
     * - `init`: initial event, fired on button click
     *
     * - `start`: fired on first click on a chart
     *
     * - `steps`: array of sequential events fired one after another on each of
     * users clicks
     *
     * - `end`: last event to be called after last step event
     *
     * @see https://api.highcharts.com/highcharts/navigation.bindings
     * @see https://api.highcharts.com/highstock/navigation.bindings
     */
    bindings?: (NavigationBindingsOptions|Dictionary<StockToolsBindingsObject>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A CSS class name where all
     * bindings will be attached to. Multiple charts on the same page should
     * have separate class names to prevent duplicating events.
     *
     * @see https://api.highcharts.com/highcharts/navigation.bindingsClassName
     * @see https://api.highcharts.com/highstock/navigation.bindingsClassName
     * @see https://api.highcharts.com/highmaps/navigation.bindingsClassName
     * @see https://api.highcharts.com/gantt/navigation.bindingsClassName
     */
    bindingsClassName?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A collection of options for
     * buttons appearing in the exporting module.
     *
     * In styled mode, the buttons are styled with the
     * `.highcharts-contextbutton` and `.highcharts-button-symbol` classes.
     *
     * @see https://api.highcharts.com/highcharts/navigation.buttonOptions
     * @see https://api.highcharts.com/highstock/navigation.buttonOptions
     * @see https://api.highcharts.com/highmaps/navigation.buttonOptions
     * @see https://api.highcharts.com/gantt/navigation.buttonOptions
     */
    buttonOptions?: NavigationButtonOptions;
    /**
     * (Highcharts, Highstock) Events to communicate between Stock Tools and
     * custom GUI.
     *
     * @see https://api.highcharts.com/highcharts/navigation.events
     * @see https://api.highcharts.com/highstock/navigation.events
     */
    events?: NavigationEventsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the hover state
     * of the individual items within the popup menu appearing by default when
     * the export icon is clicked. The menu items are rendered in HTML.
     *
     * @see https://api.highcharts.com/highcharts/navigation.menuItemHoverStyle
     * @see https://api.highcharts.com/highstock/navigation.menuItemHoverStyle
     * @see https://api.highcharts.com/highmaps/navigation.menuItemHoverStyle
     * @see https://api.highcharts.com/gantt/navigation.menuItemHoverStyle
     */
    menuItemHoverStyle?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the individual
     * items within the popup menu appearing by default when the export icon is
     * clicked. The menu items are rendered in HTML. Font size defaults to
     * `11px` on desktop and `14px` on touch devices.
     *
     * @see https://api.highcharts.com/highcharts/navigation.menuItemStyle
     * @see https://api.highcharts.com/highstock/navigation.menuItemStyle
     * @see https://api.highcharts.com/highmaps/navigation.menuItemStyle
     * @see https://api.highcharts.com/gantt/navigation.menuItemStyle
     */
    menuItemStyle?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the popup menu
     * appearing by default when the export icon is clicked. This menu is
     * rendered in HTML.
     *
     * @see https://api.highcharts.com/highcharts/navigation.menuStyle
     * @see https://api.highcharts.com/highstock/navigation.menuStyle
     * @see https://api.highcharts.com/highmaps/navigation.menuStyle
     * @see https://api.highcharts.com/gantt/navigation.menuStyle
     */
    menuStyle?: CSSObject;
}
/**
 * (Highstock) Options for the handles for dragging the zoomed area.
 *
 * @see https://api.highcharts.com/highstock/navigator.handles
 */
export interface NavigatorHandlesOptions {
    /**
     * (Highstock) The fill for the handle.
     *
     * @see https://api.highcharts.com/highstock/navigator.handles.backgroundColor
     */
    backgroundColor?: ColorString;
    /**
     * (Highstock) The stroke for the handle border and the stripes inside.
     *
     * @see https://api.highcharts.com/highstock/navigator.handles.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) Allows to enable/disable handles.
     *
     * @see https://api.highcharts.com/highstock/navigator.handles.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) Height for handles.
     *
     * @see https://api.highcharts.com/highstock/navigator.handles.height
     */
    height?: number;
    /**
     * (Highstock) The width for the handle border and the stripes inside.
     *
     * @see https://api.highcharts.com/highstock/navigator.handles.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Array to define shapes of handles. 0-index for left, 1-index
     * for right.
     *
     * Additionally, the URL to a graphic can be given on this form:
     * `url(graphic.png)`. Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/navigator.handles.symbols
     */
    symbols?: Array<string>;
    /**
     * (Highstock) Width for handles.
     *
     * @see https://api.highcharts.com/highstock/navigator.handles.width
     */
    width?: number;
}
/**
 * (Highstock) The navigator is a small series below the main series, displaying
 * a view of the entire data set. It provides tools to zoom in and out on parts
 * of the data as well as panning across the dataset.
 *
 * @see https://api.highcharts.com/highstock/navigator
 */
export interface NavigatorOptions {
    /**
     * (Highstock) Whether the navigator and scrollbar should adapt to updated
     * data in the base X axis. When loading data async, as in the demo below,
     * this should be `false`. Otherwise new data will trigger navigator redraw,
     * which will cause unwanted looping. In the demo below, the data in the
     * navigator is set only once. On navigating, only the main chart content is
     * updated.
     *
     * @see https://api.highcharts.com/highstock/navigator.adaptToUpdatedData
     */
    adaptToUpdatedData?: boolean;
    /**
     * (Highstock) An integer identifying the index to use for the base series,
     * or a string representing the id of the series.
     *
     * **Note**: As of Highcharts 5.0, this is now a deprecated option. Prefer
     * series.showInNavigator.
     *
     * @see https://api.highcharts.com/highstock/navigator.baseSeries
     */
    baseSeries?: any;
    /**
     * (Highstock) Enable or disable the navigator.
     *
     * @see https://api.highcharts.com/highstock/navigator.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) Options for the handles for dragging the zoomed area.
     *
     * @see https://api.highcharts.com/highstock/navigator.handles
     */
    handles?: NavigatorHandlesOptions;
    /**
     * (Highstock) The height of the navigator.
     *
     * @see https://api.highcharts.com/highstock/navigator.height
     */
    height?: number;
    /**
     * (Highstock) The distance from the nearest element, the X axis or X axis
     * labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.margin
     */
    margin?: number;
    /**
     * (Highstock) The color of the mask covering the areas of the navigator
     * series that are currently not visible in the main series. The default
     * color is bluish with an opacity of 0.3 to see the series below.
     *
     * @see https://api.highcharts.com/highstock/navigator.maskFill
     */
    maskFill?: ColorString;
    /**
     * (Highstock) Whether the mask should be inside the range marking the
     * zoomed range, or outside. In Highstock 1.x it was always `false`.
     *
     * @see https://api.highcharts.com/highstock/navigator.maskInside
     */
    maskInside?: boolean;
    /**
     * (Highstock) When the chart is inverted, whether to draw the navigator on
     * the opposite side.
     *
     * @see https://api.highcharts.com/highstock/navigator.opposite
     */
    opposite?: boolean;
    /**
     * (Highstock) The color of the line marking the currently zoomed area in
     * the navigator.
     *
     * @see https://api.highcharts.com/highstock/navigator.outlineColor
     */
    outlineColor?: ColorString;
    /**
     * (Highstock) The width of the line marking the currently zoomed area in
     * the navigator.
     *
     * @see https://api.highcharts.com/highstock/navigator.outlineWidth
     */
    outlineWidth?: number;
    /**
     * (Highstock) Options for the navigator series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * Unless data is explicitly defined on navigator.series, the data is
     * borrowed from the first series in the chart.
     *
     * Default series options for the navigator series are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/navigator.series
     */
    series?: NavigatorSeriesOptions;
    /**
     * (Highstock) Options for the navigator X axis. Default series options for
     * the navigator xAxis are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis
     */
    xAxis?: NavigatorXAxisOptions;
    /**
     * (Highstock) Options for the navigator Y axis. Default series options for
     * the navigator yAxis are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis
     */
    yAxis?: NavigatorYAxisOptions;
}
/**
 * (Highstock) Data grouping options for the navigator series.
 *
 * @see https://api.highcharts.com/highstock/navigator.series.dataGrouping
 */
export interface NavigatorSeriesDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.filter
 */
export interface NavigatorSeriesDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Data label options for the navigator series. Data labels are
 * disabled by default on the navigator series.
 *
 * @see https://api.highcharts.com/highstock/navigator.series.dataLabels
 */
export interface NavigatorSeriesDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/navigator.series.dataLabels.defer
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.defer
     * @see https://api.highcharts.com/gantt/navigator.series.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.filter
     */
    filter?: NavigatorSeriesDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels.zIndex
     */
    zIndex?: number;
}
export interface NavigatorSeriesMarkerOptions {
    enabled?: boolean;
}
/**
 * (Highstock) Options for the navigator series. Available options are the same
 * as any series, documented at plotOptions and series.
 *
 * Unless data is explicitly defined on navigator.series, the data is borrowed
 * from the first series in the chart.
 *
 * Default series options for the navigator series are:
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/navigator.series
 */
export interface NavigatorSeriesOptions {
    className?: string;
    /**
     * (Highstock) Data grouping options for the navigator series.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataGrouping
     */
    dataGrouping?: NavigatorSeriesDataGroupingOptions;
    /**
     * (Highstock) Data label options for the navigator series. Data labels are
     * disabled by default on the navigator series.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.dataLabels
     */
    dataLabels?: NavigatorSeriesDataLabelsOptions;
    /**
     * (Highstock) The fill opacity of the navigator series.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.fillOpacity
     */
    fillOpacity?: number;
    id?: string;
    /**
     * (Highstock) Line color for the navigator series. Allows setting the color
     * while disallowing the default candlestick setting.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.lineColor
     */
    lineColor?: (ColorString|null);
    /**
     * (Highstock) The pixel line width of the navigator series.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.lineWidth
     */
    lineWidth?: number;
    marker?: NavigatorSeriesMarkerOptions;
    pointRange?: number;
    /**
     * (Highstock) The threshold option. Setting it to 0 will make the default
     * navigator area series draw its area from the 0 value and up.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.threshold
     */
    threshold?: (number|null);
    /**
     * (Highstock) The type of the navigator series. Defaults to `areaspline` if
     * defined, otherwise `line`.
     *
     * @see https://api.highcharts.com/highstock/navigator.series.type
     */
    type?: string;
}
/**
 * (Highcharts, Highstock, Gantt) An array defining breaks in the axis, the
 * sections defined will be left out and all the points shifted closer to each
 * other.
 *
 * @see https://api.highcharts.com/highcharts/navigator.xAxis.breaks
 * @see https://api.highcharts.com/highstock/navigator.xAxis.breaks
 * @see https://api.highcharts.com/gantt/navigator.xAxis.breaks
 */
export interface NavigatorXAxisBreaksOptions {
    /**
     * (Highcharts, Highstock, Gantt) A number indicating how much space should
     * be left between the start and the end of the break. The break size is
     * given in axis units, so for instance on a `datetime` axis, a break size
     * of 3600000 would indicate the equivalent of an hour.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.breaks.breakSize
     * @see https://api.highcharts.com/highstock/navigator.xAxis.breaks.breakSize
     * @see https://api.highcharts.com/gantt/navigator.xAxis.breaks.breakSize
     */
    breakSize?: number;
    /**
     * (Highcharts, Highstock, Gantt) The point where the break starts.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.breaks.from
     * @see https://api.highcharts.com/highstock/navigator.xAxis.breaks.from
     * @see https://api.highcharts.com/gantt/navigator.xAxis.breaks.from
     */
    from?: number;
    /**
     * (Highcharts, Highstock, Gantt) Defines an interval after which the break
     * appears again. By default the breaks do not repeat.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.breaks.repeat
     * @see https://api.highcharts.com/highstock/navigator.xAxis.breaks.repeat
     * @see https://api.highcharts.com/gantt/navigator.xAxis.breaks.repeat
     */
    repeat?: number;
    /**
     * (Highcharts, Highstock, Gantt) The point where the break ends.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.breaks.to
     * @see https://api.highcharts.com/highstock/navigator.xAxis.breaks.to
     * @see https://api.highcharts.com/gantt/navigator.xAxis.breaks.to
     */
    to?: number;
}
/**
 * (Highstock) A label on the axis next to the crosshair.
 *
 * In styled mode, the label is styled with the `.highcharts-crosshair-label`
 * class.
 *
 * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label
 */
export interface NavigatorXAxisCrosshairLabelOptions {
    /**
     * (Highstock) Alignment of the label compared to the axis. Defaults to
     * `left` for right-side axes, `right` for left-side axes and `center` for
     * horizontal axes.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label.align
     */
    align?: string;
    /**
     * (Highstock) The background color for the label. Defaults to the related
     * series color, or `#666666` if that is not available.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the crosshair label
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border corner radius of the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width for the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A format string for the crosshair label. Defaults to
     * `{value}` for numeric axes and `{value:%b %d, %Y}` for datetime axes.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label.format
     */
    format?: string;
    /**
     * (Highstock) Formatter function for the label text.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label.formatter
     */
    formatter?: FormatterCallbackFunction<object>;
    /**
     * (Highstock) Padding inside the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label.padding
     */
    padding?: number;
    /**
     * (Highstock) The shape to use for the label box.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label.shape
     */
    shape?: string;
    /**
     * (Highstock) Text styles for the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) Configure a crosshair that follows either the mouse pointer or
 * the hovered point.
 *
 * In styled mode, the crosshairs are styled in the `.highcharts-crosshair`,
 * `.highcharts-crosshair-thin` or `.highcharts-xaxis-category` classes.
 *
 * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair
 */
export interface NavigatorXAxisCrosshairOptions {
    /**
     * (Highstock) A class name for the crosshair, especially as a hook for
     * styling.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.className
     */
    className?: string;
    /**
     * (Highstock) The color of the crosshair. Defaults to `#cccccc` for numeric
     * and datetime axes, and `rgba(204,214,235,0.25)` for category axes, where
     * the crosshair by default highlights the whole category.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.color
     */
    color?: ColorString;
    /**
     * (Highstock) The dash style for the crosshair. See series.dashStyle for
     * possible values.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) A label on the axis next to the crosshair.
     *
     * In styled mode, the label is styled with the
     * `.highcharts-crosshair-label` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.label
     */
    label?: NavigatorXAxisCrosshairLabelOptions;
    /**
     * (Highstock) Whether the crosshair should snap to the point or follow the
     * pointer independent of points.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.snap
     */
    snap?: boolean;
    /**
     * (Highstock) The pixel width of the crosshair. Defaults to 1 for numeric
     * or datetime axes, and for one category width for category axes.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.width
     */
    width?: number;
    /**
     * (Highstock) The Z index of the crosshair. Higher Z indices allow drawing
     * the crosshair on top of the series or behind the grid lines.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair.zIndex
     */
    zIndex?: number;
}
/**
 * (Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label
 */
export interface NavigatorXAxisCurrentDateIndicatorLabelOptions {
    /**
     * (Gantt) Horizontal alignment of the label. Can be one of "left", "center"
     * or "right".
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Gantt) Rotation of the text label in degrees. Defaults to 0 for
     * horizontal plot lines and 90 for vertical lines.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label.rotation
     */
    rotation?: number;
    /**
     * (Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-line-label` class.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label.style
     */
    style?: CSSObject;
    /**
     * (Gantt) The text itself. A subset of HTML is supported.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label.text
     */
    text?: string;
    /**
     * (Gantt) The text alignment for the label. While `align` determines where
     * the texts anchor point is placed within the plot band, `textAlign`
     * determines how the text is aligned against its anchor point. Possible
     * values are "left", "center" and "right". Defaults to the same as the
     * `align` option.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label.textAlign
     */
    textAlign?: string;
    /**
     * (Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Gantt) Vertical alignment of the label relative to the plot line. Can be
     * one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Gantt) Horizontal position relative the alignment. Default varies by
     * orientation.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label.x
     */
    x?: number;
    /**
     * (Gantt) Vertical position of the text baseline relative to the alignment.
     * Default varies by orientation.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label.y
     */
    y?: number;
}
/**
 * (Gantt) Show an indicator on the axis for the current date and time. Can be a
 * boolean or a configuration object similar to xAxis.plotLines.
 *
 * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator
 */
export interface NavigatorXAxisCurrentDateIndicatorOptions {
    /**
     * (Gantt) A custom class name, in addition to the default
     * `highcharts-plot-line`, to apply to each individual line.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.className
     */
    className?: string;
    /**
     * (Gantt) The color of the line.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.color
     */
    color?: ColorString;
    /**
     * (Gantt) The dashing or dot style for the plot line. For possible values
     * see this overview.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Gantt) An object defining mouse events for the plot line. Supported
     * properties are `click`, `mouseover`, `mouseout`, `mousemove`.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.events
     */
    events?: any;
    /**
     * (Gantt) An id used for identifying the plot line in Axis.removePlotLine.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.id
     */
    id?: string;
    /**
     * (Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.label
     */
    label?: NavigatorXAxisCurrentDateIndicatorLabelOptions;
    /**
     * (Gantt) The width or thickness of the plot line.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.width
     */
    width?: number;
    /**
     * (Gantt) The z index of the plot line within the chart.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator.zIndex
     */
    zIndex?: number;
}
export interface NavigatorXAxisDateTimeLabelFormatsDayOptions {
    main?: string;
}
export interface NavigatorXAxisDateTimeLabelFormatsHourOptions {
    main?: string;
    range?: boolean;
}
export interface NavigatorXAxisDateTimeLabelFormatsMillisecondOptions {
    main?: string;
    range?: boolean;
}
export interface NavigatorXAxisDateTimeLabelFormatsMinuteOptions {
    main?: string;
    range?: boolean;
}
export interface NavigatorXAxisDateTimeLabelFormatsMonthOptions {
    main?: string;
}
/**
 * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
 * automatically adjust to the appropriate unit. This member gives the default
 * string representations used for each unit. For intermediate values, different
 * units may be used, for example the `day` unit can be used on midnight and
 * `hour` unit be used for intermediate values on the same axis. For an overview
 * of the replacement codes, see dateFormat. Defaults to:
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/navigator.xAxis.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/navigator.xAxis.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/navigator.xAxis.dateTimeLabelFormats
 */
export interface NavigatorXAxisDateTimeLabelFormatsOptions {
    day?: NavigatorXAxisDateTimeLabelFormatsDayOptions;
    hour?: NavigatorXAxisDateTimeLabelFormatsHourOptions;
    millisecond?: NavigatorXAxisDateTimeLabelFormatsMillisecondOptions;
    minute?: NavigatorXAxisDateTimeLabelFormatsMinuteOptions;
    month?: NavigatorXAxisDateTimeLabelFormatsMonthOptions;
    second?: NavigatorXAxisDateTimeLabelFormatsSecondOptions;
    week?: NavigatorXAxisDateTimeLabelFormatsWeekOptions;
    year?: NavigatorXAxisDateTimeLabelFormatsYearOptions;
}
export interface NavigatorXAxisDateTimeLabelFormatsSecondOptions {
    main?: string;
    range?: boolean;
}
export interface NavigatorXAxisDateTimeLabelFormatsWeekOptions {
    main?: string;
}
export interface NavigatorXAxisDateTimeLabelFormatsYearOptions {
    main?: string;
}
/**
 * (Highstock) Event handlers for the axis.
 *
 * @see https://api.highcharts.com/highstock/navigator.xAxis.events
 */
export interface NavigatorXAxisEventsOptions {
    /**
     * (Highcharts, Gantt) An event fired after the breaks have rendered.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.events.afterBreaks
     * @see https://api.highcharts.com/gantt/navigator.xAxis.events.afterBreaks
     */
    afterBreaks?: AxisEventCallbackFunction;
    /**
     * (Highstock) As opposed to the `setExtremes` event, this event fires after
     * the final min and max values are computed and corrected for `minRange`.
     *
     * Fires when the minimum and maximum is set for the axis, either by calling
     * the `.setExtremes()` method or by selecting an area in the chart. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in axis
     * values. The actual data extremes are found in `event.dataMin` and
     * `event.dataMax`.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.events.afterSetExtremes
     */
    afterSetExtremes?: AxisEventCallbackFunction;
    /**
     * (Highcharts, Gantt) An event fired when a break from this axis occurs on
     * a point.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.events.pointBreak
     * @see https://api.highcharts.com/gantt/navigator.xAxis.events.pointBreak
     */
    pointBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) An event fired when a point falls inside a
     * break from this axis.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.events.pointInBreak
     * @see https://api.highcharts.com/highstock/navigator.xAxis.events.pointInBreak
     * @see https://api.highcharts.com/gantt/navigator.xAxis.events.pointInBreak
     */
    pointInBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highstock) Fires when the minimum and maximum is set for the axis,
     * either by calling the `.setExtremes()` method or by selecting an area in
     * the chart. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in data
     * values. When an axis is zoomed all the way out from the "Reset zoom"
     * button, `event.min` and `event.max` are null, and the new extremes are
     * set based on `this.dataMin` and `this.dataMax`.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.events.setExtremes
     */
    setExtremes?: AxisSetExtremesEventCallbackFunction;
}
/**
 * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
 *
 * @see https://api.highcharts.com/gantt/navigator.xAxis.grid
 */
export interface NavigatorXAxisGridOptions {
    /**
     * (Gantt) Set border color for the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.grid.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Gantt) Set border width of the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.grid.borderWidth
     */
    borderWidth?: number;
    /**
     * (Gantt) Set cell height for grid axis labels. By default this is
     * calculated from font size.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.grid.cellHeight
     */
    cellHeight?: number;
    /**
     * (Gantt) Set specific options for each column (or row for horizontal axes)
     * in the grid. Each extra column/row is its own axis, and the axis options
     * can be set here.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.grid.columns
     */
    columns?: Array<XAxisOptions>;
    /**
     * (Gantt) Enable grid on the axis labels. Defaults to true for Gantt
     * charts.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.grid.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The axis labels show the number or category for each tick.
 *
 * @see https://api.highcharts.com/highstock/navigator.xAxis.labels
 */
export interface NavigatorXAxisLabelsOptions {
    /**
     * (Highstock) What part of the string the given position is anchored to. If
     * `left`, the left side of the string is at the axis position. Can be one
     * of `"left"`, `"center"` or `"right"`. Defaults to an intelligent guess
     * based on which side of the chart the axis is on and the rotation of the
     * label.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) For horizontal axes, the allowed degrees
     * of label rotation to prevent overlapping labels. If there is enough
     * space, labels are not rotated. As the chart gets narrower, it will start
     * rotating the labels -45 degrees, then remove every second label and try
     * again with rotations 0 and -45 etc. Set it to `false` to disable
     * rotation, which will cause the labels to word-wrap if possible.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.labels.autoRotation
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.autoRotation
     * @see https://api.highcharts.com/gantt/navigator.xAxis.labels.autoRotation
     */
    autoRotation?: Array<number>;
    /**
     * (Highcharts, Gantt) When each category width is more than this many
     * pixels, we don't apply auto rotation. Instead, we lay out the axis label
     * with word wrap. A lower limit makes sense when the label contains
     * multiple short words that don't extend the available horizontal space for
     * each label.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.labels.autoRotationLimit
     * @see https://api.highcharts.com/gantt/navigator.xAxis.labels.autoRotationLimit
     */
    autoRotationLimit?: number;
    /**
     * (Highcharts, Gantt) Polar charts only. The label's pixel distance from
     * the perimeter of the plot area.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.labels.distance
     * @see https://api.highcharts.com/gantt/navigator.xAxis.labels.distance
     */
    distance?: number;
    /**
     * (Highstock) Enable or disable the axis labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A format string for the axis label.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the label. The value
     * is given by `this.value`. Additional properties for `this` are `axis`,
     * `chart`, `isFirst` and `isLast`. The value of the default label formatter
     * can be retrieved by calling `this.axis.defaultLabelFormatter.call(this)`
     * within the function.
     *
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.formatter
     */
    formatter?: FormatterCallbackFunction<AxisLabelsFormatterContextObject>;
    /**
     * (Gantt) The number of pixels to indent the labels per level in a treegrid
     * axis.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.labels.indentation
     */
    indentation?: number;
    /**
     * (Highstock) Horizontal axis only. When `staggerLines` is not set,
     * `maxStaggerLines` defines how many lines the axis is allowed to add to
     * automatically avoid overlapping X labels. Set to `1` to disable overlap
     * detection.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.maxStaggerLines
     */
    maxStaggerLines?: number;
    /**
     * (Highstock) How to handle overflowing labels on horizontal axis. If set
     * to `"allow"`, it will not be aligned at all. By default it `"justify"`
     * labels inside the chart area. If there is room to move it, it will be
     * aligned to the edge, else it will be removed.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Gantt) The pixel padding for axis labels, to ensure white
     * space between them.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.labels.padding
     * @see https://api.highcharts.com/gantt/navigator.xAxis.labels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Defines how the labels are be repositioned according to the
     * 3D chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.labels.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho");
    /**
     * (Highcharts, Gantt) Whether to reserve space for the labels. By default,
     * space is reserved for the labels in these cases:
     *
     * * On all horizontal axes.
     *
     * * On vertical axes if `label.align` is `right` on a left-side axis or
     * `left` on a right-side axis.
     *
     * * On vertical axes if `label.align` is `center`.
     *
     * This can be turned off when for example the labels are rendered inside
     * the plot area instead of outside.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.labels.reserveSpace
     * @see https://api.highcharts.com/gantt/navigator.xAxis.labels.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highstock) Rotation of the labels in degrees.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis labels will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `labels.position3d`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.labels.skew3d
     */
    skew3d?: boolean;
    /**
     * (Highstock) Horizontal axes only. The number of lines to spread the
     * labels over to make room or tighter labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.staggerLines
     */
    staggerLines?: number;
    /**
     * (Highstock) To show only every _n_'th label on the axis, set the step to
     * _n_. Setting the step to 2 shows every other label.
     *
     * By default, the step is calculated automatically to avoid overlap. To
     * prevent this, set it to 1\. This usually only happens on a category axis,
     * and is often a sign that you have chosen the wrong axis type.
     *
     * Read more at Axis docs => What axis should I use?
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.step
     */
    step?: number;
    /**
     * (Highstock) CSS styles for the label. Use `whiteSpace: 'nowrap'` to
     * prevent wrapping of category labels. Use `textOverflow: 'none'` to
     * prevent ellipsis (dots).
     *
     * In styled mode, the labels are styled with the `.highcharts-axis-labels`
     * class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The x position offset of the label relative to the tick
     * position on the axis.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the tick
     * position on the axis. The default makes it adapt to the font size on
     * bottom axis.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index for the axis labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the navigator X axis. Default series options for the
 * navigator xAxis are:
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/navigator.xAxis
 */
export interface NavigatorXAxisOptions {
    /**
     * (Highcharts, Highstock, Gantt) When using multiple axis, the ticks of two
     * or more opposite axes will automatically be aligned by adding ticks to
     * the axis or axes with the least ticks, as if `tickAmount` were specified.
     *
     * This can be prevented by setting `alignTicks` to false. If the grid lines
     * look messy, it's a good idea to hide them for the secondary axis by
     * setting `gridLineWidth` to 0.
     *
     * If `startOnTick` or `endOnTick` in an Axis options are set to false, then
     * the `alignTicks ` will be disabled for the Axis.
     *
     * Disabled for logarithmic axes.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.alignTicks
     * @see https://api.highcharts.com/highstock/navigator.xAxis.alignTicks
     * @see https://api.highcharts.com/gantt/navigator.xAxis.alignTicks
     */
    alignTicks?: boolean;
    /**
     * (Highstock) Whether to allow decimals in this axis' ticks. When counting
     * integers, like persons or hits on a web page, decimals should be avoided
     * in the labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.allowDecimals
     */
    allowDecimals?: boolean;
    /**
     * (Highstock) When using an alternate grid color, a band is painted across
     * the plot area between every other grid line.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.alternateGridColor
     */
    alternateGridColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) An array defining breaks in the axis, the
     * sections defined will be left out and all the points shifted closer to
     * each other.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.breaks
     * @see https://api.highcharts.com/highstock/navigator.xAxis.breaks
     * @see https://api.highcharts.com/gantt/navigator.xAxis.breaks
     */
    breaks?: Array<NavigatorXAxisBreaksOptions>;
    /**
     * (Highcharts, Gantt) If categories are present for the xAxis, names are
     * used instead of numbers for that axis. Since Highcharts 3.0, categories
     * can also be extracted by giving each point a name and setting axis type
     * to `category`. However, if you have multiple series, best practice
     * remains defining the `categories` array.
     *
     * Example:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.categories
     * @see https://api.highcharts.com/gantt/navigator.xAxis.categories
     */
    categories?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) The highest allowed value for
     * automatically computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.ceiling
     * @see https://api.highcharts.com/highstock/navigator.xAxis.ceiling
     * @see https://api.highcharts.com/gantt/navigator.xAxis.ceiling
     */
    ceiling?: number;
    /**
     * (Highstock) A class name that opens for styling the axis by CSS,
     * especially in Highcharts styled mode. The class name is applied to group
     * elements for the grid, axis elements and labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.className
     */
    className?: string;
    /**
     * (Highstock) Configure a crosshair that follows either the mouse pointer
     * or the hovered point.
     *
     * In styled mode, the crosshairs are styled in the `.highcharts-crosshair`,
     * `.highcharts-crosshair-thin` or `.highcharts-xaxis-category` classes.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.crosshair
     */
    crosshair?: (boolean|NavigatorXAxisCrosshairOptions);
    /**
     * (Gantt) Show an indicator on the axis for the current date and time. Can
     * be a boolean or a configuration object similar to xAxis.plotLines.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.currentDateIndicator
     */
    currentDateIndicator?: (boolean|NavigatorXAxisCurrentDateIndicatorOptions);
    /**
     * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
     * automatically adjust to the appropriate unit. This member gives the
     * default string representations used for each unit. For intermediate
     * values, different units may be used, for example the `day` unit can be
     * used on midnight and `hour` unit be used for intermediate values on the
     * same axis. For an overview of the replacement codes, see dateFormat.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/navigator.xAxis.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/navigator.xAxis.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: NavigatorXAxisDateTimeLabelFormatsOptions;
    /**
     * (Highstock) _Requires Accessibility module_
     *
     * Description of the axis to screen reader users.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.description
     */
    description?: string;
    /**
     * (Highstock) Whether to force the axis to end on a tick. Use this option
     * with the `maxPadding` option to control the axis end.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.endOnTick
     */
    endOnTick?: boolean;
    /**
     * (Highstock) Event handlers for the axis.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.events
     */
    events?: NavigatorXAxisEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) The lowest allowed value for automatically
     * computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.floor
     * @see https://api.highcharts.com/highstock/navigator.xAxis.floor
     * @see https://api.highcharts.com/gantt/navigator.xAxis.floor
     */
    floor?: number;
    /**
     * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
     *
     * @see https://api.highcharts.com/gantt/navigator.xAxis.grid
     */
    grid?: NavigatorXAxisGridOptions;
    /**
     * (Highstock) Color of the grid lines extending the ticks across the plot
     * area.
     *
     * In styled mode, the stroke is given in the `.highcharts-grid-line` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.gridLineColor
     */
    gridLineColor?: string;
    /**
     * (Highstock) The dash or dot style of the grid lines. For possible values,
     * see this demonstration.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.gridLineDashStyle
     */
    gridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) The width of the grid lines extending the ticks across the
     * plot area.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.gridLineWidth
     */
    gridLineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The Z index of the grid lines.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.gridZIndex
     * @see https://api.highcharts.com/highstock/navigator.xAxis.gridZIndex
     * @see https://api.highcharts.com/gantt/navigator.xAxis.gridZIndex
     */
    gridZIndex?: number;
    /**
     * (Highstock) An id for the axis. This can be used after render time to get
     * a pointer to the axis object through `chart.get()`.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.id
     */
    id?: string;
    /**
     * (Highstock) The axis labels show the number or category for each tick.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.labels
     */
    labels?: NavigatorXAxisLabelsOptions;
    /**
     * (Highstock) The color of the line marking the axis itself.
     *
     * In styled mode, the line stroke is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the line marking the axis itself.
     *
     * In styled mode, the stroke width is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The maximum value of the axis. If `null`, the max value is
     * automatically calculated.
     *
     * If the endOnTick option is true, the `max` value might be rounded up.
     *
     * If a tickAmount is set, the axis may be extended beyond the set max in
     * order to reach the given number of ticks. The same may happen in a chart
     * with multiple axes, determined by chart. alignTicks, where a `tickAmount`
     * is applied internally.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.max
     */
    max?: number;
    /**
     * (Highstock) Padding of the max value relative to the length of the axis.
     * A padding of 0.05 will make a 100px axis 5px longer. This is useful when
     * you don't want the highest data value to appear on the edge of the plot
     * area. When the axis' `max` option is set or a max extreme is set using
     * `axis.setExtremes()`, the maxPadding will be ignored.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.maxPadding
     */
    maxPadding?: number;
    /**
     * (Highstock) The minimum value of the axis. If `null` the min value is
     * automatically calculated.
     *
     * If the startOnTick option is true (default), the `min` value might be
     * rounded down.
     *
     * The automatically calculated minimum value is also affected by floor,
     * softMin, minPadding, minRange as well as series.threshold and
     * series.softThreshold.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.min
     */
    min?: number;
    /**
     * (Highstock) Color of the minor, secondary grid lines.
     *
     * In styled mode, the stroke width is given in the
     * `.highcharts-minor-grid-line` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minorGridLineColor
     */
    minorGridLineColor?: ColorString;
    /**
     * (Highstock) The dash or dot style of the minor grid lines. For possible
     * values, see this demonstration.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minorGridLineDashStyle
     */
    minorGridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Width of the minor, secondary grid lines.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minorGridLineWidth
     */
    minorGridLineWidth?: number;
    /**
     * (Highstock) Color for the minor tick marks.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minorTickColor
     */
    minorTickColor?: ColorString;
    /**
     * (Highstock) Specific tick interval in axis units for the minor ticks. On
     * a linear axis, if `"auto"`, the minor tick interval is calculated as a
     * fifth of the tickInterval. If `null` or `undefined`, minor ticks are not
     * shown.
     *
     * On logarithmic axes, the unit is the power of the value. For example,
     * setting the minorTickInterval to 1 puts one tick on each of 0.1, 1, 10,
     * 100 etc. Setting the minorTickInterval to 0.1 produces 9 ticks between 1
     * and 10, 10 and 100 etc.
     *
     * If user settings dictate minor ticks to become too dense, they don't make
     * sense, and will be ignored to prevent performance problems.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minorTickInterval
     */
    minorTickInterval?: (number|string|null);
    /**
     * (Highstock) The pixel length of the minor tick marks.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minorTickLength
     */
    minorTickLength?: number;
    /**
     * (Highstock) The position of the minor tick marks relative to the axis
     * line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minorTickPosition
     */
    minorTickPosition?: ("inside"|"outside");
    /**
     * (Highstock) Enable or disable minor ticks. Unless minorTickInterval is
     * set, the tick interval is calculated as a fifth of the `tickInterval`.
     *
     * On a logarithmic axis, minor ticks are laid out based on a best guess,
     * attempting to enter approximately 5 minor ticks between each major tick.
     *
     * Prior to v6.0.0, ticks were unabled in auto layout by setting
     * `minorTickInterval` to `"auto"`.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minorTicks
     */
    minorTicks?: boolean;
    /**
     * (Highstock) The pixel width of the minor tick mark.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minorTickWidth
     */
    minorTickWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Padding of the min value relative to the
     * length of the axis. A padding of 0.05 will make a 100px axis 5px longer.
     * This is useful when you don't want the lowest data value to appear on the
     * edge of the plot area. When the axis' `min` option is set or a min
     * extreme is set using `axis.setExtremes()`, the minPadding will be
     * ignored.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.minPadding
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minPadding
     * @see https://api.highcharts.com/gantt/navigator.xAxis.minPadding
     */
    minPadding?: number;
    /**
     * (Highstock) The minimum tick interval allowed in axis values. For example
     * on zooming in on an axis with daily data, this can be used to prevent the
     * axis from showing hours. Defaults to the closest distance between two
     * points on the axis.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.minTickInterval
     */
    minTickInterval?: number;
    /**
     * (Highstock) The distance in pixels from the plot area to the axis line. A
     * positive offset moves the axis with it's line, labels and ticks away from
     * the plot area. This is typically used when two or more axes are displayed
     * on the same side of the plot. With multiple axes the offset is
     * dynamically adjusted to avoid collision, this can be overridden by
     * setting offset explicitly.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.offset
     */
    offset?: number;
    /**
     * (Highstock) In an ordinal axis, the points are equally spaced in the
     * chart regardless of the actual time or x distance between them. This
     * means that missing data periods (e.g. nights or weekends for a stock
     * chart) will not take up space in the chart. Having `ordinal: false` will
     * show any gaps created by the `gapSize` setting proportionate to their
     * duration.
     *
     * In stock charts the X axis is ordinal by default, unless the boost module
     * is used and at least one of the series' data length exceeds the
     * boostThreshold.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.ordinal
     */
    ordinal?: boolean;
    /**
     * (Highstock) Additional range on the right side of the xAxis. Works
     * similar to xAxis.maxPadding, but value is set in milliseconds. Can be set
     * for both, main xAxis and navigator's xAxis.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.overscroll
     */
    overscroll?: number;
    /**
     * (Highcharts) Refers to the index in the panes array. Used for circular
     * gauges and polar charts. When the option is not set then first pane will
     * be used.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.pane
     */
    pane?: number;
    /**
     * (Highcharts, Highstock, Gantt) An array of colored bands stretching
     * across the plot area marking an interval on the axis.
     *
     * In styled mode, the plot bands are styled by the `.highcharts-plot-band`
     * class in addition to the `className` option.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands
     */
    plotBands?: Array<NavigatorXAxisPlotBandsOptions>;
    /**
     * (Highcharts, Highstock, Gantt) An array of lines stretching across the
     * plot area, marking a specific value on one of the axes.
     *
     * In styled mode, the plot lines are styled by the `.highcharts-plot-line`
     * class in addition to the `className` option.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines
     */
    plotLines?: Array<NavigatorXAxisPlotLinesOptions>;
    /**
     * (Highstock) Whether to reverse the axis so that the highest number is
     * closest to the origin. If the chart is inverted, the x axis is reversed
     * by default.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.reversed
     */
    reversed?: boolean;
    /**
     * (Highcharts, Highstock) This option determines how stacks should be
     * ordered within a group. For example reversed xAxis also reverses stacks,
     * so first series comes last in a group. To keep order like for
     * non-reversed xAxis enable this option.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.reversedStacks
     * @see https://api.highcharts.com/highstock/navigator.xAxis.reversedStacks
     */
    reversedStacks?: boolean;
    /**
     * (Highstock) Whether to show the first tick label.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.showFirstLabel
     */
    showFirstLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to show the last tick label.
     * Defaults to `true` on cartesian charts, and `false` on polar charts.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.showLastLabel
     * @see https://api.highcharts.com/highstock/navigator.xAxis.showLastLabel
     * @see https://api.highcharts.com/gantt/navigator.xAxis.showLastLabel
     */
    showLastLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A soft maximum for the axis. If the series
     * data maximum is less than this, the axis will stay at this maximum, but
     * if the series data maximum is higher, the axis will flex to show all
     * data.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.softMax
     * @see https://api.highcharts.com/highstock/navigator.xAxis.softMax
     * @see https://api.highcharts.com/gantt/navigator.xAxis.softMax
     */
    softMax?: number;
    /**
     * (Highcharts, Highstock, Gantt) A soft minimum for the axis. If the series
     * data minimum is greater than this, the axis will stay at this minimum,
     * but if the series data minimum is lower, the axis will flex to show all
     * data.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.softMin
     * @see https://api.highcharts.com/highstock/navigator.xAxis.softMin
     * @see https://api.highcharts.com/gantt/navigator.xAxis.softMin
     */
    softMin?: number;
    /**
     * (Highcharts, Highstock, Gantt) For datetime axes, this decides where to
     * put the tick between weeks. 0 = Sunday, 1 = Monday.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.startOfWeek
     * @see https://api.highcharts.com/highstock/navigator.xAxis.startOfWeek
     * @see https://api.highcharts.com/gantt/navigator.xAxis.startOfWeek
     */
    startOfWeek?: number;
    /**
     * (Highstock) Whether to force the axis to start on a tick. Use this option
     * with the `minPadding` option to control the axis start.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.startOnTick
     */
    startOnTick?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) The amount of ticks to draw on the axis.
     * This opens up for aligning the ticks of multiple charts or panes within a
     * chart. This option overrides the `tickPixelInterval` option.
     *
     * This option only has an effect on linear axes. Datetime, logarithmic or
     * category axes are not affected.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.tickAmount
     * @see https://api.highcharts.com/highstock/navigator.xAxis.tickAmount
     * @see https://api.highcharts.com/gantt/navigator.xAxis.tickAmount
     */
    tickAmount?: number;
    /**
     * (Highstock) Color for the main tick marks.
     *
     * In styled mode, the stroke is given in the `.highcharts-tick` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.tickColor
     */
    tickColor?: ColorString;
    /**
     * (Highstock) The interval of the tick marks in axis units. When
     * `undefined`, the tick interval is computed to approximately follow the
     * tickPixelInterval on linear and datetime axes. On categorized axes, a
     * `undefined` tickInterval will default to 1, one category. Note that
     * datetime axes are based on milliseconds, so for example an interval of
     * one day is expressed as `24 * 3600 * 1000`.
     *
     * On logarithmic axes, the tickInterval is based on powers, so a
     * tickInterval of 1 means one tick on each of 0.1, 1, 10, 100 etc. A
     * tickInterval of 2 means a tick of 0.1, 10, 1000 etc. A tickInterval of
     * 0.2 puts a tick on 0.1, 0.2, 0.4, 0.6, 0.8, 1, 2, 4, 6, 8, 10, 20, 40
     * etc.
     *
     * If the tickInterval is too dense for labels to be drawn, Highcharts may
     * remove ticks.
     *
     * If the chart has multiple axes, the alignTicks option may interfere with
     * the `tickInterval` setting.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.tickInterval
     */
    tickInterval?: number;
    /**
     * (Highstock) The pixel length of the main tick marks.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.tickLength
     */
    tickLength?: number;
    /**
     * (Highcharts, Gantt) For categorized axes only. If `on` the tick mark is
     * placed in the center of the category, if `between` the tick mark is
     * placed between categories. The default is `between` if the `tickInterval`
     * is 1, else `on`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.tickmarkPlacement
     * @see https://api.highcharts.com/gantt/navigator.xAxis.tickmarkPlacement
     */
    tickmarkPlacement?: ("between"|"on");
    /**
     * (Highstock) If tickInterval is `null` this option sets the approximate
     * pixel interval of the tick marks. Not applicable to categorized axis.
     *
     * The tick interval is also influenced by the minTickInterval option, that,
     * by default prevents ticks from being denser than the data points.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.tickPixelInterval
     */
    tickPixelInterval?: number;
    /**
     * (Highstock) The position of the major tick marks relative to the axis
     * line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.tickPosition
     */
    tickPosition?: ("inside"|"outside");
    /**
     * (Highstock) A callback function returning array defining where the ticks
     * are laid out on the axis. This overrides the default behaviour of
     * tickPixelInterval and tickInterval. The automatic tick positions are
     * accessible through `this.tickPositions` and can be modified by the
     * callback.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.tickPositioner
     */
    tickPositioner?: AxisTickPositionerCallbackFunction;
    /**
     * (Highstock) An array defining where the ticks are laid out on the axis.
     * This overrides the default behaviour of tickPixelInterval and
     * tickInterval.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.tickPositions
     */
    tickPositions?: Array<number>;
    /**
     * (Highstock) The pixel width of the major tick marks.
     *
     * In styled mode, the stroke width is given in the `.highcharts-tick`
     * class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.tickWidth
     */
    tickWidth?: number;
    /**
     * (Highstock) The axis title, showing next to the axis line.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title
     */
    title?: NavigatorXAxisTitleOptions;
    /**
     * (Highcharts, Gantt) The type of axis. Can be one of `linear`,
     * `logarithmic`, `datetime` or `category`. In a datetime axis, the numbers
     * are given in milliseconds, and tick marks are placed on appropriate
     * values like full hours or days. In a category axis, the point names of
     * the chart's series are used for categories, if not a categories array is
     * defined.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.type
     * @see https://api.highcharts.com/gantt/navigator.xAxis.type
     */
    type?: ("category"|"datetime"|"linear"|"logarithmic");
    /**
     * (Highcharts, Gantt) Applies only when the axis `type` is `category`. When
     * `uniqueNames` is true, points are placed on the X axis according to their
     * names. If the same point name is repeated in the same or another series,
     * the point is placed on the same X position as other points of the same
     * name. When `uniqueNames` is false, the points are laid out in increasing
     * X positions regardless of their names, and the X axis category will take
     * the name of the last point in each position.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.uniqueNames
     * @see https://api.highcharts.com/gantt/navigator.xAxis.uniqueNames
     */
    uniqueNames?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Datetime axis only. An array determining
     * what time intervals the ticks are allowed to fall on. Each array item is
     * an array where the first value is the time unit and the second value
     * another array of allowed multiples. Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.units
     * @see https://api.highcharts.com/highstock/navigator.xAxis.units
     * @see https://api.highcharts.com/gantt/navigator.xAxis.units
     */
    units?: Array<[string, (Array<number>|null)]>;
    /**
     * (Highcharts, Highstock, Gantt) Whether axis, including axis title, line,
     * ticks and labels, should be visible.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.visible
     * @see https://api.highcharts.com/highstock/navigator.xAxis.visible
     * @see https://api.highcharts.com/gantt/navigator.xAxis.visible
     */
    visible?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label
 * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label
 * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label
 */
export interface NavigatorXAxisPlotBandsLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label. Can be
     * one of "left", "center" or "right".
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label.align
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label.align
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label.align
     */
    align?: string;
    /**
     * (Highcharts, Highstock, Gantt) Rotation of the text label in degrees .
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label.rotation
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label.rotation
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-band-label` class.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label.style
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label.style
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The string text itself. A subset of HTML
     * is supported.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label.text
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label.text
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text alignment for the label. While
     * `align` determines where the texts anchor point is placed within the plot
     * band, `textAlign` determines how the text is aligned against its anchor
     * point. Possible values are "left", "center" and "right". Defaults to the
     * same as the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label.textAlign
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label.textAlign
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label.textAlign
     */
    textAlign?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label.useHTML
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label.useHTML
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label relative
     * to the plot band. Can be one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label.verticalAlign
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label.verticalAlign
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal position relative the
     * alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label.x
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label.x
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical position of the text baseline
     * relative to the alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label.y
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label.y
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of colored bands stretching across
 * the plot area marking an interval on the axis.
 *
 * In styled mode, the plot bands are styled by the `.highcharts-plot-band`
 * class in addition to the `className` option.
 *
 * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands
 * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands
 * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands
 */
export interface NavigatorXAxisPlotBandsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Border color for the plot band. Also
     * requires `borderWidth` to be set.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.borderColor
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.borderColor
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) Border width for the plot band. Also
     * requires `borderColor` to be set.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.borderWidth
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.borderWidth
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A custom class name, in addition to the
     * default `highcharts-plot-band`, to apply to each individual band.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.className
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.className
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The color of the plot band.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.color
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.color
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) An object defining mouse events for the
     * plot band. Supported properties are `click`, `mouseover`, `mouseout`,
     * `mousemove`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.events
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.events
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.events
     */
    events?: object;
    /**
     * (Highcharts, Highstock, Gantt) The start position of the plot band in
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.from
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.from
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.from
     */
    from?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id used for identifying the plot band
     * in Axis.removePlotBand.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.id
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.id
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.label
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.label
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.label
     */
    label?: NavigatorXAxisPlotBandsLabelOptions;
    /**
     * (Highcharts, Highstock, Gantt) The end position of the plot band in axis
     * units.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.to
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.to
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.to
     */
    to?: number;
    /**
     * (Highcharts, Highstock, Gantt) The z index of the plot band within the
     * chart, relative to other elements. Using the same z index as another
     * element may give unpredictable results, as the last rendered element will
     * be on top. Values from 0 to 20 make sense.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotBands.zIndex
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotBands.zIndex
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotBands.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label
 * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label
 * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label
 */
export interface NavigatorXAxisPlotLinesLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label. Can be
     * one of "left", "center" or "right".
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label.align
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label.align
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Rotation of the text label in degrees.
     * Defaults to 0 for horizontal plot lines and 90 for vertical lines.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label.rotation
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label.rotation
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-line-label` class.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label.style
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label.style
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The text itself. A subset of HTML is
     * supported.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label.text
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label.text
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text alignment for the label. While
     * `align` determines where the texts anchor point is placed within the plot
     * band, `textAlign` determines how the text is aligned against its anchor
     * point. Possible values are "left", "center" and "right". Defaults to the
     * same as the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label.textAlign
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label.textAlign
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label.textAlign
     */
    textAlign?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label.useHTML
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label.useHTML
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label relative
     * to the plot line. Can be one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label.verticalAlign
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label.verticalAlign
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal position relative the
     * alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label.x
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label.x
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical position of the text baseline
     * relative to the alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label.y
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label.y
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of lines stretching across the plot
 * area, marking a specific value on one of the axes.
 *
 * In styled mode, the plot lines are styled by the `.highcharts-plot-line`
 * class in addition to the `className` option.
 *
 * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines
 * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines
 * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines
 */
export interface NavigatorXAxisPlotLinesOptions {
    /**
     * (Highcharts, Highstock, Gantt) A custom class name, in addition to the
     * default `highcharts-plot-line`, to apply to each individual line.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.className
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.className
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The color of the line.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.color
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.color
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The dashing or dot style for the plot
     * line. For possible values see this overview.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.dashStyle
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.dashStyle
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highstock, Gantt) An object defining mouse events for the
     * plot line. Supported properties are `click`, `mouseover`, `mouseout`,
     * `mousemove`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.events
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.events
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.events
     */
    events?: any;
    /**
     * (Highcharts, Highstock, Gantt) An id used for identifying the plot line
     * in Axis.removePlotLine.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.id
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.id
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.label
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.label
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.label
     */
    label?: NavigatorXAxisPlotLinesLabelOptions;
    /**
     * (Highcharts, Highstock, Gantt) The position of the line in axis units.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.value
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.value
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.value
     */
    value?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width or thickness of the plot line.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.width
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.width
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.width
     */
    width?: number;
    /**
     * (Highcharts, Highstock, Gantt) The z index of the plot line within the
     * chart.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.plotLines.zIndex
     * @see https://api.highcharts.com/highstock/navigator.xAxis.plotLines.zIndex
     * @see https://api.highcharts.com/gantt/navigator.xAxis.plotLines.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) The axis title, showing next to the axis line.
 *
 * @see https://api.highcharts.com/highstock/navigator.xAxis.title
 */
export interface NavigatorXAxisTitleOptions {
    /**
     * (Highstock) Alignment of the title relative to the axis values. Possible
     * values are "low", "middle" or "high".
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.align
     */
    align?: ("high"|"low"|"middle");
    /**
     * (Highcharts) Deprecated. Set the `text` to `null` to disable the title.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.title.enabled
     */
    enabled?: string;
    /**
     * (Highstock) The pixel distance between the axis labels or line and the
     * title. Defaults to 0 for horizontal axes, 10 for vertical
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.margin
     */
    margin?: number;
    /**
     * (Highstock) The distance of the axis title from the axis line. By
     * default, this distance is computed from the offset width of the labels,
     * the labels' distance from the axis and the title's margin. However when
     * the offset option is set, it overrides all this.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.offset
     */
    offset?: number;
    /**
     * (Highcharts) Defines how the title is repositioned according to the 3D
     * chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * - `undefined`: Will use the config from `labels.position3d`
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.title.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho"|null);
    /**
     * (Highcharts, Highstock, Gantt) Whether to reserve space for the title
     * when laying out the axis.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.title.reserveSpace
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.reserveSpace
     * @see https://api.highcharts.com/gantt/navigator.xAxis.title.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highstock) The rotation of the text in degrees. 0 is horizontal, 270 is
     * vertical reading from bottom to top.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis title will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `title.position3d`.
     *
     * A `null` value will use the config from `labels.skew3d`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.title.skew3d
     */
    skew3d?: (boolean|null);
    /**
     * (Highstock) CSS styles for the title. If the title text is longer than
     * the axis length, it will wrap to multiple lines by default. This can be
     * customized by setting `textOverflow: 'ellipsis'`, by setting a specific
     * `width` or by setting `whiteSpace: 'nowrap'`.
     *
     * In styled mode, the stroke width is given in the `.highcharts-axis-title`
     * class.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.style
     */
    style?: CSSObject;
    /**
     * (Highstock) The actual text of the axis title. It can contain basic HTML
     * text markup like <b>, <i> and spans with style.
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.text
     */
    text?: (string|null);
    /**
     * (Highstock) Alignment of the text, can be `"left"`, `"right"` or
     * `"center"`. Default alignment depends on the title.align:
     *
     * Horizontal axes:
     *
     * - for `align` = `"low"`, `textAlign` is set to `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"`, `textAlign` is set to `right`
     *
     * Vertical axes:
     *
     * - for `align` = `"low"` and `opposite` = `true`, `textAlign` is set to
     * `right`
     *
     * - for `align` = `"low"` and `opposite` = `false`, `textAlign` is set to
     * `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"` and `opposite` = `true` `textAlign` is set to
     * `left`
     *
     * - for `align` = `"high"` and `opposite` = `false` `textAlign` is set to
     * `right`
     *
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.textAlign
     */
    textAlign?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the axis
     * title.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.title.useHTML
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.useHTML
     * @see https://api.highcharts.com/gantt/navigator.xAxis.title.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Horizontal pixel offset of the title
     * position.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.title.x
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.x
     * @see https://api.highcharts.com/gantt/navigator.xAxis.title.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical pixel offset of the title
     * position.
     *
     * @see https://api.highcharts.com/highcharts/navigator.xAxis.title.y
     * @see https://api.highcharts.com/highstock/navigator.xAxis.title.y
     * @see https://api.highcharts.com/gantt/navigator.xAxis.title.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array defining breaks in the axis, the
 * sections defined will be left out and all the points shifted closer to each
 * other.
 *
 * @see https://api.highcharts.com/highcharts/navigator.yAxis.breaks
 * @see https://api.highcharts.com/highstock/navigator.yAxis.breaks
 * @see https://api.highcharts.com/gantt/navigator.yAxis.breaks
 */
export interface NavigatorYAxisBreaksOptions {
    /**
     * (Highcharts, Highstock, Gantt) A number indicating how much space should
     * be left between the start and the end of the break. The break size is
     * given in axis units, so for instance on a `datetime` axis, a break size
     * of 3600000 would indicate the equivalent of an hour.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.breaks.breakSize
     * @see https://api.highcharts.com/highstock/navigator.yAxis.breaks.breakSize
     * @see https://api.highcharts.com/gantt/navigator.yAxis.breaks.breakSize
     */
    breakSize?: number;
    /**
     * (Highcharts, Highstock, Gantt) The point where the break starts.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.breaks.from
     * @see https://api.highcharts.com/highstock/navigator.yAxis.breaks.from
     * @see https://api.highcharts.com/gantt/navigator.yAxis.breaks.from
     */
    from?: number;
    /**
     * (Highcharts, Highstock, Gantt) Defines an interval after which the break
     * appears again. By default the breaks do not repeat.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.breaks.repeat
     * @see https://api.highcharts.com/highstock/navigator.yAxis.breaks.repeat
     * @see https://api.highcharts.com/gantt/navigator.yAxis.breaks.repeat
     */
    repeat?: number;
    /**
     * (Highcharts, Highstock, Gantt) The point where the break ends.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.breaks.to
     * @see https://api.highcharts.com/highstock/navigator.yAxis.breaks.to
     * @see https://api.highcharts.com/gantt/navigator.yAxis.breaks.to
     */
    to?: number;
}
/**
 * (Highstock) A label on the axis next to the crosshair.
 *
 * In styled mode, the label is styled with the `.highcharts-crosshair-label`
 * class.
 *
 * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label
 */
export interface NavigatorYAxisCrosshairLabelOptions {
    /**
     * (Highstock) Alignment of the label compared to the axis. Defaults to
     * `left` for right-side axes, `right` for left-side axes and `center` for
     * horizontal axes.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label.align
     */
    align?: string;
    /**
     * (Highstock) The background color for the label. Defaults to the related
     * series color, or `#666666` if that is not available.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the crosshair label
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border corner radius of the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width for the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A format string for the crosshair label. Defaults to
     * `{value}` for numeric axes and `{value:%b %d, %Y}` for datetime axes.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label.format
     */
    format?: string;
    /**
     * (Highstock) Formatter function for the label text.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label.formatter
     */
    formatter?: FormatterCallbackFunction<object>;
    /**
     * (Highstock) Padding inside the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label.padding
     */
    padding?: number;
    /**
     * (Highstock) The shape to use for the label box.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label.shape
     */
    shape?: string;
    /**
     * (Highstock) Text styles for the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) Configure a crosshair that follows either the mouse pointer or
 * the hovered point.
 *
 * In styled mode, the crosshairs are styled in the `.highcharts-crosshair`,
 * `.highcharts-crosshair-thin` or `.highcharts-xaxis-category` classes.
 *
 * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair
 */
export interface NavigatorYAxisCrosshairOptions {
    /**
     * (Highstock) A class name for the crosshair, especially as a hook for
     * styling.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.className
     */
    className?: string;
    /**
     * (Highstock) The color of the crosshair. Defaults to `#cccccc` for numeric
     * and datetime axes, and `rgba(204,214,235,0.25)` for category axes, where
     * the crosshair by default highlights the whole category.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.color
     */
    color?: ColorString;
    /**
     * (Highstock) The dash style for the crosshair. See series.dashStyle for
     * possible values.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) A label on the axis next to the crosshair.
     *
     * In styled mode, the label is styled with the
     * `.highcharts-crosshair-label` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.label
     */
    label?: NavigatorYAxisCrosshairLabelOptions;
    /**
     * (Highstock) Whether the crosshair should snap to the point or follow the
     * pointer independent of points.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.snap
     */
    snap?: boolean;
    /**
     * (Highstock) The pixel width of the crosshair. Defaults to 1 for numeric
     * or datetime axes, and for one category width for category axes.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.width
     */
    width?: number;
    /**
     * (Highstock) The Z index of the crosshair. Higher Z indices allow drawing
     * the crosshair on top of the series or behind the grid lines.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair.zIndex
     */
    zIndex?: number;
}
export interface NavigatorYAxisDateTimeLabelFormatsDayOptions {
    main?: string;
}
export interface NavigatorYAxisDateTimeLabelFormatsHourOptions {
    main?: string;
    range?: boolean;
}
export interface NavigatorYAxisDateTimeLabelFormatsMillisecondOptions {
    main?: string;
    range?: boolean;
}
export interface NavigatorYAxisDateTimeLabelFormatsMinuteOptions {
    main?: string;
    range?: boolean;
}
export interface NavigatorYAxisDateTimeLabelFormatsMonthOptions {
    main?: string;
}
/**
 * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
 * automatically adjust to the appropriate unit. This member gives the default
 * string representations used for each unit. For intermediate values, different
 * units may be used, for example the `day` unit can be used on midnight and
 * `hour` unit be used for intermediate values on the same axis. For an overview
 * of the replacement codes, see dateFormat. Defaults to:
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/navigator.yAxis.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/navigator.yAxis.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/navigator.yAxis.dateTimeLabelFormats
 */
export interface NavigatorYAxisDateTimeLabelFormatsOptions {
    day?: NavigatorYAxisDateTimeLabelFormatsDayOptions;
    hour?: NavigatorYAxisDateTimeLabelFormatsHourOptions;
    millisecond?: NavigatorYAxisDateTimeLabelFormatsMillisecondOptions;
    minute?: NavigatorYAxisDateTimeLabelFormatsMinuteOptions;
    month?: NavigatorYAxisDateTimeLabelFormatsMonthOptions;
    second?: NavigatorYAxisDateTimeLabelFormatsSecondOptions;
    week?: NavigatorYAxisDateTimeLabelFormatsWeekOptions;
    year?: NavigatorYAxisDateTimeLabelFormatsYearOptions;
}
export interface NavigatorYAxisDateTimeLabelFormatsSecondOptions {
    main?: string;
    range?: boolean;
}
export interface NavigatorYAxisDateTimeLabelFormatsWeekOptions {
    main?: string;
}
export interface NavigatorYAxisDateTimeLabelFormatsYearOptions {
    main?: string;
}
/**
 * (Highstock) Event handlers for the axis.
 *
 * @see https://api.highcharts.com/highstock/navigator.yAxis.events
 */
export interface NavigatorYAxisEventsOptions {
    /**
     * (Highcharts, Gantt) An event fired after the breaks have rendered.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.events.afterBreaks
     * @see https://api.highcharts.com/gantt/navigator.yAxis.events.afterBreaks
     */
    afterBreaks?: AxisEventCallbackFunction;
    /**
     * (Highstock) As opposed to the `setExtremes` event, this event fires after
     * the final min and max values are computed and corrected for `minRange`.
     *
     * Fires when the minimum and maximum is set for the axis, either by calling
     * the `.setExtremes()` method or by selecting an area in the chart. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in axis
     * values. The actual data extremes are found in `event.dataMin` and
     * `event.dataMax`.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.events.afterSetExtremes
     */
    afterSetExtremes?: AxisEventCallbackFunction;
    /**
     * (Highcharts, Gantt) An event fired when a break from this axis occurs on
     * a point.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.events.pointBreak
     * @see https://api.highcharts.com/gantt/navigator.yAxis.events.pointBreak
     */
    pointBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) An event fired when a point falls inside a
     * break from this axis.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.events.pointInBreak
     * @see https://api.highcharts.com/highstock/navigator.yAxis.events.pointInBreak
     * @see https://api.highcharts.com/gantt/navigator.yAxis.events.pointInBreak
     */
    pointInBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highstock) Fires when the minimum and maximum is set for the axis,
     * either by calling the `.setExtremes()` method or by selecting an area in
     * the chart. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in data
     * values. When an axis is zoomed all the way out from the "Reset zoom"
     * button, `event.min` and `event.max` are null, and the new extremes are
     * set based on `this.dataMin` and `this.dataMax`.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.events.setExtremes
     */
    setExtremes?: AxisSetExtremesEventCallbackFunction;
}
/**
 * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
 *
 * @see https://api.highcharts.com/gantt/navigator.yAxis.grid
 */
export interface NavigatorYAxisGridOptions {
    /**
     * (Gantt) Set border color for the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.grid.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Gantt) Set border width of the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.grid.borderWidth
     */
    borderWidth?: number;
    /**
     * (Gantt) Set cell height for grid axis labels. By default this is
     * calculated from font size.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.grid.cellHeight
     */
    cellHeight?: number;
    /**
     * (Gantt) Set specific options for each column (or row for horizontal axes)
     * in the grid. Each extra column/row is its own axis, and the axis options
     * can be set here.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.grid.columns
     */
    columns?: Array<XAxisOptions>;
    /**
     * (Gantt) Enable grid on the axis labels. Defaults to true for Gantt
     * charts.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.grid.enabled
     */
    enabled?: boolean;
}
/**
 * (Gantt) Set options on specific levels in a tree grid axis. Takes precedence
 * over labels options.
 *
 * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.levels
 */
export interface NavigatorYAxisLabelsLevelsOptions {
    /**
     * (Gantt) Specify the level which the options within this object applies
     * to.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.levels.level
     */
    level?: number;
    style?: CSSObject;
}
/**
 * (Highstock) The axis labels show the number or category for each tick.
 *
 * @see https://api.highcharts.com/highstock/navigator.yAxis.labels
 */
export interface NavigatorYAxisLabelsOptions {
    /**
     * (Highstock) What part of the string the given position is anchored to.
     * Can be one of `"left"`, `"center"` or `"right"`. The exact position also
     * depends on the `labels.x` setting.
     *
     * Angular gauges and solid gauges defaults to `center`.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) For horizontal axes, the allowed degrees
     * of label rotation to prevent overlapping labels. If there is enough
     * space, labels are not rotated. As the chart gets narrower, it will start
     * rotating the labels -45 degrees, then remove every second label and try
     * again with rotations 0 and -45 etc. Set it to `false` to disable
     * rotation, which will cause the labels to word-wrap if possible.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.labels.autoRotation
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.autoRotation
     * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.autoRotation
     */
    autoRotation?: Array<number>;
    /**
     * (Highcharts, Gantt) When each category width is more than this many
     * pixels, we don't apply auto rotation. Instead, we lay out the axis label
     * with word wrap. A lower limit makes sense when the label contains
     * multiple short words that don't extend the available horizontal space for
     * each label.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.labels.autoRotationLimit
     * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.autoRotationLimit
     */
    autoRotationLimit?: number;
    /**
     * (Highcharts) Angular gauges and solid gauges only. The label's pixel
     * distance from the perimeter of the plot area.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.labels.distance
     */
    distance?: number;
    /**
     * (Highstock) Enable or disable the axis labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A format string for the axis label.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the label. The value
     * is given by `this.value`. Additional properties for `this` are `axis`,
     * `chart`, `isFirst` and `isLast`. The value of the default label formatter
     * can be retrieved by calling `this.axis.defaultLabelFormatter.call(this)`
     * within the function.
     *
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.formatter
     */
    formatter?: FormatterCallbackFunction<AxisLabelsFormatterContextObject>;
    /**
     * (Gantt) The number of pixels to indent the labels per level in a treegrid
     * axis.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.indentation
     */
    indentation?: number;
    /**
     * (Gantt) Set options on specific levels in a tree grid axis. Takes
     * precedence over labels options.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.levels
     */
    levels?: Array<NavigatorYAxisLabelsLevelsOptions>;
    /**
     * (Highstock) Horizontal axis only. When `staggerLines` is not set,
     * `maxStaggerLines` defines how many lines the axis is allowed to add to
     * automatically avoid overlapping X labels. Set to `1` to disable overlap
     * detection.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.maxStaggerLines
     */
    maxStaggerLines?: number;
    /**
     * (Highstock) How to handle overflowing labels on horizontal axis. If set
     * to `"allow"`, it will not be aligned at all. By default it `"justify"`
     * labels inside the chart area. If there is room to move it, it will be
     * aligned to the edge, else it will be removed.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Gantt) The pixel padding for axis labels, to ensure white
     * space between them.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.labels.padding
     * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Defines how the labels are be repositioned according to the
     * 3D chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.labels.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho");
    /**
     * (Highcharts, Gantt) Whether to reserve space for the labels. By default,
     * space is reserved for the labels in these cases:
     *
     * * On all horizontal axes.
     *
     * * On vertical axes if `label.align` is `right` on a left-side axis or
     * `left` on a right-side axis.
     *
     * * On vertical axes if `label.align` is `center`.
     *
     * This can be turned off when for example the labels are rendered inside
     * the plot area instead of outside.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.labels.reserveSpace
     * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highstock) Rotation of the labels in degrees.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis labels will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `labels.position3d`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.labels.skew3d
     */
    skew3d?: boolean;
    /**
     * (Highstock) Horizontal axes only. The number of lines to spread the
     * labels over to make room or tighter labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.staggerLines
     */
    staggerLines?: number;
    /**
     * (Highstock) To show only every _n_'th label on the axis, set the step to
     * _n_. Setting the step to 2 shows every other label.
     *
     * By default, the step is calculated automatically to avoid overlap. To
     * prevent this, set it to 1\. This usually only happens on a category axis,
     * and is often a sign that you have chosen the wrong axis type.
     *
     * Read more at Axis docs => What axis should I use?
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.step
     */
    step?: number;
    /**
     * (Highstock) CSS styles for the label. Use `whiteSpace: 'nowrap'` to
     * prevent wrapping of category labels. Use `textOverflow: 'none'` to
     * prevent ellipsis (dots).
     *
     * In styled mode, the labels are styled with the `.highcharts-axis-labels`
     * class.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.style
     */
    style?: CSSObject;
    /**
     * (Gantt) The symbol for the collapse and expand icon in a treegrid.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.symbol
     */
    symbol?: NavigatorYAxisLabelsSymbolOptions;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The x position offset of the label relative to the tick
     * position on the axis. Defaults to -15 for left axis, 15 for right axis.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the tick
     * position on the axis.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index for the axis labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels.zIndex
     */
    zIndex?: number;
}
/**
 * (Gantt) The symbol for the collapse and expand icon in a treegrid.
 *
 * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.symbol
 */
export interface NavigatorYAxisLabelsSymbolOptions {
    height?: number;
    padding?: number;
    /**
     * (Gantt) The symbol type. Points to a definition function in the
     * `Highcharts.Renderer.symbols` collection.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.labels.symbol.type
     */
    type?: ("arc"|"circle"|"diamond"|"square"|"triangle"|"triangle-down");
    width?: number;
    x?: number;
    y?: number;
}
/**
 * (Highstock) Options for the navigator Y axis. Default series options for the
 * navigator yAxis are:
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/navigator.yAxis
 */
export interface NavigatorYAxisOptions {
    /**
     * (Highcharts, Highstock, Gantt) When using multiple axis, the ticks of two
     * or more opposite axes will automatically be aligned by adding ticks to
     * the axis or axes with the least ticks, as if `tickAmount` were specified.
     *
     * This can be prevented by setting `alignTicks` to false. If the grid lines
     * look messy, it's a good idea to hide them for the secondary axis by
     * setting `gridLineWidth` to 0.
     *
     * If `startOnTick` or `endOnTick` in an Axis options are set to false, then
     * the `alignTicks ` will be disabled for the Axis.
     *
     * Disabled for logarithmic axes.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.alignTicks
     * @see https://api.highcharts.com/highstock/navigator.yAxis.alignTicks
     * @see https://api.highcharts.com/gantt/navigator.yAxis.alignTicks
     */
    alignTicks?: boolean;
    /**
     * (Highstock) Whether to allow decimals in this axis' ticks. When counting
     * integers, like persons or hits on a web page, decimals should be avoided
     * in the labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.allowDecimals
     */
    allowDecimals?: boolean;
    /**
     * (Highstock) When using an alternate grid color, a band is painted across
     * the plot area between every other grid line.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.alternateGridColor
     */
    alternateGridColor?: ColorString;
    /**
     * (Highcharts) In a polar chart, this is the angle of the Y axis in
     * degrees, where 0 is up and 90 is right. The angle determines the position
     * of the axis line and the labels, though the coordinate system is
     * unaffected.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.angle
     */
    angle?: number;
    /**
     * (Highcharts, Highstock, Gantt) An array defining breaks in the axis, the
     * sections defined will be left out and all the points shifted closer to
     * each other.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.breaks
     * @see https://api.highcharts.com/highstock/navigator.yAxis.breaks
     * @see https://api.highcharts.com/gantt/navigator.yAxis.breaks
     */
    breaks?: Array<NavigatorYAxisBreaksOptions>;
    /**
     * (Highcharts, Gantt) If categories are present for the xAxis, names are
     * used instead of numbers for that axis. Since Highcharts 3.0, categories
     * can also be extracted by giving each point a name and setting axis type
     * to `category`. However, if you have multiple series, best practice
     * remains defining the `categories` array.
     *
     * Example:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.categories
     * @see https://api.highcharts.com/gantt/navigator.yAxis.categories
     */
    categories?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) The highest allowed value for
     * automatically computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.ceiling
     * @see https://api.highcharts.com/highstock/navigator.yAxis.ceiling
     * @see https://api.highcharts.com/gantt/navigator.yAxis.ceiling
     */
    ceiling?: number;
    /**
     * (Highstock) A class name that opens for styling the axis by CSS,
     * especially in Highcharts styled mode. The class name is applied to group
     * elements for the grid, axis elements and labels.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.className
     */
    className?: string;
    /**
     * (Highstock) Configure a crosshair that follows either the mouse pointer
     * or the hovered point.
     *
     * In styled mode, the crosshairs are styled in the `.highcharts-crosshair`,
     * `.highcharts-crosshair-thin` or `.highcharts-xaxis-category` classes.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.crosshair
     */
    crosshair?: (boolean|NavigatorYAxisCrosshairOptions);
    /**
     * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
     * automatically adjust to the appropriate unit. This member gives the
     * default string representations used for each unit. For intermediate
     * values, different units may be used, for example the `day` unit can be
     * used on midnight and `hour` unit be used for intermediate values on the
     * same axis. For an overview of the replacement codes, see dateFormat.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/navigator.yAxis.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/navigator.yAxis.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: NavigatorYAxisDateTimeLabelFormatsOptions;
    /**
     * (Highstock) _Requires Accessibility module_
     *
     * Description of the axis to screen reader users.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.description
     */
    description?: string;
    /**
     * (Highstock) Whether to force the axis to end on a tick. Use this option
     * with the `maxPadding` option to control the axis end.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.endOnTick
     */
    endOnTick?: boolean;
    /**
     * (Highstock) Event handlers for the axis.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.events
     */
    events?: NavigatorYAxisEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) The lowest allowed value for automatically
     * computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.floor
     * @see https://api.highcharts.com/highstock/navigator.yAxis.floor
     * @see https://api.highcharts.com/gantt/navigator.yAxis.floor
     */
    floor?: number;
    /**
     * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.grid
     */
    grid?: NavigatorYAxisGridOptions;
    /**
     * (Highstock) Color of the grid lines extending the ticks across the plot
     * area.
     *
     * In styled mode, the stroke is given in the `.highcharts-grid-line` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.gridLineColor
     */
    gridLineColor?: ColorString;
    /**
     * (Highstock) The dash or dot style of the grid lines. For possible values,
     * see this demonstration.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.gridLineDashStyle
     */
    gridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts) Polar charts only. Whether the grid lines should draw as a
     * polygon with straight lines between categories, or as circles. Can be
     * either `circle` or `polygon`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.gridLineInterpolation
     */
    gridLineInterpolation?: ("circle"|"polygon");
    /**
     * (Highstock) The width of the grid lines extending the ticks across the
     * plot area.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.gridLineWidth
     */
    gridLineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The Z index of the grid lines.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.gridZIndex
     * @see https://api.highcharts.com/highstock/navigator.yAxis.gridZIndex
     * @see https://api.highcharts.com/gantt/navigator.yAxis.gridZIndex
     */
    gridZIndex?: number;
    /**
     * (Highstock) An id for the axis. This can be used after render time to get
     * a pointer to the axis object through `chart.get()`.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.id
     */
    id?: string;
    /**
     * (Highstock) The axis labels show the number or category for each tick.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.labels
     */
    labels?: NavigatorYAxisLabelsOptions;
    /**
     * (Highstock) The color of the line marking the axis itself.
     *
     * In styled mode, the line stroke is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the line marking the axis itself.
     *
     * In styled mode, the stroke width is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The maximum value of the axis. If `null`, the max value is
     * automatically calculated.
     *
     * If the endOnTick option is true, the `max` value might be rounded up.
     *
     * If a tickAmount is set, the axis may be extended beyond the set max in
     * order to reach the given number of ticks. The same may happen in a chart
     * with multiple axes, determined by chart. alignTicks, where a `tickAmount`
     * is applied internally.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.max
     */
    max?: number;
    /**
     * (Highcharts) Solid gauge only. Unless stops are set, the color to
     * represent the maximum value of the Y axis.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.maxColor
     */
    maxColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) Padding of the max value relative to the
     * length of the axis. A padding of 0.05 will make a 100px axis 5px longer.
     * This is useful when you don't want the highest data value to appear on
     * the edge of the plot area. When the axis' `max` option is set or a max
     * extreme is set using `axis.setExtremes()`, the maxPadding will be
     * ignored.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.maxPadding
     * @see https://api.highcharts.com/highstock/navigator.yAxis.maxPadding
     * @see https://api.highcharts.com/gantt/navigator.yAxis.maxPadding
     */
    maxPadding?: number;
    /**
     * (Highstock) The minimum value of the axis. If `null` the min value is
     * automatically calculated.
     *
     * If the startOnTick option is true (default), the `min` value might be
     * rounded down.
     *
     * The automatically calculated minimum value is also affected by floor,
     * softMin, minPadding, minRange as well as series.threshold and
     * series.softThreshold.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.min
     */
    min?: number;
    /**
     * (Highcharts) Solid gauge only. Unless stops are set, the color to
     * represent the minimum value of the Y axis.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.minColor
     */
    minColor?: ColorString;
    /**
     * (Highstock) Color of the minor, secondary grid lines.
     *
     * In styled mode, the stroke width is given in the
     * `.highcharts-minor-grid-line` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minorGridLineColor
     */
    minorGridLineColor?: ColorString;
    /**
     * (Highstock) The dash or dot style of the minor grid lines. For possible
     * values, see this demonstration.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minorGridLineDashStyle
     */
    minorGridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Width of the minor, secondary grid lines.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minorGridLineWidth
     */
    minorGridLineWidth?: number;
    /**
     * (Highstock) Color for the minor tick marks.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minorTickColor
     */
    minorTickColor?: ColorString;
    /**
     * (Highstock) Specific tick interval in axis units for the minor ticks. On
     * a linear axis, if `"auto"`, the minor tick interval is calculated as a
     * fifth of the tickInterval. If `null` or `undefined`, minor ticks are not
     * shown.
     *
     * On logarithmic axes, the unit is the power of the value. For example,
     * setting the minorTickInterval to 1 puts one tick on each of 0.1, 1, 10,
     * 100 etc. Setting the minorTickInterval to 0.1 produces 9 ticks between 1
     * and 10, 10 and 100 etc.
     *
     * If user settings dictate minor ticks to become too dense, they don't make
     * sense, and will be ignored to prevent performance problems.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minorTickInterval
     */
    minorTickInterval?: (number|string|null);
    /**
     * (Highstock) The pixel length of the minor tick marks.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minorTickLength
     */
    minorTickLength?: number;
    /**
     * (Highstock) The position of the minor tick marks relative to the axis
     * line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minorTickPosition
     */
    minorTickPosition?: ("inside"|"outside");
    /**
     * (Highstock) Enable or disable minor ticks. Unless minorTickInterval is
     * set, the tick interval is calculated as a fifth of the `tickInterval`.
     *
     * On a logarithmic axis, minor ticks are laid out based on a best guess,
     * attempting to enter approximately 5 minor ticks between each major tick.
     *
     * Prior to v6.0.0, ticks were unabled in auto layout by setting
     * `minorTickInterval` to `"auto"`.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minorTicks
     */
    minorTicks?: boolean;
    /**
     * (Highstock) The pixel width of the minor tick mark.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minorTickWidth
     */
    minorTickWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Padding of the min value relative to the
     * length of the axis. A padding of 0.05 will make a 100px axis 5px longer.
     * This is useful when you don't want the lowest data value to appear on the
     * edge of the plot area. When the axis' `min` option is set or a max
     * extreme is set using `axis.setExtremes()`, the maxPadding will be
     * ignored.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.minPadding
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minPadding
     * @see https://api.highcharts.com/gantt/navigator.yAxis.minPadding
     */
    minPadding?: number;
    /**
     * (Highstock) The minimum tick interval allowed in axis values. For example
     * on zooming in on an axis with daily data, this can be used to prevent the
     * axis from showing hours. Defaults to the closest distance between two
     * points on the axis.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.minTickInterval
     */
    minTickInterval?: number;
    /**
     * (Highstock) The distance in pixels from the plot area to the axis line. A
     * positive offset moves the axis with it's line, labels and ticks away from
     * the plot area. This is typically used when two or more axes are displayed
     * on the same side of the plot. With multiple axes the offset is
     * dynamically adjusted to avoid collision, this can be overridden by
     * setting offset explicitly.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.offset
     */
    offset?: number;
    /**
     * (Highstock, Highcharts, Gantt) Whether to display the axis on the
     * opposite side of the normal. The normal is on the left side for vertical
     * axes and bottom for horizontal, so the opposite sides will be right and
     * top respectively. This is typically used with dual or multiple axes.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.opposite
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.opposite
     * @see https://api.highcharts.com/gantt/navigator.yAxis.opposite
     */
    opposite?: boolean;
    /**
     * (Highcharts) Refers to the index in the panes array. Used for circular
     * gauges and polar charts. When the option is not set then first pane will
     * be used.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.pane
     */
    pane?: number;
    /**
     * (Highcharts, Highstock, Gantt) An array of objects defining plot bands on
     * the Y axis.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands
     */
    plotBands?: Array<NavigatorYAxisPlotBandsOptions>;
    /**
     * (Highcharts, Highstock, Gantt) An array of objects representing plot
     * lines on the X axis
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines
     */
    plotLines?: Array<NavigatorYAxisPlotLinesOptions>;
    /**
     * (Highstock) Whether to reverse the axis so that the highest number is
     * closest to the origin.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.reversed
     */
    reversed?: boolean;
    /**
     * (Highcharts, Highstock) If `true`, the first series in a stack will be
     * drawn on top in a positive, non-reversed Y axis. If `false`, the first
     * series is in the base of the stack.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.reversedStacks
     * @see https://api.highcharts.com/highstock/navigator.yAxis.reversedStacks
     */
    reversedStacks?: boolean;
    /**
     * (Highstock) Whether to show the first tick label.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.showFirstLabel
     */
    showFirstLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to show the last tick label.
     * Defaults to `true` on cartesian charts, and `false` on polar charts.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.showLastLabel
     * @see https://api.highcharts.com/highstock/navigator.yAxis.showLastLabel
     * @see https://api.highcharts.com/gantt/navigator.yAxis.showLastLabel
     */
    showLastLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A soft maximum for the axis. If the series
     * data maximum is less than this, the axis will stay at this maximum, but
     * if the series data maximum is higher, the axis will flex to show all
     * data.
     *
     * **Note**: The series.softThreshold option takes precedence over this
     * option.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.softMax
     * @see https://api.highcharts.com/highstock/navigator.yAxis.softMax
     * @see https://api.highcharts.com/gantt/navigator.yAxis.softMax
     */
    softMax?: number;
    /**
     * (Highcharts, Highstock, Gantt) A soft minimum for the axis. If the series
     * data minimum is greater than this, the axis will stay at this minimum,
     * but if the series data minimum is lower, the axis will flex to show all
     * data.
     *
     * **Note**: The series.softThreshold option takes precedence over this
     * option.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.softMin
     * @see https://api.highcharts.com/highstock/navigator.yAxis.softMin
     * @see https://api.highcharts.com/gantt/navigator.yAxis.softMin
     */
    softMin?: number;
    /**
     * (Highcharts) The stack labels show the total value for each bar in a
     * stacked column or bar chart. The label will be placed on top of positive
     * columns and below negative columns. In case of an inverted column chart
     * or a bar chart the label is placed to the right of positive bars and to
     * the left of negative bars.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels
     */
    stackLabels?: NavigatorYAxisStackLabelsOptions;
    /**
     * (Highcharts, Highstock, Gantt) For datetime axes, this decides where to
     * put the tick between weeks. 0 = Sunday, 1 = Monday.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.startOfWeek
     * @see https://api.highcharts.com/highstock/navigator.yAxis.startOfWeek
     * @see https://api.highcharts.com/gantt/navigator.yAxis.startOfWeek
     */
    startOfWeek?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether to force the axis to start on a
     * tick. Use this option with the `maxPadding` option to control the axis
     * start.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.startOnTick
     * @see https://api.highcharts.com/highstock/navigator.yAxis.startOnTick
     * @see https://api.highcharts.com/gantt/navigator.yAxis.startOnTick
     */
    startOnTick?: boolean;
    /**
     * (Gantt) For vertical axes only. Setting the static scale ensures that
     * each tick unit is translated into a fixed pixel height. For example,
     * setting the static scale to 24 results in each Y axis category taking up
     * 24 pixels, and the height of the chart adjusts. Adding or removing items
     * will make the chart resize.
     *
     * @see https://api.highcharts.com/gantt/navigator.yAxis.staticScale
     */
    staticScale?: number;
    /**
     * (Highcharts) Solid gauge series only. Color stops for the solid gauge.
     * Use this in cases where a linear gradient between a `minColor` and
     * `maxColor` is not sufficient. The stops is an array of tuples, where the
     * first item is a float between 0 and 1 assigning the relative position in
     * the gradient, and the second item is the color.
     *
     * For solid gauges, the Y axis also inherits the concept of data classes
     * from the Highmaps color axis.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stops
     */
    stops?: Array<[number, ColorString]>;
    /**
     * (Highcharts, Highstock, Gantt) The amount of ticks to draw on the axis.
     * This opens up for aligning the ticks of multiple charts or panes within a
     * chart. This option overrides the `tickPixelInterval` option.
     *
     * This option only has an effect on linear axes. Datetime, logarithmic or
     * category axes are not affected.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.tickAmount
     * @see https://api.highcharts.com/highstock/navigator.yAxis.tickAmount
     * @see https://api.highcharts.com/gantt/navigator.yAxis.tickAmount
     */
    tickAmount?: number;
    /**
     * (Highstock) Color for the main tick marks.
     *
     * In styled mode, the stroke is given in the `.highcharts-tick` class.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.tickColor
     */
    tickColor?: ColorString;
    /**
     * (Highstock) The interval of the tick marks in axis units. When
     * `undefined`, the tick interval is computed to approximately follow the
     * tickPixelInterval on linear and datetime axes. On categorized axes, a
     * `undefined` tickInterval will default to 1, one category. Note that
     * datetime axes are based on milliseconds, so for example an interval of
     * one day is expressed as `24 * 3600 * 1000`.
     *
     * On logarithmic axes, the tickInterval is based on powers, so a
     * tickInterval of 1 means one tick on each of 0.1, 1, 10, 100 etc. A
     * tickInterval of 2 means a tick of 0.1, 10, 1000 etc. A tickInterval of
     * 0.2 puts a tick on 0.1, 0.2, 0.4, 0.6, 0.8, 1, 2, 4, 6, 8, 10, 20, 40
     * etc.
     *
     * If the tickInterval is too dense for labels to be drawn, Highcharts may
     * remove ticks.
     *
     * If the chart has multiple axes, the alignTicks option may interfere with
     * the `tickInterval` setting.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.tickInterval
     */
    tickInterval?: number;
    /**
     * (Highstock) The pixel length of the main tick marks.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.tickLength
     */
    tickLength?: number;
    /**
     * (Highcharts, Gantt) For categorized axes only. If `on` the tick mark is
     * placed in the center of the category, if `between` the tick mark is
     * placed between categories. The default is `between` if the `tickInterval`
     * is 1, else `on`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.tickmarkPlacement
     * @see https://api.highcharts.com/gantt/navigator.yAxis.tickmarkPlacement
     */
    tickmarkPlacement?: ("between"|"on");
    /**
     * (Highstock) If tickInterval is `null` this option sets the approximate
     * pixel interval of the tick marks. Not applicable to categorized axis.
     *
     * The tick interval is also influenced by the minTickInterval option, that,
     * by default prevents ticks from being denser than the data points.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.tickPixelInterval
     */
    tickPixelInterval?: number;
    /**
     * (Highstock) The position of the major tick marks relative to the axis
     * line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.tickPosition
     */
    tickPosition?: ("inside"|"outside");
    /**
     * (Highstock) A callback function returning array defining where the ticks
     * are laid out on the axis. This overrides the default behaviour of
     * tickPixelInterval and tickInterval. The automatic tick positions are
     * accessible through `this.tickPositions` and can be modified by the
     * callback.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.tickPositioner
     */
    tickPositioner?: AxisTickPositionerCallbackFunction;
    /**
     * (Highstock) An array defining where the ticks are laid out on the axis.
     * This overrides the default behaviour of tickPixelInterval and
     * tickInterval.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.tickPositions
     */
    tickPositions?: Array<number>;
    /**
     * (Highcharts, Highstock, Gantt) The pixel width of the major tick marks.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.tickWidth
     * @see https://api.highcharts.com/highstock/navigator.yAxis.tickWidth
     * @see https://api.highcharts.com/gantt/navigator.yAxis.tickWidth
     */
    tickWidth?: number;
    /**
     * (Highstock) The axis title, showing next to the axis line.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title
     */
    title?: NavigatorYAxisTitleOptions;
    /**
     * (Highcharts) Parallel coordinates only. Format that will be used for
     * point.y and available in tooltip.pointFormat as `{point.formattedValue}`.
     * If not set, `{point.formattedValue}` will use other options, in this
     * order:
     *
     * 1. yAxis.labels.format will be used if set
     *
     * 2. If yAxis is a category, then category name will be displayed
     *
     * 3. If yAxis is a datetime, then value will use the same format as yAxis
     * labels
     *
     * 4. If yAxis is linear/logarithmic type, then simple value will be used
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.tooltipValueFormat
     */
    tooltipValueFormat?: string;
    /**
     * (Highcharts, Gantt) The type of axis. Can be one of `linear`,
     * `logarithmic`, `datetime`, `category` or `treegrid`. Defaults to
     * `treegrid` for Gantt charts, `linear` for other chart types.
     *
     * In a datetime axis, the numbers are given in milliseconds, and tick marks
     * are placed on appropriate values, like full hours or days. In a category
     * or treegrid axis, the point names of the chart's series are used for
     * categories, if a categories array is not defined.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.type
     * @see https://api.highcharts.com/gantt/navigator.yAxis.type
     */
    type?: ("category"|"datetime"|"linear"|"logarithmic"|"treegrid");
    /**
     * (Highcharts, Gantt) Applies only when the axis `type` is `category`. When
     * `uniqueNames` is true, points are placed on the X axis according to their
     * names. If the same point name is repeated in the same or another series,
     * the point is placed on the same X position as other points of the same
     * name. When `uniqueNames` is false, the points are laid out in increasing
     * X positions regardless of their names, and the X axis category will take
     * the name of the last point in each position.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.uniqueNames
     * @see https://api.highcharts.com/gantt/navigator.yAxis.uniqueNames
     */
    uniqueNames?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether axis, including axis title, line,
     * ticks and labels, should be visible.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.visible
     * @see https://api.highcharts.com/highstock/navigator.yAxis.visible
     * @see https://api.highcharts.com/gantt/navigator.yAxis.visible
     */
    visible?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label
 * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label
 * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label
 */
export interface NavigatorYAxisPlotBandsLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label. Can be
     * one of "left", "center" or "right".
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label.align
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label.align
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label.align
     */
    align?: string;
    /**
     * (Highcharts, Highstock, Gantt) Rotation of the text label in degrees .
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label.rotation
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label.rotation
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-band-label` class.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label.style
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label.style
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The string text itself. A subset of HTML
     * is supported.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label.text
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label.text
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text alignment for the label. While
     * `align` determines where the texts anchor point is placed within the plot
     * band, `textAlign` determines how the text is aligned against its anchor
     * point. Possible values are "left", "center" and "right". Defaults to the
     * same as the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label.textAlign
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label.textAlign
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label.textAlign
     */
    textAlign?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label.useHTML
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label.useHTML
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label relative
     * to the plot band. Can be one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label.verticalAlign
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label.verticalAlign
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal position relative the
     * alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label.x
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label.x
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical position of the text baseline
     * relative to the alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label.y
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label.y
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of objects defining plot bands on the
 * Y axis.
 *
 * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands
 * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands
 * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands
 */
export interface NavigatorYAxisPlotBandsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Border color for the plot band. Also
     * requires `borderWidth` to be set.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.borderColor
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.borderColor
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) Border width for the plot band. Also
     * requires `borderColor` to be set.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.borderWidth
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.borderWidth
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A custom class name, in addition to the
     * default `highcharts-plot-band`, to apply to each individual band.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.className
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.className
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The color of the plot band.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.color
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.color
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) An object defining mouse events for the
     * plot band. Supported properties are `click`, `mouseover`, `mouseout`,
     * `mousemove`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.events
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.events
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.events
     */
    events?: object;
    /**
     * (Highcharts, Highstock, Gantt) The start position of the plot band in
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.from
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.from
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.from
     */
    from?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id used for identifying the plot band
     * in Axis.removePlotBand.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.id
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.id
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.id
     */
    id?: string;
    /**
     * (Highcharts) In a gauge chart, this option determines the inner radius of
     * the plot band that stretches along the perimeter. It can be given as a
     * percentage string, like `"100%"`, or as a pixel number, like `100`. By
     * default, the inner radius is controlled by the thickness option.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.innerRadius
     */
    innerRadius?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.label
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.label
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.label
     */
    label?: NavigatorYAxisPlotBandsLabelOptions;
    /**
     * (Highcharts) In a gauge chart, this option determines the outer radius of
     * the plot band that stretches along the perimeter. It can be given as a
     * percentage string, like `"100%"`, or as a pixel number, like `100`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.outerRadius
     */
    outerRadius?: (number|string);
    /**
     * (Highcharts) In a gauge chart, this option sets the width of the plot
     * band stretching along the perimeter. It can be given as a percentage
     * string, like `"10%"`, or as a pixel number, like `10`. The default value
     * 10 is the same as the default tickLength, thus making the plot band act
     * as a background for the tick markers.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.thickness
     */
    thickness?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The end position of the plot band in axis
     * units.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.to
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.to
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.to
     */
    to?: number;
    /**
     * (Highcharts, Highstock, Gantt) The z index of the plot band within the
     * chart, relative to other elements. Using the same z index as another
     * element may give unpredictable results, as the last rendered element will
     * be on top. Values from 0 to 20 make sense.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotBands.zIndex
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotBands.zIndex
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotBands.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label
 * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label
 * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label
 */
export interface NavigatorYAxisPlotLinesLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label. Can be
     * one of "left", "center" or "right".
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label.align
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label.align
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Rotation of the text label in degrees.
     * Defaults to 0 for horizontal plot lines and 90 for vertical lines.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label.rotation
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label.rotation
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-line-label` class.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label.style
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label.style
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The text itself. A subset of HTML is
     * supported.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label.text
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label.text
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text alignment for the label. While
     * `align` determines where the texts anchor point is placed within the plot
     * band, `textAlign` determines how the text is aligned against its anchor
     * point. Possible values are "left", "center" and "right". Defaults to the
     * same as the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label.textAlign
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label.textAlign
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label.textAlign
     */
    textAlign?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label.useHTML
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label.useHTML
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label relative
     * to the plot line. Can be one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label.verticalAlign
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label.verticalAlign
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal position relative the
     * alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label.x
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label.x
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical position of the text baseline
     * relative to the alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label.y
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label.y
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of objects representing plot lines on
 * the X axis
 *
 * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines
 * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines
 * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines
 */
export interface NavigatorYAxisPlotLinesOptions {
    /**
     * (Highcharts, Highstock, Gantt) A custom class name, in addition to the
     * default `highcharts-plot-line`, to apply to each individual line.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.className
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.className
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The color of the line.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.color
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.color
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The dashing or dot style for the plot
     * line. For possible values see this overview.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.dashStyle
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.dashStyle
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highstock, Gantt) An object defining mouse events for the
     * plot line. Supported properties are `click`, `mouseover`, `mouseout`,
     * `mousemove`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.events
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.events
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.events
     */
    events?: any;
    /**
     * (Highcharts, Highstock, Gantt) An id used for identifying the plot line
     * in Axis.removePlotLine.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.id
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.id
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.label
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.label
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.label
     */
    label?: NavigatorYAxisPlotLinesLabelOptions;
    /**
     * (Highcharts, Highstock, Gantt) The position of the line in axis units.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.value
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.value
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.value
     */
    value?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width or thickness of the plot line.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.width
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.width
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.width
     */
    width?: number;
    /**
     * (Highcharts, Highstock, Gantt) The z index of the plot line within the
     * chart.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.plotLines.zIndex
     * @see https://api.highcharts.com/highstock/navigator.yAxis.plotLines.zIndex
     * @see https://api.highcharts.com/gantt/navigator.yAxis.plotLines.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) The stack labels show the total value for each bar in a stacked
 * column or bar chart. The label will be placed on top of positive columns and
 * below negative columns. In case of an inverted column chart or a bar chart
 * the label is placed to the right of positive bars and to the left of negative
 * bars.
 *
 * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels
 */
export interface NavigatorYAxisStackLabelsOptions {
    /**
     * (Highcharts) Defines the horizontal alignment of the stack total label.
     * Can be one of `"left"`, `"center"` or `"right"`. The default value is
     * calculated at runtime and depends on orientation and whether the stack is
     * positive or negative.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Allow the stack labels to overlap.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) Enable or disable the stack total labels.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.format
     * @see https://api.highcharts.com/highstock/navigator.yAxis.stackLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the label. The value
     * is given by `this.total`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.formatter
     */
    formatter?: FormatterCallbackFunction<object>;
    /**
     * (Highcharts) Rotation of the labels in degrees.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) CSS styles for the label.
     *
     * In styled mode, the styles are set in the `.highcharts-stack-label`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) The text alignment for the label. While `align` determines
     * where the texts anchor point is placed with regards to the stack,
     * `textAlign` determines how the text is aligned against its anchor point.
     * Possible values are `"left"`, `"center"` and `"right"`. The default value
     * is calculated at runtime and depends on orientation and whether the stack
     * is positive or negative.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.textAlign
     */
    textAlign?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.useHTML
     * @see https://api.highcharts.com/highstock/navigator.yAxis.stackLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) Defines the vertical alignment of the stack total label. Can
     * be one of `"top"`, `"middle"` or `"bottom"`. The default value is
     * calculated at runtime and depends on orientation and whether the stack is
     * positive or negative.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the left of
     * the stacked bar. The default value is calculated at runtime and depends
     * on orientation and whether the stack is positive or negative.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the tick
     * position on the axis. The default value is calculated at runtime and
     * depends on orientation and whether the stack is positive or negative.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.stackLabels.y
     */
    y?: number;
}
/**
 * (Highstock) The axis title, showing next to the axis line.
 *
 * @see https://api.highcharts.com/highstock/navigator.yAxis.title
 */
export interface NavigatorYAxisTitleOptions {
    /**
     * (Highstock) Alignment of the title relative to the axis values. Possible
     * values are "low", "middle" or "high".
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.align
     */
    align?: ("high"|"low"|"middle");
    /**
     * (Highcharts) Deprecated. Set the `text` to `null` to disable the title.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.title.enabled
     */
    enabled?: string;
    /**
     * (Highstock) The pixel distance between the axis labels and the title.
     * Positive values are outside the axis line, negative are inside.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.margin
     */
    margin?: number;
    /**
     * (Highstock) The distance of the axis title from the axis line. By
     * default, this distance is computed from the offset width of the labels,
     * the labels' distance from the axis and the title's margin. However when
     * the offset option is set, it overrides all this.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.offset
     */
    offset?: number;
    /**
     * (Highcharts) Defines how the title is repositioned according to the 3D
     * chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * - `undefined`: Will use the config from `labels.position3d`
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.title.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho"|null);
    /**
     * (Highcharts, Highstock, Gantt) Whether to reserve space for the title
     * when laying out the axis.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.title.reserveSpace
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.reserveSpace
     * @see https://api.highcharts.com/gantt/navigator.yAxis.title.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highstock) The rotation of the text in degrees. 0 is horizontal, 270 is
     * vertical reading from bottom to top.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis title will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `title.position3d`.
     *
     * A `null` value will use the config from `labels.skew3d`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.title.skew3d
     */
    skew3d?: (boolean|null);
    /**
     * (Highstock) CSS styles for the title. If the title text is longer than
     * the axis length, it will wrap to multiple lines by default. This can be
     * customized by setting `textOverflow: 'ellipsis'`, by setting a specific
     * `width` or by setting `whiteSpace: 'nowrap'`.
     *
     * In styled mode, the stroke width is given in the `.highcharts-axis-title`
     * class.
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The actual text of the axis title.
     * Horizontal texts can contain HTML, but rotated texts are painted using
     * vector techniques and must be clean text. The Y axis title is disabled by
     * setting the `text` option to `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.title.text
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.text
     * @see https://api.highcharts.com/gantt/navigator.yAxis.title.text
     */
    text?: any;
    /**
     * (Highstock) Alignment of the text, can be `"left"`, `"right"` or
     * `"center"`. Default alignment depends on the title.align:
     *
     * Horizontal axes:
     *
     * - for `align` = `"low"`, `textAlign` is set to `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"`, `textAlign` is set to `right`
     *
     * Vertical axes:
     *
     * - for `align` = `"low"` and `opposite` = `true`, `textAlign` is set to
     * `right`
     *
     * - for `align` = `"low"` and `opposite` = `false`, `textAlign` is set to
     * `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"` and `opposite` = `true` `textAlign` is set to
     * `left`
     *
     * - for `align` = `"high"` and `opposite` = `false` `textAlign` is set to
     * `right`
     *
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.textAlign
     */
    textAlign?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the axis
     * title.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.title.useHTML
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.useHTML
     * @see https://api.highcharts.com/gantt/navigator.yAxis.title.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Horizontal pixel offset of the title
     * position.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.title.x
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.x
     * @see https://api.highcharts.com/gantt/navigator.yAxis.title.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical pixel offset of the title
     * position.
     *
     * @see https://api.highcharts.com/highcharts/navigator.yAxis.title.y
     * @see https://api.highcharts.com/highstock/navigator.yAxis.title.y
     * @see https://api.highcharts.com/gantt/navigator.yAxis.title.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for displaying a message like "No data
 * to display". This feature requires the file no-data-to-display.js to be
 * loaded in the page. The actual text to display is set in the lang.noData
 * option.
 *
 * @see https://api.highcharts.com/highcharts/noData
 * @see https://api.highcharts.com/highstock/noData
 * @see https://api.highcharts.com/gantt/noData
 */
export interface NoDataOptions {
    /**
     * (Highcharts, Highstock, Gantt) An object of additional SVG attributes for
     * the no-data label.
     *
     * @see https://api.highcharts.com/highcharts/noData.attr
     * @see https://api.highcharts.com/highstock/noData.attr
     * @see https://api.highcharts.com/gantt/noData.attr
     */
    attr?: SVGAttributes;
    /**
     * (Highcharts, Highstock, Gantt) The position of the no-data label,
     * relative to the plot area.
     *
     * @see https://api.highcharts.com/highcharts/noData.position
     * @see https://api.highcharts.com/highstock/noData.position
     * @see https://api.highcharts.com/gantt/noData.position
     */
    position?: NoDataPositionOptions;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the no-data label.
     *
     * @see https://api.highcharts.com/highcharts/noData.style
     * @see https://api.highcharts.com/highstock/noData.style
     * @see https://api.highcharts.com/gantt/noData.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) Whether to insert the label as HTML, or as
     * pseudo-HTML rendered with SVG.
     *
     * @see https://api.highcharts.com/highcharts/noData.useHTML
     * @see https://api.highcharts.com/highstock/noData.useHTML
     * @see https://api.highcharts.com/gantt/noData.useHTML
     */
    useHTML?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) The position of the no-data label, relative to
 * the plot area.
 *
 * @see https://api.highcharts.com/highcharts/noData.position
 * @see https://api.highcharts.com/highstock/noData.position
 * @see https://api.highcharts.com/gantt/noData.position
 */
export interface NoDataPositionOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label.
     *
     * @see https://api.highcharts.com/highcharts/noData.position.align
     * @see https://api.highcharts.com/highstock/noData.position.align
     * @see https://api.highcharts.com/gantt/noData.position.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label.
     *
     * @see https://api.highcharts.com/highcharts/noData.position.verticalAlign
     * @see https://api.highcharts.com/highstock/noData.position.verticalAlign
     * @see https://api.highcharts.com/gantt/noData.position.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal offset of the label, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/noData.position.x
     * @see https://api.highcharts.com/highstock/noData.position.x
     * @see https://api.highcharts.com/gantt/noData.position.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical offset of the label, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/noData.position.y
     * @see https://api.highcharts.com/highstock/noData.position.y
     * @see https://api.highcharts.com/gantt/noData.position.y
     */
    y?: number;
}
/**
 * Normalized interval.
 */
export interface NormalizedIntervalObject {
    /**
     * The count.
     */
    count: number;
    /**
     * The interval in axis values (ms).
     */
    unitRange: number;
}
/**
 * An object containing `left` and `top` properties for the position in the
 * page.
 */
export interface OffsetObject {
    /**
     * Left distance to the page border.
     */
    left: number;
    /**
     * Top distance to the page border.
     */
    top: number;
}
/**
 * The option tree for every chart.
 */
export interface Options {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for configuring
     * accessibility for the chart. Requires the accessibility module to be
     * loaded. For a description of the module and information on its features,
     * see Highcharts Accessibility.
     *
     * @see https://api.highcharts.com/highcharts/accessibility
     * @see https://api.highcharts.com/highstock/accessibility
     * @see https://api.highcharts.com/highmaps/accessibility
     * @see https://api.highcharts.com/gantt/accessibility
     */
    accessibility?: AccessibilityOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for configuring
     * annotations, for example labels, arrows or shapes. Annotations can be
     * tied to points, axis coordinates or chart pixel coordinates.
     *
     * @see https://api.highcharts.com/highcharts/annotations
     * @see https://api.highcharts.com/highstock/annotations
     * @see https://api.highcharts.com/highmaps/annotations
     * @see https://api.highcharts.com/gantt/annotations
     */
    annotations?: Array<AnnotationsOptions>;
    /**
     * (Highcharts, Highstock) Options for the Boost module. The Boost module
     * allows certain series types to be rendered by WebGL instead of the
     * default SVG. This allows hundreds of thousands of data points to be
     * rendered in milliseconds. In addition to the WebGL rendering it saves
     * time by skipping processing and inspection of the data wherever possible.
     * This introduces some limitations to what features are available in Boost
     * mode. See the docs for details.
     *
     * In addition to the global `boost` option, each series has a
     * boostThreshold that defines when the boost should kick in.
     *
     * Requires the `modules/boost.js` module.
     *
     * @see https://api.highcharts.com/highcharts/boost
     * @see https://api.highcharts.com/highstock/boost
     */
    boost?: BoostOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) General options for the chart.
     *
     * @see https://api.highcharts.com/highcharts/chart
     * @see https://api.highcharts.com/highstock/chart
     * @see https://api.highcharts.com/highmaps/chart
     * @see https://api.highcharts.com/gantt/chart
     */
    chart?: ChartOptions;
    /**
     * (Highcharts, Highmaps) A color axis for choropleth maps and heat maps.
     * Visually, the color axis will appear as a gradient or as separate items
     * inside the legend, depending on whether the axis is scalar or based on
     * data classes.
     *
     * For supported color formats, see the docs article about colors.
     *
     * A scalar color axis is represented by a gradient. The colors either range
     * between the minColor and the maxColor, or for more fine grained control
     * the colors can be defined in stops. Often times, the color axis needs to
     * be adjusted to get the right color spread for the data. In addition to
     * stops, consider using a logarithmic axis type, or setting min and max to
     * avoid the colors being determined by outliers.
     *
     * When dataClasses are used, the ranges are subdivided into separate
     * classes like categories based on their values. This can be used for
     * ranges between two values, but also for a true category. However, when
     * your data is categorized, it may be as convenient to add each category to
     * a separate series.
     *
     * See the Axis object for programmatic access to the axis.
     *
     * @see https://api.highcharts.com/highcharts/colorAxis
     * @see https://api.highcharts.com/highmaps/colorAxis
     */
    colorAxis?: ColorAxisOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array containing the default
     * colors for the chart's series. When all colors are used, new colors are
     * pulled from the start again.
     *
     * Default colors can also be set on a series or series.type basis, see
     * column.colors, pie.colors.
     *
     * In styled mode, the colors option doesn't exist. Instead, colors are
     * defined in CSS and applied either through series or point class names, or
     * through the chart.colorCount option.
     *
     * ### Legacy
     *
     * In Highcharts 3.x, the default colors were:
     *
     * (see online documentation for example)
     *
     * In Highcharts 2.x, the default colors were:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/colors
     * @see https://api.highcharts.com/highstock/colors
     * @see https://api.highcharts.com/highmaps/colors
     * @see https://api.highcharts.com/gantt/colors
     */
    colors?: Array<ColorString>;
    /**
     * (Gantt) The Pathfinder module allows you to define connections between
     * any two points, represented as lines - optionally with markers for the
     * start and/or end points. Multiple algorithms are available for
     * calculating how the connecting lines are drawn.
     *
     * Connector functionality requires Highcharts Gantt to be loaded. In Gantt
     * charts, the connectors are used to draw dependencies between tasks.
     *
     * @see https://api.highcharts.com/gantt/connectors
     */
    connectors?: ConnectorsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Highchart by default puts a
     * credits label in the lower right corner of the chart. This can be changed
     * using these options.
     *
     * @see https://api.highcharts.com/highcharts/credits
     * @see https://api.highcharts.com/highstock/credits
     * @see https://api.highcharts.com/highmaps/credits
     * @see https://api.highcharts.com/gantt/credits
     */
    credits?: CreditsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Data module provides a
     * simplified interface for adding data to a chart from sources like CVS,
     * HTML tables or grid views. See also the tutorial article on the Data
     * module.
     *
     * It requires the `modules/data.js` file to be loaded.
     *
     * Please note that the default way of adding data in Highcharts, without
     * the need of a module, is through the series.data option.
     *
     * @see https://api.highcharts.com/highcharts/data
     * @see https://api.highcharts.com/highstock/data
     * @see https://api.highcharts.com/highmaps/data
     * @see https://api.highcharts.com/gantt/data
     */
    data?: DataOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Styled mode only. Configuration
     * object for adding SVG definitions for reusable elements. See gradients,
     * shadows and patterns for more information and code examples.
     *
     * @see https://api.highcharts.com/highcharts/defs
     * @see https://api.highcharts.com/highstock/defs
     * @see https://api.highcharts.com/highmaps/defs
     * @see https://api.highcharts.com/gantt/defs
     */
    defs?: any;
    /**
     * (Highcharts, Highstock, Highmaps) Options for drill down, the concept of
     * inspecting increasingly high resolution data through clicking on chart
     * items like columns or pie slices.
     *
     * The drilldown feature requires the drilldown.js file to be loaded, found
     * in the modules directory of the download package, or online at
     * code.highcharts.com/modules/drilldown.js.
     *
     * @see https://api.highcharts.com/highcharts/drilldown
     * @see https://api.highcharts.com/highstock/drilldown
     * @see https://api.highcharts.com/highmaps/drilldown
     */
    drilldown?: DrilldownOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the exporting
     * module. For an overview on the matter, see the docs.
     *
     * @see https://api.highcharts.com/highcharts/exporting
     * @see https://api.highcharts.com/highstock/exporting
     * @see https://api.highcharts.com/highmaps/exporting
     * @see https://api.highcharts.com/gantt/exporting
     */
    exporting?: ExportingOptions;
    global?: GlobalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) HTML labels that can be
     * positioned anywhere in the chart area.
     *
     * @see https://api.highcharts.com/highcharts/labels
     * @see https://api.highcharts.com/highstock/labels
     * @see https://api.highcharts.com/highmaps/labels
     * @see https://api.highcharts.com/gantt/labels
     */
    labels?: LabelsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Language object. The language
     * object is global and it can't be set on each chart initiation. Instead,
     * use `Highcharts.setOptions` to set it before any chart is initialized.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/lang
     * @see https://api.highcharts.com/highstock/lang
     * @see https://api.highcharts.com/highmaps/lang
     * @see https://api.highcharts.com/gantt/lang
     */
    lang?: LangOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The legend is a box containing a
     * symbol and name for each series item or point item in the chart. Each
     * series (or points in case of pie charts) is represented by a symbol and
     * its name in the legend.
     *
     * It is possible to override the symbol creator function and create custom
     * legend symbols.
     *
     * @see https://api.highcharts.com/highcharts/legend
     * @see https://api.highcharts.com/highstock/legend
     * @see https://api.highcharts.com/highmaps/legend
     * @see https://api.highcharts.com/gantt/legend
     */
    legend?: LegendOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The loading options control the
     * appearance of the loading screen that covers the plot area on chart
     * operations. This screen only appears after an explicit call to
     * `chart.showLoading()`. It is a utility for developers to communicate to
     * the end user that something is going on, for example while retrieving new
     * data via an XHR connection. The "Loading..." text itself is not part of
     * this configuration object, but part of the `lang` object.
     *
     * @see https://api.highcharts.com/highcharts/loading
     * @see https://api.highcharts.com/highstock/loading
     * @see https://api.highcharts.com/highmaps/loading
     * @see https://api.highcharts.com/gantt/loading
     */
    loading?: LoadingOptions;
    mapNavigation?: MapNavigationOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A collection of options for
     * buttons and menus appearing in the exporting module.
     *
     * @see https://api.highcharts.com/highcharts/navigation
     * @see https://api.highcharts.com/highstock/navigation
     * @see https://api.highcharts.com/highmaps/navigation
     * @see https://api.highcharts.com/gantt/navigation
     */
    navigation?: NavigationOptions;
    /**
     * (Highstock) The navigator is a small series below the main series,
     * displaying a view of the entire data set. It provides tools to zoom in
     * and out on parts of the data as well as panning across the dataset.
     *
     * @see https://api.highcharts.com/highstock/navigator
     */
    navigator?: NavigatorOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for displaying a message like "No
     * data to display". This feature requires the file no-data-to-display.js to
     * be loaded in the page. The actual text to display is set in the
     * lang.noData option.
     *
     * @see https://api.highcharts.com/highcharts/noData
     * @see https://api.highcharts.com/highstock/noData
     * @see https://api.highcharts.com/gantt/noData
     */
    noData?: NoDataOptions;
    /**
     * (Highcharts) The pane serves as a container for axes and backgrounds for
     * circular gauges and polar charts.
     *
     * @see https://api.highcharts.com/highcharts/pane
     */
    pane?: PaneOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The plotOptions is a wrapper
     * object for config objects for each series type. The config objects for
     * each series can also be overridden for each series item as given in the
     * series array.
     *
     * Configuration options for the series are given in three levels. Options
     * for all series in a chart are given in the plotOptions.series object.
     * Then options for all series of a specific type are given in the
     * plotOptions of that type, for example `plotOptions.line`. Next, options
     * for one single series are given in the series array.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions
     * @see https://api.highcharts.com/highstock/plotOptions
     * @see https://api.highcharts.com/highmaps/plotOptions
     * @see https://api.highcharts.com/gantt/plotOptions
     */
    plotOptions?: PlotOptions;
    /**
     * (Highstock) The range selector is a tool for selecting ranges to display
     * within the chart. It provides buttons to select preconfigured ranges in
     * the chart, like 1 day, 1 week, 1 month etc. It also provides input boxes
     * where min and max dates can be manually input.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector
     */
    rangeSelector?: RangeSelectorOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Allows setting a set of rules to
     * apply for different screen or chart sizes. Each rule specifies additional
     * chart options.
     *
     * @see https://api.highcharts.com/highcharts/responsive
     * @see https://api.highcharts.com/highstock/responsive
     * @see https://api.highcharts.com/highmaps/responsive
     * @see https://api.highcharts.com/gantt/responsive
     */
    responsive?: ResponsiveOptions;
    /**
     * (Highstock) The scrollbar is a means of panning over the X axis of a
     * stock chart. Scrollbars can also be applied to other types of axes.
     *
     * Another approach to scrollable charts is the chart.scrollablePlotArea
     * option that is especially suitable for simpler cartesian charts on
     * mobile.
     *
     * In styled mode, all the presentational options for the scrollbar are
     * replaced by the classes `.highcharts-scrollbar-thumb`,
     * `.highcharts-scrollbar-arrow`, `.highcharts-scrollbar-button`,
     * `.highcharts-scrollbar-rifles` and `.highcharts-scrollbar-track`.
     *
     * @see https://api.highcharts.com/highstock/scrollbar
     */
    scrollbar?: ScrollbarOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Series options for specific data
     * and the data itself. In TypeScript you have to cast the series options to
     * specific series types, to get all possible options for a series.
     *
     * @see https://api.highcharts.com/highcharts/series
     * @see https://api.highcharts.com/highstock/series
     * @see https://api.highcharts.com/highmaps/series
     * @see https://api.highcharts.com/gantt/series
     */
    series?: Array<SeriesOptionsType>;
    /**
     * (Highstock) Configure the stockTools gui strings in the chart. Requires
     * the [stockTools module]() to be loaded. For a description of the module
     * and information on its features, see [Highcharts StockTools]().
     *
     * @see https://api.highcharts.com/highstock/stockTools
     */
    stockTools?: (object|StockToolsOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The chart's subtitle. This can
     * be used both to display a subtitle below the main title, and to display
     * random text anywhere in the chart. The subtitle can be updated after
     * chart initialization through the `Chart.setTitle` method.
     *
     * @see https://api.highcharts.com/highcharts/subtitle
     * @see https://api.highcharts.com/highstock/subtitle
     * @see https://api.highcharts.com/highmaps/subtitle
     * @see https://api.highcharts.com/gantt/subtitle
     */
    subtitle?: SubtitleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Time options that can apply
     * globally or to individual charts. These settings affect how `datetime`
     * axes are laid out, how tooltips are formatted, how series
     * pointIntervalUnit works and how the Highstock range selector handles
     * time.
     *
     * The common use case is that all charts in the same Highcharts object
     * share the same time settings, in which case the global settings are set
     * using `setOptions`.(see online documentation for example)
     *
     * Since v6.0.5, the time options were moved from the `global` obect to the
     * `time` object, and time options can be set on each individual chart.
     *
     * @see https://api.highcharts.com/highcharts/time
     * @see https://api.highcharts.com/highstock/time
     * @see https://api.highcharts.com/highmaps/time
     * @see https://api.highcharts.com/gantt/time
     */
    time?: TimeOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The chart's main title.
     *
     * @see https://api.highcharts.com/highcharts/title
     * @see https://api.highcharts.com/highstock/title
     * @see https://api.highcharts.com/highmaps/title
     * @see https://api.highcharts.com/gantt/title
     */
    title?: TitleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the tooltip that
     * appears when the user hovers over a series or point.
     *
     * @see https://api.highcharts.com/highcharts/tooltip
     * @see https://api.highcharts.com/highstock/tooltip
     * @see https://api.highcharts.com/highmaps/tooltip
     * @see https://api.highcharts.com/gantt/tooltip
     */
    tooltip?: TooltipOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X axis or category axis.
     * Normally this is the horizontal axis, though if the chart is inverted
     * this is the vertical axis. In case of multiple axes, the xAxis node is an
     * array of configuration objects.
     *
     * See the Axis class for programmatic access to the axis.
     *
     * @see https://api.highcharts.com/highcharts/xAxis
     * @see https://api.highcharts.com/highstock/xAxis
     * @see https://api.highcharts.com/highmaps/xAxis
     * @see https://api.highcharts.com/gantt/xAxis
     */
    xAxis?: (XAxisOptions|Array<XAxisOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y axis or value axis.
     * Normally this is the vertical axis, though if the chart is inverted this
     * is the horizontal axis. In case of multiple axes, the yAxis node is an
     * array of configuration objects.
     *
     * See the Axis object for programmatic access to the axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis
     * @see https://api.highcharts.com/highstock/yAxis
     * @see https://api.highcharts.com/highmaps/yAxis
     * @see https://api.highcharts.com/gantt/yAxis
     */
    yAxis?: (YAxisOptions|Array<YAxisOptions>);
    /**
     * (Highcharts) The Z axis or depth axis for 3D plots.
     *
     * See the Axis class for programmatic access to the axis.
     *
     * @see https://api.highcharts.com/highcharts/zAxis
     */
    zAxis?: (ZAxisOptions|Array<ZAxisOptions>);
}
/**
 * (Highcharts) An array of background items for the pane.
 *
 * @see https://api.highcharts.com/highcharts/pane.background
 */
export interface PaneBackgroundOptions {
    /**
     * (Highcharts) The background color or gradient for the pane.
     *
     * @see https://api.highcharts.com/highcharts/pane.background.backgroundColor
     */
    backgroundColor?: GradientColorObject;
    /**
     * (Highcharts) The pane background border color.
     *
     * @see https://api.highcharts.com/highcharts/pane.background.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The pixel border width of the pane background.
     *
     * @see https://api.highcharts.com/highcharts/pane.background.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) The class name for this background.
     *
     * @see https://api.highcharts.com/highcharts/pane.background.className
     */
    className?: string;
    /**
     * (Highcharts) The inner radius of the pane background. Can be either
     * numeric (pixels) or a percentage string.
     *
     * @see https://api.highcharts.com/highcharts/pane.background.innerRadius
     */
    innerRadius?: (number|string);
    /**
     * (Highcharts) The outer radius of the circular pane background. Can be
     * either numeric (pixels) or a percentage string.
     *
     * @see https://api.highcharts.com/highcharts/pane.background.outerRadius
     */
    outerRadius?: (number|string);
    /**
     * (Highcharts) The shape of the pane background. When `solid`, the
     * background is circular. When `arc`, the background extends only from the
     * min to the max of the value axis.
     *
     * @see https://api.highcharts.com/highcharts/pane.background.shape
     */
    shape?: ("arc"|"circle"|"solid");
}
/**
 * (Highcharts) The pane serves as a container for axes and backgrounds for
 * circular gauges and polar charts.
 *
 * @see https://api.highcharts.com/highcharts/pane
 */
export interface PaneOptions {
    /**
     * (Highcharts) An array of background items for the pane.
     *
     * @see https://api.highcharts.com/highcharts/pane.background
     */
    background?: Array<PaneBackgroundOptions>;
    /**
     * (Highcharts) The center of a polar chart or angular gauge, given as an
     * array of [x, y] positions. Positions can be given as integers that
     * transform to pixels, or as percentages of the plot area size.
     *
     * @see https://api.highcharts.com/highcharts/pane.center
     */
    center?: Array<(string|number)>;
    /**
     * (Highcharts) The end angle of the polar X axis or gauge value axis, given
     * in degrees where 0 is north. Defaults to startAngle
     *
     * + 360.
     *
     * @see https://api.highcharts.com/highcharts/pane.endAngle
     */
    endAngle?: number;
    /**
     * (Highcharts) The size of the pane, either as a number defining pixels, or
     * a percentage defining a percentage of the plot are.
     *
     * @see https://api.highcharts.com/highcharts/pane.size
     */
    size?: (number|string);
    /**
     * (Highcharts) The start angle of the polar X axis or gauge axis, given in
     * degrees where 0 is north. Defaults to 0.
     *
     * @see https://api.highcharts.com/highcharts/pane.startAngle
     */
    startAngle?: number;
}
/**
 * Holds a pattern definition.
 */
export interface PatternObject {
    /**
     * Animation options for the image pattern loading.
     */
    animation?: (boolean|AnimationOptionsObject);
    /**
     * Pattern options
     */
    pattern: PatternOptionsObject;
}
/**
 * Pattern options
 */
export interface PatternOptionsObject {
    /**
     * For automatically calculated width and height on images, it is possible
     * to set an aspect ratio. The image will be zoomed to fill the bounding
     * box, maintaining the aspect ratio defined.
     */
    aspectRatio: number;
    /**
     * Pattern color, used as default path stroke.
     */
    color: ColorString;
    /**
     * Analogous to pattern.width.
     */
    height: number;
    /**
     * ID to assign to the pattern. This is automatically computed if not added,
     * and identical patterns are reused. To refer to an existing pattern for a
     * Highcharts color, use `color: "url(#pattern-id)"`.
     */
    id: string;
    /**
     * URL to an image to use as the pattern.
     */
    image: string;
    /**
     * Opacity of the pattern as a float value from 0 to 1.
     */
    opacity: number;
    /**
     * Either an SVG path as string, or an object. As an object, supply the path
     * string in the `path.d` property. Other supported properties are standard
     * SVG attributes like `path.stroke` and `path.fill`. If a path is supplied
     * for the pattern, the `image` property is ignored.
     */
    path: (string|SVGAttributes);
    /**
     * Width of the pattern. For images this is automatically set to the width
     * of the element bounding box if not supplied. For non-image patterns the
     * default is 32px. Note that automatic resizing of image patterns to fill a
     * bounding box dynamically is only supported for patterns with an
     * automatically calculated ID.
     */
    with: number;
    /**
     * Horizontal offset of the pattern. Defaults to 0.
     */
    x?: number;
    /**
     * Vertical offset of the pattern. Defaults to 0.
     */
    y?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.animation
 */
export interface PlotAbandsAnimationOptions {
    duration?: number;
}
export interface PlotAbandsBottomLineOptions {
    styles?: PlotAbandsBottomLineStylesOptions;
}
export interface PlotAbandsBottomLineStylesOptions {
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.bottomLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker
 */
export interface PlotAbandsConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker
 */
export interface PlotAbandsConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors
 */
export interface PlotAbandsConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.endMarker
     */
    endMarker?: PlotAbandsConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.marker
     */
    marker?: PlotAbandsConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker
     */
    startMarker?: PlotAbandsConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker
 */
export interface PlotAbandsConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.dataGrouping
 */
export interface PlotAbandsDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.filter
 */
export interface PlotAbandsDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels
 */
export interface PlotAbandsDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.abands.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.filter
     */
    filter?: PlotAbandsDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragHandle
 */
export interface PlotAbandsDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.guideBox.default
 */
export interface PlotAbandsDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.guideBox
 */
export interface PlotAbandsDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.guideBox.default
     */
    default?: PlotAbandsDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop
 */
export interface PlotAbandsDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragHandle
     */
    dragHandle?: PlotAbandsDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.guideBox
     */
    guideBox?: (PlotAbandsDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.events
 */
export interface PlotAbandsEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.abands.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.abands.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.label
 * @see https://api.highcharts.com/highstock/plotOptions.abands.label
 * @see https://api.highcharts.com/gantt/plotOptions.abands.label
 */
export interface PlotAbandsLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.abands.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.abands.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.abands.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.abands.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.abands.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.abands.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.abands.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.abands.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.abands.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.abands.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.abands.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.abands.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.abands.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.abands.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.abands.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.abands.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.lastPrice
 */
export interface PlotAbandsLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotAbandsLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.lastVisiblePrice
 */
export interface PlotAbandsLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotAbandsLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.marker
 */
export interface PlotAbandsMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states
     */
    states?: PlotAbandsMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover.animation
 */
export interface PlotAbandsMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover
 */
export interface PlotAbandsMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAbandsMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.normal
 */
export interface PlotAbandsMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states
 */
export interface PlotAbandsMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.hover
     */
    hover?: PlotAbandsMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.normal
     */
    normal?: PlotAbandsMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.select
     */
    select?: PlotAbandsMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.select
 */
export interface PlotAbandsMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Acceleration bands (ABANDS). This series requires the `linkedTo`
 * option to be set and should be loaded after the
 * `stock/indicators/indicators.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `abands` series are defined in plotOptions.abands.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands
 */
export interface PlotAbandsOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAbandsAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.borderWidth
     */
    borderWidth?: number;
    bottomLine?: PlotAbandsBottomLineOptions;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.abands.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.abands.connectors
     */
    connectors?: PlotAbandsConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.abands.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataGrouping
     */
    dataGrouping?: PlotAbandsDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dataLabels
     */
    dataLabels?: PlotAbandsDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.dragDrop
     */
    dragDrop?: PlotAbandsDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.events
     */
    events?: PlotAbandsEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.abands.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.abands.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.label
     * @see https://api.highcharts.com/highstock/plotOptions.abands.label
     * @see https://api.highcharts.com/gantt/plotOptions.abands.label
     */
    label?: PlotAbandsLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.lastPrice
     */
    lastPrice?: PlotAbandsLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.lastVisiblePrice
     */
    lastVisiblePrice?: PlotAbandsLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.abands.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.abands.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.abands.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.abands.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.marker
     */
    marker?: PlotAbandsMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.params
     */
    params?: PlotAbandsParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point
     */
    point?: PlotAbandsPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.abands.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states
     */
    states?: PlotAbandsStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.step
     * @see https://api.highcharts.com/highstock/plotOptions.abands.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.abands.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip
     */
    tooltip?: PlotAbandsTooltipOptions;
    topLine?: PlotAbandsTopLineOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.abands.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.abands.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.abands.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.zones
     * @see https://api.highcharts.com/highstock/plotOptions.abands.zones
     */
    zones?: Array<PlotAbandsZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.params
 */
export interface PlotAbandsParamsOptions {
    /**
     * (Highstock) The algorithms factor value used to calculate bands.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.params.factor
     */
    factor?: number;
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events
 */
export interface PlotAbandsPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.point
 */
export interface PlotAbandsPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.point.events
     */
    events?: PlotAbandsPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.animation
 */
export interface PlotAbandsStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.halo
 */
export interface PlotAbandsStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker
 */
export interface PlotAbandsStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states
     */
    states?: PlotAbandsStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover.animation
 */
export interface PlotAbandsStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover
 */
export interface PlotAbandsStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAbandsStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.normal
 */
export interface PlotAbandsStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states
 */
export interface PlotAbandsStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.hover
     */
    hover?: PlotAbandsStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.normal
     */
    normal?: PlotAbandsStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.select
     */
    select?: PlotAbandsStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.select
 */
export interface PlotAbandsStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover
 */
export interface PlotAbandsStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAbandsStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.halo
     */
    halo?: PlotAbandsStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover.marker
     */
    marker?: PlotAbandsStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.normal
 */
export interface PlotAbandsStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states
 */
export interface PlotAbandsStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.hover
     */
    hover?: PlotAbandsStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.normal
     */
    normal?: PlotAbandsStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.select
     */
    select?: PlotAbandsStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.animation
 */
export interface PlotAbandsStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.halo
 */
export interface PlotAbandsStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker
 */
export interface PlotAbandsStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states
     */
    states?: PlotAbandsStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover.animation
 */
export interface PlotAbandsStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover
 */
export interface PlotAbandsStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAbandsStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.normal
 */
export interface PlotAbandsStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states
 */
export interface PlotAbandsStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.hover
     */
    hover?: PlotAbandsStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.normal
     */
    normal?: PlotAbandsStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.select
     */
    select?: PlotAbandsStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.select
 */
export interface PlotAbandsStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.select
 */
export interface PlotAbandsStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAbandsStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.abands.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.halo
     */
    halo?: PlotAbandsStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.abands.states.select.marker
     */
    marker?: PlotAbandsStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.abands.tooltip.dateTimeLabelFormats
 */
export interface PlotAbandsTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip
 */
export interface PlotAbandsTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.abands.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotAbandsTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.abands.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.abands.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
export interface PlotAbandsTopLineOptions {
    styles?: PlotAbandsTopLineStylesOptions;
}
export interface PlotAbandsTopLineStylesOptions {
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands.topLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.abands.zones
 * @see https://api.highcharts.com/highstock/plotOptions.abands.zones
 */
export interface PlotAbandsZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.abands.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.abands.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.abands.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.abands.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.abands.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.abands.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.animation
 */
export interface PlotAdAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker
 */
export interface PlotAdConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker
 */
export interface PlotAdConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors
 */
export interface PlotAdConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.endMarker
     */
    endMarker?: PlotAdConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.marker
     */
    marker?: PlotAdConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker
     */
    startMarker?: PlotAdConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker
 */
export interface PlotAdConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.dataGrouping
 */
export interface PlotAdDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.filter
 */
export interface PlotAdDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels
 */
export interface PlotAdDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.ad.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.filter
     */
    filter?: PlotAdDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragHandle
 */
export interface PlotAdDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.guideBox.default
 */
export interface PlotAdDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.guideBox
 */
export interface PlotAdDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.guideBox.default
     */
    default?: PlotAdDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop
 */
export interface PlotAdDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragHandle
     */
    dragHandle?: PlotAdDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.guideBox
     */
    guideBox?: (PlotAdDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.events
 */
export interface PlotAdEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.ad.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.ad.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.label
 * @see https://api.highcharts.com/highstock/plotOptions.ad.label
 * @see https://api.highcharts.com/gantt/plotOptions.ad.label
 */
export interface PlotAdLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.ad.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.ad.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.ad.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.ad.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.ad.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.ad.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ad.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.ad.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ad.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ad.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ad.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ad.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.ad.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.ad.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.ad.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.ad.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.lastPrice
 */
export interface PlotAdLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotAdLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.lastVisiblePrice
 */
export interface PlotAdLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotAdLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.marker
 */
export interface PlotAdMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states
     */
    states?: PlotAdMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover.animation
 */
export interface PlotAdMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover
 */
export interface PlotAdMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAdMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.normal
 */
export interface PlotAdMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states
 */
export interface PlotAdMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.hover
     */
    hover?: PlotAdMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.normal
     */
    normal?: PlotAdMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.select
     */
    select?: PlotAdMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.select
 */
export interface PlotAdMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Accumulation Distribution (AD). This series requires `linkedTo`
 * option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ad` series are defined in plotOptions.ad.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad
 */
export interface PlotAdOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAdAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.ad.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ad.connectors
     */
    connectors?: PlotAdConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ad.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataGrouping
     */
    dataGrouping?: PlotAdDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dataLabels
     */
    dataLabels?: PlotAdDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.dragDrop
     */
    dragDrop?: PlotAdDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.events
     */
    events?: PlotAdEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.ad.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.ad.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.label
     * @see https://api.highcharts.com/highstock/plotOptions.ad.label
     * @see https://api.highcharts.com/gantt/plotOptions.ad.label
     */
    label?: PlotAdLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.lastPrice
     */
    lastPrice?: PlotAdLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.lastVisiblePrice
     */
    lastVisiblePrice?: PlotAdLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.ad.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ad.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.ad.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.ad.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.marker
     */
    marker?: PlotAdMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.params
     */
    params?: PlotAdParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point
     */
    point?: PlotAdPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ad.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states
     */
    states?: PlotAdStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.step
     * @see https://api.highcharts.com/highstock/plotOptions.ad.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.ad.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip
     */
    tooltip?: PlotAdTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ad.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.ad.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.ad.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.zones
     * @see https://api.highcharts.com/highstock/plotOptions.ad.zones
     */
    zones?: Array<PlotAdZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.params
 */
export interface PlotAdParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.params.period
     */
    period?: number;
    /**
     * (Highstock) The id of volume series which is mandatory. For example using
     * OHLC data, volumeSeriesID='volume' means the indicator will be calculated
     * using OHLC and volume values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.params.volumeSeriesID
     */
    volumeSeriesID?: string;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events
 */
export interface PlotAdPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.point
 */
export interface PlotAdPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.point.events
     */
    events?: PlotAdPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.animation
 */
export interface PlotAdStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.halo
 */
export interface PlotAdStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker
 */
export interface PlotAdStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states
     */
    states?: PlotAdStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover.animation
 */
export interface PlotAdStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover
 */
export interface PlotAdStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAdStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.normal
 */
export interface PlotAdStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states
 */
export interface PlotAdStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.hover
     */
    hover?: PlotAdStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.normal
     */
    normal?: PlotAdStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.select
     */
    select?: PlotAdStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.select
 */
export interface PlotAdStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover
 */
export interface PlotAdStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAdStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.halo
     */
    halo?: PlotAdStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover.marker
     */
    marker?: PlotAdStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.normal
 */
export interface PlotAdStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states
 */
export interface PlotAdStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.hover
     */
    hover?: PlotAdStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.normal
     */
    normal?: PlotAdStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.select
     */
    select?: PlotAdStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.animation
 */
export interface PlotAdStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.halo
 */
export interface PlotAdStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker
 */
export interface PlotAdStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states
     */
    states?: PlotAdStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover.animation
 */
export interface PlotAdStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover
 */
export interface PlotAdStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAdStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.normal
 */
export interface PlotAdStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states
 */
export interface PlotAdStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.hover
     */
    hover?: PlotAdStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.normal
     */
    normal?: PlotAdStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.select
     */
    select?: PlotAdStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.select
 */
export interface PlotAdStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.select
 */
export interface PlotAdStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAdStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ad.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.halo
     */
    halo?: PlotAdStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.ad.states.select.marker
     */
    marker?: PlotAdStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.ad.tooltip.dateTimeLabelFormats
 */
export interface PlotAdTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip
 */
export interface PlotAdTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.ad.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotAdTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.ad.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.ad.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ad.zones
 * @see https://api.highcharts.com/highstock/plotOptions.ad.zones
 */
export interface PlotAdZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.ad.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.ad.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.ad.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ad.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ad.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.ad.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.animation
 */
export interface PlotAoAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker
 */
export interface PlotAoConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker
 */
export interface PlotAoConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors
 */
export interface PlotAoConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.endMarker
     */
    endMarker?: PlotAoConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.marker
     */
    marker?: PlotAoConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker
     */
    startMarker?: PlotAoConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker
 */
export interface PlotAoConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.dataGrouping
 */
export interface PlotAoDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.filter
 */
export interface PlotAoDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels
 */
export interface PlotAoDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.ao.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.filter
     */
    filter?: PlotAoDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragHandle
 */
export interface PlotAoDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.guideBox.default
 */
export interface PlotAoDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.guideBox
 */
export interface PlotAoDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.guideBox.default
     */
    default?: PlotAoDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop
 */
export interface PlotAoDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragHandle
     */
    dragHandle?: PlotAoDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.guideBox
     */
    guideBox?: (PlotAoDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.events
 */
export interface PlotAoEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.ao.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.ao.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.label
 * @see https://api.highcharts.com/highstock/plotOptions.ao.label
 * @see https://api.highcharts.com/gantt/plotOptions.ao.label
 */
export interface PlotAoLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.ao.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.ao.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.ao.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.ao.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.ao.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.ao.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ao.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.ao.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ao.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ao.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ao.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ao.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.ao.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.ao.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.ao.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.ao.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.lastPrice
 */
export interface PlotAoLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotAoLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.lastVisiblePrice
 */
export interface PlotAoLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotAoLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.marker
 */
export interface PlotAoMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states
     */
    states?: PlotAoMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover.animation
 */
export interface PlotAoMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover
 */
export interface PlotAoMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAoMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.normal
 */
export interface PlotAoMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states
 */
export interface PlotAoMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.hover
     */
    hover?: PlotAoMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.normal
     */
    normal?: PlotAoMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.select
     */
    select?: PlotAoMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.select
 */
export interface PlotAoMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Awesome Oscillator. This series requires the `linkedTo` option to
 * be set and should be loaded after the `stock/indicators/indicators.js`
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ao` series are defined in plotOptions.ao.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao
 */
export interface PlotAoOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAoAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.ao.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ao.connectors
     */
    connectors?: PlotAoConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ao.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataGrouping
     */
    dataGrouping?: PlotAoDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dataLabels
     */
    dataLabels?: PlotAoDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.dragDrop
     */
    dragDrop?: PlotAoDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.events
     */
    events?: PlotAoEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.ao.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.ao.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highstock) Color of the Awesome oscillator series bar that is greater
     * than the previous one. Note that if a `color` is defined, the `color`
     * takes precedence and the `greaterBarColor` is ignored.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.greaterBarColor
     */
    greaterBarColor?: (ColorString|GradientColorObject|PatternObject);
    groupPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.label
     * @see https://api.highcharts.com/highstock/plotOptions.ao.label
     * @see https://api.highcharts.com/gantt/plotOptions.ao.label
     */
    label?: PlotAoLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.lastPrice
     */
    lastPrice?: PlotAoLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.lastVisiblePrice
     */
    lastVisiblePrice?: PlotAoLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.ao.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ao.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.ao.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.ao.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Color of the Awesome oscillator series bar that is lower than
     * the previous one. Note that if a `color` is defined, the `color` takes
     * precedence and the `lowerBarColor` is ignored.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.lowerBarColor
     */
    lowerBarColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.marker
     */
    marker?: PlotAoMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point
     */
    point?: PlotAoPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    pointPadding?: number;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ao.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states
     */
    states?: PlotAoStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.step
     * @see https://api.highcharts.com/highstock/plotOptions.ao.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.ao.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip
     */
    tooltip?: PlotAoTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ao.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.ao.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.ao.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.zones
     * @see https://api.highcharts.com/highstock/plotOptions.ao.zones
     */
    zones?: Array<PlotAoZonesOptions>;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events
 */
export interface PlotAoPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.point
 */
export interface PlotAoPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.point.events
     */
    events?: PlotAoPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.animation
 */
export interface PlotAoStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.halo
 */
export interface PlotAoStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker
 */
export interface PlotAoStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states
     */
    states?: PlotAoStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover.animation
 */
export interface PlotAoStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover
 */
export interface PlotAoStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAoStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.normal
 */
export interface PlotAoStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states
 */
export interface PlotAoStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.hover
     */
    hover?: PlotAoStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.normal
     */
    normal?: PlotAoStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.select
     */
    select?: PlotAoStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.select
 */
export interface PlotAoStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover
 */
export interface PlotAoStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAoStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.halo
     */
    halo?: PlotAoStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover.marker
     */
    marker?: PlotAoStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.normal
 */
export interface PlotAoStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states
 */
export interface PlotAoStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.hover
     */
    hover?: PlotAoStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.normal
     */
    normal?: PlotAoStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.select
     */
    select?: PlotAoStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.animation
 */
export interface PlotAoStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.halo
 */
export interface PlotAoStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker
 */
export interface PlotAoStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states
     */
    states?: PlotAoStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover.animation
 */
export interface PlotAoStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover
 */
export interface PlotAoStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAoStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.normal
 */
export interface PlotAoStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states
 */
export interface PlotAoStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.hover
     */
    hover?: PlotAoStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.normal
     */
    normal?: PlotAoStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.select
     */
    select?: PlotAoStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.select
 */
export interface PlotAoStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.select
 */
export interface PlotAoStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAoStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ao.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.halo
     */
    halo?: PlotAoStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.ao.states.select.marker
     */
    marker?: PlotAoStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.ao.tooltip.dateTimeLabelFormats
 */
export interface PlotAoTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip
 */
export interface PlotAoTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.ao.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotAoTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.ao.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.ao.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ao.zones
 * @see https://api.highcharts.com/highstock/plotOptions.ao.zones
 */
export interface PlotAoZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.ao.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.ao.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.ao.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ao.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ao.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.ao.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.animation
 */
export interface PlotApoAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker
 */
export interface PlotApoConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker
 */
export interface PlotApoConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors
 */
export interface PlotApoConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.endMarker
     */
    endMarker?: PlotApoConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.marker
     */
    marker?: PlotApoConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker
     */
    startMarker?: PlotApoConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker
 */
export interface PlotApoConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.dataGrouping
 */
export interface PlotApoDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.filter
 */
export interface PlotApoDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels
 */
export interface PlotApoDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.apo.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.filter
     */
    filter?: PlotApoDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragHandle
 */
export interface PlotApoDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.guideBox.default
 */
export interface PlotApoDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.guideBox
 */
export interface PlotApoDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.guideBox.default
     */
    default?: PlotApoDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop
 */
export interface PlotApoDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragHandle
     */
    dragHandle?: PlotApoDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.guideBox
     */
    guideBox?: (PlotApoDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.events
 */
export interface PlotApoEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.apo.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.apo.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.label
 * @see https://api.highcharts.com/highstock/plotOptions.apo.label
 * @see https://api.highcharts.com/gantt/plotOptions.apo.label
 */
export interface PlotApoLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.apo.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.apo.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.apo.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.apo.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.apo.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.apo.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.apo.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.apo.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.apo.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.apo.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.apo.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.apo.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.apo.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.apo.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.apo.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.apo.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.lastPrice
 */
export interface PlotApoLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotApoLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.lastVisiblePrice
 */
export interface PlotApoLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotApoLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.marker
 */
export interface PlotApoMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states
     */
    states?: PlotApoMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover.animation
 */
export interface PlotApoMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover
 */
export interface PlotApoMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotApoMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.normal
 */
export interface PlotApoMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states
 */
export interface PlotApoMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.hover
     */
    hover?: PlotApoMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.normal
     */
    normal?: PlotApoMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.select
     */
    select?: PlotApoMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.select
 */
export interface PlotApoMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Absolute Price Oscillator. This series requires the `linkedTo`
 * option to be set and should be loaded after the
 * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `apo` series are defined in plotOptions.apo.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo
 */
export interface PlotApoOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotApoAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.apo.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.apo.connectors
     */
    connectors?: PlotApoConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.apo.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataGrouping
     */
    dataGrouping?: PlotApoDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dataLabels
     */
    dataLabels?: PlotApoDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.dragDrop
     */
    dragDrop?: PlotApoDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.events
     */
    events?: PlotApoEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.apo.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.apo.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.label
     * @see https://api.highcharts.com/highstock/plotOptions.apo.label
     * @see https://api.highcharts.com/gantt/plotOptions.apo.label
     */
    label?: PlotApoLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.lastPrice
     */
    lastPrice?: PlotApoLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.lastVisiblePrice
     */
    lastVisiblePrice?: PlotApoLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.apo.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.apo.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.apo.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.apo.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.marker
     */
    marker?: PlotApoMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of Absolute Price Oscillator
     * series points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.params
     */
    params?: PlotApoParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point
     */
    point?: PlotApoPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.apo.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states
     */
    states?: PlotApoStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.step
     * @see https://api.highcharts.com/highstock/plotOptions.apo.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.apo.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip
     */
    tooltip?: PlotApoTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.apo.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.apo.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.apo.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.zones
     * @see https://api.highcharts.com/highstock/plotOptions.apo.zones
     */
    zones?: Array<PlotApoZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of Absolute Price Oscillator series
 * points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.params
 */
export interface PlotApoParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * By default index value used to be set to 0. Since Highstock 7 by default
     * index is set to 3 which means that the ema indicator will be calculated
     * using Close values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.params.index
     */
    index?: number;
    /**
     * (Highstock) Periods for Absolute Price Oscillator calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.params.periods
     */
    periods?: Array<number>;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events
 */
export interface PlotApoPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.point
 */
export interface PlotApoPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.point.events
     */
    events?: PlotApoPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.animation
 */
export interface PlotApoStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.halo
 */
export interface PlotApoStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker
 */
export interface PlotApoStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states
     */
    states?: PlotApoStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover.animation
 */
export interface PlotApoStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover
 */
export interface PlotApoStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotApoStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.normal
 */
export interface PlotApoStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states
 */
export interface PlotApoStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.hover
     */
    hover?: PlotApoStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.normal
     */
    normal?: PlotApoStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.select
     */
    select?: PlotApoStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.select
 */
export interface PlotApoStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover
 */
export interface PlotApoStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotApoStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.halo
     */
    halo?: PlotApoStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover.marker
     */
    marker?: PlotApoStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.normal
 */
export interface PlotApoStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states
 */
export interface PlotApoStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.hover
     */
    hover?: PlotApoStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.normal
     */
    normal?: PlotApoStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.select
     */
    select?: PlotApoStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.animation
 */
export interface PlotApoStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.halo
 */
export interface PlotApoStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker
 */
export interface PlotApoStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states
     */
    states?: PlotApoStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover.animation
 */
export interface PlotApoStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover
 */
export interface PlotApoStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotApoStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.normal
 */
export interface PlotApoStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states
 */
export interface PlotApoStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.hover
     */
    hover?: PlotApoStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.normal
     */
    normal?: PlotApoStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.select
     */
    select?: PlotApoStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.select
 */
export interface PlotApoStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.select
 */
export interface PlotApoStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotApoStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.apo.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.halo
     */
    halo?: PlotApoStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.apo.states.select.marker
     */
    marker?: PlotApoStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.apo.tooltip.dateTimeLabelFormats
 */
export interface PlotApoTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip
 */
export interface PlotApoTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.apo.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotApoTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.apo.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.apo.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.apo.zones
 * @see https://api.highcharts.com/highstock/plotOptions.apo.zones
 */
export interface PlotApoZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.apo.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.apo.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.apo.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.apo.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.apo.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.apo.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.animation
 * @see https://api.highcharts.com/highstock/plotOptions.area.animation
 */
export interface PlotAreaAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker
 */
export interface PlotAreaConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker
 */
export interface PlotAreaConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.area.connectors
 */
export interface PlotAreaConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.endMarker
     */
    endMarker?: PlotAreaConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.marker
     */
    marker?: PlotAreaConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker
     */
    startMarker?: PlotAreaConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker
 */
export interface PlotAreaConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.area.dataGrouping
 */
export interface PlotAreaDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.filter
 */
export interface PlotAreaDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels
 */
export interface PlotAreaDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.area.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.filter
     */
    filter?: PlotAreaDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragHandle
 */
export interface PlotAreaDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.guideBox.default
 */
export interface PlotAreaDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.guideBox
 */
export interface PlotAreaDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.guideBox.default
     */
    default?: PlotAreaDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop
 */
export interface PlotAreaDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragHandle
     */
    dragHandle?: PlotAreaDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.guideBox
     */
    guideBox?: (PlotAreaDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.events
 * @see https://api.highcharts.com/highstock/plotOptions.area.events
 */
export interface PlotAreaEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.area.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.area.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.area.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.area.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.area.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.area.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.area.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.area.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.area.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.label
 * @see https://api.highcharts.com/highstock/plotOptions.area.label
 * @see https://api.highcharts.com/gantt/plotOptions.area.label
 */
export interface PlotAreaLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.area.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.area.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.area.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.area.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.area.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.area.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.area.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.area.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.area.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.area.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.area.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.area.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.area.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.area.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.area.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.area.lastPrice
 */
export interface PlotAreaLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotAreaLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.area.lastVisiblePrice
 */
export interface PlotAreaLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotAreaLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.marker
 * @see https://api.highcharts.com/highstock/plotOptions.area.marker
 */
export interface PlotAreaMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states
     */
    states?: PlotAreaMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover.animation
 */
export interface PlotAreaMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover
 */
export interface PlotAreaMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreaMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.normal
 */
export interface PlotAreaMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states
 */
export interface PlotAreaMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.hover
     */
    hover?: PlotAreaMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.normal
     */
    normal?: PlotAreaMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.select
     */
    select?: PlotAreaMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.select
 */
export interface PlotAreaMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) The area series type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `area` series are defined in plotOptions.area.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area
 * @see https://api.highcharts.com/highstock/plotOptions.area
 */
export interface PlotAreaOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.area.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.animation
     * @see https://api.highcharts.com/highstock/plotOptions.area.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreaAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.area.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.area.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.className
     * @see https://api.highcharts.com/highstock/plotOptions.area.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.clip
     * @see https://api.highcharts.com/highstock/plotOptions.area.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.color
     * @see https://api.highcharts.com/highstock/plotOptions.area.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.area.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.area.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.area.connectors
     */
    connectors?: PlotAreaConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.area.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.area.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph,
     * or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.area.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataGrouping
     */
    dataGrouping?: PlotAreaDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.area.dataLabels
     */
    dataLabels?: PlotAreaDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.description
     * @see https://api.highcharts.com/highstock/plotOptions.area.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.area.dragDrop
     */
    dragDrop?: PlotAreaDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.area.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.events
     * @see https://api.highcharts.com/highstock/plotOptions.area.events
     */
    events?: PlotAreaEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.area.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Fill color or gradient for the area. When `null`,
     * the series' `color` is used with the series' `fillOpacity`.
     *
     * In styled mode, the fill color can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.fillColor
     */
    fillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Fill opacity for the area. When you set an
     * explicit `fillColor`, the `fillOpacity` is not applied. Instead, you
     * should define the opacity in the `fillColor` with an rgba color
     * definition. The `fillOpacity` setting, also the default setting,
     * overrides the alpha component of the `color` setting.
     *
     * In styled mode, the fill opacity can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.fillOpacity
     * @see https://api.highcharts.com/highstock/plotOptions.area.fillOpacity
     */
    fillOpacity?: number;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.area.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.area.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.area.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.keys
     * @see https://api.highcharts.com/highstock/plotOptions.area.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.label
     * @see https://api.highcharts.com/highstock/plotOptions.area.label
     * @see https://api.highcharts.com/gantt/plotOptions.area.label
     */
    label?: PlotAreaLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.lastPrice
     */
    lastPrice?: PlotAreaLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.lastVisiblePrice
     */
    lastVisiblePrice?: PlotAreaLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.area.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) A separate color for the graph line. By default
     * the line takes the `color` of the series, but the lineColor setting
     * allows setting a separate color for the line without altering the
     * `fillColor`.
     *
     * In styled mode, the line stroke can be set with the `.highcharts-graph`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.area.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.area.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.marker
     * @see https://api.highcharts.com/highstock/plotOptions.area.marker
     */
    marker?: PlotAreaMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) A separate color for the negative part of the area.
     *
     * In styled mode, a negative color is set with the `.highcharts-negative`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.negativeFillColor
     */
    negativeFillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point
     * @see https://api.highcharts.com/highstock/plotOptions.area.point
     */
    point?: PlotAreaPointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.area.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.area.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.area.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.area.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.area.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.area.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.area.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.area.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.area.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.selected
     * @see https://api.highcharts.com/highstock/plotOptions.area.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) Whether to apply a drop shadow to the graph line.
     * Since 2.3 the shadow can be an object configuration containing `color`,
     * `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.area.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.area.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.area.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.area.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.area.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.area.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states
     * @see https://api.highcharts.com/highstock/plotOptions.area.states
     */
    states?: PlotAreaStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.step
     * @see https://api.highcharts.com/highstock/plotOptions.area.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.area.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The Y axis value to serve as the base for the
     * area, for distinguishing between values above and below a threshold. The
     * area between the graph and the threshold is filled.
     *
     * * If a number is given, the Y axis will scale to the threshold.
     *
     * * If `null`, the scaling behaves like a line series with fill between the
     * graph and the Y axis minimum.
     *
     * * If `Infinity` or `-Infinity`, the area between the graph and the
     * corresponing Y axis extreme is filled (since v6.1.0).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.area.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip
     */
    tooltip?: PlotAreaTooltipOptions;
    /**
     * (Highcharts, Highstock) Whether the whole area or just the line should
     * respond to mouseover tooltips and other mouse or touch events.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.trackByArea
     * @see https://api.highcharts.com/highstock/plotOptions.area.trackByArea
     */
    trackByArea?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.area.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.area.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.visible
     * @see https://api.highcharts.com/highstock/plotOptions.area.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.area.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.zones
     * @see https://api.highcharts.com/highstock/plotOptions.area.zones
     */
    zones?: Array<PlotAreaZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.area.point.events
 */
export interface PlotAreaPointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.point
 * @see https://api.highcharts.com/highstock/plotOptions.area.point
 */
export interface PlotAreaPointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.area.point.events
     */
    events?: PlotAreaPointEventsOptions;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.animation
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.animation
 */
export interface PlotArearangeAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker
 */
export interface PlotArearangeConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker
 */
export interface PlotArearangeConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors
 */
export interface PlotArearangeConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.endMarker
     */
    endMarker?: PlotArearangeConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.marker
     */
    marker?: PlotArearangeConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker
     */
    startMarker?: PlotArearangeConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker
 */
export interface PlotArearangeConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataGrouping
 */
export interface PlotArearangeDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.filter
 */
export interface PlotArearangeDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Extended data labels for range series types. Range
 * series data labels have no `x` and `y` options. Instead, they have `xLow`,
 * `xHigh`, `yLow` and `yHigh` options to allow the higher and lower data label
 * sets individually.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels
 */
export interface PlotArearangeDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.filter
     */
    filter?: PlotArearangeDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) X offset of the higher data labels relative to
     * the point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.xHigh
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.xHigh
     */
    xHigh?: number;
    /**
     * (Highcharts, Highstock) X offset of the lower data labels relative to the
     * point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.xLow
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.xLow
     */
    xLow?: number;
    /**
     * (Highcharts, Highstock) Y offset of the higher data labels relative to
     * the point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.yHigh
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.yHigh
     */
    yHigh?: number;
    /**
     * (Highcharts, Highstock) Y offset of the lower data labels relative to the
     * point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.yLow
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.yLow
     */
    yLow?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragHandle
 */
export interface PlotArearangeDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.guideBox.default
 */
export interface PlotArearangeDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.guideBox
 */
export interface PlotArearangeDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.guideBox.default
     */
    default?: PlotArearangeDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop
 */
export interface PlotArearangeDragDropOptions {
    /**
     * (Highcharts, Highstock) Allow high value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.draggableHigh
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.draggableHigh
     */
    draggableHigh?: boolean;
    /**
     * (Highcharts, Highstock) Allow low value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.draggableLow
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.draggableLow
     */
    draggableLow?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragHandle
     */
    dragHandle?: PlotArearangeDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.guideBox
     */
    guideBox?: (PlotArearangeDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.events
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.events
 */
export interface PlotArearangeEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.label
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.label
 * @see https://api.highcharts.com/gantt/plotOptions.arearange.label
 */
export interface PlotArearangeLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.lastPrice
 */
export interface PlotArearangeLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotArearangeLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.lastVisiblePrice
 */
export interface PlotArearangeLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotArearangeLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker
 */
export interface PlotArearangeMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states
     */
    states?: PlotArearangeMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover.animation
 */
export interface PlotArearangeMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover
 */
export interface PlotArearangeMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotArearangeMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.normal
 */
export interface PlotArearangeMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states
 */
export interface PlotArearangeMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.hover
     */
    hover?: PlotArearangeMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.normal
     */
    normal?: PlotArearangeMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.select
     */
    select?: PlotArearangeMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.select
 */
export interface PlotArearangeMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) The area range series is a carteseian series with
 * higher and lower values for each point along an X axis, where the area
 * between the values is shaded. Requires `highcharts-more.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `arearange` series are defined in plotOptions.arearange.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange
 * @see https://api.highcharts.com/highstock/plotOptions.arearange
 */
export interface PlotArearangeOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.animation
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotArearangeAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.className
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.clip
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.color
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.connectors
     */
    connectors?: PlotArearangeConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph,
     * or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataGrouping
     */
    dataGrouping?: PlotArearangeDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Extended data labels for range series types.
     * Range series data labels have no `x` and `y` options. Instead, they have
     * `xLow`, `xHigh`, `yLow` and `yHigh` options to allow the higher and lower
     * data label sets individually.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dataLabels
     */
    dataLabels?: PlotArearangeDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.description
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.dragDrop
     */
    dragDrop?: PlotArearangeDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.events
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.events
     */
    events?: PlotArearangeEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Fill color or gradient for the area. When `null`,
     * the series' `color` is used with the series' `fillOpacity`.
     *
     * In styled mode, the fill color can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.fillColor
     */
    fillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Fill opacity for the area. When you set an
     * explicit `fillColor`, the `fillOpacity` is not applied. Instead, you
     * should define the opacity in the `fillColor` with an rgba color
     * definition. The `fillOpacity` setting, also the default setting,
     * overrides the alpha component of the `color` setting.
     *
     * In styled mode, the fill opacity can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.fillOpacity
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.fillOpacity
     */
    fillOpacity?: number;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.keys
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.label
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.label
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.label
     */
    label?: PlotArearangeLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.lastPrice
     */
    lastPrice?: PlotArearangeLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.lastVisiblePrice
     */
    lastVisiblePrice?: PlotArearangeLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) A separate color for the graph line. By default
     * the line takes the `color` of the series, but the lineColor setting
     * allows setting a separate color for the line without altering the
     * `fillColor`.
     *
     * In styled mode, the line stroke can be set with the `.highcharts-graph`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Pixel width of the arearange graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.marker
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.marker
     */
    marker?: PlotArearangeMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) A separate color for the negative part of the area.
     *
     * In styled mode, a negative color is set with the `.highcharts-negative`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.negativeFillColor
     */
    negativeFillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point
     */
    point?: PlotArearangePointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.selected
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states
     */
    states?: PlotArearangeStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.step
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The Y axis value to serve as the base for the
     * area, for distinguishing between values above and below a threshold. The
     * area between the graph and the threshold is filled.
     *
     * * If a number is given, the Y axis will scale to the threshold.
     *
     * * If `null`, the scaling behaves like a line series with fill between the
     * graph and the Y axis minimum.
     *
     * * If `Infinity` or `-Infinity`, the area between the graph and the
     * corresponing Y axis extreme is filled (since v6.1.0).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.threshold
     */
    threshold?: any;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip
     */
    tooltip?: PlotArearangeTooltipOptions;
    /**
     * (Highcharts, Highstock) Whether the whole area or just the line should
     * respond to mouseover tooltips and other mouse or touch events.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.trackByArea
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.trackByArea
     */
    trackByArea?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.visible
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.zones
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.zones
     */
    zones?: Array<PlotArearangeZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events
 */
export interface PlotArearangePointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.point
 */
export interface PlotArearangePointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.point.events
     */
    events?: PlotArearangePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.animation
 */
export interface PlotArearangeStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.halo
 */
export interface PlotArearangeStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker
 */
export interface PlotArearangeStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states
     */
    states?: PlotArearangeStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover.animation
 */
export interface PlotArearangeStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover
 */
export interface PlotArearangeStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotArearangeStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.normal
 */
export interface PlotArearangeStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states
 */
export interface PlotArearangeStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.hover
     */
    hover?: PlotArearangeStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.normal
     */
    normal?: PlotArearangeStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.select
     */
    select?: PlotArearangeStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.select
 */
export interface PlotArearangeStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover
 */
export interface PlotArearangeStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotArearangeStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.halo
     */
    halo?: PlotArearangeStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover.marker
     */
    marker?: PlotArearangeStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.normal
 */
export interface PlotArearangeStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states
 */
export interface PlotArearangeStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.hover
     */
    hover?: PlotArearangeStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.normal
     */
    normal?: PlotArearangeStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.select
     */
    select?: PlotArearangeStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.animation
 */
export interface PlotArearangeStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.halo
 */
export interface PlotArearangeStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker
 */
export interface PlotArearangeStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states
     */
    states?: PlotArearangeStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover.animation
 */
export interface PlotArearangeStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover
 */
export interface PlotArearangeStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotArearangeStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.normal
 */
export interface PlotArearangeStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states
 */
export interface PlotArearangeStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.hover
     */
    hover?: PlotArearangeStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.normal
     */
    normal?: PlotArearangeStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.select
     */
    select?: PlotArearangeStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.select
 */
export interface PlotArearangeStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.select
 */
export interface PlotArearangeStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotArearangeStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.arearange.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.halo
     */
    halo?: PlotArearangeStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.states.select.marker
     */
    marker?: PlotArearangeStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.arearange.tooltip.dateTimeLabelFormats
 */
export interface PlotArearangeTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip
 */
export interface PlotArearangeTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotArearangeTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.arearange.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.arearange.zones
 * @see https://api.highcharts.com/highstock/plotOptions.arearange.zones
 */
export interface PlotArearangeZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.arearange.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.animation
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.animation
 */
export interface PlotAreasplineAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker
 */
export interface PlotAreasplineConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker
 */
export interface PlotAreasplineConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors
 */
export interface PlotAreasplineConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.endMarker
     */
    endMarker?: PlotAreasplineConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.marker
     */
    marker?: PlotAreasplineConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker
     */
    startMarker?: PlotAreasplineConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker
 */
export interface PlotAreasplineConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataGrouping
 */
export interface PlotAreasplineDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.filter
 */
export interface PlotAreasplineDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels
 */
export interface PlotAreasplineDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.filter
     */
    filter?: PlotAreasplineDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragHandle
 */
export interface PlotAreasplineDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.guideBox.default
 */
export interface PlotAreasplineDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.guideBox
 */
export interface PlotAreasplineDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.guideBox.default
     */
    default?: PlotAreasplineDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop
 */
export interface PlotAreasplineDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragHandle
     */
    dragHandle?: PlotAreasplineDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.guideBox
     */
    guideBox?: (PlotAreasplineDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.events
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.events
 */
export interface PlotAreasplineEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.label
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.label
 * @see https://api.highcharts.com/gantt/plotOptions.areaspline.label
 */
export interface PlotAreasplineLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.lastPrice
 */
export interface PlotAreasplineLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotAreasplineLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.lastVisiblePrice
 */
export interface PlotAreasplineLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotAreasplineLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker
 */
export interface PlotAreasplineMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states
     */
    states?: PlotAreasplineMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover.animation
 */
export interface PlotAreasplineMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover
 */
export interface PlotAreasplineMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplineMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.normal
 */
export interface PlotAreasplineMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states
 */
export interface PlotAreasplineMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.hover
     */
    hover?: PlotAreasplineMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.normal
     */
    normal?: PlotAreasplineMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.select
     */
    select?: PlotAreasplineMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.select
 */
export interface PlotAreasplineMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) The area spline series is an area series where the
 * graph between the points is smoothed into a spline.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `areaspline` series are defined in plotOptions.areaspline.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline
 */
export interface PlotAreasplineOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplineAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.className
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.clip
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.color
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.connectors
     */
    connectors?: PlotAreasplineConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph,
     * or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataGrouping
     */
    dataGrouping?: PlotAreasplineDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dataLabels
     */
    dataLabels?: PlotAreasplineDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.description
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.dragDrop
     */
    dragDrop?: PlotAreasplineDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.events
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.events
     */
    events?: PlotAreasplineEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Fill color or gradient for the area. When `null`,
     * the series' `color` is used with the series' `fillOpacity`.
     *
     * In styled mode, the fill color can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.fillColor
     */
    fillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Fill opacity for the area. When you set an
     * explicit `fillColor`, the `fillOpacity` is not applied. Instead, you
     * should define the opacity in the `fillColor` with an rgba color
     * definition. The `fillOpacity` setting, also the default setting,
     * overrides the alpha component of the `color` setting.
     *
     * In styled mode, the fill opacity can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.fillOpacity
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.fillOpacity
     */
    fillOpacity?: number;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.keys
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.label
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.label
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.label
     */
    label?: PlotAreasplineLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.lastPrice
     */
    lastPrice?: PlotAreasplineLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.lastVisiblePrice
     */
    lastVisiblePrice?: PlotAreasplineLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) A separate color for the graph line. By default
     * the line takes the `color` of the series, but the lineColor setting
     * allows setting a separate color for the line without altering the
     * `fillColor`.
     *
     * In styled mode, the line stroke can be set with the `.highcharts-graph`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.marker
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.marker
     */
    marker?: PlotAreasplineMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) A separate color for the negative part of the area.
     *
     * In styled mode, a negative color is set with the `.highcharts-negative`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.negativeFillColor
     */
    negativeFillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point
     */
    point?: PlotAreasplinePointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.selected
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) Whether to apply a drop shadow to the graph line.
     * Since 2.3 the shadow can be an object configuration containing `color`,
     * `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states
     */
    states?: PlotAreasplineStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The Y axis value to serve as the base for the
     * area, for distinguishing between values above and below a threshold. The
     * area between the graph and the threshold is filled.
     *
     * * If a number is given, the Y axis will scale to the threshold.
     *
     * * If `null`, the scaling behaves like a line series with fill between the
     * graph and the Y axis minimum.
     *
     * * If `Infinity` or `-Infinity`, the area between the graph and the
     * corresponing Y axis extreme is filled (since v6.1.0).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip
     */
    tooltip?: PlotAreasplineTooltipOptions;
    /**
     * (Highcharts, Highstock) Whether the whole area or just the line should
     * respond to mouseover tooltips and other mouse or touch events.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.trackByArea
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.trackByArea
     */
    trackByArea?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.visible
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.zones
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.zones
     */
    zones?: Array<PlotAreasplineZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events
 */
export interface PlotAreasplinePointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point
 */
export interface PlotAreasplinePointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.point.events
     */
    events?: PlotAreasplinePointEventsOptions;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.animation
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.animation
 */
export interface PlotAreasplinerangeAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker
 */
export interface PlotAreasplinerangeConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker
 */
export interface PlotAreasplinerangeConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors
 */
export interface PlotAreasplinerangeConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.endMarker
     */
    endMarker?: PlotAreasplinerangeConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.marker
     */
    marker?: PlotAreasplinerangeConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker
     */
    startMarker?: PlotAreasplinerangeConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker
 */
export interface PlotAreasplinerangeConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataGrouping
 */
export interface PlotAreasplinerangeDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.filter
 */
export interface PlotAreasplinerangeDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Extended data labels for range series types. Range
 * series data labels have no `x` and `y` options. Instead, they have `xLow`,
 * `xHigh`, `yLow` and `yHigh` options to allow the higher and lower data label
 * sets individually.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels
 */
export interface PlotAreasplinerangeDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.filter
     */
    filter?: PlotAreasplinerangeDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) X offset of the higher data labels relative to
     * the point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.xHigh
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.xHigh
     */
    xHigh?: number;
    /**
     * (Highcharts, Highstock) X offset of the lower data labels relative to the
     * point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.xLow
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.xLow
     */
    xLow?: number;
    /**
     * (Highcharts, Highstock) Y offset of the higher data labels relative to
     * the point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.yHigh
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.yHigh
     */
    yHigh?: number;
    /**
     * (Highcharts, Highstock) Y offset of the lower data labels relative to the
     * point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.yLow
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.yLow
     */
    yLow?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragHandle
 */
export interface PlotAreasplinerangeDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.guideBox.default
 */
export interface PlotAreasplinerangeDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.guideBox
 */
export interface PlotAreasplinerangeDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.guideBox.default
     */
    default?: PlotAreasplinerangeDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop
 */
export interface PlotAreasplinerangeDragDropOptions {
    /**
     * (Highcharts, Highstock) Allow high value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.draggableHigh
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.draggableHigh
     */
    draggableHigh?: boolean;
    /**
     * (Highcharts, Highstock) Allow low value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.draggableLow
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.draggableLow
     */
    draggableLow?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragHandle
     */
    dragHandle?: PlotAreasplinerangeDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.guideBox
     */
    guideBox?: (PlotAreasplinerangeDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.events
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.events
 */
export interface PlotAreasplinerangeEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.label
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.label
 * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.label
 */
export interface PlotAreasplinerangeLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.lastPrice
 */
export interface PlotAreasplinerangeLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotAreasplinerangeLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.lastVisiblePrice
 */
export interface PlotAreasplinerangeLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotAreasplinerangeLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker
 */
export interface PlotAreasplinerangeMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states
     */
    states?: PlotAreasplinerangeMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover.animation
 */
export interface PlotAreasplinerangeMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover
 */
export interface PlotAreasplinerangeMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplinerangeMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.normal
 */
export interface PlotAreasplinerangeMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states
 */
export interface PlotAreasplinerangeMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.hover
     */
    hover?: PlotAreasplinerangeMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.normal
     */
    normal?: PlotAreasplinerangeMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.select
     */
    select?: PlotAreasplinerangeMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.select
 */
export interface PlotAreasplinerangeMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) The area spline range is a cartesian series type with
 * higher and lower Y values along an X axis. The area inside the range is
 * colored, and the graph outlining the area is a smoothed spline. Requires
 * `highcharts-more.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `areasplinerange` series are defined in
 * plotOptions.areasplinerange.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange
 */
export interface PlotAreasplinerangeOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplinerangeAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.className
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.clip
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.color
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.connectors
     */
    connectors?: PlotAreasplinerangeConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph,
     * or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataGrouping
     */
    dataGrouping?: PlotAreasplinerangeDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Extended data labels for range series types.
     * Range series data labels have no `x` and `y` options. Instead, they have
     * `xLow`, `xHigh`, `yLow` and `yHigh` options to allow the higher and lower
     * data label sets individually.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dataLabels
     */
    dataLabels?: PlotAreasplinerangeDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.description
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.dragDrop
     */
    dragDrop?: PlotAreasplinerangeDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.events
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.events
     */
    events?: PlotAreasplinerangeEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Fill color or gradient for the area. When `null`,
     * the series' `color` is used with the series' `fillOpacity`.
     *
     * In styled mode, the fill color can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.fillColor
     */
    fillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Fill opacity for the area. When you set an
     * explicit `fillColor`, the `fillOpacity` is not applied. Instead, you
     * should define the opacity in the `fillColor` with an rgba color
     * definition. The `fillOpacity` setting, also the default setting,
     * overrides the alpha component of the `color` setting.
     *
     * In styled mode, the fill opacity can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.fillOpacity
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.fillOpacity
     */
    fillOpacity?: number;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.keys
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.label
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.label
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.label
     */
    label?: PlotAreasplinerangeLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.lastPrice
     */
    lastPrice?: PlotAreasplinerangeLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.lastVisiblePrice
     */
    lastVisiblePrice?: PlotAreasplinerangeLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) A separate color for the graph line. By default
     * the line takes the `color` of the series, but the lineColor setting
     * allows setting a separate color for the line without altering the
     * `fillColor`.
     *
     * In styled mode, the line stroke can be set with the `.highcharts-graph`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Pixel width of the arearange graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.marker
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.marker
     */
    marker?: PlotAreasplinerangeMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) A separate color for the negative part of the area.
     *
     * In styled mode, a negative color is set with the `.highcharts-negative`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.negativeFillColor
     */
    negativeFillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point
     */
    point?: PlotAreasplinerangePointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.selected
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states
     */
    states?: PlotAreasplinerangeStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The Y axis value to serve as the base for the
     * area, for distinguishing between values above and below a threshold. The
     * area between the graph and the threshold is filled.
     *
     * * If a number is given, the Y axis will scale to the threshold.
     *
     * * If `null`, the scaling behaves like a line series with fill between the
     * graph and the Y axis minimum.
     *
     * * If `Infinity` or `-Infinity`, the area between the graph and the
     * corresponing Y axis extreme is filled (since v6.1.0).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.threshold
     */
    threshold?: any;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip
     */
    tooltip?: PlotAreasplinerangeTooltipOptions;
    /**
     * (Highcharts, Highstock) Whether the whole area or just the line should
     * respond to mouseover tooltips and other mouse or touch events.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.trackByArea
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.trackByArea
     */
    trackByArea?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.visible
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.zones
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.zones
     */
    zones?: Array<PlotAreasplinerangeZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events
 */
export interface PlotAreasplinerangePointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point
 */
export interface PlotAreasplinerangePointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.point.events
     */
    events?: PlotAreasplinerangePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.animation
 */
export interface PlotAreasplinerangeStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.halo
 */
export interface PlotAreasplinerangeStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker
 */
export interface PlotAreasplinerangeStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states
     */
    states?: PlotAreasplinerangeStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover.animation
 */
export interface PlotAreasplinerangeStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover
 */
export interface PlotAreasplinerangeStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplinerangeStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.normal
 */
export interface PlotAreasplinerangeStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states
 */
export interface PlotAreasplinerangeStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.hover
     */
    hover?: PlotAreasplinerangeStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.normal
     */
    normal?: PlotAreasplinerangeStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.select
     */
    select?: PlotAreasplinerangeStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.select
 */
export interface PlotAreasplinerangeStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover
 */
export interface PlotAreasplinerangeStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplinerangeStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.halo
     */
    halo?: PlotAreasplinerangeStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover.marker
     */
    marker?: PlotAreasplinerangeStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.normal
 */
export interface PlotAreasplinerangeStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states
 */
export interface PlotAreasplinerangeStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.hover
     */
    hover?: PlotAreasplinerangeStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.normal
     */
    normal?: PlotAreasplinerangeStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.select
     */
    select?: PlotAreasplinerangeStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.animation
 */
export interface PlotAreasplinerangeStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.halo
 */
export interface PlotAreasplinerangeStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker
 */
export interface PlotAreasplinerangeStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states
     */
    states?: PlotAreasplinerangeStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover.animation
 */
export interface PlotAreasplinerangeStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover
 */
export interface PlotAreasplinerangeStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplinerangeStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.normal
 */
export interface PlotAreasplinerangeStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states
 */
export interface PlotAreasplinerangeStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.hover
     */
    hover?: PlotAreasplinerangeStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.normal
     */
    normal?: PlotAreasplinerangeStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.select
     */
    select?: PlotAreasplinerangeStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.select
 */
export interface PlotAreasplinerangeStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.select
 */
export interface PlotAreasplinerangeStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplinerangeStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areasplinerange.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.halo
     */
    halo?: PlotAreasplinerangeStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.states.select.marker
     */
    marker?: PlotAreasplinerangeStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.tooltip.dateTimeLabelFormats
 */
export interface PlotAreasplinerangeTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip
 */
export interface PlotAreasplinerangeTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotAreasplinerangeTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.areasplinerange.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.zones
 * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.zones
 */
export interface PlotAreasplinerangeZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.animation
 */
export interface PlotAreasplineStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.halo
 */
export interface PlotAreasplineStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker
 */
export interface PlotAreasplineStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states
     */
    states?: PlotAreasplineStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover.animation
 */
export interface PlotAreasplineStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover
 */
export interface PlotAreasplineStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplineStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.normal
 */
export interface PlotAreasplineStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states
 */
export interface PlotAreasplineStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.hover
     */
    hover?: PlotAreasplineStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.normal
     */
    normal?: PlotAreasplineStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.select
     */
    select?: PlotAreasplineStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.select
 */
export interface PlotAreasplineStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover
 */
export interface PlotAreasplineStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplineStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.halo
     */
    halo?: PlotAreasplineStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover.marker
     */
    marker?: PlotAreasplineStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.normal
 */
export interface PlotAreasplineStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states
 */
export interface PlotAreasplineStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.hover
     */
    hover?: PlotAreasplineStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.normal
     */
    normal?: PlotAreasplineStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.select
     */
    select?: PlotAreasplineStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.animation
 */
export interface PlotAreasplineStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.halo
 */
export interface PlotAreasplineStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker
 */
export interface PlotAreasplineStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states
     */
    states?: PlotAreasplineStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover.animation
 */
export interface PlotAreasplineStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover
 */
export interface PlotAreasplineStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplineStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.normal
 */
export interface PlotAreasplineStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states
 */
export interface PlotAreasplineStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.hover
     */
    hover?: PlotAreasplineStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.normal
     */
    normal?: PlotAreasplineStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.select
     */
    select?: PlotAreasplineStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.select
 */
export interface PlotAreasplineStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.select
 */
export interface PlotAreasplineStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreasplineStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.areaspline.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.halo
     */
    halo?: PlotAreasplineStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.states.select.marker
     */
    marker?: PlotAreasplineStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.areaspline.tooltip.dateTimeLabelFormats
 */
export interface PlotAreasplineTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip
 */
export interface PlotAreasplineTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotAreasplineTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.areaspline.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.zones
 * @see https://api.highcharts.com/highstock/plotOptions.areaspline.zones
 */
export interface PlotAreasplineZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.animation
 */
export interface PlotAreaStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.halo
 */
export interface PlotAreaStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker
 */
export interface PlotAreaStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states
     */
    states?: PlotAreaStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover.animation
 */
export interface PlotAreaStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover
 */
export interface PlotAreaStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreaStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.normal
 */
export interface PlotAreaStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states
 */
export interface PlotAreaStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.hover
     */
    hover?: PlotAreaStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.normal
     */
    normal?: PlotAreaStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.select
     */
    select?: PlotAreaStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.select
 */
export interface PlotAreaStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover
 */
export interface PlotAreaStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreaStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.halo
     */
    halo?: PlotAreaStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover.marker
     */
    marker?: PlotAreaStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.area.states.normal
 */
export interface PlotAreaStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states
 * @see https://api.highcharts.com/highstock/plotOptions.area.states
 */
export interface PlotAreaStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.hover
     */
    hover?: PlotAreaStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.normal
     */
    normal?: PlotAreaStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.select
     */
    select?: PlotAreaStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.animation
 */
export interface PlotAreaStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.halo
 */
export interface PlotAreaStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker
 */
export interface PlotAreaStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states
     */
    states?: PlotAreaStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover.animation
 */
export interface PlotAreaStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover
 */
export interface PlotAreaStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreaStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.normal
 */
export interface PlotAreaStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states
 */
export interface PlotAreaStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.hover
     */
    hover?: PlotAreaStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.normal
     */
    normal?: PlotAreaStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.select
     */
    select?: PlotAreaStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.select
 */
export interface PlotAreaStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.area.states.select
 */
export interface PlotAreaStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAreaStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.area.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.halo
     */
    halo?: PlotAreaStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.area.states.select.marker
     */
    marker?: PlotAreaStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.area.tooltip.dateTimeLabelFormats
 */
export interface PlotAreaTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip
 */
export interface PlotAreaTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.area.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotAreaTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.area.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.area.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.area.zones
 * @see https://api.highcharts.com/highstock/plotOptions.area.zones
 */
export interface PlotAreaZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.area.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.area.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.area.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.area.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.area.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.animation
 */
export interface PlotAroonAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) aroonDown line options.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.aroonDown
 */
export interface PlotAroonAroonDownOptions {
    /**
     * (Highstock) Styles for an aroonDown line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.aroonDown.styles
     */
    styles?: PlotAroonAroonDownStylesOptions;
}
/**
 * (Highstock) Styles for an aroonDown line.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.aroonDown.styles
 */
export interface PlotAroonAroonDownStylesOptions {
    /**
     * (Highstock) Color of the line. If not set, it's inherited from
     * plotOptions.aroon.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.aroonDown.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.aroonDown.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker
 */
export interface PlotAroonConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker
 */
export interface PlotAroonConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors
 */
export interface PlotAroonConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.endMarker
     */
    endMarker?: PlotAroonConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.marker
     */
    marker?: PlotAroonConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker
     */
    startMarker?: PlotAroonConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker
 */
export interface PlotAroonConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataGrouping
 */
export interface PlotAroonDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.filter
 */
export interface PlotAroonDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels
 */
export interface PlotAroonDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.filter
     */
    filter?: PlotAroonDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragHandle
 */
export interface PlotAroonDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.guideBox.default
 */
export interface PlotAroonDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.guideBox
 */
export interface PlotAroonDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.guideBox.default
     */
    default?: PlotAroonDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop
 */
export interface PlotAroonDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragHandle
     */
    dragHandle?: PlotAroonDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.guideBox
     */
    guideBox?: (PlotAroonDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.events
 */
export interface PlotAroonEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.label
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.label
 * @see https://api.highcharts.com/gantt/plotOptions.aroon.label
 */
export interface PlotAroonLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.lastPrice
 */
export interface PlotAroonLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotAroonLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.lastVisiblePrice
 */
export interface PlotAroonLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotAroonLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker
 */
export interface PlotAroonMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states
     */
    states?: PlotAroonMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover.animation
 */
export interface PlotAroonMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover
 */
export interface PlotAroonMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.normal
 */
export interface PlotAroonMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states
 */
export interface PlotAroonMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.hover
     */
    hover?: PlotAroonMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.normal
     */
    normal?: PlotAroonMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.select
     */
    select?: PlotAroonMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.select
 */
export interface PlotAroonMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Aroon. This series requires the `linkedTo` option to be set and
 * should be loaded after the `stock/indicators/indicators.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `aroon` series are defined in plotOptions.aroon.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon
 */
export interface PlotAroonOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) aroonDown line options.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.aroonDown
     */
    aroonDown?: PlotAroonAroonDownOptions;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.connectors
     */
    connectors?: PlotAroonConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataGrouping
     */
    dataGrouping?: PlotAroonDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dataLabels
     */
    dataLabels?: PlotAroonDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.dragDrop
     */
    dragDrop?: PlotAroonDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.events
     */
    events?: PlotAroonEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.label
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.label
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.label
     */
    label?: PlotAroonLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.lastPrice
     */
    lastPrice?: PlotAroonLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.lastVisiblePrice
     */
    lastVisiblePrice?: PlotAroonLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.marker
     */
    marker?: PlotAroonMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of aroon series points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.params
     */
    params?: PlotAroonParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point
     */
    point?: PlotAroonPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states
     */
    states?: PlotAroonStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.step
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip
     */
    tooltip?: PlotAroonTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.zones
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.zones
     */
    zones?: Array<PlotAroonZonesOptions>;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.animation
 */
export interface PlotAroonoscillatorAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker
 */
export interface PlotAroonoscillatorConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker
 */
export interface PlotAroonoscillatorConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors
 */
export interface PlotAroonoscillatorConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.endMarker
     */
    endMarker?: PlotAroonoscillatorConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.marker
     */
    marker?: PlotAroonoscillatorConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker
     */
    startMarker?: PlotAroonoscillatorConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker
 */
export interface PlotAroonoscillatorConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataGrouping
 */
export interface PlotAroonoscillatorDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.filter
 */
export interface PlotAroonoscillatorDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels
 */
export interface PlotAroonoscillatorDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.filter
     */
    filter?: PlotAroonoscillatorDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragHandle
 */
export interface PlotAroonoscillatorDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.guideBox.default
 */
export interface PlotAroonoscillatorDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.guideBox
 */
export interface PlotAroonoscillatorDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.guideBox.default
     */
    default?: PlotAroonoscillatorDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop
 */
export interface PlotAroonoscillatorDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragHandle
     */
    dragHandle?: PlotAroonoscillatorDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.guideBox
     */
    guideBox?: (PlotAroonoscillatorDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.events
 */
export interface PlotAroonoscillatorEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.label
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.label
 * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.label
 */
export interface PlotAroonoscillatorLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.lastPrice
 */
export interface PlotAroonoscillatorLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotAroonoscillatorLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.lastVisiblePrice
 */
export interface PlotAroonoscillatorLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotAroonoscillatorLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker
 */
export interface PlotAroonoscillatorMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states
     */
    states?: PlotAroonoscillatorMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover.animation
 */
export interface PlotAroonoscillatorMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover
 */
export interface PlotAroonoscillatorMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonoscillatorMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.normal
 */
export interface PlotAroonoscillatorMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states
 */
export interface PlotAroonoscillatorMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.hover
     */
    hover?: PlotAroonoscillatorMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.normal
     */
    normal?: PlotAroonoscillatorMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.select
     */
    select?: PlotAroonoscillatorMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.select
 */
export interface PlotAroonoscillatorMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Aroon Oscillator. This series requires the `linkedTo` option to
 * be set and should be loaded after the `stock/indicators/indicators.js` and
 * `stock/indicators/aroon.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `aroonoscillator` series are defined in
 * plotOptions.aroonoscillator.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator
 */
export interface PlotAroonoscillatorOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonoscillatorAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.connectors
     */
    connectors?: PlotAroonoscillatorConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataGrouping
     */
    dataGrouping?: PlotAroonoscillatorDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dataLabels
     */
    dataLabels?: PlotAroonoscillatorDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.dragDrop
     */
    dragDrop?: PlotAroonoscillatorDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.events
     */
    events?: PlotAroonoscillatorEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.label
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.label
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.label
     */
    label?: PlotAroonoscillatorLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.lastPrice
     */
    lastPrice?: PlotAroonoscillatorLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.lastVisiblePrice
     */
    lastVisiblePrice?: PlotAroonoscillatorLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.marker
     */
    marker?: PlotAroonoscillatorMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of aroon oscillator series
     * points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.params
     */
    params?: PlotAroonoscillatorParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point
     */
    point?: PlotAroonoscillatorPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states
     */
    states?: PlotAroonoscillatorStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.step
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip
     */
    tooltip?: PlotAroonoscillatorTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.zones
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.zones
     */
    zones?: Array<PlotAroonoscillatorZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of aroon oscillator series points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.params
 */
export interface PlotAroonoscillatorParamsOptions {
    /**
     * (Highstock) Period for Aroon Oscillator
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events
 */
export interface PlotAroonoscillatorPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point
 */
export interface PlotAroonoscillatorPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.point.events
     */
    events?: PlotAroonoscillatorPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.animation
 */
export interface PlotAroonoscillatorStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.halo
 */
export interface PlotAroonoscillatorStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker
 */
export interface PlotAroonoscillatorStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states
     */
    states?: PlotAroonoscillatorStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover.animation
 */
export interface PlotAroonoscillatorStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover
 */
export interface PlotAroonoscillatorStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonoscillatorStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.normal
 */
export interface PlotAroonoscillatorStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states
 */
export interface PlotAroonoscillatorStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.hover
     */
    hover?: PlotAroonoscillatorStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.normal
     */
    normal?: PlotAroonoscillatorStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.select
     */
    select?: PlotAroonoscillatorStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.select
 */
export interface PlotAroonoscillatorStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover
 */
export interface PlotAroonoscillatorStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonoscillatorStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.halo
     */
    halo?: PlotAroonoscillatorStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover.marker
     */
    marker?: PlotAroonoscillatorStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.normal
 */
export interface PlotAroonoscillatorStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states
 */
export interface PlotAroonoscillatorStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.hover
     */
    hover?: PlotAroonoscillatorStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.normal
     */
    normal?: PlotAroonoscillatorStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.select
     */
    select?: PlotAroonoscillatorStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.animation
 */
export interface PlotAroonoscillatorStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.halo
 */
export interface PlotAroonoscillatorStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker
 */
export interface PlotAroonoscillatorStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states
     */
    states?: PlotAroonoscillatorStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover.animation
 */
export interface PlotAroonoscillatorStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover
 */
export interface PlotAroonoscillatorStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonoscillatorStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.normal
 */
export interface PlotAroonoscillatorStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states
 */
export interface PlotAroonoscillatorStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.hover
     */
    hover?: PlotAroonoscillatorStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.normal
     */
    normal?: PlotAroonoscillatorStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.select
     */
    select?: PlotAroonoscillatorStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.select
 */
export interface PlotAroonoscillatorStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.select
 */
export interface PlotAroonoscillatorStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonoscillatorStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroonoscillator.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.halo
     */
    halo?: PlotAroonoscillatorStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.states.select.marker
     */
    marker?: PlotAroonoscillatorStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.tooltip.dateTimeLabelFormats
 */
export interface PlotAroonoscillatorTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip
 */
export interface PlotAroonoscillatorTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotAroonoscillatorTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.aroonoscillator.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.zones
 * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.zones
 */
export interface PlotAroonoscillatorZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroonoscillator.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Paramters used in calculation of aroon series points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.params
 */
export interface PlotAroonParamsOptions {
    /**
     * (Highstock) Period for Aroon indicator
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events
 */
export interface PlotAroonPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.point
 */
export interface PlotAroonPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.point.events
     */
    events?: PlotAroonPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.animation
 */
export interface PlotAroonStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.halo
 */
export interface PlotAroonStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker
 */
export interface PlotAroonStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states
     */
    states?: PlotAroonStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover.animation
 */
export interface PlotAroonStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover
 */
export interface PlotAroonStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.normal
 */
export interface PlotAroonStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states
 */
export interface PlotAroonStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.hover
     */
    hover?: PlotAroonStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.normal
     */
    normal?: PlotAroonStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.select
     */
    select?: PlotAroonStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.select
 */
export interface PlotAroonStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover
 */
export interface PlotAroonStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.halo
     */
    halo?: PlotAroonStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover.marker
     */
    marker?: PlotAroonStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.normal
 */
export interface PlotAroonStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states
 */
export interface PlotAroonStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.hover
     */
    hover?: PlotAroonStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.normal
     */
    normal?: PlotAroonStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.select
     */
    select?: PlotAroonStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.animation
 */
export interface PlotAroonStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.halo
 */
export interface PlotAroonStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker
 */
export interface PlotAroonStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states
     */
    states?: PlotAroonStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover.animation
 */
export interface PlotAroonStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover
 */
export interface PlotAroonStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.normal
 */
export interface PlotAroonStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states
 */
export interface PlotAroonStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.hover
     */
    hover?: PlotAroonStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.normal
     */
    normal?: PlotAroonStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.select
     */
    select?: PlotAroonStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.select
 */
export interface PlotAroonStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.select
 */
export interface PlotAroonStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAroonStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.aroon.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.halo
     */
    halo?: PlotAroonStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.states.select.marker
     */
    marker?: PlotAroonStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.aroon.tooltip.dateTimeLabelFormats
 */
export interface PlotAroonTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip
 */
export interface PlotAroonTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotAroonTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.aroon.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.aroon.zones
 * @see https://api.highcharts.com/highstock/plotOptions.aroon.zones
 */
export interface PlotAroonZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.aroon.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.aroon.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.animation
 */
export interface PlotAtrAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker
 */
export interface PlotAtrConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker
 */
export interface PlotAtrConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors
 */
export interface PlotAtrConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.endMarker
     */
    endMarker?: PlotAtrConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.marker
     */
    marker?: PlotAtrConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker
     */
    startMarker?: PlotAtrConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker
 */
export interface PlotAtrConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.dataGrouping
 */
export interface PlotAtrDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.filter
 */
export interface PlotAtrDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels
 */
export interface PlotAtrDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.atr.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.filter
     */
    filter?: PlotAtrDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragHandle
 */
export interface PlotAtrDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.guideBox.default
 */
export interface PlotAtrDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.guideBox
 */
export interface PlotAtrDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.guideBox.default
     */
    default?: PlotAtrDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop
 */
export interface PlotAtrDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragHandle
     */
    dragHandle?: PlotAtrDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.guideBox
     */
    guideBox?: (PlotAtrDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.events
 */
export interface PlotAtrEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.atr.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.atr.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.label
 * @see https://api.highcharts.com/highstock/plotOptions.atr.label
 * @see https://api.highcharts.com/gantt/plotOptions.atr.label
 */
export interface PlotAtrLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.atr.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.atr.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.atr.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.atr.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.atr.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.atr.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.atr.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.atr.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.atr.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.atr.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.atr.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.atr.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.atr.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.atr.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.atr.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.atr.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.lastPrice
 */
export interface PlotAtrLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotAtrLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.lastVisiblePrice
 */
export interface PlotAtrLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotAtrLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.marker
 */
export interface PlotAtrMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states
     */
    states?: PlotAtrMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover.animation
 */
export interface PlotAtrMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover
 */
export interface PlotAtrMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAtrMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.normal
 */
export interface PlotAtrMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states
 */
export interface PlotAtrMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.hover
     */
    hover?: PlotAtrMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.normal
     */
    normal?: PlotAtrMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.select
     */
    select?: PlotAtrMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.select
 */
export interface PlotAtrMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Average true range indicator (ATR). This series requires
 * `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `atr` series are defined in plotOptions.atr.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr
 */
export interface PlotAtrOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAtrAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.atr.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.atr.connectors
     */
    connectors?: PlotAtrConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.atr.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataGrouping
     */
    dataGrouping?: PlotAtrDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dataLabels
     */
    dataLabels?: PlotAtrDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.dragDrop
     */
    dragDrop?: PlotAtrDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.events
     */
    events?: PlotAtrEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.atr.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.atr.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.label
     * @see https://api.highcharts.com/highstock/plotOptions.atr.label
     * @see https://api.highcharts.com/gantt/plotOptions.atr.label
     */
    label?: PlotAtrLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.lastPrice
     */
    lastPrice?: PlotAtrLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.lastVisiblePrice
     */
    lastVisiblePrice?: PlotAtrLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.atr.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.atr.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.atr.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.atr.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.marker
     */
    marker?: PlotAtrMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.params
     */
    params?: PlotAtrParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point
     */
    point?: PlotAtrPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.atr.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states
     */
    states?: PlotAtrStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.step
     * @see https://api.highcharts.com/highstock/plotOptions.atr.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.atr.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip
     */
    tooltip?: PlotAtrTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.atr.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.atr.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.atr.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.zones
     * @see https://api.highcharts.com/highstock/plotOptions.atr.zones
     */
    zones?: Array<PlotAtrZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.params
 */
export interface PlotAtrParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events
 */
export interface PlotAtrPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.point
 */
export interface PlotAtrPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.point.events
     */
    events?: PlotAtrPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.animation
 */
export interface PlotAtrStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.halo
 */
export interface PlotAtrStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker
 */
export interface PlotAtrStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states
     */
    states?: PlotAtrStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover.animation
 */
export interface PlotAtrStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover
 */
export interface PlotAtrStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAtrStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.normal
 */
export interface PlotAtrStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states
 */
export interface PlotAtrStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.hover
     */
    hover?: PlotAtrStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.normal
     */
    normal?: PlotAtrStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.select
     */
    select?: PlotAtrStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.select
 */
export interface PlotAtrStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover
 */
export interface PlotAtrStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAtrStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.halo
     */
    halo?: PlotAtrStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover.marker
     */
    marker?: PlotAtrStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.normal
 */
export interface PlotAtrStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states
 */
export interface PlotAtrStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.hover
     */
    hover?: PlotAtrStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.normal
     */
    normal?: PlotAtrStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.select
     */
    select?: PlotAtrStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.animation
 */
export interface PlotAtrStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.halo
 */
export interface PlotAtrStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker
 */
export interface PlotAtrStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states
     */
    states?: PlotAtrStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover.animation
 */
export interface PlotAtrStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover
 */
export interface PlotAtrStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAtrStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.normal
 */
export interface PlotAtrStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states
 */
export interface PlotAtrStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.hover
     */
    hover?: PlotAtrStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.normal
     */
    normal?: PlotAtrStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.select
     */
    select?: PlotAtrStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.select
 */
export interface PlotAtrStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.select
 */
export interface PlotAtrStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotAtrStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.atr.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.halo
     */
    halo?: PlotAtrStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.atr.states.select.marker
     */
    marker?: PlotAtrStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.atr.tooltip.dateTimeLabelFormats
 */
export interface PlotAtrTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip
 */
export interface PlotAtrTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.atr.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotAtrTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.atr.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.atr.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.atr.zones
 * @see https://api.highcharts.com/highstock/plotOptions.atr.zones
 */
export interface PlotAtrZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.atr.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.atr.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.atr.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.atr.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.atr.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.atr.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.animation
 */
export interface PlotBarAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker
 */
export interface PlotBarConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker
 */
export interface PlotBarConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors
 */
export interface PlotBarConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.endMarker
     */
    endMarker?: PlotBarConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.marker
     */
    marker?: PlotBarConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker
     */
    startMarker?: PlotBarConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker
 */
export interface PlotBarConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bar.dataGrouping
 */
export interface PlotBarDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.filter
 */
export interface PlotBarDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels
 */
export interface PlotBarDataLabelsOptions {
    /**
     * (Highcharts) Alignment of the data label relative to the data point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.bar.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.bar.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.filter
     */
    filter?: PlotBarDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position of the data label relative to the data point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragHandle
 */
export interface PlotBarDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.guideBox.default
 */
export interface PlotBarDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.guideBox
 */
export interface PlotBarDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.guideBox.default
     */
    default?: PlotBarDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop
 */
export interface PlotBarDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragHandle
     */
    dragHandle?: PlotBarDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.guideBox
     */
    guideBox?: (PlotBarDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.events
 */
export interface PlotBarEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.bar.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.bar.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.label
 * @see https://api.highcharts.com/highstock/plotOptions.bar.label
 * @see https://api.highcharts.com/gantt/plotOptions.bar.label
 */
export interface PlotBarLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.bar.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.bar.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.bar.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.bar.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.bar.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.bar.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bar.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.bar.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.bar.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.bar.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.bar.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.bar.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.bar.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.bar.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.bar.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.bar.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bar.lastPrice
 */
export interface PlotBarLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotBarLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bar.lastVisiblePrice
 */
export interface PlotBarLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotBarLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A bar series is a special type of column series where the
 * columns are horizontal.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `bar` series are defined in plotOptions.bar.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar
 */
export interface PlotBarOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bar.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBarAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.bar.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.bar.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.bar.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.bar.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bar.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.bar.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bar.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.bar.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.bar.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.colors
     * @see https://api.highcharts.com/highstock/plotOptions.bar.colors
     * @see https://api.highcharts.com/gantt/plotOptions.bar.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bar.connectors
     */
    connectors?: PlotBarConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.bar.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.bar.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bar.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.bar.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.dataGrouping
     */
    dataGrouping?: PlotBarDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dataLabels
     */
    dataLabels?: PlotBarDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.depth
     */
    depth?: number;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.dragDrop
     */
    dragDrop?: PlotBarDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.events
     */
    events?: PlotBarEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.bar.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.bar.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.bar.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.bar.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.bar.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.bar.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bar.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.label
     * @see https://api.highcharts.com/highstock/plotOptions.bar.label
     * @see https://api.highcharts.com/gantt/plotOptions.bar.label
     */
    label?: PlotBarLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.lastPrice
     */
    lastPrice?: PlotBarLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.lastVisiblePrice
     */
    lastVisiblePrice?: PlotBarLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.bar.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.bar.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bar.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.bar.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.bar.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.bar.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The color for the parts of the graph or points that are
     * below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point
     */
    point?: PlotBarPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.bar.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.bar.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.bar.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.bar.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.bar.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.bar.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.bar.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.bar.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.bar.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.bar.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.bar.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.bar.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bar.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.bar.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bar.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.bar.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states
     */
    states?: PlotBarStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.threshold
     */
    threshold?: number;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip
     */
    tooltip?: PlotBarTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bar.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.bar.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bar.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.bar.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.zones
     * @see https://api.highcharts.com/highstock/plotOptions.bar.zones
     */
    zones?: Array<PlotBarZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events
 */
export interface PlotBarPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.point
 */
export interface PlotBarPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.point.events
     */
    events?: PlotBarPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.hover.animation
 */
export interface PlotBarStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.bar.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.bar.states.hover
 */
export interface PlotBarStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBarStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.bar.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bar.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.bar.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.bar.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.bar.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bar.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.bar.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.bar.states.normal
 */
export interface PlotBarStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bar.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.states
 */
export interface PlotBarStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.bar.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.bar.states.hover
     */
    hover?: PlotBarStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bar.states.normal
     */
    normal?: PlotBarStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.bar.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.bar.states.select
     */
    select?: PlotBarStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.select.animation
 */
export interface PlotBarStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.bar.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.bar.states.select
 */
export interface PlotBarStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBarStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.bar.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.bar.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bar.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.bar.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.bar.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bar.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.bar.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.bar.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.bar.tooltip.dateTimeLabelFormats
 */
export interface PlotBarTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip
 */
export interface PlotBarTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bar.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.bar.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.bar.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotBarTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.bar.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.bar.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.bar.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bar.zones
 * @see https://api.highcharts.com/highstock/plotOptions.bar.zones
 */
export interface PlotBarZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.bar.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.bar.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.bar.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bar.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.bar.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.animation
 */
export interface PlotBbAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) Bottom line options.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.bottomLine
 */
export interface PlotBbBottomLineOptions {
    /**
     * (Highstock) Styles for a bottom line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.bottomLine.styles
     */
    styles?: PlotBbBottomLineStylesOptions;
}
/**
 * (Highstock) Styles for a bottom line.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.bottomLine.styles
 */
export interface PlotBbBottomLineStylesOptions {
    /**
     * (Highstock) Color of the line. If not set, it's inherited from
     * plotOptions.bb.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.bottomLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.bottomLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker
 */
export interface PlotBbConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker
 */
export interface PlotBbConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors
 */
export interface PlotBbConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.endMarker
     */
    endMarker?: PlotBbConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.marker
     */
    marker?: PlotBbConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker
     */
    startMarker?: PlotBbConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker
 */
export interface PlotBbConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.dataGrouping
 */
export interface PlotBbDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.filter
 */
export interface PlotBbDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels
 */
export interface PlotBbDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.bb.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.filter
     */
    filter?: PlotBbDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragHandle
 */
export interface PlotBbDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.guideBox.default
 */
export interface PlotBbDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.guideBox
 */
export interface PlotBbDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.guideBox.default
     */
    default?: PlotBbDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop
 */
export interface PlotBbDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragHandle
     */
    dragHandle?: PlotBbDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.guideBox
     */
    guideBox?: (PlotBbDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.events
 */
export interface PlotBbEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.bb.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.bb.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.label
 * @see https://api.highcharts.com/highstock/plotOptions.bb.label
 * @see https://api.highcharts.com/gantt/plotOptions.bb.label
 */
export interface PlotBbLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.bb.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.bb.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.bb.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.bb.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.bb.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.bb.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bb.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.bb.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.bb.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.bb.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.bb.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.bb.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.bb.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.bb.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.bb.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.bb.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.lastPrice
 */
export interface PlotBbLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotBbLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.lastVisiblePrice
 */
export interface PlotBbLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotBbLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.marker
 */
export interface PlotBbMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states
     */
    states?: PlotBbMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover.animation
 */
export interface PlotBbMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover
 */
export interface PlotBbMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBbMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.normal
 */
export interface PlotBbMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states
 */
export interface PlotBbMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.hover
     */
    hover?: PlotBbMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.normal
     */
    normal?: PlotBbMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.select
     */
    select?: PlotBbMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.select
 */
export interface PlotBbMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Bollinger bands (BB). This series requires the `linkedTo` option
 * to be set and should be loaded after the `stock/indicators/indicators.js`
 * file.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `bb` series are defined in plotOptions.bb.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb
 */
export interface PlotBbOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBbAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) Bottom line options.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.bottomLine
     */
    bottomLine?: PlotBbBottomLineOptions;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.bb.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bb.connectors
     */
    connectors?: PlotBbConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bb.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataGrouping
     */
    dataGrouping?: PlotBbDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dataLabels
     */
    dataLabels?: PlotBbDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.dragDrop
     */
    dragDrop?: PlotBbDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.events
     */
    events?: PlotBbEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.bb.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.bb.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.label
     * @see https://api.highcharts.com/highstock/plotOptions.bb.label
     * @see https://api.highcharts.com/gantt/plotOptions.bb.label
     */
    label?: PlotBbLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.lastPrice
     */
    lastPrice?: PlotBbLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.lastVisiblePrice
     */
    lastVisiblePrice?: PlotBbLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.bb.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bb.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.bb.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.bb.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.marker
     */
    marker?: PlotBbMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.params
     */
    params?: PlotBbParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point
     */
    point?: PlotBbPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bb.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states
     */
    states?: PlotBbStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.step
     * @see https://api.highcharts.com/highstock/plotOptions.bb.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.bb.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip
     */
    tooltip?: PlotBbTooltipOptions;
    /**
     * (Highstock) Top line options.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.topLine
     */
    topLine?: PlotBbTopLineOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bb.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.bb.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.bb.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.zones
     * @see https://api.highcharts.com/highstock/plotOptions.bb.zones
     */
    zones?: Array<PlotBbZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.params
 */
export interface PlotBbParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.params.period
     */
    period?: number;
    /**
     * (Highstock) Standard deviation for top and bottom bands.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.params.standardDeviation
     */
    standardDeviation?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events
 */
export interface PlotBbPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.point
 */
export interface PlotBbPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.point.events
     */
    events?: PlotBbPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.animation
 */
export interface PlotBbStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.halo
 */
export interface PlotBbStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker
 */
export interface PlotBbStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states
     */
    states?: PlotBbStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover.animation
 */
export interface PlotBbStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover
 */
export interface PlotBbStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBbStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.normal
 */
export interface PlotBbStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states
 */
export interface PlotBbStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.hover
     */
    hover?: PlotBbStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.normal
     */
    normal?: PlotBbStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.select
     */
    select?: PlotBbStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.select
 */
export interface PlotBbStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover
 */
export interface PlotBbStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBbStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.halo
     */
    halo?: PlotBbStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover.marker
     */
    marker?: PlotBbStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.normal
 */
export interface PlotBbStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states
 */
export interface PlotBbStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.hover
     */
    hover?: PlotBbStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.normal
     */
    normal?: PlotBbStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.select
     */
    select?: PlotBbStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.animation
 */
export interface PlotBbStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.halo
 */
export interface PlotBbStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker
 */
export interface PlotBbStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states
     */
    states?: PlotBbStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover.animation
 */
export interface PlotBbStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover
 */
export interface PlotBbStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBbStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.normal
 */
export interface PlotBbStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states
 */
export interface PlotBbStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.hover
     */
    hover?: PlotBbStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.normal
     */
    normal?: PlotBbStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.select
     */
    select?: PlotBbStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.select
 */
export interface PlotBbStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.select
 */
export interface PlotBbStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBbStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bb.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.halo
     */
    halo?: PlotBbStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.bb.states.select.marker
     */
    marker?: PlotBbStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.bb.tooltip.dateTimeLabelFormats
 */
export interface PlotBbTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip
 */
export interface PlotBbTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.bb.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotBbTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.bb.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.bb.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highstock) Top line options.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.topLine
 */
export interface PlotBbTopLineOptions {
    /**
     * (Highstock) Styles for a bottom line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.topLine.styles
     */
    styles?: PlotBbTopLineStylesOptions;
}
/**
 * (Highstock) Styles for a bottom line.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bb.topLine.styles
 */
export interface PlotBbTopLineStylesOptions {
    /**
     * (Highstock) Color of the line. If not set, it's inherited from
     * plotOptions.bb.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.topLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb.topLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bb.zones
 * @see https://api.highcharts.com/highstock/plotOptions.bb.zones
 */
export interface PlotBbZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.bb.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.bb.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.bb.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bb.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bb.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.bb.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.animation
 */
export interface PlotBellcurveAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker
 */
export interface PlotBellcurveConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker
 */
export interface PlotBellcurveConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors
 */
export interface PlotBellcurveConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.endMarker
     */
    endMarker?: PlotBellcurveConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.marker
     */
    marker?: PlotBellcurveConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker
     */
    startMarker?: PlotBellcurveConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker
 */
export interface PlotBellcurveConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataGrouping
 */
export interface PlotBellcurveDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.filter
 */
export interface PlotBellcurveDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels
 */
export interface PlotBellcurveDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.filter
     */
    filter?: PlotBellcurveDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragHandle
 */
export interface PlotBellcurveDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.guideBox.default
 */
export interface PlotBellcurveDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.guideBox
 */
export interface PlotBellcurveDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.guideBox.default
     */
    default?: PlotBellcurveDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop
 */
export interface PlotBellcurveDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragHandle
     */
    dragHandle?: PlotBellcurveDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.guideBox
     */
    guideBox?: (PlotBellcurveDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.events
 */
export interface PlotBellcurveEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.label
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.label
 * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.label
 */
export interface PlotBellcurveLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.lastPrice
 */
export interface PlotBellcurveLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotBellcurveLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.lastVisiblePrice
 */
export interface PlotBellcurveLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotBellcurveLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker
 */
export interface PlotBellcurveMarkerOptions {
    /**
     * (Highcharts) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.height
     */
    height?: number;
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states
     */
    states?: PlotBellcurveMarkerStatesOptions;
    /**
     * (Highcharts) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.width
     */
    width?: number;
}
/**
 * (Highcharts) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover.animation
 */
export interface PlotBellcurveMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover
 */
export interface PlotBellcurveMarkerStatesHoverOptions {
    /**
     * (Highcharts) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBellcurveMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.normal
 */
export interface PlotBellcurveMarkerStatesNormalOptions {
    /**
     * (Highcharts) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states
 */
export interface PlotBellcurveMarkerStatesOptions {
    /**
     * (Highcharts) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.hover
     */
    hover?: PlotBellcurveMarkerStatesHoverOptions;
    /**
     * (Highcharts) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.normal
     */
    normal?: PlotBellcurveMarkerStatesNormalOptions;
    /**
     * (Highcharts) The appearance of the point marker when selected. In order
     * to allow a point to be selected, set the `series.allowPointSelect` option
     * to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.select
     */
    select?: PlotBellcurveMarkerStatesSelectOptions;
}
/**
 * (Highcharts) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.select
 */
export interface PlotBellcurveMarkerStatesSelectOptions {
    /**
     * (Highcharts) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) A bell curve is an areaspline series which represents the
 * probability density function of the normal distribution. It calculates mean
 * and standard deviation of the base series data and plots the curve according
 * to the calculated parameters.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `bellcurve` series are defined in plotOptions.bellcurve.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve
 */
export interface PlotBellcurveOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBellcurveAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.connectors
     */
    connectors?: PlotBellcurveConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.dataGrouping
     */
    dataGrouping?: PlotBellcurveDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dataLabels
     */
    dataLabels?: PlotBellcurveDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.dragDrop
     */
    dragDrop?: PlotBellcurveDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.events
     */
    events?: PlotBellcurveEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Fill color or gradient for the area. When `null`,
     * the series' `color` is used with the series' `fillOpacity`.
     *
     * In styled mode, the fill color can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.fillColor
     */
    fillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Fill opacity for the area. When you set an
     * explicit `fillColor`, the `fillOpacity` is not applied. Instead, you
     * should define the opacity in the `fillColor` with an rgba color
     * definition. The `fillOpacity` setting, also the default setting,
     * overrides the alpha component of the `color` setting.
     *
     * In styled mode, the fill opacity can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.fillOpacity
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.fillOpacity
     */
    fillOpacity?: number;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts) This option allows to define the length of the bell curve. A
     * unit of the length of the bell curve is standard deviation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.intervals
     */
    intervals?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.label
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.label
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.label
     */
    label?: PlotBellcurveLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.lastPrice
     */
    lastPrice?: PlotBellcurveLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.lastVisiblePrice
     */
    lastVisiblePrice?: PlotBellcurveLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) A separate color for the graph line. By default
     * the line takes the `color` of the series, but the lineColor setting
     * allows setting a separate color for the line without altering the
     * `fillColor`.
     *
     * In styled mode, the line stroke can be set with the `.highcharts-graph`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) Options for the point markers of line-like series.
     * Properties like `fillColor`, `lineColor` and `lineWidth` define the
     * visual appearance of the markers. Other series types, like column series,
     * don't have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.marker
     */
    marker?: PlotBellcurveMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The color for the parts of the graph or points that are
     * below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) A separate color for the negative part of the area.
     *
     * In styled mode, a negative color is set with the `.highcharts-negative`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.negativeFillColor
     */
    negativeFillColor?: ColorString;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point
     */
    point?: PlotBellcurvePointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts) Defines how many points should be plotted within 1 interval.
     * See `plotOptions.bellcurve.intervals`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.pointsInInterval
     */
    pointsInInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states
     */
    states?: PlotBellcurveStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The Y axis value to serve as the base for the
     * area, for distinguishing between values above and below a threshold. The
     * area between the graph and the threshold is filled.
     *
     * * If a number is given, the Y axis will scale to the threshold.
     *
     * * If `null`, the scaling behaves like a line series with fill between the
     * graph and the Y axis minimum.
     *
     * * If `Infinity` or `-Infinity`, the area between the graph and the
     * corresponing Y axis extreme is filled (since v6.1.0).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.threshold
     */
    threshold?: number;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip
     */
    tooltip?: PlotBellcurveTooltipOptions;
    /**
     * (Highcharts, Highstock) Whether the whole area or just the line should
     * respond to mouseover tooltips and other mouse or touch events.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.trackByArea
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.trackByArea
     */
    trackByArea?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.zones
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.zones
     */
    zones?: Array<PlotBellcurveZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events
 */
export interface PlotBellcurvePointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point
 */
export interface PlotBellcurvePointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.point.events
     */
    events?: PlotBellcurvePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.animation
 */
export interface PlotBellcurveStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.halo
 */
export interface PlotBellcurveStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker
 */
export interface PlotBellcurveStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states
     */
    states?: PlotBellcurveStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover.animation
 */
export interface PlotBellcurveStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover
 */
export interface PlotBellcurveStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBellcurveStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.normal
 */
export interface PlotBellcurveStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states
 */
export interface PlotBellcurveStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.hover
     */
    hover?: PlotBellcurveStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.normal
     */
    normal?: PlotBellcurveStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.select
     */
    select?: PlotBellcurveStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.select
 */
export interface PlotBellcurveStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover
 */
export interface PlotBellcurveStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBellcurveStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.halo
     */
    halo?: PlotBellcurveStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.hover.marker
     */
    marker?: PlotBellcurveStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.normal
 */
export interface PlotBellcurveStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states
 */
export interface PlotBellcurveStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.hover
     */
    hover?: PlotBellcurveStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.normal
     */
    normal?: PlotBellcurveStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.select
     */
    select?: PlotBellcurveStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.animation
 */
export interface PlotBellcurveStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.halo
 */
export interface PlotBellcurveStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker
 */
export interface PlotBellcurveStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states
     */
    states?: PlotBellcurveStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover.animation
 */
export interface PlotBellcurveStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover
 */
export interface PlotBellcurveStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBellcurveStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.normal
 */
export interface PlotBellcurveStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states
 */
export interface PlotBellcurveStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.hover
     */
    hover?: PlotBellcurveStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.normal
     */
    normal?: PlotBellcurveStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.select
     */
    select?: PlotBellcurveStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.select
 */
export interface PlotBellcurveStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.select
 */
export interface PlotBellcurveStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBellcurveStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bellcurve.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.halo
     */
    halo?: PlotBellcurveStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.states.select.marker
     */
    marker?: PlotBellcurveStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.tooltip.dateTimeLabelFormats
 */
export interface PlotBellcurveTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip
 */
export interface PlotBellcurveTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotBellcurveTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.bellcurve.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.zones
 * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.zones
 */
export interface PlotBellcurveZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.bellcurve.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.animation
 */
export interface PlotBoxplotAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker
 */
export interface PlotBoxplotConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker
 */
export interface PlotBoxplotConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors
 */
export interface PlotBoxplotConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.endMarker
     */
    endMarker?: PlotBoxplotConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.marker
     */
    marker?: PlotBoxplotConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker
     */
    startMarker?: PlotBoxplotConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker
 */
export interface PlotBoxplotConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataGrouping
 */
export interface PlotBoxplotDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.filter
 */
export interface PlotBoxplotDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels
 */
export interface PlotBoxplotDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.filter
     */
    filter?: PlotBoxplotDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragHandle
 */
export interface PlotBoxplotDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.guideBox.default
 */
export interface PlotBoxplotDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.guideBox
 */
export interface PlotBoxplotDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.guideBox.default
     */
    default?: PlotBoxplotDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop
 */
export interface PlotBoxplotDragDropOptions {
    /**
     * (Highcharts) Allow high value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.draggableHigh
     */
    draggableHigh?: boolean;
    /**
     * (Highcharts) Allow low value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.draggableLow
     */
    draggableLow?: boolean;
    /**
     * (Highcharts) Allow Q1 value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.draggableQ1
     */
    draggableQ1?: boolean;
    /**
     * (Highcharts) Allow Q3 value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.draggableQ3
     */
    draggableQ3?: boolean;
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragHandle
     */
    dragHandle?: PlotBoxplotDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.guideBox
     */
    guideBox?: (PlotBoxplotDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.events
 */
export interface PlotBoxplotEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.label
 * @see https://api.highcharts.com/highstock/plotOptions.boxplot.label
 * @see https://api.highcharts.com/gantt/plotOptions.boxplot.label
 */
export interface PlotBoxplotLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.boxplot.lastPrice
 */
export interface PlotBoxplotLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotBoxplotLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.boxplot.lastVisiblePrice
 */
export interface PlotBoxplotLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotBoxplotLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A box plot is a convenient way of depicting groups of data
 * through their five-number summaries: the smallest observation (sample
 * minimum), lower quartile (Q1), median (Q2), upper quartile (Q3), and largest
 * observation (sample maximum).
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `boxplot` series are defined in plotOptions.boxplot.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot
 */
export interface PlotBoxplotOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.boxplot.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBoxplotAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.boxplot.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.colors
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.colors
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.connectors
     */
    connectors?: PlotBoxplotConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.dataGrouping
     */
    dataGrouping?: PlotBoxplotDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dataLabels
     */
    dataLabels?: PlotBoxplotDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.depth
     */
    depth?: number;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.dragDrop
     */
    dragDrop?: PlotBoxplotDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.events
     */
    events?: PlotBoxplotEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) The fill color of the box.
     *
     * In styled mode, the fill color can be set with the
     * `.highcharts-boxplot-box` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.fillColor
     */
    fillColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.boxplot.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.label
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.label
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.label
     */
    label?: PlotBoxplotLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.lastPrice
     */
    lastPrice?: PlotBoxplotLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.lastVisiblePrice
     */
    lastVisiblePrice?: PlotBoxplotLastVisiblePriceOptions;
    /**
     * (Highcharts) The width of the line surrounding the box. If any of
     * stemWidth, medianWidth or whiskerWidth are `null`, the lineWidth also
     * applies to these lines.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts) The color of the median line. If `undefined`, the general
     * series color applies.
     *
     * In styled mode, the median stroke width can be set with the
     * `.highcharts-boxplot-median` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.medianColor
     */
    medianColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts) The pixel width of the median line. If `null`, the lineWidth
     * is used.
     *
     * In styled mode, the median stroke width can be set with the
     * `.highcharts-boxplot-median` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.medianWidth
     */
    medianWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The color for the parts of the graph or points that are
     * below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point
     */
    point?: PlotBoxplotPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts) The dash style of the stem, the vertical line extending from
     * the box to the whiskers.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.stemDashStyle
     */
    stemDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts) The width of the stem, the vertical line extending from the
     * box to the whiskers. If `undefined`, the width is inherited from the
     * lineWidth option.
     *
     * In styled mode, the stem stroke width can be set with the
     * `.highcharts-boxplot-stem` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.stemWidth
     */
    stemWidth?: number;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.threshold
     */
    threshold?: any;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip
     */
    tooltip?: PlotBoxplotTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.visible
     */
    visible?: boolean;
    /**
     * (Highcharts) The color of the whiskers, the horizontal lines marking low
     * and high values. When `undefined`, the general series color is used.
     *
     * In styled mode, the whisker stroke can be set with the
     * `.highcharts-boxplot-whisker` class .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.whiskerColor
     */
    whiskerColor?: ColorString;
    /**
     * (Highcharts) The length of the whiskers, the horizontal lines marking low
     * and high values. It can be a numerical pixel value, or a percentage value
     * of the box width. Set `0` to disable whiskers.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.whiskerLength
     */
    whiskerLength?: (number|string);
    /**
     * (Highcharts) The line width of the whiskers, the horizontal lines marking
     * low and high values. When `undefined`, the general lineWidth applies.
     *
     * In styled mode, the whisker stroke width can be set with the
     * `.highcharts-boxplot-whisker` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.whiskerWidth
     */
    whiskerWidth?: number;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.boxplot.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.zones
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.zones
     */
    zones?: Array<PlotBoxplotZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events
 */
export interface PlotBoxplotPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point
 */
export interface PlotBoxplotPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.point.events
     */
    events?: PlotBoxplotPointEventsOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.boxplot.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.boxplot.tooltip.dateTimeLabelFormats
 */
export interface PlotBoxplotTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip
 */
export interface PlotBoxplotTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotBoxplotTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.boxplot.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.zones
 * @see https://api.highcharts.com/highstock/plotOptions.boxplot.zones
 */
export interface PlotBoxplotZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.boxplot.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.animation
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.animation
 */
export interface PlotBubbleAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker
 */
export interface PlotBubbleConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker
 */
export interface PlotBubbleConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors
 */
export interface PlotBubbleConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.endMarker
     */
    endMarker?: PlotBubbleConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.marker
     */
    marker?: PlotBubbleConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker
     */
    startMarker?: PlotBubbleConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker
 */
export interface PlotBubbleConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataGrouping
 */
export interface PlotBubbleDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.filter
 */
export interface PlotBubbleDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels
 */
export interface PlotBubbleDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.filter
     */
    filter?: PlotBubbleDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragHandle
 */
export interface PlotBubbleDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.guideBox.default
 */
export interface PlotBubbleDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.guideBox
 */
export interface PlotBubbleDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.guideBox.default
     */
    default?: PlotBubbleDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop
 */
export interface PlotBubbleDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragHandle
     */
    dragHandle?: PlotBubbleDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.guideBox
     */
    guideBox?: (PlotBubbleDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.events
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.events
 */
export interface PlotBubbleEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.label
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.label
 * @see https://api.highcharts.com/gantt/plotOptions.bubble.label
 */
export interface PlotBubbleLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.lastPrice
 */
export interface PlotBubbleLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotBubbleLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.lastVisiblePrice
 */
export interface PlotBubbleLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotBubbleLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker
 */
export interface PlotBubbleMarkerOptions {
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The fill opacity of the bubble markers.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.fillOpacity
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.fillOpacity
     */
    fillOpacity?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.lineColor
     */
    lineColor?: any;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states
     */
    states?: PlotBubbleMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker.
     * Possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on the form
     * `url(graphic.png)`. Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.symbol
     */
    symbol?: ("circle"|"diamond"|"square"|"triangle"|"triangle-down");
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover.animation
 */
export interface PlotBubbleMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover
 */
export interface PlotBubbleMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBubbleMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.normal
 */
export interface PlotBubbleMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states
 */
export interface PlotBubbleMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.hover
     */
    hover?: PlotBubbleMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.normal
     */
    normal?: PlotBubbleMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.select
     */
    select?: PlotBubbleMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.select
 */
export interface PlotBubbleMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) A bubble series is a three dimensional series type
 * where each point renders an X, Y and Z value. Each points is drawn as a
 * bubble where the position along the X and Y axes mark the X and Y values, and
 * the size of the bubble relates to the Z value. Requires `highcharts-more.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `bubble` series are defined in plotOptions.bubble.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble
 * @see https://api.highcharts.com/highstock/plotOptions.bubble
 */
export interface PlotBubbleOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBubbleAnimationOptions);
    /**
     * (Highcharts, Highstock) If there are more points in the series than the
     * `animationLimit`, the animation won't run. Animation affects overall
     * performance and doesn't work well with heavy data series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.className
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.clip
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.color
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.connectors
     */
    connectors?: PlotBubbleConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph,
     * or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataGrouping
     */
    dataGrouping?: PlotBubbleDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dataLabels
     */
    dataLabels?: PlotBubbleDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.description
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) Whether to display negative sized bubbles. The
     * threshold is given by the zThreshold option, and negative bubbles can be
     * visualized by setting negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.displayNegative
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.displayNegative
     */
    displayNegative?: boolean;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.dragDrop
     */
    dragDrop?: PlotBubbleDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.events
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.events
     */
    events?: PlotBubbleEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.keys
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.label
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.label
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.label
     */
    label?: PlotBubbleLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.lastPrice
     */
    lastPrice?: PlotBubbleLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.lastVisiblePrice
     */
    lastVisiblePrice?: PlotBubbleLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) The width of the line connecting the data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.marker
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.marker
     */
    marker?: PlotBubbleMarkerOptions;
    /**
     * (Highcharts, Highstock) Maximum bubble size. Bubbles will automatically
     * size between the `minSize` and `maxSize` to reflect the `z` value of each
     * bubble. Can be either pixels (when no unit is given), or a percentage of
     * the smallest one of the plot width and height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.maxSize
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.maxSize
     */
    maxSize?: (number|string);
    /**
     * (Highcharts, Highstock) Minimum bubble size. Bubbles will automatically
     * size between the `minSize` and `maxSize` to reflect the `z` value of each
     * bubble. Can be either pixels (when no unit is given), or a percentage of
     * the smallest one of the plot width and height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.minSize
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.minSize
     */
    minSize?: (number|string);
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) When a point's Z value is below the zThreshold setting, this
     * color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point
     */
    point?: PlotBubblePointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.selected
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) Whether the bubble's value should be represented
     * by the area or the width of the bubble. The default, `area`, corresponds
     * best to the human perception of the size of each bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.sizeBy
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.sizeBy
     */
    sizeBy?: ("area"|"width");
    /**
     * (Highcharts) When this is true, the absolute value of z determines the
     * size of the bubble. This means that with the default `zThreshold` of 0, a
     * bubble of value -1 will have the same size as a bubble of value 1, while
     * a bubble of value 0 will have a smaller size according to `minSize`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.sizeByAbsoluteValue
     */
    sizeByAbsoluteValue?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) When this is true, the series will not cause the Y axis to
     * cross the zero plane (or threshold option) unless the data actually
     * crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states
     */
    states?: PlotBubbleStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.step
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip
     */
    tooltip?: PlotBubbleTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.visible
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts) The minimum for the Z value range. Defaults to the highest Z
     * value in the data.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zMax
     */
    zMax?: number;
    /**
     * (Highcharts) The minimum for the Z value range. Defaults to the lowest Z
     * value in the data.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zMin
     */
    zMin?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zones
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.zones
     */
    zones?: Array<PlotBubbleZonesOptions>;
    /**
     * (Highcharts) When displayNegative is `false`, bubbles with lower Z values
     * are skipped. When `displayNegative` is `true` and a negativeColor is
     * given, points with lower Z is colored.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zThreshold
     */
    zThreshold?: number;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events
 */
export interface PlotBubblePointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.point
 */
export interface PlotBubblePointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.point.events
     */
    events?: PlotBubblePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.animation
 */
export interface PlotBubbleStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.halo
 */
export interface PlotBubbleStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker
 */
export interface PlotBubbleStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states
     */
    states?: PlotBubbleStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover.animation
 */
export interface PlotBubbleStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover
 */
export interface PlotBubbleStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBubbleStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.normal
 */
export interface PlotBubbleStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states
 */
export interface PlotBubbleStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.hover
     */
    hover?: PlotBubbleStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.normal
     */
    normal?: PlotBubbleStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.select
     */
    select?: PlotBubbleStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.select
 */
export interface PlotBubbleStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover
 */
export interface PlotBubbleStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBubbleStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.halo
     */
    halo?: PlotBubbleStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover.marker
     */
    marker?: PlotBubbleStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.normal
 */
export interface PlotBubbleStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states
 */
export interface PlotBubbleStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.hover
     */
    hover?: PlotBubbleStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.normal
     */
    normal?: PlotBubbleStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.select
     */
    select?: PlotBubbleStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.animation
 */
export interface PlotBubbleStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.halo
 */
export interface PlotBubbleStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker
 */
export interface PlotBubbleStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states
     */
    states?: PlotBubbleStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover.animation
 */
export interface PlotBubbleStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover
 */
export interface PlotBubbleStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBubbleStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.normal
 */
export interface PlotBubbleStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states
 */
export interface PlotBubbleStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.hover
     */
    hover?: PlotBubbleStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.normal
     */
    normal?: PlotBubbleStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.select
     */
    select?: PlotBubbleStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.select
 */
export interface PlotBubbleStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.select
 */
export interface PlotBubbleStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBubbleStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bubble.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.halo
     */
    halo?: PlotBubbleStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.states.select.marker
     */
    marker?: PlotBubbleStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.bubble.tooltip.dateTimeLabelFormats
 */
export interface PlotBubbleTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip
 */
export interface PlotBubbleTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotBubbleTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.bubble.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zones
 * @see https://api.highcharts.com/highstock/plotOptions.bubble.zones
 */
export interface PlotBubbleZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.bubble.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.animation
 */
export interface PlotBulletAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker
 */
export interface PlotBulletConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker
 */
export interface PlotBulletConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors
 */
export interface PlotBulletConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.endMarker
     */
    endMarker?: PlotBulletConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.marker
     */
    marker?: PlotBulletConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker
     */
    startMarker?: PlotBulletConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker
 */
export interface PlotBulletConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataGrouping
 */
export interface PlotBulletDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.filter
 */
export interface PlotBulletDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels
 */
export interface PlotBulletDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.filter
     */
    filter?: PlotBulletDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragHandle
 */
export interface PlotBulletDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.guideBox.default
 */
export interface PlotBulletDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.guideBox
 */
export interface PlotBulletDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.guideBox.default
     */
    default?: PlotBulletDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop
 */
export interface PlotBulletDragDropOptions {
    /**
     * (Highcharts) Allow target value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.draggableTarget
     */
    draggableTarget?: boolean;
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragHandle
     */
    dragHandle?: PlotBulletDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.guideBox
     */
    guideBox?: (PlotBulletDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.events
 */
export interface PlotBulletEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.label
 * @see https://api.highcharts.com/highstock/plotOptions.bullet.label
 * @see https://api.highcharts.com/gantt/plotOptions.bullet.label
 */
export interface PlotBulletLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bullet.lastPrice
 */
export interface PlotBulletLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotBulletLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.bullet.lastVisiblePrice
 */
export interface PlotBulletLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotBulletLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A bullet graph is a variation of a bar graph. The bullet graph
 * features a single measure, compares it to a target, and displays it in the
 * context of qualitative ranges of performance that could be set using
 * plotBands on yAxis.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `bullet` series are defined in plotOptions.bullet.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet
 */
export interface PlotBulletOptions {
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBulletAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.colors
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.colors
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.connectors
     */
    connectors?: PlotBulletConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.dataGrouping
     */
    dataGrouping?: PlotBulletDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dataLabels
     */
    dataLabels?: PlotBulletDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.depth
     */
    depth?: number;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.dragDrop
     */
    dragDrop?: PlotBulletDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.events
     */
    events?: PlotBulletEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bullet.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.label
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.label
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.label
     */
    label?: PlotBulletLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.lastPrice
     */
    lastPrice?: PlotBulletLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.lastVisiblePrice
     */
    lastVisiblePrice?: PlotBulletLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The color for the parts of the graph or points that are
     * below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point
     */
    point?: PlotBulletPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states
     */
    states?: PlotBulletStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) All options related with look and positiong of targets.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.targetOptions
     */
    targetOptions?: PlotBulletTargetOptions;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.threshold
     */
    threshold?: number;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip
     */
    tooltip?: PlotBulletTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bullet.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.zones
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.zones
     */
    zones?: Array<PlotBulletZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events
 */
export interface PlotBulletPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point
 */
export interface PlotBulletPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.point.events
     */
    events?: PlotBulletPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.hover.animation
 */
export interface PlotBulletStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.bullet.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.hover
 */
export interface PlotBulletStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBulletStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bullet.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.bullet.states.normal
 */
export interface PlotBulletStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bullet.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states
 */
export interface PlotBulletStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.hover
     */
    hover?: PlotBulletStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bullet.states.normal
     */
    normal?: PlotBulletStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.select
     */
    select?: PlotBulletStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.select.animation
 */
export interface PlotBulletStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.bullet.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.select
 */
export interface PlotBulletStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotBulletStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.bullet.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts) All options related with look and positiong of targets.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.targetOptions
 */
export interface PlotBulletTargetOptions {
    /**
     * (Highcharts) The border color of the rectangle representing the target.
     * When not set, the point's border color is used.
     *
     * In styled mode, use class `highcharts-bullet-target` instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.targetOptions.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border width of the rectangle representing the target.
     *
     * In styled mode, use class `highcharts-bullet-target` instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.targetOptions.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) The color of the rectangle representing the target. When not
     * set, point's color (if set in point's options - `color`) or zone of the
     * target value (if `zones` or `negativeColor` are set) or the same color as
     * the point has is used.
     *
     * In styled mode, use class `highcharts-bullet-target` instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.targetOptions.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Highcharts) The height of the rectangle representing the target.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.targetOptions.height
     */
    height?: number;
    /**
     * (Highcharts) The width of the rectangle representing the target. Could be
     * set as a pixel value or as a percentage of a column width.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.targetOptions.width
     */
    width?: (number|string);
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.bullet.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.bullet.tooltip.dateTimeLabelFormats
 */
export interface PlotBulletTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip
 */
export interface PlotBulletTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotBulletTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.bullet.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.bullet.zones
 * @see https://api.highcharts.com/highstock/plotOptions.bullet.zones
 */
export interface PlotBulletZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.bullet.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.animation
 */
export interface PlotCandlestickAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker
 */
export interface PlotCandlestickConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker
 */
export interface PlotCandlestickConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors
 */
export interface PlotCandlestickConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.endMarker
     */
    endMarker?: PlotCandlestickConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.marker
     */
    marker?: PlotCandlestickConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker
     */
    startMarker?: PlotCandlestickConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker
 */
export interface PlotCandlestickConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataGrouping
 */
export interface PlotCandlestickDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `5`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.filter
 */
export interface PlotCandlestickDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels
 */
export interface PlotCandlestickDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.filter
     */
    filter?: PlotCandlestickDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragHandle
 */
export interface PlotCandlestickDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.guideBox.default
 */
export interface PlotCandlestickDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.guideBox
 */
export interface PlotCandlestickDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.guideBox.default
     */
    default?: PlotCandlestickDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop
 */
export interface PlotCandlestickDragDropOptions {
    /**
     * (Highstock) Allow close value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.draggableClose
     */
    draggableClose?: boolean;
    /**
     * (Highstock) Allow high value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.draggableHigh
     */
    draggableHigh?: boolean;
    /**
     * (Highstock) Allow low value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.draggableLow
     */
    draggableLow?: boolean;
    /**
     * (Highstock) Allow open value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.draggableOpen
     */
    draggableOpen?: boolean;
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragHandle
     */
    dragHandle?: PlotCandlestickDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.guideBox
     */
    guideBox?: (PlotCandlestickDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.events
 */
export interface PlotCandlestickEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.label
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.label
 * @see https://api.highcharts.com/gantt/plotOptions.candlestick.label
 */
export interface PlotCandlestickLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.lastPrice
 */
export interface PlotCandlestickLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotCandlestickLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.lastVisiblePrice
 */
export interface PlotCandlestickLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotCandlestickLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) A candlestick chart is a style of financial chart used to
 * describe price movements over time.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `candlestick` series are defined in
 * plotOptions.candlestick.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick
 */
export interface PlotCandlestickOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.candlestick.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCandlestickAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.candlestick.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.colors
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.colors
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.connectors
     */
    connectors?: PlotCandlestickConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataGrouping
     */
    dataGrouping?: PlotCandlestickDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dataLabels
     */
    dataLabels?: PlotCandlestickDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.depth
     */
    depth?: number;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.dragDrop
     */
    dragDrop?: PlotCandlestickDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.events
     */
    events?: PlotCandlestickEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.candlestick.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highstock) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.label
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.label
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.label
     */
    label?: PlotCandlestickLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.lastPrice
     */
    lastPrice?: PlotCandlestickLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.lastVisiblePrice
     */
    lastVisiblePrice?: PlotCandlestickLastVisiblePriceOptions;
    /**
     * (Highstock) The color of the line/border of the candlestick.
     *
     * In styled mode, the line stroke can be set with the
     * `.highcharts-candlestick-series .highcahrts-point` rule.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The pixel width of the candlestick line/border. Defaults to
     * `1`.
     *
     * In styled mode, the line stroke width can be set with the
     * `.highcharts-candlestick-series .highcahrts-point` rule.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point
     */
    point?: PlotCandlestickPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.pointStart
     */
    pointStart?: number;
    /**
     * (Highstock) Determines which one of `open`, `high`, `low`, `close` values
     * should be represented as `point.y`, which is later used to set dataLabel
     * position.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.pointValKey
     */
    pointValKey?: ("close"|"high"|"low"|"open");
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states
     */
    states?: PlotCandlestickStatesOptions;
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highstock) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.threshold
     */
    threshold?: (number|null);
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip
     */
    tooltip?: PlotCandlestickTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) The fill color of the candlestick when values are rising.
     *
     * In styled mode, the up color can be set with the
     * `.highcharts-candlestick-series .highcharts-point-up` rule.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.upColor
     */
    upColor?: ColorString;
    /**
     * (Highstock) The specific line color for up candle sticks. The default is
     * to inherit the general `lineColor` setting.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.upLineColor
     */
    upLineColor?: ColorString;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.candlestick.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.zones
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.zones
     */
    zones?: Array<PlotCandlestickZonesOptions>;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events
 */
export interface PlotCandlestickPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point
 */
export interface PlotCandlestickPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.point.events
     */
    events?: PlotCandlestickPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.hover.animation
 */
export interface PlotCandlestickStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highstock) Options for the hovered point. These settings override the normal
 * state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states.hover
 */
export interface PlotCandlestickStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCandlestickStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.candlestick.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The pixel width of the line/border around the candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states.hover.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.candlestick.states.normal
 */
export interface PlotCandlestickStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.candlestick.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states
 */
export interface PlotCandlestickStatesOptions {
    /**
     * (Highstock) Options for the hovered point. These settings override the
     * normal state options when a point is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states.hover
     */
    hover?: PlotCandlestickStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.candlestick.states.normal
     */
    normal?: PlotCandlestickStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.states.select
     */
    select?: PlotCandlestickStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.select.animation
 */
export interface PlotCandlestickStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.candlestick.states.select
 */
export interface PlotCandlestickStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCandlestickStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.candlestick.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.candlestick.tooltip.dateTimeLabelFormats
 */
export interface PlotCandlestickTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip
 */
export interface PlotCandlestickTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotCandlestickTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.candlestick.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.zones
 * @see https://api.highcharts.com/highstock/plotOptions.candlestick.zones
 */
export interface PlotCandlestickZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.candlestick.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.animation
 */
export interface PlotCciAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker
 */
export interface PlotCciConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker
 */
export interface PlotCciConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors
 */
export interface PlotCciConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.endMarker
     */
    endMarker?: PlotCciConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.marker
     */
    marker?: PlotCciConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker
     */
    startMarker?: PlotCciConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker
 */
export interface PlotCciConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.dataGrouping
 */
export interface PlotCciDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.filter
 */
export interface PlotCciDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels
 */
export interface PlotCciDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.cci.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.filter
     */
    filter?: PlotCciDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragHandle
 */
export interface PlotCciDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.guideBox.default
 */
export interface PlotCciDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.guideBox
 */
export interface PlotCciDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.guideBox.default
     */
    default?: PlotCciDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop
 */
export interface PlotCciDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragHandle
     */
    dragHandle?: PlotCciDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.guideBox
     */
    guideBox?: (PlotCciDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.events
 */
export interface PlotCciEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.cci.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.cci.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.label
 * @see https://api.highcharts.com/highstock/plotOptions.cci.label
 * @see https://api.highcharts.com/gantt/plotOptions.cci.label
 */
export interface PlotCciLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.cci.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.cci.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.cci.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.cci.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.cci.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.cci.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cci.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.cci.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.cci.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.cci.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.cci.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.cci.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.cci.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.cci.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.cci.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.cci.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.lastPrice
 */
export interface PlotCciLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotCciLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.lastVisiblePrice
 */
export interface PlotCciLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotCciLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.marker
 */
export interface PlotCciMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states
     */
    states?: PlotCciMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover.animation
 */
export interface PlotCciMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover
 */
export interface PlotCciMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCciMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.normal
 */
export interface PlotCciMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states
 */
export interface PlotCciMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.hover
     */
    hover?: PlotCciMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.normal
     */
    normal?: PlotCciMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.select
     */
    select?: PlotCciMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.select
 */
export interface PlotCciMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Commodity Channel Index (CCI). This series requires `linkedTo`
 * option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `cci` series are defined in plotOptions.cci.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci
 */
export interface PlotCciOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCciAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.cci.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cci.connectors
     */
    connectors?: PlotCciConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cci.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataGrouping
     */
    dataGrouping?: PlotCciDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dataLabels
     */
    dataLabels?: PlotCciDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.dragDrop
     */
    dragDrop?: PlotCciDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.events
     */
    events?: PlotCciEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.cci.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.cci.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.label
     * @see https://api.highcharts.com/highstock/plotOptions.cci.label
     * @see https://api.highcharts.com/gantt/plotOptions.cci.label
     */
    label?: PlotCciLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.lastPrice
     */
    lastPrice?: PlotCciLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.lastVisiblePrice
     */
    lastVisiblePrice?: PlotCciLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.cci.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cci.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.cci.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.cci.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.marker
     */
    marker?: PlotCciMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.params
     */
    params?: PlotCciParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point
     */
    point?: PlotCciPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cci.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states
     */
    states?: PlotCciStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.step
     * @see https://api.highcharts.com/highstock/plotOptions.cci.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.cci.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip
     */
    tooltip?: PlotCciTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cci.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.cci.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.cci.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.zones
     * @see https://api.highcharts.com/highstock/plotOptions.cci.zones
     */
    zones?: Array<PlotCciZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.params
 */
export interface PlotCciParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events
 */
export interface PlotCciPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.point
 */
export interface PlotCciPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.point.events
     */
    events?: PlotCciPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.animation
 */
export interface PlotCciStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.halo
 */
export interface PlotCciStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker
 */
export interface PlotCciStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states
     */
    states?: PlotCciStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover.animation
 */
export interface PlotCciStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover
 */
export interface PlotCciStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCciStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.normal
 */
export interface PlotCciStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states
 */
export interface PlotCciStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.hover
     */
    hover?: PlotCciStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.normal
     */
    normal?: PlotCciStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.select
     */
    select?: PlotCciStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.select
 */
export interface PlotCciStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover
 */
export interface PlotCciStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCciStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.halo
     */
    halo?: PlotCciStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover.marker
     */
    marker?: PlotCciStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.normal
 */
export interface PlotCciStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states
 */
export interface PlotCciStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.hover
     */
    hover?: PlotCciStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.normal
     */
    normal?: PlotCciStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.select
     */
    select?: PlotCciStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.animation
 */
export interface PlotCciStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.halo
 */
export interface PlotCciStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker
 */
export interface PlotCciStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states
     */
    states?: PlotCciStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover.animation
 */
export interface PlotCciStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover
 */
export interface PlotCciStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCciStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.normal
 */
export interface PlotCciStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states
 */
export interface PlotCciStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.hover
     */
    hover?: PlotCciStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.normal
     */
    normal?: PlotCciStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.select
     */
    select?: PlotCciStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.select
 */
export interface PlotCciStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.select
 */
export interface PlotCciStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCciStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cci.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.halo
     */
    halo?: PlotCciStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.cci.states.select.marker
     */
    marker?: PlotCciStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.cci.tooltip.dateTimeLabelFormats
 */
export interface PlotCciTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip
 */
export interface PlotCciTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.cci.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotCciTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.cci.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.cci.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cci.zones
 * @see https://api.highcharts.com/highstock/plotOptions.cci.zones
 */
export interface PlotCciZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.cci.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.cci.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.cci.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cci.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cci.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.cci.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.animation
 */
export interface PlotChaikinAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker
 */
export interface PlotChaikinConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker
 */
export interface PlotChaikinConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors
 */
export interface PlotChaikinConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.endMarker
     */
    endMarker?: PlotChaikinConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.marker
     */
    marker?: PlotChaikinConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker
     */
    startMarker?: PlotChaikinConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker
 */
export interface PlotChaikinConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataGrouping
 */
export interface PlotChaikinDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.filter
 */
export interface PlotChaikinDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels
 */
export interface PlotChaikinDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.filter
     */
    filter?: PlotChaikinDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragHandle
 */
export interface PlotChaikinDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.guideBox.default
 */
export interface PlotChaikinDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.guideBox
 */
export interface PlotChaikinDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.guideBox.default
     */
    default?: PlotChaikinDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop
 */
export interface PlotChaikinDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragHandle
     */
    dragHandle?: PlotChaikinDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.guideBox
     */
    guideBox?: (PlotChaikinDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.events
 */
export interface PlotChaikinEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.label
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.label
 * @see https://api.highcharts.com/gantt/plotOptions.chaikin.label
 */
export interface PlotChaikinLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.lastPrice
 */
export interface PlotChaikinLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotChaikinLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.lastVisiblePrice
 */
export interface PlotChaikinLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotChaikinLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker
 */
export interface PlotChaikinMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states
     */
    states?: PlotChaikinMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover.animation
 */
export interface PlotChaikinMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover
 */
export interface PlotChaikinMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotChaikinMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.normal
 */
export interface PlotChaikinMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states
 */
export interface PlotChaikinMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.hover
     */
    hover?: PlotChaikinMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.normal
     */
    normal?: PlotChaikinMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.select
     */
    select?: PlotChaikinMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.select
 */
export interface PlotChaikinMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Chaikin Oscillator. This series requires the `linkedTo` option to
 * be set and should be loaded after the `stock/indicators/indicators.js` and
 * `stock/indicators/ema.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `chaikin` series are defined in plotOptions.chaikin.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin
 */
export interface PlotChaikinOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotChaikinAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.connectors
     */
    connectors?: PlotChaikinConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataGrouping
     */
    dataGrouping?: PlotChaikinDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dataLabels
     */
    dataLabels?: PlotChaikinDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.dragDrop
     */
    dragDrop?: PlotChaikinDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.events
     */
    events?: PlotChaikinEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.label
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.label
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.label
     */
    label?: PlotChaikinLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.lastPrice
     */
    lastPrice?: PlotChaikinLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.lastVisiblePrice
     */
    lastVisiblePrice?: PlotChaikinLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.marker
     */
    marker?: PlotChaikinMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of Chaikin Oscillator series
     * points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.params
     */
    params?: PlotChaikinParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point
     */
    point?: PlotChaikinPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states
     */
    states?: PlotChaikinStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.step
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip
     */
    tooltip?: PlotChaikinTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.zones
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.zones
     */
    zones?: Array<PlotChaikinZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of Chaikin Oscillator series
 * points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.params
 */
export interface PlotChaikinParamsOptions {
    /**
     * (Highstock) Periods for Chaikin Oscillator calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.params.periods
     */
    periods?: Array<number>;
    /**
     * (Highstock) The id of volume series which is mandatory. For example using
     * OHLC data, volumeSeriesID='volume' means the indicator will be calculated
     * using OHLC and volume values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.params.volumeSeriesID
     */
    volumeSeriesID?: string;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events
 */
export interface PlotChaikinPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point
 */
export interface PlotChaikinPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.point.events
     */
    events?: PlotChaikinPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.animation
 */
export interface PlotChaikinStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.halo
 */
export interface PlotChaikinStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker
 */
export interface PlotChaikinStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states
     */
    states?: PlotChaikinStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover.animation
 */
export interface PlotChaikinStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover
 */
export interface PlotChaikinStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotChaikinStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.normal
 */
export interface PlotChaikinStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states
 */
export interface PlotChaikinStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.hover
     */
    hover?: PlotChaikinStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.normal
     */
    normal?: PlotChaikinStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.select
     */
    select?: PlotChaikinStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.select
 */
export interface PlotChaikinStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover
 */
export interface PlotChaikinStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotChaikinStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.halo
     */
    halo?: PlotChaikinStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover.marker
     */
    marker?: PlotChaikinStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.normal
 */
export interface PlotChaikinStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states
 */
export interface PlotChaikinStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.hover
     */
    hover?: PlotChaikinStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.normal
     */
    normal?: PlotChaikinStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.select
     */
    select?: PlotChaikinStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.animation
 */
export interface PlotChaikinStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.halo
 */
export interface PlotChaikinStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker
 */
export interface PlotChaikinStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states
     */
    states?: PlotChaikinStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover.animation
 */
export interface PlotChaikinStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover
 */
export interface PlotChaikinStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotChaikinStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.normal
 */
export interface PlotChaikinStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states
 */
export interface PlotChaikinStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.hover
     */
    hover?: PlotChaikinStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.normal
     */
    normal?: PlotChaikinStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.select
     */
    select?: PlotChaikinStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.select
 */
export interface PlotChaikinStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.select
 */
export interface PlotChaikinStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotChaikinStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.chaikin.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.halo
     */
    halo?: PlotChaikinStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.states.select.marker
     */
    marker?: PlotChaikinStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.chaikin.tooltip.dateTimeLabelFormats
 */
export interface PlotChaikinTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip
 */
export interface PlotChaikinTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotChaikinTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.chaikin.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.zones
 * @see https://api.highcharts.com/highstock/plotOptions.chaikin.zones
 */
export interface PlotChaikinZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.chaikin.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.animation
 */
export interface PlotCmfAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker
 */
export interface PlotCmfConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker
 */
export interface PlotCmfConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors
 */
export interface PlotCmfConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.endMarker
     */
    endMarker?: PlotCmfConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.marker
     */
    marker?: PlotCmfConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker
     */
    startMarker?: PlotCmfConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker
 */
export interface PlotCmfConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataGrouping
 */
export interface PlotCmfDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.filter
 */
export interface PlotCmfDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels
 */
export interface PlotCmfDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.filter
     */
    filter?: PlotCmfDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragHandle
 */
export interface PlotCmfDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.guideBox.default
 */
export interface PlotCmfDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.guideBox
 */
export interface PlotCmfDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.guideBox.default
     */
    default?: PlotCmfDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop
 */
export interface PlotCmfDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragHandle
     */
    dragHandle?: PlotCmfDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.guideBox
     */
    guideBox?: (PlotCmfDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.events
 */
export interface PlotCmfEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.label
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.label
 * @see https://api.highcharts.com/gantt/plotOptions.cmf.label
 */
export interface PlotCmfLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.lastPrice
 */
export interface PlotCmfLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotCmfLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.lastVisiblePrice
 */
export interface PlotCmfLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotCmfLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker
 */
export interface PlotCmfMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states
     */
    states?: PlotCmfMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover.animation
 */
export interface PlotCmfMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover
 */
export interface PlotCmfMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCmfMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.normal
 */
export interface PlotCmfMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states
 */
export interface PlotCmfMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.hover
     */
    hover?: PlotCmfMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.normal
     */
    normal?: PlotCmfMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.select
     */
    select?: PlotCmfMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.select
 */
export interface PlotCmfMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Chaikin Money Flow indicator (cmf).
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `cmf` series are defined in plotOptions.cmf.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf
 */
export interface PlotCmfOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCmfAnimationOptions);
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.connectors
     */
    connectors?: PlotCmfConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataGrouping
     */
    dataGrouping?: PlotCmfDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dataLabels
     */
    dataLabels?: PlotCmfDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.dragDrop
     */
    dragDrop?: PlotCmfDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.events
     */
    events?: PlotCmfEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.label
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.label
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.label
     */
    label?: PlotCmfLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.lastPrice
     */
    lastPrice?: PlotCmfLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.lastVisiblePrice
     */
    lastVisiblePrice?: PlotCmfLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.marker
     */
    marker?: PlotCmfMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.params
     */
    params?: PlotCmfParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point
     */
    point?: PlotCmfPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states
     */
    states?: PlotCmfStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.step
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip
     */
    tooltip?: PlotCmfTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.zones
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.zones
     */
    zones?: Array<PlotCmfZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.params
 */
export interface PlotCmfParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.params.period
     */
    period?: number;
    /**
     * (Highstock) The id of another series to use its data as volume data for
     * the indiator calculation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.params.volumeSeriesID
     */
    volumeSeriesID?: string;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events
 */
export interface PlotCmfPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.point
 */
export interface PlotCmfPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.point.events
     */
    events?: PlotCmfPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.animation
 */
export interface PlotCmfStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.halo
 */
export interface PlotCmfStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker
 */
export interface PlotCmfStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states
     */
    states?: PlotCmfStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover.animation
 */
export interface PlotCmfStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover
 */
export interface PlotCmfStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCmfStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.normal
 */
export interface PlotCmfStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states
 */
export interface PlotCmfStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.hover
     */
    hover?: PlotCmfStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.normal
     */
    normal?: PlotCmfStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.select
     */
    select?: PlotCmfStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.select
 */
export interface PlotCmfStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover
 */
export interface PlotCmfStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCmfStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.halo
     */
    halo?: PlotCmfStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover.marker
     */
    marker?: PlotCmfStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.normal
 */
export interface PlotCmfStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states
 */
export interface PlotCmfStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.hover
     */
    hover?: PlotCmfStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.normal
     */
    normal?: PlotCmfStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.select
     */
    select?: PlotCmfStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.animation
 */
export interface PlotCmfStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.halo
 */
export interface PlotCmfStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker
 */
export interface PlotCmfStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states
     */
    states?: PlotCmfStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover.animation
 */
export interface PlotCmfStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover
 */
export interface PlotCmfStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCmfStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.normal
 */
export interface PlotCmfStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states
 */
export interface PlotCmfStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.hover
     */
    hover?: PlotCmfStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.normal
     */
    normal?: PlotCmfStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.select
     */
    select?: PlotCmfStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.select
 */
export interface PlotCmfStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.select
 */
export interface PlotCmfStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCmfStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cmf.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.halo
     */
    halo?: PlotCmfStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.states.select.marker
     */
    marker?: PlotCmfStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.cmf.tooltip.dateTimeLabelFormats
 */
export interface PlotCmfTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip
 */
export interface PlotCmfTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotCmfTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.cmf.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cmf.zones
 * @see https://api.highcharts.com/highstock/plotOptions.cmf.zones
 */
export interface PlotCmfZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cmf.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.cmf.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.animation
 * @see https://api.highcharts.com/highstock/plotOptions.column.animation
 */
export interface PlotColumnAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker
 */
export interface PlotColumnConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker
 */
export interface PlotColumnConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.column.connectors
 */
export interface PlotColumnConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.endMarker
     */
    endMarker?: PlotColumnConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.marker
     */
    marker?: PlotColumnConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker
     */
    startMarker?: PlotColumnConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker
 */
export interface PlotColumnConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.column.dataGrouping
 */
export interface PlotColumnDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.filter
 */
export interface PlotColumnDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels
 */
export interface PlotColumnDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.column.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.filter
     */
    filter?: PlotColumnDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragHandle
 */
export interface PlotColumnDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.guideBox.default
 */
export interface PlotColumnDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.guideBox
 */
export interface PlotColumnDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.guideBox.default
     */
    default?: PlotColumnDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop
 */
export interface PlotColumnDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragHandle
     */
    dragHandle?: PlotColumnDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.guideBox
     */
    guideBox?: (PlotColumnDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.events
 * @see https://api.highcharts.com/highstock/plotOptions.column.events
 */
export interface PlotColumnEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.column.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.column.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.column.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.column.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.column.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.column.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.column.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.column.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.column.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.label
 * @see https://api.highcharts.com/highstock/plotOptions.column.label
 * @see https://api.highcharts.com/gantt/plotOptions.column.label
 */
export interface PlotColumnLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.column.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.column.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.column.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.column.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.column.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.column.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.column.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.column.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.column.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.column.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.column.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.column.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.column.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.column.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.column.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.column.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.column.lastPrice
 */
export interface PlotColumnLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotColumnLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.column.lastVisiblePrice
 */
export interface PlotColumnLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotColumnLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Column series display one column per value along an X
 * axis.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `column` series are defined in plotOptions.column.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column
 * @see https://api.highcharts.com/highstock/plotOptions.column
 */
export interface PlotColumnOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.column.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.column.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.animation
     * @see https://api.highcharts.com/highstock/plotOptions.column.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotColumnAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.column.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.column.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.column.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.column.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.column.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.column.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.column.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.column.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.className
     * @see https://api.highcharts.com/highstock/plotOptions.column.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.clip
     * @see https://api.highcharts.com/highstock/plotOptions.column.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.color
     * @see https://api.highcharts.com/highstock/plotOptions.column.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.column.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.column.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.column.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.column.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.colors
     * @see https://api.highcharts.com/highstock/plotOptions.column.colors
     * @see https://api.highcharts.com/gantt/plotOptions.column.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.column.connectors
     */
    connectors?: PlotColumnConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.column.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.column.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.column.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.column.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.column.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataGrouping
     */
    dataGrouping?: PlotColumnDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.column.dataLabels
     */
    dataLabels?: PlotColumnDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.depth
     */
    depth?: number;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.description
     * @see https://api.highcharts.com/highstock/plotOptions.column.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.column.dragDrop
     */
    dragDrop?: PlotColumnDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.column.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.events
     * @see https://api.highcharts.com/highstock/plotOptions.column.events
     */
    events?: PlotColumnEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.column.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.column.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.column.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.column.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.column.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.column.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.column.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.column.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.column.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.keys
     * @see https://api.highcharts.com/highstock/plotOptions.column.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.label
     * @see https://api.highcharts.com/highstock/plotOptions.column.label
     * @see https://api.highcharts.com/gantt/plotOptions.column.label
     */
    label?: PlotColumnLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.lastPrice
     */
    lastPrice?: PlotColumnLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.lastVisiblePrice
     */
    lastVisiblePrice?: PlotColumnLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.column.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.column.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.column.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.column.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.column.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.column.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.column.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point
     * @see https://api.highcharts.com/highstock/plotOptions.column.point
     */
    point?: PlotColumnPointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.column.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.column.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.column.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.column.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.column.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.column.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.column.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.column.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.column.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.column.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.column.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.column.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.column.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.column.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.column.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.selected
     * @see https://api.highcharts.com/highstock/plotOptions.column.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) Whether to apply a drop shadow to the graph line.
     * Since 2.3 the shadow can be an object configuration containing `color`,
     * `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.column.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.column.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.column.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.column.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.column.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.column.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states
     * @see https://api.highcharts.com/highstock/plotOptions.column.states
     */
    states?: PlotColumnStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.column.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip
     */
    tooltip?: PlotColumnTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.column.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.column.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.visible
     * @see https://api.highcharts.com/highstock/plotOptions.column.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.column.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.column.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.zones
     * @see https://api.highcharts.com/highstock/plotOptions.column.zones
     */
    zones?: Array<PlotColumnZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.column.point.events
 */
export interface PlotColumnPointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.point
 * @see https://api.highcharts.com/highstock/plotOptions.column.point
 */
export interface PlotColumnPointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.column.point.events
     */
    events?: PlotColumnPointEventsOptions;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.animation
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.animation
 */
export interface PlotColumnpyramidAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker
 */
export interface PlotColumnpyramidConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker
 */
export interface PlotColumnpyramidConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors
 */
export interface PlotColumnpyramidConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.endMarker
     */
    endMarker?: PlotColumnpyramidConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.marker
     */
    marker?: PlotColumnpyramidConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker
     */
    startMarker?: PlotColumnpyramidConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker
 */
export interface PlotColumnpyramidConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataGrouping
 */
export interface PlotColumnpyramidDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.filter
 */
export interface PlotColumnpyramidDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels
 */
export interface PlotColumnpyramidDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.filter
     */
    filter?: PlotColumnpyramidDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragHandle
 */
export interface PlotColumnpyramidDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.guideBox.default
 */
export interface PlotColumnpyramidDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.guideBox
 */
export interface PlotColumnpyramidDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.guideBox.default
     */
    default?: PlotColumnpyramidDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop
 */
export interface PlotColumnpyramidDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragHandle
     */
    dragHandle?: PlotColumnpyramidDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.guideBox
     */
    guideBox?: (PlotColumnpyramidDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.events
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.events
 */
export interface PlotColumnpyramidEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.label
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.label
 * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.label
 */
export interface PlotColumnpyramidLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.lastPrice
 */
export interface PlotColumnpyramidLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotColumnpyramidLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.lastVisiblePrice
 */
export interface PlotColumnpyramidLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotColumnpyramidLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Column pyramid series display one pyramid per value
 * along an X axis. Requires `highcharts-more.js`. To display horizontal
 * pyramids, set chart.inverted to `true`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `columnpyramid` series are defined in
 * plotOptions.columnpyramid.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid
 */
export interface PlotColumnpyramidOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnpyramid.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.animation
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotColumnpyramidAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.className
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.clip
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnpyramid.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.colors
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.colors
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.connectors
     */
    connectors?: PlotColumnpyramidConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataGrouping
     */
    dataGrouping?: PlotColumnpyramidDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dataLabels
     */
    dataLabels?: PlotColumnpyramidDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.description
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.dragDrop
     */
    dragDrop?: PlotColumnpyramidDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.events
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.events
     */
    events?: PlotColumnpyramidEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnpyramid.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.keys
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.label
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.label
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.label
     */
    label?: PlotColumnpyramidLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.lastPrice
     */
    lastPrice?: PlotColumnpyramidLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.lastVisiblePrice
     */
    lastVisiblePrice?: PlotColumnpyramidLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point
     */
    point?: PlotColumnpyramidPointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.selected
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) Whether to apply a drop shadow to the graph line.
     * Since 2.3 the shadow can be an object configuration containing `color`,
     * `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states
     */
    states?: PlotColumnpyramidStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip
     */
    tooltip?: PlotColumnpyramidTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.visible
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnpyramid.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events
 */
export interface PlotColumnpyramidPointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point
 */
export interface PlotColumnpyramidPointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.point.events
     */
    events?: PlotColumnpyramidPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.hover.animation
 */
export interface PlotColumnpyramidStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.hover
 */
export interface PlotColumnpyramidStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotColumnpyramidStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnpyramid.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.columnpyramid.states.normal
 */
export interface PlotColumnpyramidStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnpyramid.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states
 */
export interface PlotColumnpyramidStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.hover
     */
    hover?: PlotColumnpyramidStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnpyramid.states.normal
     */
    normal?: PlotColumnpyramidStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.select
     */
    select?: PlotColumnpyramidStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.select.animation
 */
export interface PlotColumnpyramidStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.select
 */
export interface PlotColumnpyramidStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotColumnpyramidStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnpyramid.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.tooltip.dateTimeLabelFormats
 */
export interface PlotColumnpyramidTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip
 */
export interface PlotColumnpyramidTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotColumnpyramidTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.columnpyramid.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.animation
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.animation
 */
export interface PlotColumnrangeAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker
 */
export interface PlotColumnrangeConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker
 */
export interface PlotColumnrangeConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors
 */
export interface PlotColumnrangeConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.endMarker
     */
    endMarker?: PlotColumnrangeConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.marker
     */
    marker?: PlotColumnrangeConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker
     */
    startMarker?: PlotColumnrangeConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker
 */
export interface PlotColumnrangeConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataGrouping
 */
export interface PlotColumnrangeDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.filter
 */
export interface PlotColumnrangeDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Extended data labels for range series types. Range
 * series data labels have no `x` and `y` options. Instead, they have `xLow`,
 * `xHigh`, `yLow` and `yHigh` options to allow the higher and lower data label
 * sets individually.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels
 */
export interface PlotColumnrangeDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.filter
     */
    filter?: PlotColumnrangeDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) X offset of the higher data labels relative to
     * the point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.xHigh
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.xHigh
     */
    xHigh?: number;
    /**
     * (Highcharts, Highstock) X offset of the lower data labels relative to the
     * point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.xLow
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.xLow
     */
    xLow?: number;
    /**
     * (Highcharts, Highstock) Y offset of the higher data labels relative to
     * the point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.yHigh
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.yHigh
     */
    yHigh?: number;
    /**
     * (Highcharts, Highstock) Y offset of the lower data labels relative to the
     * point value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.yLow
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.yLow
     */
    yLow?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragHandle
 */
export interface PlotColumnrangeDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.guideBox.default
 */
export interface PlotColumnrangeDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.guideBox
 */
export interface PlotColumnrangeDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.guideBox.default
     */
    default?: PlotColumnrangeDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop
 */
export interface PlotColumnrangeDragDropOptions {
    /**
     * (Highcharts, Highstock) Allow high value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.draggableHigh
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.draggableHigh
     */
    draggableHigh?: boolean;
    /**
     * (Highcharts, Highstock) Allow low value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.draggableLow
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.draggableLow
     */
    draggableLow?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragHandle
     */
    dragHandle?: PlotColumnrangeDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.guideBox
     */
    guideBox?: (PlotColumnrangeDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.events
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.events
 */
export interface PlotColumnrangeEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.label
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.label
 * @see https://api.highcharts.com/gantt/plotOptions.columnrange.label
 */
export interface PlotColumnrangeLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.lastPrice
 */
export interface PlotColumnrangeLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotColumnrangeLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.lastVisiblePrice
 */
export interface PlotColumnrangeLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotColumnrangeLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) The column range is a cartesian series type with
 * higher and lower Y values along an X axis. Requires `highcharts-more.js`. To
 * display horizontal bars, set chart.inverted to `true`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `columnrange` series are defined in
 * plotOptions.columnrange.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange
 */
export interface PlotColumnrangeOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnrange.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.animation
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotColumnrangeAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.className
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.clip
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnrange.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.colors
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.colors
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.connectors
     */
    connectors?: PlotColumnrangeConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataGrouping
     */
    dataGrouping?: PlotColumnrangeDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Extended data labels for range series types.
     * Range series data labels have no `x` and `y` options. Instead, they have
     * `xLow`, `xHigh`, `yLow` and `yHigh` options to allow the higher and lower
     * data label sets individually.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dataLabels
     */
    dataLabels?: PlotColumnrangeDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.depth
     */
    depth?: number;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.description
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.dragDrop
     */
    dragDrop?: PlotColumnrangeDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.events
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.events
     */
    events?: PlotColumnrangeEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnrange.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.keys
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.label
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.label
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.label
     */
    label?: PlotColumnrangeLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.lastPrice
     */
    lastPrice?: PlotColumnrangeLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.lastVisiblePrice
     */
    lastVisiblePrice?: PlotColumnrangeLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point
     */
    point?: PlotColumnrangePointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.pointRange
     */
    pointRange?: any;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.selected
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) Whether to apply a drop shadow to the graph line.
     * Since 2.3 the shadow can be an object configuration containing `color`,
     * `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states
     */
    states?: PlotColumnrangeStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip
     */
    tooltip?: PlotColumnrangeTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.visible
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnrange.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.zones
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.zones
     */
    zones?: Array<PlotColumnrangeZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events
 */
export interface PlotColumnrangePointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point
 */
export interface PlotColumnrangePointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.point.events
     */
    events?: PlotColumnrangePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.hover.animation
 */
export interface PlotColumnrangeStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.hover
 */
export interface PlotColumnrangeStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotColumnrangeStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnrange.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.columnrange.states.normal
 */
export interface PlotColumnrangeStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnrange.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states
 */
export interface PlotColumnrangeStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.hover
     */
    hover?: PlotColumnrangeStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnrange.states.normal
     */
    normal?: PlotColumnrangeStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.select
     */
    select?: PlotColumnrangeStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.select.animation
 */
export interface PlotColumnrangeStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.select
 */
export interface PlotColumnrangeStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotColumnrangeStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.columnrange.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.columnrange.tooltip.dateTimeLabelFormats
 */
export interface PlotColumnrangeTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip
 */
export interface PlotColumnrangeTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotColumnrangeTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.columnrange.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.zones
 * @see https://api.highcharts.com/highstock/plotOptions.columnrange.zones
 */
export interface PlotColumnrangeZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.states.hover.animation
 */
export interface PlotColumnStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.column.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.column.states.hover
 */
export interface PlotColumnStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotColumnStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.column.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.column.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.column.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.column.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.column.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.column.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.column.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.column.states.normal
 */
export interface PlotColumnStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.column.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.states
 * @see https://api.highcharts.com/highstock/plotOptions.column.states
 */
export interface PlotColumnStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.column.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.column.states.hover
     */
    hover?: PlotColumnStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.column.states.normal
     */
    normal?: PlotColumnStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.column.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.column.states.select
     */
    select?: PlotColumnStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.states.select.animation
 */
export interface PlotColumnStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.column.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.column.states.select
 */
export interface PlotColumnStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotColumnStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.column.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.column.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.column.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.column.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.column.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.column.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.column.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.column.tooltip.dateTimeLabelFormats
 */
export interface PlotColumnTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip
 */
export interface PlotColumnTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.column.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotColumnTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.column.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.column.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.column.zones
 * @see https://api.highcharts.com/highstock/plotOptions.column.zones
 */
export interface PlotColumnZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.column.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.column.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.column.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.column.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.column.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.animation
 */
export interface PlotCylinderAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker
 */
export interface PlotCylinderConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker
 */
export interface PlotCylinderConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors
 */
export interface PlotCylinderConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.endMarker
     */
    endMarker?: PlotCylinderConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.marker
     */
    marker?: PlotCylinderConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker
     */
    startMarker?: PlotCylinderConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker
 */
export interface PlotCylinderConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataGrouping
 */
export interface PlotCylinderDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.filter
 */
export interface PlotCylinderDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels
 */
export interface PlotCylinderDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.filter
     */
    filter?: PlotCylinderDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragHandle
 */
export interface PlotCylinderDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.guideBox.default
 */
export interface PlotCylinderDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.guideBox
 */
export interface PlotCylinderDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.guideBox.default
     */
    default?: PlotCylinderDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop
 */
export interface PlotCylinderDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragHandle
     */
    dragHandle?: PlotCylinderDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.guideBox
     */
    guideBox?: (PlotCylinderDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.events
 */
export interface PlotCylinderEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.label
 * @see https://api.highcharts.com/highstock/plotOptions.cylinder.label
 * @see https://api.highcharts.com/gantt/plotOptions.cylinder.label
 */
export interface PlotCylinderLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cylinder.lastPrice
 */
export interface PlotCylinderLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotCylinderLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.cylinder.lastVisiblePrice
 */
export interface PlotCylinderLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotCylinderLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A cylinder graph is a variation of a 3d column graph. The
 * cylinder graph features cylindrical points.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `cylinder` series are defined in plotOptions.cylinder.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder
 */
export interface PlotCylinderOptions {
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCylinderAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.colors
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.colors
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.connectors
     */
    connectors?: PlotCylinderConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.dataGrouping
     */
    dataGrouping?: PlotCylinderDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dataLabels
     */
    dataLabels?: PlotCylinderDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.depth
     */
    depth?: number;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.dragDrop
     */
    dragDrop?: PlotCylinderDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.events
     */
    events?: PlotCylinderEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cylinder.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.label
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.label
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.label
     */
    label?: PlotCylinderLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.lastPrice
     */
    lastPrice?: PlotCylinderLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.lastVisiblePrice
     */
    lastVisiblePrice?: PlotCylinderLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The color for the parts of the graph or points that are
     * below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point
     */
    point?: PlotCylinderPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states
     */
    states?: PlotCylinderStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.threshold
     */
    threshold?: number;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip
     */
    tooltip?: PlotCylinderTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cylinder.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.zones
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.zones
     */
    zones?: Array<PlotCylinderZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events
 */
export interface PlotCylinderPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point
 */
export interface PlotCylinderPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.point.events
     */
    events?: PlotCylinderPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.hover.animation
 */
export interface PlotCylinderStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.cylinder.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.hover
 */
export interface PlotCylinderStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCylinderStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cylinder.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.cylinder.states.normal
 */
export interface PlotCylinderStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cylinder.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states
 */
export interface PlotCylinderStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.hover
     */
    hover?: PlotCylinderStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cylinder.states.normal
     */
    normal?: PlotCylinderStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.select
     */
    select?: PlotCylinderStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.select.animation
 */
export interface PlotCylinderStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.cylinder.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.select
 */
export interface PlotCylinderStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotCylinderStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.cylinder.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.cylinder.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.cylinder.tooltip.dateTimeLabelFormats
 */
export interface PlotCylinderTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip
 */
export interface PlotCylinderTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotCylinderTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.cylinder.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.zones
 * @see https://api.highcharts.com/highstock/plotOptions.cylinder.zones
 */
export interface PlotCylinderZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.cylinder.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.animation
 */
export interface PlotDemaAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker
 */
export interface PlotDemaConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker
 */
export interface PlotDemaConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors
 */
export interface PlotDemaConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.endMarker
     */
    endMarker?: PlotDemaConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.marker
     */
    marker?: PlotDemaConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker
     */
    startMarker?: PlotDemaConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker
 */
export interface PlotDemaConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.dataGrouping
 */
export interface PlotDemaDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.filter
 */
export interface PlotDemaDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels
 */
export interface PlotDemaDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.dema.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.filter
     */
    filter?: PlotDemaDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragHandle
 */
export interface PlotDemaDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.guideBox.default
 */
export interface PlotDemaDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.guideBox
 */
export interface PlotDemaDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.guideBox.default
     */
    default?: PlotDemaDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop
 */
export interface PlotDemaDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragHandle
     */
    dragHandle?: PlotDemaDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.guideBox
     */
    guideBox?: (PlotDemaDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.events
 */
export interface PlotDemaEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.dema.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.dema.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.label
 * @see https://api.highcharts.com/highstock/plotOptions.dema.label
 * @see https://api.highcharts.com/gantt/plotOptions.dema.label
 */
export interface PlotDemaLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.dema.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.dema.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.dema.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.dema.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.dema.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.dema.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dema.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.dema.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.dema.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.dema.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.dema.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.dema.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.dema.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.dema.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.dema.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.dema.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.lastPrice
 */
export interface PlotDemaLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotDemaLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.lastVisiblePrice
 */
export interface PlotDemaLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotDemaLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.marker
 */
export interface PlotDemaMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states
     */
    states?: PlotDemaMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover.animation
 */
export interface PlotDemaMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover
 */
export interface PlotDemaMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDemaMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.normal
 */
export interface PlotDemaMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states
 */
export interface PlotDemaMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.hover
     */
    hover?: PlotDemaMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.normal
     */
    normal?: PlotDemaMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.select
     */
    select?: PlotDemaMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.select
 */
export interface PlotDemaMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Normalized average true range indicator (NATR). This series
 * requires `linkedTo` option to be set and should be loaded after the
 * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `dema` series are defined in plotOptions.dema.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema
 */
export interface PlotDemaOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDemaAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.dema.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dema.connectors
     */
    connectors?: PlotDemaConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.dema.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataGrouping
     */
    dataGrouping?: PlotDemaDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dataLabels
     */
    dataLabels?: PlotDemaDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.dragDrop
     */
    dragDrop?: PlotDemaDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.events
     */
    events?: PlotDemaEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.dema.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.dema.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.label
     * @see https://api.highcharts.com/highstock/plotOptions.dema.label
     * @see https://api.highcharts.com/gantt/plotOptions.dema.label
     */
    label?: PlotDemaLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.lastPrice
     */
    lastPrice?: PlotDemaLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.lastVisiblePrice
     */
    lastVisiblePrice?: PlotDemaLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.dema.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dema.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.dema.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.dema.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.marker
     */
    marker?: PlotDemaMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.params
     */
    params?: PlotDemaParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point
     */
    point?: PlotDemaPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.dema.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states
     */
    states?: PlotDemaStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.step
     * @see https://api.highcharts.com/highstock/plotOptions.dema.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.dema.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip
     */
    tooltip?: PlotDemaTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.dema.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.dema.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.dema.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.zones
     * @see https://api.highcharts.com/highstock/plotOptions.dema.zones
     */
    zones?: Array<PlotDemaZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.params
 */
export interface PlotDemaParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * By default index value used to be set to 0. Since Highstock 7 by default
     * index is set to 3 which means that the ema indicator will be calculated
     * using Close values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events
 */
export interface PlotDemaPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.point
 */
export interface PlotDemaPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.point.events
     */
    events?: PlotDemaPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.animation
 */
export interface PlotDemaStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.halo
 */
export interface PlotDemaStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker
 */
export interface PlotDemaStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states
     */
    states?: PlotDemaStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover.animation
 */
export interface PlotDemaStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover
 */
export interface PlotDemaStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDemaStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.normal
 */
export interface PlotDemaStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states
 */
export interface PlotDemaStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.hover
     */
    hover?: PlotDemaStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.normal
     */
    normal?: PlotDemaStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.select
     */
    select?: PlotDemaStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.select
 */
export interface PlotDemaStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover
 */
export interface PlotDemaStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDemaStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.halo
     */
    halo?: PlotDemaStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover.marker
     */
    marker?: PlotDemaStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.normal
 */
export interface PlotDemaStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states
 */
export interface PlotDemaStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.hover
     */
    hover?: PlotDemaStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.normal
     */
    normal?: PlotDemaStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.select
     */
    select?: PlotDemaStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.animation
 */
export interface PlotDemaStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.halo
 */
export interface PlotDemaStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker
 */
export interface PlotDemaStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states
     */
    states?: PlotDemaStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover.animation
 */
export interface PlotDemaStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover
 */
export interface PlotDemaStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDemaStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.normal
 */
export interface PlotDemaStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states
 */
export interface PlotDemaStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.hover
     */
    hover?: PlotDemaStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.normal
     */
    normal?: PlotDemaStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.select
     */
    select?: PlotDemaStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.select
 */
export interface PlotDemaStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.select
 */
export interface PlotDemaStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDemaStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dema.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.halo
     */
    halo?: PlotDemaStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.dema.states.select.marker
     */
    marker?: PlotDemaStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.dema.tooltip.dateTimeLabelFormats
 */
export interface PlotDemaTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip
 */
export interface PlotDemaTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.dema.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotDemaTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.dema.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.dema.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dema.zones
 * @see https://api.highcharts.com/highstock/plotOptions.dema.zones
 */
export interface PlotDemaZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.dema.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.dema.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.dema.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dema.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dema.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.dema.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.animation
 */
export interface PlotDpoAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker
 */
export interface PlotDpoConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker
 */
export interface PlotDpoConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors
 */
export interface PlotDpoConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.endMarker
     */
    endMarker?: PlotDpoConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.marker
     */
    marker?: PlotDpoConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker
     */
    startMarker?: PlotDpoConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker
 */
export interface PlotDpoConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataGrouping
 */
export interface PlotDpoDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.filter
 */
export interface PlotDpoDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels
 */
export interface PlotDpoDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.filter
     */
    filter?: PlotDpoDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragHandle
 */
export interface PlotDpoDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.guideBox.default
 */
export interface PlotDpoDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.guideBox
 */
export interface PlotDpoDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.guideBox.default
     */
    default?: PlotDpoDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop
 */
export interface PlotDpoDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragHandle
     */
    dragHandle?: PlotDpoDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.guideBox
     */
    guideBox?: (PlotDpoDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.events
 */
export interface PlotDpoEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.label
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.label
 * @see https://api.highcharts.com/gantt/plotOptions.dpo.label
 */
export interface PlotDpoLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.lastPrice
 */
export interface PlotDpoLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotDpoLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.lastVisiblePrice
 */
export interface PlotDpoLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotDpoLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker
 */
export interface PlotDpoMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states
     */
    states?: PlotDpoMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover.animation
 */
export interface PlotDpoMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover
 */
export interface PlotDpoMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDpoMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.normal
 */
export interface PlotDpoMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states
 */
export interface PlotDpoMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.hover
     */
    hover?: PlotDpoMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.normal
     */
    normal?: PlotDpoMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.select
     */
    select?: PlotDpoMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.select
 */
export interface PlotDpoMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Detrended Price Oscillator. This series requires the `linkedTo`
 * option to be set and should be loaded after the
 * `stock/indicators/indicators.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `dpo` series are defined in plotOptions.dpo.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo
 */
export interface PlotDpoOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDpoAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.connectors
     */
    connectors?: PlotDpoConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataGrouping
     */
    dataGrouping?: PlotDpoDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dataLabels
     */
    dataLabels?: PlotDpoDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.dragDrop
     */
    dragDrop?: PlotDpoDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.events
     */
    events?: PlotDpoEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.label
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.label
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.label
     */
    label?: PlotDpoLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.lastPrice
     */
    lastPrice?: PlotDpoLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.lastVisiblePrice
     */
    lastVisiblePrice?: PlotDpoLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.marker
     */
    marker?: PlotDpoMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Parameters used in calculation of Detrended Price Oscillator
     * series points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.params
     */
    params?: PlotDpoParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point
     */
    point?: PlotDpoPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states
     */
    states?: PlotDpoStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.step
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip
     */
    tooltip?: PlotDpoTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.zones
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.zones
     */
    zones?: Array<PlotDpoZonesOptions>;
}
/**
 * (Highstock) Parameters used in calculation of Detrended Price Oscillator
 * series points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.params
 */
export interface PlotDpoParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.params.index
     */
    index?: number;
    /**
     * (Highstock) Period for Detrended Price Oscillator
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events
 */
export interface PlotDpoPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.point
 */
export interface PlotDpoPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.point.events
     */
    events?: PlotDpoPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.animation
 */
export interface PlotDpoStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.halo
 */
export interface PlotDpoStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker
 */
export interface PlotDpoStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states
     */
    states?: PlotDpoStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover.animation
 */
export interface PlotDpoStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover
 */
export interface PlotDpoStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDpoStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.normal
 */
export interface PlotDpoStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states
 */
export interface PlotDpoStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.hover
     */
    hover?: PlotDpoStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.normal
     */
    normal?: PlotDpoStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.select
     */
    select?: PlotDpoStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.select
 */
export interface PlotDpoStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover
 */
export interface PlotDpoStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDpoStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.halo
     */
    halo?: PlotDpoStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover.marker
     */
    marker?: PlotDpoStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.normal
 */
export interface PlotDpoStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states
 */
export interface PlotDpoStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.hover
     */
    hover?: PlotDpoStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.normal
     */
    normal?: PlotDpoStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.select
     */
    select?: PlotDpoStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.animation
 */
export interface PlotDpoStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.halo
 */
export interface PlotDpoStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker
 */
export interface PlotDpoStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states
     */
    states?: PlotDpoStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover.animation
 */
export interface PlotDpoStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover
 */
export interface PlotDpoStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDpoStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.normal
 */
export interface PlotDpoStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states
 */
export interface PlotDpoStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.hover
     */
    hover?: PlotDpoStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.normal
     */
    normal?: PlotDpoStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.select
     */
    select?: PlotDpoStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.select
 */
export interface PlotDpoStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.select
 */
export interface PlotDpoStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotDpoStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.dpo.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.halo
     */
    halo?: PlotDpoStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.states.select.marker
     */
    marker?: PlotDpoStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.dpo.tooltip.dateTimeLabelFormats
 */
export interface PlotDpoTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip
 */
export interface PlotDpoTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotDpoTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.dpo.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.dpo.zones
 * @see https://api.highcharts.com/highstock/plotOptions.dpo.zones
 */
export interface PlotDpoZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.dpo.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.dpo.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.animation
 */
export interface PlotEmaAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker
 */
export interface PlotEmaConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker
 */
export interface PlotEmaConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors
 */
export interface PlotEmaConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.endMarker
     */
    endMarker?: PlotEmaConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.marker
     */
    marker?: PlotEmaConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker
     */
    startMarker?: PlotEmaConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker
 */
export interface PlotEmaConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.dataGrouping
 */
export interface PlotEmaDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.filter
 */
export interface PlotEmaDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels
 */
export interface PlotEmaDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.ema.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.filter
     */
    filter?: PlotEmaDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragHandle
 */
export interface PlotEmaDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.guideBox.default
 */
export interface PlotEmaDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.guideBox
 */
export interface PlotEmaDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.guideBox.default
     */
    default?: PlotEmaDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop
 */
export interface PlotEmaDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragHandle
     */
    dragHandle?: PlotEmaDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.guideBox
     */
    guideBox?: (PlotEmaDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.events
 */
export interface PlotEmaEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.ema.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.ema.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.label
 * @see https://api.highcharts.com/highstock/plotOptions.ema.label
 * @see https://api.highcharts.com/gantt/plotOptions.ema.label
 */
export interface PlotEmaLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.ema.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.ema.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.ema.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.ema.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.ema.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.ema.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ema.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.ema.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ema.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ema.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ema.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ema.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.ema.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.ema.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.ema.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.ema.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.lastPrice
 */
export interface PlotEmaLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotEmaLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.lastVisiblePrice
 */
export interface PlotEmaLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotEmaLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.marker
 */
export interface PlotEmaMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states
     */
    states?: PlotEmaMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover.animation
 */
export interface PlotEmaMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover
 */
export interface PlotEmaMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotEmaMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.normal
 */
export interface PlotEmaMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states
 */
export interface PlotEmaMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.hover
     */
    hover?: PlotEmaMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.normal
     */
    normal?: PlotEmaMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.select
     */
    select?: PlotEmaMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.select
 */
export interface PlotEmaMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Exponential moving average indicator (EMA). This series requires
 * the `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ema` series are defined in plotOptions.ema.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema
 */
export interface PlotEmaOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotEmaAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.ema.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ema.connectors
     */
    connectors?: PlotEmaConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ema.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataGrouping
     */
    dataGrouping?: PlotEmaDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dataLabels
     */
    dataLabels?: PlotEmaDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.dragDrop
     */
    dragDrop?: PlotEmaDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.events
     */
    events?: PlotEmaEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.ema.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.ema.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.label
     * @see https://api.highcharts.com/highstock/plotOptions.ema.label
     * @see https://api.highcharts.com/gantt/plotOptions.ema.label
     */
    label?: PlotEmaLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.lastPrice
     */
    lastPrice?: PlotEmaLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.lastVisiblePrice
     */
    lastVisiblePrice?: PlotEmaLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.ema.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ema.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.ema.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.ema.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.marker
     */
    marker?: PlotEmaMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.params
     */
    params?: PlotEmaParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point
     */
    point?: PlotEmaPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ema.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states
     */
    states?: PlotEmaStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.step
     * @see https://api.highcharts.com/highstock/plotOptions.ema.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.ema.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip
     */
    tooltip?: PlotEmaTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ema.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.ema.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.ema.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.zones
     * @see https://api.highcharts.com/highstock/plotOptions.ema.zones
     */
    zones?: Array<PlotEmaZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.params
 */
export interface PlotEmaParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * By default index value used to be set to 0. Since Highstock 7 by default
     * index is set to 3 which means that the ema indicator will be calculated
     * using Close values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events
 */
export interface PlotEmaPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.point
 */
export interface PlotEmaPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.point.events
     */
    events?: PlotEmaPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.animation
 */
export interface PlotEmaStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.halo
 */
export interface PlotEmaStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker
 */
export interface PlotEmaStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states
     */
    states?: PlotEmaStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover.animation
 */
export interface PlotEmaStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover
 */
export interface PlotEmaStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotEmaStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.normal
 */
export interface PlotEmaStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states
 */
export interface PlotEmaStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.hover
     */
    hover?: PlotEmaStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.normal
     */
    normal?: PlotEmaStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.select
     */
    select?: PlotEmaStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.select
 */
export interface PlotEmaStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover
 */
export interface PlotEmaStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotEmaStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.halo
     */
    halo?: PlotEmaStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover.marker
     */
    marker?: PlotEmaStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.normal
 */
export interface PlotEmaStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states
 */
export interface PlotEmaStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.hover
     */
    hover?: PlotEmaStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.normal
     */
    normal?: PlotEmaStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.select
     */
    select?: PlotEmaStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.animation
 */
export interface PlotEmaStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.halo
 */
export interface PlotEmaStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker
 */
export interface PlotEmaStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states
     */
    states?: PlotEmaStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover.animation
 */
export interface PlotEmaStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover
 */
export interface PlotEmaStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotEmaStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.normal
 */
export interface PlotEmaStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states
 */
export interface PlotEmaStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.hover
     */
    hover?: PlotEmaStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.normal
     */
    normal?: PlotEmaStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.select
     */
    select?: PlotEmaStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.select
 */
export interface PlotEmaStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.select
 */
export interface PlotEmaStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotEmaStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ema.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.halo
     */
    halo?: PlotEmaStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.ema.states.select.marker
     */
    marker?: PlotEmaStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.ema.tooltip.dateTimeLabelFormats
 */
export interface PlotEmaTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip
 */
export interface PlotEmaTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.ema.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotEmaTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.ema.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.ema.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ema.zones
 * @see https://api.highcharts.com/highstock/plotOptions.ema.zones
 */
export interface PlotEmaZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.ema.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.ema.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.ema.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ema.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ema.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.ema.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.animation
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.animation
 */
export interface PlotErrorbarAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker
 */
export interface PlotErrorbarConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker
 */
export interface PlotErrorbarConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors
 */
export interface PlotErrorbarConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.endMarker
     */
    endMarker?: PlotErrorbarConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.marker
     */
    marker?: PlotErrorbarConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker
     */
    startMarker?: PlotErrorbarConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker
 */
export interface PlotErrorbarConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataGrouping
 */
export interface PlotErrorbarDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.filter
 */
export interface PlotErrorbarDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels
 */
export interface PlotErrorbarDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.filter
     */
    filter?: PlotErrorbarDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragHandle
 */
export interface PlotErrorbarDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.guideBox.default
 */
export interface PlotErrorbarDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.guideBox
 */
export interface PlotErrorbarDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.guideBox.default
     */
    default?: PlotErrorbarDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop
 */
export interface PlotErrorbarDragDropOptions {
    /**
     * (Highcharts, Highstock) Allow high value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.draggableHigh
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.draggableHigh
     */
    draggableHigh?: boolean;
    /**
     * (Highcharts, Highstock) Allow low value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.draggableLow
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.draggableLow
     */
    draggableLow?: boolean;
    /**
     * (Highcharts, Highstock) Allow Q1 value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.draggableQ1
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.draggableQ1
     */
    draggableQ1?: boolean;
    /**
     * (Highcharts, Highstock) Allow Q3 value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.draggableQ3
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.draggableQ3
     */
    draggableQ3?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragHandle
     */
    dragHandle?: PlotErrorbarDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.guideBox
     */
    guideBox?: (PlotErrorbarDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.events
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.events
 */
export interface PlotErrorbarEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.label
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.label
 * @see https://api.highcharts.com/gantt/plotOptions.errorbar.label
 */
export interface PlotErrorbarLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.lastPrice
 */
export interface PlotErrorbarLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotErrorbarLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.lastVisiblePrice
 */
export interface PlotErrorbarLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotErrorbarLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Error bars are a graphical representation of the
 * variability of data and are used on graphs to indicate the error, or
 * uncertainty in a reported measurement.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `errorbar` series are defined in plotOptions.errorbar.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar
 */
export interface PlotErrorbarOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.errorbar.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.animation
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotErrorbarAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.className
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.clip
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the bars. This can be overridden by
     * stemColor and whiskerColor individually.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.errorbar.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.colors
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.colors
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.connectors
     */
    connectors?: PlotErrorbarConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataGrouping
     */
    dataGrouping?: PlotErrorbarDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dataLabels
     */
    dataLabels?: PlotErrorbarDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.depth
     */
    depth?: number;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.description
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.dragDrop
     */
    dragDrop?: PlotErrorbarDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.events
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.events
     */
    events?: PlotErrorbarEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) The fill color of the box.
     *
     * In styled mode, the fill color can be set with the
     * `.highcharts-boxplot-box` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.fillColor
     */
    fillColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.errorbar.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.keys
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.label
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.label
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.label
     */
    label?: PlotErrorbarLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.lastPrice
     */
    lastPrice?: PlotErrorbarLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.lastVisiblePrice
     */
    lastVisiblePrice?: PlotErrorbarLastVisiblePriceOptions;
    /**
     * (Highcharts) The width of the line surrounding the box. If any of
     * stemWidth, medianWidth or whiskerWidth are `null`, the lineWidth also
     * applies to these lines.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The parent series of the error bar. The default value links
     * it to the previous series. Otherwise, use the id of the parent series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts) The color of the median line. If `undefined`, the general
     * series color applies.
     *
     * In styled mode, the median stroke width can be set with the
     * `.highcharts-boxplot-median` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.medianColor
     */
    medianColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts) The pixel width of the median line. If `null`, the lineWidth
     * is used.
     *
     * In styled mode, the median stroke width can be set with the
     * `.highcharts-boxplot-median` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.medianWidth
     */
    medianWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point
     */
    point?: PlotErrorbarPointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.selected
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) Whether to apply a drop shadow to the graph line.
     * Since 2.3 the shadow can be an object configuration containing `color`,
     * `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts) The dash style of the stem, the vertical line extending from
     * the box to the whiskers.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.stemDashStyle
     */
    stemDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts) The width of the stem, the vertical line extending from the
     * box to the whiskers. If `undefined`, the width is inherited from the
     * lineWidth option.
     *
     * In styled mode, the stem stroke width can be set with the
     * `.highcharts-boxplot-stem` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.stemWidth
     */
    stemWidth?: number;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.threshold
     */
    threshold?: any;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip
     */
    tooltip?: PlotErrorbarTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.visible
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.visible
     */
    visible?: boolean;
    /**
     * (Highcharts) The color of the whiskers, the horizontal lines marking low
     * and high values. When `undefined`, the general series color is used.
     *
     * In styled mode, the whisker stroke can be set with the
     * `.highcharts-boxplot-whisker` class .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.whiskerColor
     */
    whiskerColor?: ColorString;
    /**
     * (Highcharts) The length of the whiskers, the horizontal lines marking low
     * and high values. It can be a numerical pixel value, or a percentage value
     * of the box width. Set `0` to disable whiskers.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.whiskerLength
     */
    whiskerLength?: (number|string);
    /**
     * (Highcharts) The line width of the whiskers, the horizontal lines marking
     * low and high values. When `null`, the general lineWidth applies.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.whiskerWidth
     */
    whiskerWidth?: number;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.errorbar.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.zones
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.zones
     */
    zones?: Array<PlotErrorbarZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events
 */
export interface PlotErrorbarPointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point
 */
export interface PlotErrorbarPointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.point.events
     */
    events?: PlotErrorbarPointEventsOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.errorbar.tooltip.dateTimeLabelFormats
 */
export interface PlotErrorbarTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip
 */
export interface PlotErrorbarTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotErrorbarTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.errorbar.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.zones
 * @see https://api.highcharts.com/highstock/plotOptions.errorbar.zones
 */
export interface PlotErrorbarZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar.zones.value
     */
    value?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker
 */
export interface PlotFlagsConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker
 */
export interface PlotFlagsConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors
 */
export interface PlotFlagsConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.endMarker
     */
    endMarker?: PlotFlagsConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.marker
     */
    marker?: PlotFlagsConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker
     */
    startMarker?: PlotFlagsConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker
 */
export interface PlotFlagsConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.filter
 */
export interface PlotFlagsDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels
 */
export interface PlotFlagsDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.flags.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.filter
     */
    filter?: PlotFlagsDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragHandle
 */
export interface PlotFlagsDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.guideBox.default
 */
export interface PlotFlagsDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.guideBox
 */
export interface PlotFlagsDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.guideBox.default
     */
    default?: PlotFlagsDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop
 */
export interface PlotFlagsDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragHandle
     */
    dragHandle?: PlotFlagsDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.guideBox
     */
    guideBox?: (PlotFlagsDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.events
 */
export interface PlotFlagsEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.flags.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.flags.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.flags.label
 * @see https://api.highcharts.com/highstock/plotOptions.flags.label
 * @see https://api.highcharts.com/gantt/plotOptions.flags.label
 */
export interface PlotFlagsLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.flags.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.flags.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.flags.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.flags.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.flags.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.flags.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.flags.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.flags.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.flags.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.flags.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.flags.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.flags.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.flags.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.flags.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.flags.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.flags.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.lastPrice
 */
export interface PlotFlagsLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotFlagsLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.lastVisiblePrice
 */
export interface PlotFlagsLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotFlagsLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Flags are used to mark events in stock charts. They can be added
 * on the timeline, or attached to a specific series.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `flags` series are defined in plotOptions.flags.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags
 */
export interface PlotFlagsOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.flags.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highstock) Whether the flags are allowed to overlap sideways. If
     * `false`, the flags are moved sideways using an algorithm that seeks to
     * place every flag as close as possible to its original position.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.allowOverlapX
     */
    allowOverlapX?: boolean;
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.flags.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.colors
     * @see https://api.highcharts.com/highstock/plotOptions.flags.colors
     * @see https://api.highcharts.com/gantt/plotOptions.flags.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.flags.connectors
     */
    connectors?: PlotFlagsConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.flags.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.flags.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.flags.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.flags.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dataLabels
     */
    dataLabels?: PlotFlagsDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.depth
     */
    depth?: number;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.dragDrop
     */
    dragDrop?: PlotFlagsDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.events
     */
    events?: PlotFlagsEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) The fill color for the flags.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.fillColor
     */
    fillColor?: (ColorString|GradientColorObject);
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.flags.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.flags.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.flags.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.flags.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.flags.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.flags.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highstock) Fixed height of the flag's shape. By default, height is
     * autocalculated according to the flag's title.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.height
     */
    height?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.flags.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highstock) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.label
     * @see https://api.highcharts.com/highstock/plotOptions.flags.label
     * @see https://api.highcharts.com/gantt/plotOptions.flags.label
     */
    label?: PlotFlagsLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.lastPrice
     */
    lastPrice?: PlotFlagsLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.lastVisiblePrice
     */
    lastVisiblePrice?: PlotFlagsLastVisiblePriceOptions;
    /**
     * (Highstock) The color of the line/border of the flag.
     *
     * In styled mode, the stroke is set in the
     * `.highcharts-flag-series.highcharts-point` rule.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The pixel width of the flag's line/border.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.flags.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.flags.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.flags.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.flags.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.flags.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.flags.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) In case the flag is placed on a series, on what point key to
     * place it. Line and columns have one key, `y`. In range or OHLC-type
     * series, however, the flag can optionally be placed on the `open`, `high`,
     * `low` or `close` key.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.onKey
     */
    onKey?: ("close"|"high"|"low"|"open"|"y");
    /**
     * (Highstock) The id of the series that the flags should be drawn on. If no
     * id is given, the flags are drawn on the x axis.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.onSeries
     */
    onSeries?: string;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point
     */
    point?: PlotFlagsPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.flags.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.flags.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.flags.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.flags.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.flags.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.flags.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.flags.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.flags.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.flags.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.flags.pointStart
     */
    pointStart?: number;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The shape of the marker. Can be one of "flag", "circlepin",
     * "squarepin", or an image of the format `url(/path-to-image.jpg)`.
     * Individual shapes can also be set for each point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.shape
     */
    shape?: ("circlepin"|"flag"|"squarepin");
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.flags.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) When multiple flags in the same series fall on the same
     * value, this number determines the vertical offset between them.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.stackDistance
     */
    stackDistance?: number;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.flags.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.states
     */
    states?: PlotFlagsStatesOptions;
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highstock) The text styles of the flag.
     *
     * In styled mode, the styles are set in the `.highcharts-flag-series
     * .highcharts-point` rule.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Text alignment for the text inside the flag.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.textAlign
     */
    textAlign?: ("center"|"left"|"right");
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.threshold
     */
    threshold?: any;
    /**
     * (Highstock) The text to display on each flag. This can be defined on
     * series level, or individually for each point. Defaults to `"A"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.title
     */
    title?: string;
    /**
     * (Highstock) Specific tooltip options for flag series. Flag series
     * tooltips are different from most other types in that a flag doesn't have
     * a data value, so the tooltip rather displays the `text` option for each
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip
     */
    tooltip?: PlotFlagsTooltipOptions;
    /**
     * (Highstock) Whether to use HTML to render the flag texts. Using HTML
     * allows for advanced formatting, images and reliable bi-directional text
     * rendering. Note that exported images won't respect the HTML, and that
     * HTML won't respect Z-index settings.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.visible
     */
    visible?: boolean;
    /**
     * (Highstock) Fixed width of the flag's shape. By default, width is
     * autocalculated according to the flag's title.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.width
     */
    width?: number;
    /**
     * (Highstock) The y position of the top left corner of the flag relative to
     * either the series (if onSeries is defined), or the x axis. Defaults to
     * `-30`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.y
     */
    y?: number;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.flags.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.flags.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.zones
     * @see https://api.highcharts.com/highstock/plotOptions.flags.zones
     */
    zones?: Array<PlotFlagsZonesOptions>;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events
 */
export interface PlotFlagsPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.point
 */
export interface PlotFlagsPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.point.events
     */
    events?: PlotFlagsPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.hover.animation
 */
export interface PlotFlagsStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highstock) Options for the hovered point. These settings override the normal
 * state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.states.hover
 */
export interface PlotFlagsStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotFlagsStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.flags.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.flags.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.flags.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.flags.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.flags.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill or background color of the flag.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject);
    /**
     * (Highstock) The color of the line/border of the flag.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.states.hover.lineColor
     */
    lineColor?: ColorString;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.flags.states.normal
 */
export interface PlotFlagsStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.flags.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.states
 */
export interface PlotFlagsStatesOptions {
    /**
     * (Highstock) Options for the hovered point. These settings override the
     * normal state options when a point is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.states.hover
     */
    hover?: PlotFlagsStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.flags.states.normal
     */
    normal?: PlotFlagsStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.flags.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.flags.states.select
     */
    select?: PlotFlagsStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.select.animation
 */
export interface PlotFlagsStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.flags.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.flags.states.select
 */
export interface PlotFlagsStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotFlagsStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.flags.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.flags.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.flags.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.flags.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.flags.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.flags.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.flags.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.flags.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.flags.tooltip.dateTimeLabelFormats
 */
export interface PlotFlagsTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) Specific tooltip options for flag series. Flag series tooltips
 * are different from most other types in that a flag doesn't have a data value,
 * so the tooltip rather displays the `text` option for each point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip
 */
export interface PlotFlagsTooltipOptions {
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.flags.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotFlagsTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.flags.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.flags.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.flags.zones
 * @see https://api.highcharts.com/highstock/plotOptions.flags.zones
 */
export interface PlotFlagsZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.flags.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.flags.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.flags.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.flags.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.flags.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.flags.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Initial animation is by default disabled for the funnel chart.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.animation
 */
export interface PlotFunnelAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker
 */
export interface PlotFunnelConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker
 */
export interface PlotFunnelConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors
 */
export interface PlotFunnelConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.endMarker
     */
    endMarker?: PlotFunnelConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.marker
     */
    marker?: PlotFunnelConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker
     */
    startMarker?: PlotFunnelConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker
 */
export interface PlotFunnelConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataGrouping
 */
export interface PlotFunnelDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.filter
 */
export interface PlotFunnelDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels
 */
export interface PlotFunnelDataLabelsOptions {
    /**
     * (Highcharts) Alignment method for data labels. Possible values are:
     * `'toPlotEdges'` (each label touches the nearest vertical edge of the plot
     * area) or `'connectors'` (connectors have the same x position and the
     * widest label of each half (left & right) touches the nearest vertical
     * edge of the plot area).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.alignTo
     */
    alignTo?: string;
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The color of the line connecting the data label to the pie
     * slice. The default color is the same as the point's color.
     *
     * In styled mode, the connector stroke is given in the
     * `.highcharts-data-label-connector` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.connectorColor
     */
    connectorColor?: ColorString;
    /**
     * (Highcharts) The distance from the data label to the connector. Note that
     * data labels also have a default `padding`, so in order for the connector
     * to touch the text, the `padding` must also be 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.connectorPadding
     */
    connectorPadding?: number;
    /**
     * (Highcharts) Specifies the method that is used to generate the connector
     * path. Highcharts provides 3 built-in connector shapes: `'fixedOffset'`
     * (default), `'straight'` and `'crookedLine'`. Using `'crookedLine'` has
     * the most sense (in most of the cases) when `'alignTo'` is set.
     *
     * Users can provide their own method by passing a function instead of a
     * String. 3 arguments are passed to the callback:
     *
     * (see online documentation for example)
     *
     * The function has to return an SVG path definition in array form (see the
     * example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.connectorShape
     */
    connectorShape?: (() => void|string);
    /**
     * (Highcharts) The width of the line connecting the data label to the pie
     * slice.
     *
     * In styled mode, the connector stroke width is given in the
     * `.highcharts-data-label-connector` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.connectorWidth
     */
    connectorWidth?: number;
    /**
     * (Highcharts) Works only if `connectorShape` is `'crookedLine'`. It
     * defines how far from the vertical plot edge the coonnector path should be
     * crooked.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.crookDistance
     */
    crookDistance?: string;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) The distance of the data label from the pie's edge. Negative
     * numbers put the data label on top of the pie slices. Connectors are only
     * shown for data labels outside the pie.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.distance
     */
    distance?: number;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.filter
     */
    filter?: PlotFunnelDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Whether to render the connector as a soft arc or a line with
     * sharp break. Works only if `connectorShape` equals to `fixedOffset`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.softConnector
     */
    softConnector?: number;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragHandle
 */
export interface PlotFunnelDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.guideBox.default
 */
export interface PlotFunnelDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.guideBox
 */
export interface PlotFunnelDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.guideBox.default
     */
    default?: PlotFunnelDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop
 */
export interface PlotFunnelDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragHandle
     */
    dragHandle?: PlotFunnelDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.guideBox
     */
    guideBox?: (PlotFunnelDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.events
 */
export interface PlotFunnelEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the point name in the legend
     * is clicked. One parameter, event, is passed to the function. The state of
     * the checkbox is found by event.checked. The checked item is found by
     * event.item. Return false to prevent the default action which is to toggle
     * the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.events.checkboxClick
     */
    checkboxClick?: () => void;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.label
 * @see https://api.highcharts.com/highstock/plotOptions.funnel.label
 * @see https://api.highcharts.com/gantt/plotOptions.funnel.label
 */
export interface PlotFunnelLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.funnel.lastPrice
 */
export interface PlotFunnelLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotFunnelLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.funnel.lastVisiblePrice
 */
export interface PlotFunnelLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotFunnelLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) Funnel charts are a type of chart often used to visualize stages
 * in a sales project, where the top are the initial stages with the most
 * clients. It requires that the modules/funnel.js file is loaded.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `funnel` series are defined in plotOptions.funnel.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel
 */
export interface PlotFunnelOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Initial animation is by default disabled for the funnel
     * chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.animation
     */
    animation?: (boolean|PlotFunnelAnimationOptions);
    /**
     * (Highcharts) The color of the border surrounding each slice. When `null`,
     * the border takes the same color as the slice fill. This can be used
     * together with a `borderWidth` to fill drawing gaps created by
     * antialiazing artefacts in borderless pies.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The width of the border surrounding each slice.
     *
     * When setting the border width to 0, there may be small gaps between the
     * slices due to SVG antialiasing artefacts. To work around this, keep the
     * border width at 0.5 or 1, but set the `borderColor` to `null` instead.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) The center of the series. By default, it is centered in the
     * middle of the plot area, so it fills the plot area height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.center
     */
    center?: Array<(number|string)>;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts) A series specific or series type specific color set to use
     * instead of the global colors.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.connectors
     */
    connectors?: PlotFunnelConnectorsOptions;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.dataGrouping
     */
    dataGrouping?: PlotFunnelDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dataLabels
     */
    dataLabels?: PlotFunnelDataLabelsOptions;
    /**
     * (Highcharts) The thickness of a 3D pie. Requires `highcharts-3d.js`
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.depth
     */
    depth?: number;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.dragDrop
     */
    dragDrop?: PlotFunnelDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) The end angle of the pie in degrees where 0 is top and 90 is
     * right. Defaults to `startAngle` plus 360.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.endAngle
     */
    endAngle?: number;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.events
     */
    events?: PlotFunnelEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts) The height of the funnel or pyramid. If it is a number it
     * defines the pixel height, if it is a percentage string it is the
     * percentage of the plot area height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.height
     */
    height?: (number|string);
    /**
     * (Highcharts) Equivalent to chart.ignoreHiddenSeries, this option tells
     * whether the series shall be redrawn as if the hidden point were `null`.
     *
     * The default value changed from `false` to `true` with Highcharts 3.0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.ignoreHiddenPoint
     */
    ignoreHiddenPoint?: boolean;
    /**
     * (Highcharts) The size of the inner diameter for the pie. A size greater
     * than 0 renders a donut chart. Can be a percentage or pixel value.
     * Percentages are relative to the pie size. Pixel values are given as
     * integers.
     *
     * Note: in Highcharts < 4.1.2, the percentage was relative to the plot
     * area, not the pie size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.innerSize
     */
    innerSize?: (number|string);
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.label
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.label
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.label
     */
    label?: PlotFunnelLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.lastPrice
     */
    lastPrice?: PlotFunnelLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.lastVisiblePrice
     */
    lastVisiblePrice?: PlotFunnelLastVisiblePriceOptions;
    legendType?: string;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) The minimum size for a pie in response to auto margins. The
     * pie will try to shrink to make room for data labels in side the plot
     * area, but only to this size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.minSize
     */
    minSize?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The height of the neck, the lower part of the funnel. A
     * number defines pixel width, a percentage string defines a percentage of
     * the plot area height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.neckHeight
     */
    neckHeight?: (number|string);
    /**
     * (Highcharts) The width of the neck, the lower part of the funnel. A
     * number defines pixel width, a percentage string defines a percentage of
     * the plot area width.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.neckWidth
     */
    neckWidth?: (number|string);
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point
     */
    point?: PlotFunnelPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts) A reversed funnel has the widest area down. A reversed
     * funnel with no neck width and neck height is a pyramid.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.reversed
     */
    reversed?: boolean;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. Since 2.1, pies are not shown in the legend by default.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) If a point is sliced, moved out from the center, how many
     * pixels should it be moved?.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.slicedOffset
     */
    slicedOffset?: number;
    /**
     * (Highcharts) The start angle of the pie slices in degrees where 0 is top
     * and 90 right.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.startAngle
     */
    startAngle?: number;
    /**
     * (Highcharts) Options for the series states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states
     */
    states?: PlotFunnelStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip. When `stickyTracking` is
     * false and `tooltip.shared` is false, the tooltip will be hidden when
     * moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip
     */
    tooltip?: PlotFunnelTooltipOptions;
    /**
     * (Highstock) The parameter allows setting line series type and use OHLC
     * indicators. Data in OHLC format is required.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.useOhlcData
     */
    useOhlcData?: boolean;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.visible
     */
    visible?: boolean;
    /**
     * (Highcharts) The width of the funnel compared to the width of the plot
     * area, or the pixel width if it is a number.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.width
     */
    width?: (number|string);
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events
 */
export interface PlotFunnelPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the legend item belonging to the pie point
     * (slice) is clicked. The `this` keyword refers to the point itself. One
     * parameter, `event`, is passed to the function, containing common event
     * information. The default action is to toggle the visibility of the point.
     * This can be prevented by calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point
 */
export interface PlotFunnelPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.point.events
     */
    events?: PlotFunnelPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states.hover.animation
 */
export interface PlotFunnelStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states.hover
 */
export interface PlotFunnelStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotFunnelStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) How much to brighten the point on interaction. Requires the
     * main color to be defined in hex or rgb(a) format.
     *
     * In styled mode, the hover brightness is by default replaced by a
     * fill-opacity given in the `.highcharts-point-hover` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.normal
 */
export interface PlotFunnelStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) Options for the series states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states
 */
export interface PlotFunnelStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states.hover
     */
    hover?: PlotFunnelStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.normal
     */
    normal?: PlotFunnelStatesNormalOptions;
    /**
     * (Highmaps) Options for a selected funnel item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.select
     */
    select?: PlotFunnelStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states.select.animation
 */
export interface PlotFunnelStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highmaps) Options for a selected funnel item.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.select
 */
export interface PlotFunnelStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotFunnelStatesSelectAnimationOptions);
    /**
     * (Highmaps) A specific border color for the selected point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.select.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.funnel.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.funnel.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.funnel.tooltip.dateTimeLabelFormats
 */
export interface PlotFunnelTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip
 */
export interface PlotFunnelTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotFunnelTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.funnel.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.funnel.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Gantt) Enable or disable the initial animation when a series is displayed.
 * The animation can also be set as a configuration object. Please note that
 * this option only applies to the initial animation of the series itself. For
 * other animations, see chart.animation and the animation parameter under the
 * API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.animation
 */
export interface PlotGanttAnimationOptions {
    duration?: number;
}
export interface PlotGanttConnectorsAnimationOptions {
    reversed?: boolean;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker
 */
export interface PlotGanttConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker
 */
export interface PlotGanttConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors
 */
export interface PlotGanttConnectorsOptions {
    animation?: PlotGanttConnectorsAnimationOptions;
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.endMarker
     */
    endMarker?: PlotGanttConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.marker
     */
    marker?: PlotGanttConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker
     */
    startMarker?: PlotGanttConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker
 */
export interface PlotGanttConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.enabled
     */
    enabled?: boolean;
    fill?: string;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataGrouping
 */
export interface PlotGanttDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Gantt) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.filter
 */
export interface PlotGanttDataLabelsFilterOptions {
    /**
     * (Gantt) The operator to compare by. Can be one of `>`, `<`, `>=`, `<=`,
     * `==`, and `===`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Gantt) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Gantt) The value to compare against.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Gantt) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels
 */
export interface PlotGanttDataLabelsOptions {
    /**
     * (Gantt) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Gantt) Whether to allow data labels to overlap. To make the labels less
     * sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Gantt) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Gantt) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Gantt) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Gantt) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Gantt) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.className
     */
    className?: string;
    /**
     * (Gantt) The text color for the data labels. Defaults to `undefined`. For
     * certain series types, like column or map, the data labels can be drawn
     * inside the points. In this case the data label will be drawn with maximum
     * contrast by default. Additionally, it will be given a `text-outline`
     * style with the opposite color, to further increase the contrast. This can
     * be overridden by setting the `text-outline` style to `none` in the
     * `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Gantt) Whether to hide data labels that are outside the plot area. By
     * default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Gantt) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.filter
     */
    filter?: PlotGanttDataLabelsFilterOptions;
    /**
     * (Gantt) A format string for the data label. Available variables are the
     * same as for `formatter`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.format
     */
    format?: string;
    /**
     * (Gantt) The default formatter for X-range data labels displays the
     * percentage of the partial fill amount.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Gantt) For points with an extent, like columns or map areas, whether to
     * align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Gantt) How to handle data labels that flow outside the plot area. The
     * default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Gantt) When either the `borderWidth` or the `backgroundColor` is set,
     * this is the padding within the box.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.padding
     */
    padding?: number;
    /**
     * (Gantt) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Gantt) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Gantt) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.shape
     */
    shape?: string;
    /**
     * (Gantt) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Gantt) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Gantt) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.x
     */
    x?: number;
    /**
     * (Gantt) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Gantt) The Z index of the data labels. The default Z index puts it above
     * the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragHandle
 */
export interface PlotGanttDragDropDragHandleOptions {
    /**
     * (Gantt) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Gantt) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Gantt) The mouse cursor to use for the drag handles. By default this is
     * intelligently switching between `ew-resize` and `ns-resize` depending on
     * the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Gantt) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Gantt) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Gantt) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.guideBox.default
 */
export interface PlotGanttDragDropGuideBoxDefaultOptions {
    /**
     * (Gantt) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Gantt) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Gantt) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.guideBox
 */
export interface PlotGanttDragDropGuideBoxOptions {
    /**
     * (Gantt) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.guideBox.default
     */
    default?: PlotGanttDragDropGuideBoxDefaultOptions;
}
/**
 * (Gantt) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop
 */
export interface PlotGanttDragDropOptions {
    /**
     * (Gantt) Allow end value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.draggableEnd
     */
    draggableEnd?: boolean;
    /**
     * (Gantt) Allow start value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.draggableStart
     */
    draggableStart?: boolean;
    /**
     * (Gantt) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Gantt) Allow x value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.draggableX1
     */
    draggableX1?: boolean;
    /**
     * (Gantt) Allow x2 value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.draggableX2
     */
    draggableX2?: boolean;
    /**
     * (Gantt) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragHandle
     */
    dragHandle?: PlotGanttDragDropDragHandleOptions;
    /**
     * (Gantt) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Gantt) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Gantt) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Gantt) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Gantt) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Gantt) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Gantt) The amount of pixels to drag the pointer before it counts as a
     * drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Gantt) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Gantt) Style options for the guide box. The guide box has one state by
     * default, the `default` state.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.guideBox
     */
    guideBox?: (PlotGanttDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Gantt) Update points as they are dragged. If false, a guide box is drawn
     * to illustrate the new point size.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Gantt) General event handlers for the series items. These event hooks can
 * also be attached to the series at run time using the `Highcharts.addEvent`
 * function.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.events
 */
export interface PlotGanttEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Gantt) Fires when the checkbox next to the series' name in the legend is
     * clicked. One parameter, `event`, is passed to the function. The state of
     * the checkbox is found by `event.checked`. The checked item is found by
     * `event.item`. Return `false` to prevent the default action which is to
     * toggle the select state of the series.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Gantt) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Gantt) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.events.hide
     */
    hide?: () => void;
    /**
     * (Gantt) Fires when the legend item belonging to the series is clicked.
     * One parameter, `event`, is passed to the function. The default action is
     * to toggle the visibility of the series. This can be prevented by
     * returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Gantt) Fires when the mouse leaves the graph. One parameter, `event`, is
     * passed to the function, containing common event information. If the
     * stickyTracking option is true, `mouseOut` doesn't happen before the mouse
     * enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Gantt) Fires when the mouse enters the graph. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Gantt) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gantt.label
 * @see https://api.highcharts.com/highstock/plotOptions.gantt.label
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.label
 */
export interface PlotGanttLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.gantt.lastPrice
 */
export interface PlotGanttLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotGanttLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.gantt.lastVisiblePrice
 */
export interface PlotGanttLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotGanttLastVisiblePriceLabelOptions;
}
/**
 * (Gantt) A `gantt` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `gantt` series are defined in plotOptions.gantt.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt
 */
export interface PlotGanttOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gantt.allAreas
     */
    allAreas?: boolean;
    /**
     * (Gantt) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Gantt) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotGanttAnimationOptions);
    /**
     * (Gantt) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.borderWidth
     */
    borderWidth?: number;
    /**
     * (Gantt) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.className
     */
    className?: string;
    /**
     * (Gantt) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.clip
     */
    clip?: boolean;
    /**
     * (Gantt) The main color of the series. In line type series it applies to
     * the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gantt.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) In an X-range series, this option makes
     * all points of the same Y-axis category the same color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Gantt) Styled mode only. A specific color index to use for the series,
     * so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.colors
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.colors
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.connectors
     */
    connectors?: PlotGanttConnectorsOptions;
    /**
     * (Gantt) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.dataGrouping
     */
    dataGrouping?: PlotGanttDataGroupingOptions;
    /**
     * (Gantt) Options for the series data labels, appearing next to each data
     * point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dataLabels
     */
    dataLabels?: PlotGanttDataLabelsOptions;
    /**
     * (Gantt) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.description
     */
    description?: string;
    /**
     * (Gantt) The draggable-points module allows points to be moved around or
     * modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.dragDrop
     */
    dragDrop?: PlotGanttDragDropOptions;
    /**
     * (Gantt) Enable or disable the mouse tracking for a specific series. This
     * includes point tooltips and click events on graphs and points. For large
     * datasets it improves performance.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Gantt) General event handlers for the series items. These event hooks
     * can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.events
     */
    events?: PlotGanttEventsOptions;
    /**
     * (Gantt) By default, series are exposed to screen readers as regions. By
     * enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gantt.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Gantt) An array specifying which option maps to which key in the data
     * point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.label
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.label
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.label
     */
    label?: PlotGanttLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.lastPrice
     */
    lastPrice?: PlotGanttLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.lastVisiblePrice
     */
    lastVisiblePrice?: PlotGanttLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Gantt) A partial fill for each point, typically used to visualize how
     * much of a task is performed. See completed.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.partialFill
     */
    partialFill?: PlotGanttPartialFillOptions;
    /**
     * (Gantt) Properties for each single point.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point
     */
    point?: PlotGanttPointOptions;
    /**
     * (Gantt) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.pointPadding
     */
    pointPadding?: number;
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.pointWidth
     */
    pointWidth?: number;
    /**
     * (Gantt) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.selected
     */
    selected?: boolean;
    /**
     * (Gantt) Whether to apply a drop shadow to the graph line. Since 2.3 the
     * shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Gantt) If true, a checkbox is displayed next to the legend item to allow
     * selecting the series. The state of the checkbox is determined by the
     * `selected` option.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Gantt) Whether to display this particular series or series type in the
     * legend. The default value is `true` for standalone series, `false` for
     * linked series.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Gantt) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Gantt) A wrapper object for all the series options in specific states.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.states
     */
    states?: PlotGanttStatesOptions;
    /**
     * (Gantt) Sticky tracking of mouse events. When true, the `mouseOut` event
     * on a series isn't triggered until the mouse moves over another series, or
     * out of the plot area. When false, the `mouseOut` event on a series is
     * triggered when the mouse leaves the area around the series' graph or
     * markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Gantt) A configuration object for the tooltip rendering of each single
     * series. Properties are inherited from tooltip, but only the following
     * properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip
     */
    tooltip?: PlotGanttTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Gantt) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gantt.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.zones
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.zones
     */
    zones?: Array<PlotGanttZonesOptions>;
}
/**
 * (Gantt) A partial fill for each point, typically used to visualize how much
 * of a task is performed. See completed.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.partialFill
 */
export interface PlotGanttPartialFillOptions {
    /**
     * (Highcharts, Highstock, Gantt) The fill color to be used for partial
     * fills. Defaults to a darker shade of the point color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.partialFill.fill
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.partialFill.fill
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.partialFill.fill
     */
    fill?: (ColorString|GradientColorObject|PatternObject);
}
/**
 * (Gantt) Events for each single point.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events
 */
export interface PlotGanttPointEventsOptions {
    /**
     * (Gantt) Fires when a point is clicked. One parameter, `event`, is passed
     * to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Gantt) Callback that fires while dragging a point. The mouse event is
     * passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Gantt) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Gantt) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Gantt) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Gantt) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Gantt) Fires when the point is removed using the `.remove()` method. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events.remove
     */
    remove?: () => void;
    /**
     * (Gantt) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events.select
     */
    select?: () => void;
    /**
     * (Gantt) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Gantt) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events.update
     */
    update?: () => void;
}
/**
 * (Gantt) Properties for each single point.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.point
 */
export interface PlotGanttPointOptions {
    /**
     * (Gantt) Events for each single point.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.point.events
     */
    events?: PlotGanttPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.hover.animation
 */
export interface PlotGanttStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.gantt.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.hover
 */
export interface PlotGanttStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotGanttStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gantt.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.gantt.states.normal
 */
export interface PlotGanttStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gantt.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Gantt) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.states
 */
export interface PlotGanttStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.hover
     */
    hover?: PlotGanttStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gantt.states.normal
     */
    normal?: PlotGanttStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.select
     */
    select?: PlotGanttStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.select.animation
 */
export interface PlotGanttStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.gantt.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.select
 */
export interface PlotGanttStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotGanttStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gantt.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gantt.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.gantt.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.dateTimeLabelFormats
 */
export interface PlotGanttTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Gantt) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip
 */
export interface PlotGanttTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotGanttTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Gantt) Whether the tooltip should follow the mouse as it moves across
     * columns, pie slices and other point types with an extent. By default it
     * behaves this way for scatter, bubble and pie series by override in the
     * `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Gantt) Whether the tooltip should update as the finger moves on a touch
     * device. If this is `true` and chart.panning is set,`followTouchMove` will
     * take over one-finger touches, so the user needs to use two fingers for
     * zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Gantt) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Gantt) The HTML of the tooltip header line. Variables are enclosed by
     * curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Gantt) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Gantt) The number of milliseconds to wait until the tooltip is hidden
     * when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Gantt) Whether to allow the tooltip to render outside the chart's SVG
     * element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Gantt) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.padding
     */
    padding?: number;
    /**
     * (Gantt) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.pointFormat
     */
    pointFormat?: any;
    /**
     * (Gantt) A callback function for formatting the HTML output for a single
     * point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.tooltip.split
     */
    split?: boolean;
    /**
     * (Gantt) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Gantt) A string to prepend to each series' y value. Overridable in each
     * series' tooltip options object.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Gantt) A string to append to each series' y value. Overridable in each
     * series' tooltip options object.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.gantt.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gantt.zones
 * @see https://api.highcharts.com/highstock/plotOptions.gantt.zones
 */
export interface PlotGanttZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gantt.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.gantt.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.animation
 */
export interface PlotGaugeAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker
 */
export interface PlotGaugeConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker
 */
export interface PlotGaugeConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors
 */
export interface PlotGaugeConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.endMarker
     */
    endMarker?: PlotGaugeConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.marker
     */
    marker?: PlotGaugeConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker
     */
    startMarker?: PlotGaugeConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker
 */
export interface PlotGaugeConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataGrouping
 */
export interface PlotGaugeDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.filter
 */
export interface PlotGaugeDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Data labels for the gauge. For gauges, the data labels are
 * enabled by default and shown in a bordered box below the point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels
 */
export interface PlotGaugeDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highmaps) The border color for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.borderColor
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highmaps) The border radius in pixels for the gauge's data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.borderRadius
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highmaps) The border width in pixels for the gauge data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.borderWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highmaps) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.filter
     */
    filter?: PlotGaugeDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highmaps) The vertical alignment of the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highmaps) The y position offset of the label relative to the
     * center of the gauge.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.y
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highmaps) The Z index of the data labels. A value of 2
     * display them behind the dial.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the dial or arrow pointer of the gauge.
 *
 * In styled mode, the dial is styled with the `.highcharts-gauge-series
 * .highcharts-dial` rule.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dial
 */
export interface PlotGaugeDialOptions {
    /**
     * (Highcharts) The background or fill color of the gauge's dial.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dial.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts) The length of the dial's base part, relative to the total
     * radius or length of the dial.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dial.baseLength
     */
    baseLength?: string;
    /**
     * (Highcharts) The pixel width of the base of the gauge dial. The base is
     * the part closest to the pivot, defined by baseLength.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dial.baseWidth
     */
    baseWidth?: number;
    /**
     * (Highcharts) The border color or stroke of the gauge's dial. By default,
     * the borderWidth is 0, so this must be set in addition to a custom border
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dial.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The width of the gauge dial border in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dial.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) The radius or length of the dial, in percentages relative to
     * the radius of the gauge itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dial.radius
     */
    radius?: string;
    /**
     * (Highcharts) The length of the dial's rear end, the part that extends out
     * on the other side of the pivot. Relative to the dial's length.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dial.rearLength
     */
    rearLength?: string;
    /**
     * (Highcharts) The width of the top of the dial, closest to the perimeter.
     * The pivot narrows in from the base to the top.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dial.topWidth
     */
    topWidth?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragHandle
 */
export interface PlotGaugeDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.guideBox.default
 */
export interface PlotGaugeDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.guideBox
 */
export interface PlotGaugeDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.guideBox.default
     */
    default?: PlotGaugeDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop
 */
export interface PlotGaugeDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragHandle
     */
    dragHandle?: PlotGaugeDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.guideBox
     */
    guideBox?: (PlotGaugeDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.events
 */
export interface PlotGaugeEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.label
 * @see https://api.highcharts.com/highstock/plotOptions.gauge.label
 * @see https://api.highcharts.com/gantt/plotOptions.gauge.label
 */
export interface PlotGaugeLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.gauge.lastPrice
 */
export interface PlotGaugeLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotGaugeLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.gauge.lastVisiblePrice
 */
export interface PlotGaugeLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotGaugeLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) Gauges are circular plots displaying one or more values with a
 * dial pointing to values along the perimeter.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `gauge` series are defined in plotOptions.gauge.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge
 */
export interface PlotGaugeOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotGaugeAnimationOptions);
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.connectors
     */
    connectors?: PlotGaugeConnectorsOptions;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.dataGrouping
     */
    dataGrouping?: PlotGaugeDataGroupingOptions;
    /**
     * (Highcharts) Data labels for the gauge. For gauges, the data labels are
     * enabled by default and shown in a bordered box below the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dataLabels
     */
    dataLabels?: PlotGaugeDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.description
     */
    description?: string;
    /**
     * (Highcharts) Options for the dial or arrow pointer of the gauge.
     *
     * In styled mode, the dial is styled with the `.highcharts-gauge-series
     * .highcharts-dial` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dial
     */
    dial?: PlotGaugeDialOptions;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.dragDrop
     */
    dragDrop?: PlotGaugeDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.events
     */
    events?: PlotGaugeEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.label
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.label
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.label
     */
    label?: PlotGaugeLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.lastPrice
     */
    lastPrice?: PlotGaugeLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.lastVisiblePrice
     */
    lastVisiblePrice?: PlotGaugeLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) Allow the dial to overshoot the end of the perimeter axis by
     * this many degrees. Say if the gauge axis goes from 0 to 60, a value of
     * 100, or 1000, will show 5 degrees beyond the end of the axis when this
     * option is set to 5.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.overshoot
     */
    overshoot?: number;
    /**
     * (Highcharts) Options for the pivot or the center point of the gauge.
     *
     * In styled mode, the pivot is styled with the `.highcharts-gauge-series
     * .highcharts-pivot` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.pivot
     */
    pivot?: PlotGaugePivotOptions;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point
     */
    point?: PlotGaugePointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. Defaults to false for gauge series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip
     */
    tooltip?: PlotGaugeTooltipOptions;
    /**
     * (Highstock) The parameter allows setting line series type and use OHLC
     * indicators. Data in OHLC format is required.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.useOhlcData
     */
    useOhlcData?: boolean;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.visible
     */
    visible?: boolean;
    /**
     * (Highcharts) When this option is `true`, the dial will wrap around the
     * axes. For instance, in a full-range gauge going from 0 to 360, a value of
     * 400 will point to 40\. When `wrap` is `false`, the dial stops at 360.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.wrap
     */
    wrap?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.gauge.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the pivot or the center point of the gauge.
 *
 * In styled mode, the pivot is styled with the `.highcharts-gauge-series
 * .highcharts-pivot` rule.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.pivot
 */
export interface PlotGaugePivotOptions {
    /**
     * (Highcharts) The background color or fill of the pivot.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.pivot.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts) The border or stroke color of the pivot. In able to change
     * this, the borderWidth must also be set to something other than the
     * default 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.pivot.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border or stroke width of the pivot.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.pivot.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) The pixel radius of the pivot.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.pivot.radius
     */
    radius?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events
 */
export interface PlotGaugePointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point
 */
export interface PlotGaugePointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.point.events
     */
    events?: PlotGaugePointEventsOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.gauge.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.gauge.tooltip.dateTimeLabelFormats
 */
export interface PlotGaugeTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip
 */
export interface PlotGaugeTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotGaugeTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.gauge.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.gauge.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highmaps) Animation is disabled by default on the heatmap
 * series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.animation
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.animation
 */
export interface PlotHeatmapAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker
 */
export interface PlotHeatmapConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker
 */
export interface PlotHeatmapConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors
 */
export interface PlotHeatmapConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.endMarker
     */
    endMarker?: PlotHeatmapConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.marker
     */
    marker?: PlotHeatmapConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker
     */
    startMarker?: PlotHeatmapConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker
 */
export interface PlotHeatmapConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataGrouping
 */
export interface PlotHeatmapDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highmaps) A declarative filter for which data labels to display.
 * The declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.filter
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.filter
 */
export interface PlotHeatmapDataLabelsFilterOptions {
    /**
     * (Highcharts, Highmaps) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.filter.operator
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highmaps) The point property to filter by. Point options are
     * passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.filter.property
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highmaps) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.filter.value
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highmaps) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels
 */
export interface PlotHeatmapDataLabelsOptions {
    /**
     * (Highcharts, Highmaps) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.align
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highmaps) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highmaps) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highmaps) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.borderColor
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highmaps) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.borderRadius
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highmaps) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.borderWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highmaps) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.className
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.color
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highmaps) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.crop
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highmaps) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highmaps) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.filter
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.filter
     */
    filter?: PlotHeatmapDataLabelsFilterOptions;
    /**
     * (Highcharts, Highmaps) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.format
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highmaps) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.formatter
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highmaps) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.inside
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highmaps) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.overflow
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highmaps) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.padding
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highmaps) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.rotation
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highmaps) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.shadow
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highmaps) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.shape
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highmaps) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.style
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highmaps) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.useHTML
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highmaps) The vertical alignment of a data label. Can be one
     * of `top`, `middle` or `bottom`. The default value depends on the data,
     * for instance in a column chart, the label is above positive values and
     * below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highmaps) The x position offset of the label relative to the
     * point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.x
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highmaps) The y position offset of the label relative to the
     * point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.y
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highmaps) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highmaps) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragHandle
 */
export interface PlotHeatmapDragDropDragHandleOptions {
    /**
     * (Highcharts, Highmaps) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highmaps) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highmaps) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highmaps) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highmaps) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highmaps) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highmaps) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.guideBox.default
 */
export interface PlotHeatmapDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highmaps) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highmaps) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highmaps) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highmaps) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highmaps) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highmaps) Style options for the guide box. The guide box has one
 * state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.guideBox
 */
export interface PlotHeatmapDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highmaps) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.guideBox.default
     */
    default?: PlotHeatmapDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highmaps) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop
 */
export interface PlotHeatmapDragDropOptions {
    /**
     * (Highcharts, Highmaps) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highmaps) Enable dragging in the Y dimension. Note that this
     * is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highmaps) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragHandle
     */
    dragHandle?: PlotHeatmapDragDropDragHandleOptions;
    /**
     * (Highcharts, Highmaps) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highmaps) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highmaps) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highmaps) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highmaps) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highmaps) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highmaps) The amount of pixels to drag the pointer before it
     * counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highmaps) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highmaps) Style options for the guide box. The guide box has
     * one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.guideBox
     */
    guideBox?: (PlotHeatmapDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highmaps) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highmaps) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.events
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.events
 */
export interface PlotHeatmapEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highmaps) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.events.checkboxClick
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highmaps) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.events.click
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highmaps) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.events.hide
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the legend item belonging to the series
     * is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.events.legendItemClick
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.events.mouseOut
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.events.mouseOver
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.events.show
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.label
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.label
 * @see https://api.highcharts.com/gantt/plotOptions.heatmap.label
 */
export interface PlotHeatmapLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.lastPrice
 */
export interface PlotHeatmapLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotHeatmapLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.lastVisiblePrice
 */
export interface PlotHeatmapLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotHeatmapLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highmaps) A heatmap is a graphical representation of data where
 * the individual values contained in a matrix are represented as colors.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `heatmap` series are defined in plotOptions.heatmap.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap
 */
export interface PlotHeatmapOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highmaps) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.allowPointSelect
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highmaps) Animation is disabled by default on the heatmap
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.animation
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.animation
     */
    animation?: (boolean|PlotHeatmapAnimationOptions);
    /**
     * (Highcharts, Highmaps) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.boostThreshold
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width for each heat map item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highmaps) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.className
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.clip
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In heat maps this color is
     * rarely used, as we mostly use the color to denote the value of each
     * point. Unless options are set in the colorAxis, the default value is
     * pulled from the options.colors array.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highmaps) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.colorIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highmaps) The column size - how many X axis units each
     * column in the heatmap should span.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.colsize
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.colsize
     */
    colsize?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.connectors
     */
    connectors?: PlotHeatmapConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highmaps) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.cursor
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.dataGrouping
     */
    dataGrouping?: PlotHeatmapDataGroupingOptions;
    /**
     * (Highcharts, Highmaps) Options for the series data labels, appearing next
     * to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dataLabels
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dataLabels
     */
    dataLabels?: PlotHeatmapDataLabelsOptions;
    /**
     * (Highcharts, Highmaps) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.description
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.description
     */
    description?: string;
    /**
     * (Highcharts, Highmaps) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.dragDrop
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.dragDrop
     */
    dragDrop?: PlotHeatmapDragDropOptions;
    /**
     * (Highcharts, Highmaps) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.enableMouseTracking
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highmaps) General event handlers for the series items. These
     * event hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.events
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.events
     */
    events?: PlotHeatmapEventsOptions;
    /**
     * (Highcharts, Highmaps) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.exposeElementToA11y
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highmaps) An array specifying which option maps to which key
     * in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.keys
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.label
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.label
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.label
     */
    label?: PlotHeatmapLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.lastPrice
     */
    lastPrice?: PlotHeatmapLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.lastVisiblePrice
     */
    lastVisiblePrice?: PlotHeatmapLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highmaps) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.negativeColor
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highmaps) The color applied to null points. In styled mode,
     * a general CSS class is applied instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.nullColor
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.nullColor
     */
    nullColor?: ColorString;
    /**
     * (Highcharts, Highmaps) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point
     */
    point?: PlotHeatmapPointOptions;
    /**
     * (Highcharts, Highmaps) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.pointDescriptionFormatter
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highmaps) Padding between the points in the heatmap.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.pointPadding
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highmaps) The row size - how many Y axis units each heatmap
     * row should span.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.rowsize
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.rowsize
     */
    rowsize?: number;
    /**
     * (Highcharts, Highmaps) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.selected
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highmaps) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.showCheckbox
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highmaps) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.showInLegend
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highmaps) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.skipKeyboardNavigation
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highmaps) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states
     */
    states?: PlotHeatmapStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip
     */
    tooltip?: PlotHeatmapTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highmaps) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.visible
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.zones
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.zones
     */
    zones?: Array<PlotHeatmapZonesOptions>;
}
/**
 * (Highcharts, Highmaps) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events
 */
export interface PlotHeatmapPointEventsOptions {
    /**
     * (Highcharts, Highmaps) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events.click
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highmaps) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events.drag
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highmaps) Callback that fires when starting to drag a point.
     * The mouse event object is passed in as an argument. If a drag handle is
     * used, `e.updateProp` is set to the data property being dragged. The
     * `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events.dragStart
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highmaps) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events.drop
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highmaps) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events.mouseOut
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events.mouseOver
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events.remove
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events.select
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events.unselect
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events.update
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highmaps) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point
 */
export interface PlotHeatmapPointOptions {
    /**
     * (Highcharts, Highmaps) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.point.events
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.point.events
     */
    events?: PlotHeatmapPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.animation
 */
export interface PlotHeatmapStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.halo
 */
export interface PlotHeatmapStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker
 */
export interface PlotHeatmapStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states
     */
    states?: PlotHeatmapStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover.animation
 */
export interface PlotHeatmapStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover
 */
export interface PlotHeatmapStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotHeatmapStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.normal
 */
export interface PlotHeatmapStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states
 */
export interface PlotHeatmapStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.hover
     */
    hover?: PlotHeatmapStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.normal
     */
    normal?: PlotHeatmapStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.select
     */
    select?: PlotHeatmapStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.select
 */
export interface PlotHeatmapStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highmaps) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.hover
 */
export interface PlotHeatmapStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotHeatmapStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) How much to brighten the point on interaction. Requires the
     * main color to be defined in hex or rgb(a) format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highmaps) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.halo
     */
    halo?: PlotHeatmapStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.hover.marker
     */
    marker?: PlotHeatmapStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.normal
 */
export interface PlotHeatmapStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highmaps) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states
 */
export interface PlotHeatmapStatesOptions {
    /**
     * (Highcharts, Highmaps) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.hover
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.hover
     */
    hover?: PlotHeatmapStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.normal
     */
    normal?: PlotHeatmapStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.select
     */
    select?: PlotHeatmapStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.animation
 */
export interface PlotHeatmapStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.halo
 */
export interface PlotHeatmapStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker
 */
export interface PlotHeatmapStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states
     */
    states?: PlotHeatmapStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover.animation
 */
export interface PlotHeatmapStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover
 */
export interface PlotHeatmapStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotHeatmapStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.normal
 */
export interface PlotHeatmapStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states
 */
export interface PlotHeatmapStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.hover
     */
    hover?: PlotHeatmapStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.normal
     */
    normal?: PlotHeatmapStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.select
     */
    select?: PlotHeatmapStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.select
 */
export interface PlotHeatmapStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.select
 */
export interface PlotHeatmapStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotHeatmapStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.halo
     */
    halo?: PlotHeatmapStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.states.select.marker
     */
    marker?: PlotHeatmapStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.heatmap.tooltip.dateTimeLabelFormats
 */
export interface PlotHeatmapTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip
 */
export interface PlotHeatmapTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotHeatmapTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.heatmap.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.zones
 * @see https://api.highcharts.com/highstock/plotOptions.heatmap.zones
 */
export interface PlotHeatmapZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.heatmap.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.animation
 */
export interface PlotHistogramAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker
 */
export interface PlotHistogramConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker
 */
export interface PlotHistogramConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors
 */
export interface PlotHistogramConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.endMarker
     */
    endMarker?: PlotHistogramConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.marker
     */
    marker?: PlotHistogramConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker
     */
    startMarker?: PlotHistogramConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker
 */
export interface PlotHistogramConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataGrouping
 */
export interface PlotHistogramDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.filter
 */
export interface PlotHistogramDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels
 */
export interface PlotHistogramDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.filter
     */
    filter?: PlotHistogramDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragHandle
 */
export interface PlotHistogramDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.guideBox.default
 */
export interface PlotHistogramDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.guideBox
 */
export interface PlotHistogramDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.guideBox.default
     */
    default?: PlotHistogramDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop
 */
export interface PlotHistogramDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragHandle
     */
    dragHandle?: PlotHistogramDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.guideBox
     */
    guideBox?: (PlotHistogramDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.events
 */
export interface PlotHistogramEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.label
 * @see https://api.highcharts.com/highstock/plotOptions.histogram.label
 * @see https://api.highcharts.com/gantt/plotOptions.histogram.label
 */
export interface PlotHistogramLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.histogram.lastPrice
 */
export interface PlotHistogramLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotHistogramLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.histogram.lastVisiblePrice
 */
export interface PlotHistogramLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotHistogramLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A histogram is a column series which represents the distribution
 * of the data set in the base series. Histogram splits data into bins and shows
 * their frequencies.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `histogram` series are defined in plotOptions.histogram.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram
 */
export interface PlotHistogramOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.histogram.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotHistogramAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts) A preferable number of bins. It is a suggestion, so a
     * histogram may have a different number of bins. By default it is set to
     * the square root of the base series' data length. Available options are:
     * `square-root`, `sturges`, `rice`. You can also define a function which
     * takes a `baseSeries` as a parameter and should return a positive integer.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.binsNumber
     */
    binsNumber?: ("rice"|"square-root"|"sturges");
    /**
     * (Highcharts) Width of each bin. By default the bin's width is calculated
     * as `(max - min) / number of bins`. This option takes precedence over
     * binsNumber.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.binWidth
     */
    binWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.histogram.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.colors
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.colors
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.connectors
     */
    connectors?: PlotHistogramConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.dataGrouping
     */
    dataGrouping?: PlotHistogramDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dataLabels
     */
    dataLabels?: PlotHistogramDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.depth
     */
    depth?: number;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.dragDrop
     */
    dragDrop?: PlotHistogramDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.events
     */
    events?: PlotHistogramEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.histogram.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.label
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.label
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.label
     */
    label?: PlotHistogramLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.lastPrice
     */
    lastPrice?: PlotHistogramLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.lastVisiblePrice
     */
    lastVisiblePrice?: PlotHistogramLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The color for the parts of the graph or points that are
     * below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point
     */
    point?: PlotHistogramPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.pointPlacement
     */
    pointPlacement?: string;
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states
     */
    states?: PlotHistogramStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.threshold
     */
    threshold?: number;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip
     */
    tooltip?: PlotHistogramTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.histogram.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.zones
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.zones
     */
    zones?: Array<PlotHistogramZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events
 */
export interface PlotHistogramPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point
 */
export interface PlotHistogramPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.point.events
     */
    events?: PlotHistogramPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.hover.animation
 */
export interface PlotHistogramStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.histogram.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.hover
 */
export interface PlotHistogramStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotHistogramStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.histogram.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.histogram.states.normal
 */
export interface PlotHistogramStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.histogram.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states
 */
export interface PlotHistogramStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.hover
     */
    hover?: PlotHistogramStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.histogram.states.normal
     */
    normal?: PlotHistogramStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.select
     */
    select?: PlotHistogramStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.select.animation
 */
export interface PlotHistogramStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.histogram.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.select
 */
export interface PlotHistogramStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotHistogramStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.histogram.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.histogram.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.histogram.tooltip.dateTimeLabelFormats
 */
export interface PlotHistogramTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip
 */
export interface PlotHistogramTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotHistogramTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.histogram.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.histogram.zones
 * @see https://api.highcharts.com/highstock/plotOptions.histogram.zones
 */
export interface PlotHistogramZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.histogram.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.animation
 */
export interface PlotIkhAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The styles for Chikou line
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.chikouLine
 */
export interface PlotIkhChikouLineOptions {
    styles?: PlotIkhChikouLineStylesOptions;
}
export interface PlotIkhChikouLineStylesOptions {
    /**
     * (Highstock) Color of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.chikouLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.chikouLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker
 */
export interface PlotIkhConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker
 */
export interface PlotIkhConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors
 */
export interface PlotIkhConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.endMarker
     */
    endMarker?: PlotIkhConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.marker
     */
    marker?: PlotIkhConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker
     */
    startMarker?: PlotIkhConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker
 */
export interface PlotIkhConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataGrouping
 */
export interface PlotIkhDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.filter
 */
export interface PlotIkhDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels
 */
export interface PlotIkhDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.filter
     */
    filter?: PlotIkhDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragHandle
 */
export interface PlotIkhDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.guideBox.default
 */
export interface PlotIkhDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.guideBox
 */
export interface PlotIkhDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.guideBox.default
     */
    default?: PlotIkhDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop
 */
export interface PlotIkhDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragHandle
     */
    dragHandle?: PlotIkhDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.guideBox
     */
    guideBox?: (PlotIkhDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.events
 */
export interface PlotIkhEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.events.show
     */
    show?: () => void;
}
/**
 * (Highstock) The styles for Kijun line
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.kijunLine
 */
export interface PlotIkhKijunLineOptions {
    styles?: PlotIkhKijunLineStylesOptions;
}
export interface PlotIkhKijunLineStylesOptions {
    /**
     * (Highstock) Color of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.kijunLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.kijunLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.label
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.label
 * @see https://api.highcharts.com/gantt/plotOptions.ikh.label
 */
export interface PlotIkhLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.lastPrice
 */
export interface PlotIkhLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotIkhLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.lastVisiblePrice
 */
export interface PlotIkhLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotIkhLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker
 */
export interface PlotIkhMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states
     */
    states?: PlotIkhMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover.animation
 */
export interface PlotIkhMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover
 */
export interface PlotIkhMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotIkhMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.normal
 */
export interface PlotIkhMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states
 */
export interface PlotIkhMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.hover
     */
    hover?: PlotIkhMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.normal
     */
    normal?: PlotIkhMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.select
     */
    select?: PlotIkhMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.select
 */
export interface PlotIkhMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Ichimoku Kinko Hyo (IKH). This series requires `linkedTo` option
 * to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ikh` series are defined in plotOptions.ikh.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh
 */
export interface PlotIkhOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotIkhAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) The styles for Chikou line
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.chikouLine
     */
    chikouLine?: PlotIkhChikouLineOptions;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.connectors
     */
    connectors?: PlotIkhConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataGrouping
     */
    dataGrouping?: PlotIkhDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dataLabels
     */
    dataLabels?: PlotIkhDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.dragDrop
     */
    dragDrop?: PlotIkhDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.events
     */
    events?: PlotIkhEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highstock) The styles for Kijun line
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.kijunLine
     */
    kijunLine?: PlotIkhKijunLineOptions;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.label
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.label
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.label
     */
    label?: PlotIkhLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.lastPrice
     */
    lastPrice?: PlotIkhLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.lastVisiblePrice
     */
    lastVisiblePrice?: PlotIkhLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.marker
     */
    marker?: PlotIkhMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.params
     */
    params?: PlotIkhParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point
     */
    point?: PlotIkhPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.selected
     */
    selected?: boolean;
    /**
     * (Highstock) The styles for area between Senkou Span A and B.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpan
     */
    senkouSpan?: PlotIkhSenkouSpanOptions;
    /**
     * (Highstock) The styles for Senkou Span A line
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpanA
     */
    senkouSpanA?: PlotIkhSenkouSpanAOptions;
    /**
     * (Highstock) The styles for Senkou Span B line
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpanB
     */
    senkouSpanB?: PlotIkhSenkouSpanBOptions;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states
     */
    states?: PlotIkhStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.step
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highstock) The styles for Tenkan line
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tenkanLine
     */
    tenkanLine?: PlotIkhTenkanLineOptions;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip
     */
    tooltip?: PlotIkhTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.zones
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.zones
     */
    zones?: Array<PlotIkhZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.params
 */
export interface PlotIkhParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.params.period
     */
    period?: number;
    /**
     * (Highstock) The base period for Senkou Span B calculations
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.params.periodSenkouSpanB
     */
    periodSenkouSpanB?: number;
    /**
     * (Highstock) The base period for Tenkan calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.params.periodTenkan
     */
    periodTenkan?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events
 */
export interface PlotIkhPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.point
 */
export interface PlotIkhPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.point.events
     */
    events?: PlotIkhPointEventsOptions;
}
/**
 * (Highstock) The styles for Senkou Span A line
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpanA
 */
export interface PlotIkhSenkouSpanAOptions {
    styles?: PlotIkhSenkouSpanAStylesOptions;
}
export interface PlotIkhSenkouSpanAStylesOptions {
    /**
     * (Highstock) Color of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpanA.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpanA.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highstock) The styles for Senkou Span B line
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpanB
 */
export interface PlotIkhSenkouSpanBOptions {
    styles?: PlotIkhSenkouSpanBStylesOptions;
}
export interface PlotIkhSenkouSpanBStylesOptions {
    /**
     * (Highstock) Color of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpanB.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpanB.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highstock) The styles for area between Senkou Span A and B.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpan
 */
export interface PlotIkhSenkouSpanOptions {
    /**
     * (Highstock) Color of the area between Senkou Span A and B, when Senkou
     * Span A is above Senkou Span B. Note that if a `style.fill` is defined,
     * the `color` takes precedence and the `style.fill` is ignored.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpan.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Color of the area between Senkou Span A and B, when Senkou
     * Span A is under Senkou Span B.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpan.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    styles?: PlotIkhSenkouSpanStylesOptions;
}
export interface PlotIkhSenkouSpanStylesOptions {
    /**
     * (Highstock) Color of the area between Senkou Span A and B.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.senkouSpan.styles.fill
     */
    fill?: (ColorString|GradientColorObject|PatternObject);
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.animation
 */
export interface PlotIkhStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.halo
 */
export interface PlotIkhStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker
 */
export interface PlotIkhStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states
     */
    states?: PlotIkhStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover.animation
 */
export interface PlotIkhStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover
 */
export interface PlotIkhStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotIkhStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.normal
 */
export interface PlotIkhStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states
 */
export interface PlotIkhStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.hover
     */
    hover?: PlotIkhStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.normal
     */
    normal?: PlotIkhStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.select
     */
    select?: PlotIkhStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.select
 */
export interface PlotIkhStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover
 */
export interface PlotIkhStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotIkhStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.halo
     */
    halo?: PlotIkhStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover.marker
     */
    marker?: PlotIkhStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.normal
 */
export interface PlotIkhStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states
 */
export interface PlotIkhStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.hover
     */
    hover?: PlotIkhStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.normal
     */
    normal?: PlotIkhStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.select
     */
    select?: PlotIkhStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.animation
 */
export interface PlotIkhStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.halo
 */
export interface PlotIkhStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker
 */
export interface PlotIkhStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states
     */
    states?: PlotIkhStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover.animation
 */
export interface PlotIkhStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover
 */
export interface PlotIkhStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotIkhStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.normal
 */
export interface PlotIkhStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states
 */
export interface PlotIkhStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.hover
     */
    hover?: PlotIkhStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.normal
     */
    normal?: PlotIkhStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.select
     */
    select?: PlotIkhStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.select
 */
export interface PlotIkhStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.select
 */
export interface PlotIkhStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotIkhStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ikh.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.halo
     */
    halo?: PlotIkhStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.states.select.marker
     */
    marker?: PlotIkhStatesSelectMarkerOptions;
}
/**
 * (Highstock) The styles for Tenkan line
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.tenkanLine
 */
export interface PlotIkhTenkanLineOptions {
    styles?: PlotIkhTenkanLineStylesOptions;
}
export interface PlotIkhTenkanLineStylesOptions {
    /**
     * (Highstock) Color of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tenkanLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tenkanLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.ikh.tooltip.dateTimeLabelFormats
 */
export interface PlotIkhTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip
 */
export interface PlotIkhTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotIkhTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.ikh.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ikh.zones
 * @see https://api.highcharts.com/highstock/plotOptions.ikh.zones
 */
export interface PlotIkhZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ikh.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.ikh.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.animation
 */
export interface PlotKeltnerchannelsAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) Bottom line options.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.bottomLine
 */
export interface PlotKeltnerchannelsBottomLineOptions {
    /**
     * (Highstock) Styles for a bottom line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.bottomLine.styles
     */
    styles?: PlotKeltnerchannelsBottomLineStylesOptions;
}
/**
 * (Highstock) Styles for a bottom line.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.bottomLine.styles
 */
export interface PlotKeltnerchannelsBottomLineStylesOptions {
    /**
     * (Highstock) Color of the line. If not set, it's inherited from
     * `plotOptions.keltnerchannels.color`
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.bottomLine.styles.lineColor
     */
    lineColor?: object;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.bottomLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker
 */
export interface PlotKeltnerchannelsConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker
 */
export interface PlotKeltnerchannelsConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors
 */
export interface PlotKeltnerchannelsConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.endMarker
     */
    endMarker?: PlotKeltnerchannelsConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.marker
     */
    marker?: PlotKeltnerchannelsConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker
     */
    startMarker?: PlotKeltnerchannelsConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker
 */
export interface PlotKeltnerchannelsConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataGrouping
 */
export interface PlotKeltnerchannelsDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.filter
 */
export interface PlotKeltnerchannelsDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels
 */
export interface PlotKeltnerchannelsDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.filter
     */
    filter?: PlotKeltnerchannelsDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragHandle
 */
export interface PlotKeltnerchannelsDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.guideBox.default
 */
export interface PlotKeltnerchannelsDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.guideBox
 */
export interface PlotKeltnerchannelsDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.guideBox.default
     */
    default?: PlotKeltnerchannelsDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop
 */
export interface PlotKeltnerchannelsDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragHandle
     */
    dragHandle?: PlotKeltnerchannelsDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.guideBox
     */
    guideBox?: (PlotKeltnerchannelsDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.events
 */
export interface PlotKeltnerchannelsEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.label
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.label
 * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.label
 */
export interface PlotKeltnerchannelsLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.lastPrice
 */
export interface PlotKeltnerchannelsLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotKeltnerchannelsLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.lastVisiblePrice
 */
export interface PlotKeltnerchannelsLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotKeltnerchannelsLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker
 */
export interface PlotKeltnerchannelsMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states
     */
    states?: PlotKeltnerchannelsMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover.animation
 */
export interface PlotKeltnerchannelsMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover
 */
export interface PlotKeltnerchannelsMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotKeltnerchannelsMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.normal
 */
export interface PlotKeltnerchannelsMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states
 */
export interface PlotKeltnerchannelsMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.hover
     */
    hover?: PlotKeltnerchannelsMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.normal
     */
    normal?: PlotKeltnerchannelsMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.select
     */
    select?: PlotKeltnerchannelsMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.select
 */
export interface PlotKeltnerchannelsMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Keltner Channels. This series requires the `linkedTo` option to
 * be set and should be loaded after the `stock/indicators/indicators.js`,
 * `stock/indicators/atr.js`, and `stock/ema/.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `keltnerchannels` series are defined in
 * plotOptions.keltnerchannels.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels
 */
export interface PlotKeltnerchannelsOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotKeltnerchannelsAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) Bottom line options.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.bottomLine
     */
    bottomLine?: PlotKeltnerchannelsBottomLineOptions;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.connectors
     */
    connectors?: PlotKeltnerchannelsConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataGrouping
     */
    dataGrouping?: PlotKeltnerchannelsDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dataLabels
     */
    dataLabels?: PlotKeltnerchannelsDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.dragDrop
     */
    dragDrop?: PlotKeltnerchannelsDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.events
     */
    events?: PlotKeltnerchannelsEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.label
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.label
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.label
     */
    label?: PlotKeltnerchannelsLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.lastPrice
     */
    lastPrice?: PlotKeltnerchannelsLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.lastVisiblePrice
     */
    lastVisiblePrice?: PlotKeltnerchannelsLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.marker
     */
    marker?: PlotKeltnerchannelsMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.params
     */
    params?: PlotKeltnerchannelsParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point
     */
    point?: PlotKeltnerchannelsPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states
     */
    states?: PlotKeltnerchannelsStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.step
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip
     */
    tooltip?: PlotKeltnerchannelsTooltipOptions;
    /**
     * (Highstock) Top line options.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.topLine
     */
    topLine?: PlotKeltnerchannelsTopLineOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.zones
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.zones
     */
    zones?: Array<PlotKeltnerchannelsZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.params
 */
export interface PlotKeltnerchannelsParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.params.index
     */
    index?: number;
    /**
     * (Highstock) The ATR multiplier.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.params.multiplierATR
     */
    multiplierATR?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.params.period
     */
    period?: number;
    /**
     * (Highstock) The ATR period.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.params.periodATR
     */
    periodATR?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events
 */
export interface PlotKeltnerchannelsPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point
 */
export interface PlotKeltnerchannelsPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.point.events
     */
    events?: PlotKeltnerchannelsPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.animation
 */
export interface PlotKeltnerchannelsStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.halo
 */
export interface PlotKeltnerchannelsStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker
 */
export interface PlotKeltnerchannelsStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states
     */
    states?: PlotKeltnerchannelsStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover.animation
 */
export interface PlotKeltnerchannelsStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover
 */
export interface PlotKeltnerchannelsStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotKeltnerchannelsStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.normal
 */
export interface PlotKeltnerchannelsStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states
 */
export interface PlotKeltnerchannelsStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.hover
     */
    hover?: PlotKeltnerchannelsStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.normal
     */
    normal?: PlotKeltnerchannelsStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.select
     */
    select?: PlotKeltnerchannelsStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.select
 */
export interface PlotKeltnerchannelsStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover
 */
export interface PlotKeltnerchannelsStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotKeltnerchannelsStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.halo
     */
    halo?: PlotKeltnerchannelsStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover.marker
     */
    marker?: PlotKeltnerchannelsStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.normal
 */
export interface PlotKeltnerchannelsStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states
 */
export interface PlotKeltnerchannelsStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.hover
     */
    hover?: PlotKeltnerchannelsStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.normal
     */
    normal?: PlotKeltnerchannelsStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.select
     */
    select?: PlotKeltnerchannelsStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.animation
 */
export interface PlotKeltnerchannelsStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.halo
 */
export interface PlotKeltnerchannelsStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker
 */
export interface PlotKeltnerchannelsStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states
     */
    states?: PlotKeltnerchannelsStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover.animation
 */
export interface PlotKeltnerchannelsStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover
 */
export interface PlotKeltnerchannelsStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotKeltnerchannelsStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.normal
 */
export interface PlotKeltnerchannelsStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states
 */
export interface PlotKeltnerchannelsStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.hover
     */
    hover?: PlotKeltnerchannelsStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.normal
     */
    normal?: PlotKeltnerchannelsStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.select
     */
    select?: PlotKeltnerchannelsStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.select
 */
export interface PlotKeltnerchannelsStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.select
 */
export interface PlotKeltnerchannelsStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotKeltnerchannelsStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.keltnerchannels.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.halo
     */
    halo?: PlotKeltnerchannelsStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.states.select.marker
     */
    marker?: PlotKeltnerchannelsStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.tooltip.dateTimeLabelFormats
 */
export interface PlotKeltnerchannelsTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip
 */
export interface PlotKeltnerchannelsTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotKeltnerchannelsTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.keltnerchannels.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highstock) Top line options.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.topLine
 */
export interface PlotKeltnerchannelsTopLineOptions {
    /**
     * (Highstock) Styles for a bottom line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.topLine.styles
     */
    styles?: PlotKeltnerchannelsTopLineStylesOptions;
}
/**
 * (Highstock) Styles for a bottom line.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.topLine.styles
 */
export interface PlotKeltnerchannelsTopLineStylesOptions {
    /**
     * (Highstock) Color of the line. If not set, it's inherited from
     * `plotOptions.keltnerchannels.color`
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.topLine.styles.lineColor
     */
    lineColor?: object;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.topLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.zones
 * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.zones
 */
export interface PlotKeltnerchannelsZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.keltnerchannels.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.animation
 * @see https://api.highcharts.com/highstock/plotOptions.line.animation
 */
export interface PlotLineAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.animation
 */
export interface PlotLinearregressionangleAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker
 */
export interface PlotLinearregressionangleConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker
 */
export interface PlotLinearregressionangleConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors
 */
export interface PlotLinearregressionangleConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.endMarker
     */
    endMarker?: PlotLinearregressionangleConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.marker
     */
    marker?: PlotLinearregressionangleConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker
     */
    startMarker?: PlotLinearregressionangleConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker
 */
export interface PlotLinearregressionangleConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataGrouping
 */
export interface PlotLinearregressionangleDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.filter
 */
export interface PlotLinearregressionangleDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels
 */
export interface PlotLinearregressionangleDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.filter
     */
    filter?: PlotLinearregressionangleDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragHandle
 */
export interface PlotLinearregressionangleDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.guideBox.default
 */
export interface PlotLinearregressionangleDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.guideBox
 */
export interface PlotLinearregressionangleDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.guideBox.default
     */
    default?: PlotLinearregressionangleDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop
 */
export interface PlotLinearregressionangleDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragHandle
     */
    dragHandle?: PlotLinearregressionangleDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.guideBox
     */
    guideBox?: (PlotLinearregressionangleDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.events
 */
export interface PlotLinearregressionangleEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.label
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.label
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.label
 */
export interface PlotLinearregressionangleLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.lastPrice
 */
export interface PlotLinearregressionangleLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotLinearregressionangleLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.lastVisiblePrice
 */
export interface PlotLinearregressionangleLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotLinearregressionangleLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker
 */
export interface PlotLinearregressionangleMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states
     */
    states?: PlotLinearregressionangleMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover.animation
 */
export interface PlotLinearregressionangleMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover
 */
export interface PlotLinearregressionangleMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionangleMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.normal
 */
export interface PlotLinearregressionangleMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states
 */
export interface PlotLinearregressionangleMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.hover
     */
    hover?: PlotLinearregressionangleMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.normal
     */
    normal?: PlotLinearregressionangleMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.select
     */
    select?: PlotLinearregressionangleMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.select
 */
export interface PlotLinearregressionangleMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Linear regression angle indicator. This series requires
 * `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `linearregressionangle` series are defined in
 * plotOptions.linearregressionangle.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle
 */
export interface PlotLinearregressionangleOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionangleAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.connectors
     */
    connectors?: PlotLinearregressionangleConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataGrouping
     */
    dataGrouping?: PlotLinearregressionangleDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dataLabels
     */
    dataLabels?: PlotLinearregressionangleDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.dragDrop
     */
    dragDrop?: PlotLinearregressionangleDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.events
     */
    events?: PlotLinearregressionangleEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.label
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.label
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.label
     */
    label?: PlotLinearregressionangleLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.lastPrice
     */
    lastPrice?: PlotLinearregressionangleLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.lastVisiblePrice
     */
    lastVisiblePrice?: PlotLinearregressionangleLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.marker
     */
    marker?: PlotLinearregressionangleMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.params
     */
    params?: PlotLinearregressionangleParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point
     */
    point?: PlotLinearregressionanglePointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states
     */
    states?: PlotLinearregressionangleStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.step
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip
     */
    tooltip?: PlotLinearregressionangleTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.zones
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.zones
     */
    zones?: Array<PlotLinearregressionangleZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.params
 */
export interface PlotLinearregressionangleParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.params.period
     */
    period?: number;
    /**
     * (Highstock) Unit (in milliseconds) for the x axis distances used to
     * compute the regression line paramters (slope & intercept) for every
     * range. In Highstock the x axis values are always represented in
     * milliseconds which may cause that distances between points are "big"
     * integer numbers.
     *
     * Highstock's linear regression algorithm (least squares method) will
     * utilize these "big" integers for finding the slope and the intercept of
     * the regression line for each period. In consequence, this value may be a
     * very "small" decimal number that's hard to interpret by a human.
     *
     * For instance: `xAxisUnit` equealed to `86400000` ms (1 day) forces the
     * algorithm to treat `86400000` as `1` while computing the slope and the
     * intercept. This may enchance the legiblitity of the indicator's values.
     *
     * Default value is the closest distance between two data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.params.xAxisUnit
     */
    xAxisUnit?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events
 */
export interface PlotLinearregressionanglePointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point
 */
export interface PlotLinearregressionanglePointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.point.events
     */
    events?: PlotLinearregressionanglePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.animation
 */
export interface PlotLinearregressionangleStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.halo
 */
export interface PlotLinearregressionangleStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker
 */
export interface PlotLinearregressionangleStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states
     */
    states?: PlotLinearregressionangleStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover.animation
 */
export interface PlotLinearregressionangleStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover
 */
export interface PlotLinearregressionangleStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionangleStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.normal
 */
export interface PlotLinearregressionangleStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states
 */
export interface PlotLinearregressionangleStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.hover
     */
    hover?: PlotLinearregressionangleStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.normal
     */
    normal?: PlotLinearregressionangleStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.select
     */
    select?: PlotLinearregressionangleStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.select
 */
export interface PlotLinearregressionangleStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover
 */
export interface PlotLinearregressionangleStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionangleStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.halo
     */
    halo?: PlotLinearregressionangleStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover.marker
     */
    marker?: PlotLinearregressionangleStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.normal
 */
export interface PlotLinearregressionangleStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states
 */
export interface PlotLinearregressionangleStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.hover
     */
    hover?: PlotLinearregressionangleStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.normal
     */
    normal?: PlotLinearregressionangleStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.select
     */
    select?: PlotLinearregressionangleStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.animation
 */
export interface PlotLinearregressionangleStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.halo
 */
export interface PlotLinearregressionangleStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker
 */
export interface PlotLinearregressionangleStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states
     */
    states?: PlotLinearregressionangleStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover.animation
 */
export interface PlotLinearregressionangleStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover
 */
export interface PlotLinearregressionangleStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionangleStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.normal
 */
export interface PlotLinearregressionangleStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states
 */
export interface PlotLinearregressionangleStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.hover
     */
    hover?: PlotLinearregressionangleStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.normal
     */
    normal?: PlotLinearregressionangleStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.select
     */
    select?: PlotLinearregressionangleStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.select
 */
export interface PlotLinearregressionangleStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.select
 */
export interface PlotLinearregressionangleStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionangleStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionangle.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.halo
     */
    halo?: PlotLinearregressionangleStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.states.select.marker
     */
    marker?: PlotLinearregressionangleStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.tooltip.dateTimeLabelFormats
 */
export interface PlotLinearregressionangleTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip
 */
export interface PlotLinearregressionangleTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotLinearregressionangleTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionangle.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.zones
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.zones
 */
export interface PlotLinearregressionangleZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionangle.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.animation
 */
export interface PlotLinearregressionAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker
 */
export interface PlotLinearregressionConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker
 */
export interface PlotLinearregressionConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors
 */
export interface PlotLinearregressionConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.endMarker
     */
    endMarker?: PlotLinearregressionConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.marker
     */
    marker?: PlotLinearregressionConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker
     */
    startMarker?: PlotLinearregressionConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker
 */
export interface PlotLinearregressionConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataGrouping
 */
export interface PlotLinearregressionDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.filter
 */
export interface PlotLinearregressionDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels
 */
export interface PlotLinearregressionDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.filter
     */
    filter?: PlotLinearregressionDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragHandle
 */
export interface PlotLinearregressionDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.guideBox.default
 */
export interface PlotLinearregressionDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.guideBox
 */
export interface PlotLinearregressionDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.guideBox.default
     */
    default?: PlotLinearregressionDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop
 */
export interface PlotLinearregressionDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragHandle
     */
    dragHandle?: PlotLinearregressionDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.guideBox
     */
    guideBox?: (PlotLinearregressionDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.events
 */
export interface PlotLinearregressionEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.events.show
     */
    show?: () => void;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.animation
 */
export interface PlotLinearregressioninterceptAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker
 */
export interface PlotLinearregressioninterceptConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker
 */
export interface PlotLinearregressioninterceptConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors
 */
export interface PlotLinearregressioninterceptConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.endMarker
     */
    endMarker?: PlotLinearregressioninterceptConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.marker
     */
    marker?: PlotLinearregressioninterceptConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker
     */
    startMarker?: PlotLinearregressioninterceptConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker
 */
export interface PlotLinearregressioninterceptConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataGrouping
 */
export interface PlotLinearregressioninterceptDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.filter
 */
export interface PlotLinearregressioninterceptDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels
 */
export interface PlotLinearregressioninterceptDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.filter
     */
    filter?: PlotLinearregressioninterceptDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragHandle
 */
export interface PlotLinearregressioninterceptDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.guideBox.default
 */
export interface PlotLinearregressioninterceptDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.guideBox
 */
export interface PlotLinearregressioninterceptDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.guideBox.default
     */
    default?: PlotLinearregressioninterceptDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop
 */
export interface PlotLinearregressioninterceptDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragHandle
     */
    dragHandle?: PlotLinearregressioninterceptDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.guideBox
     */
    guideBox?: (PlotLinearregressioninterceptDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.events
 */
export interface PlotLinearregressioninterceptEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.label
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.label
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.label
 */
export interface PlotLinearregressioninterceptLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.lastPrice
 */
export interface PlotLinearregressioninterceptLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotLinearregressioninterceptLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.lastVisiblePrice
 */
export interface PlotLinearregressioninterceptLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotLinearregressioninterceptLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker
 */
export interface PlotLinearregressioninterceptMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states
     */
    states?: PlotLinearregressioninterceptMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover.animation
 */
export interface PlotLinearregressioninterceptMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover
 */
export interface PlotLinearregressioninterceptMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressioninterceptMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.normal
 */
export interface PlotLinearregressioninterceptMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states
 */
export interface PlotLinearregressioninterceptMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.hover
     */
    hover?: PlotLinearregressioninterceptMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.normal
     */
    normal?: PlotLinearregressioninterceptMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.select
     */
    select?: PlotLinearregressioninterceptMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.select
 */
export interface PlotLinearregressioninterceptMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Linear regression intercept indicator. This series requires
 * `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `linearregressionintercept` series are defined in
 * plotOptions.linearregressionintercept.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept
 */
export interface PlotLinearregressioninterceptOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressioninterceptAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.connectors
     */
    connectors?: PlotLinearregressioninterceptConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataGrouping
     */
    dataGrouping?: PlotLinearregressioninterceptDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dataLabels
     */
    dataLabels?: PlotLinearregressioninterceptDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.dragDrop
     */
    dragDrop?: PlotLinearregressioninterceptDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.events
     */
    events?: PlotLinearregressioninterceptEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.label
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.label
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.label
     */
    label?: PlotLinearregressioninterceptLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.lastPrice
     */
    lastPrice?: PlotLinearregressioninterceptLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.lastVisiblePrice
     */
    lastVisiblePrice?: PlotLinearregressioninterceptLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.marker
     */
    marker?: PlotLinearregressioninterceptMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.params
     */
    params?: PlotLinearregressioninterceptParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point
     */
    point?: PlotLinearregressioninterceptPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states
     */
    states?: PlotLinearregressioninterceptStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.step
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip
     */
    tooltip?: PlotLinearregressioninterceptTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.zones
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.zones
     */
    zones?: Array<PlotLinearregressioninterceptZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.params
 */
export interface PlotLinearregressioninterceptParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.params.period
     */
    period?: number;
    /**
     * (Highstock) Unit (in milliseconds) for the x axis distances used to
     * compute the regression line paramters (slope & intercept) for every
     * range. In Highstock the x axis values are always represented in
     * milliseconds which may cause that distances between points are "big"
     * integer numbers.
     *
     * Highstock's linear regression algorithm (least squares method) will
     * utilize these "big" integers for finding the slope and the intercept of
     * the regression line for each period. In consequence, this value may be a
     * very "small" decimal number that's hard to interpret by a human.
     *
     * For instance: `xAxisUnit` equealed to `86400000` ms (1 day) forces the
     * algorithm to treat `86400000` as `1` while computing the slope and the
     * intercept. This may enchance the legiblitity of the indicator's values.
     *
     * Default value is the closest distance between two data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.params.xAxisUnit
     */
    xAxisUnit?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events
 */
export interface PlotLinearregressioninterceptPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point
 */
export interface PlotLinearregressioninterceptPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.point.events
     */
    events?: PlotLinearregressioninterceptPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.animation
 */
export interface PlotLinearregressioninterceptStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.halo
 */
export interface PlotLinearregressioninterceptStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker
 */
export interface PlotLinearregressioninterceptStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states
     */
    states?: PlotLinearregressioninterceptStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover.animation
 */
export interface PlotLinearregressioninterceptStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover
 */
export interface PlotLinearregressioninterceptStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressioninterceptStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.normal
 */
export interface PlotLinearregressioninterceptStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states
 */
export interface PlotLinearregressioninterceptStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.hover
     */
    hover?: PlotLinearregressioninterceptStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.normal
     */
    normal?: PlotLinearregressioninterceptStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.select
     */
    select?: PlotLinearregressioninterceptStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.select
 */
export interface PlotLinearregressioninterceptStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover
 */
export interface PlotLinearregressioninterceptStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressioninterceptStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.halo
     */
    halo?: PlotLinearregressioninterceptStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover.marker
     */
    marker?: PlotLinearregressioninterceptStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.normal
 */
export interface PlotLinearregressioninterceptStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states
 */
export interface PlotLinearregressioninterceptStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.hover
     */
    hover?: PlotLinearregressioninterceptStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.normal
     */
    normal?: PlotLinearregressioninterceptStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.select
     */
    select?: PlotLinearregressioninterceptStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.animation
 */
export interface PlotLinearregressioninterceptStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.halo
 */
export interface PlotLinearregressioninterceptStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker
 */
export interface PlotLinearregressioninterceptStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states
     */
    states?: PlotLinearregressioninterceptStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover.animation
 */
export interface PlotLinearregressioninterceptStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover
 */
export interface PlotLinearregressioninterceptStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressioninterceptStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.normal
 */
export interface PlotLinearregressioninterceptStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states
 */
export interface PlotLinearregressioninterceptStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.hover
     */
    hover?: PlotLinearregressioninterceptStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.normal
     */
    normal?: PlotLinearregressioninterceptStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.select
     */
    select?: PlotLinearregressioninterceptStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.select
 */
export interface PlotLinearregressioninterceptStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.select
 */
export interface PlotLinearregressioninterceptStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressioninterceptStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionintercept.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.halo
     */
    halo?: PlotLinearregressioninterceptStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.states.select.marker
     */
    marker?: PlotLinearregressioninterceptStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.tooltip.dateTimeLabelFormats
 */
export interface PlotLinearregressioninterceptTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip
 */
export interface PlotLinearregressioninterceptTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotLinearregressioninterceptTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionintercept.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.zones
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.zones
 */
export interface PlotLinearregressioninterceptZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionintercept.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.label
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.label
 * @see https://api.highcharts.com/gantt/plotOptions.linearregression.label
 */
export interface PlotLinearregressionLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.lastPrice
 */
export interface PlotLinearregressionLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotLinearregressionLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.lastVisiblePrice
 */
export interface PlotLinearregressionLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotLinearregressionLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker
 */
export interface PlotLinearregressionMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states
     */
    states?: PlotLinearregressionMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover.animation
 */
export interface PlotLinearregressionMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover
 */
export interface PlotLinearregressionMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.normal
 */
export interface PlotLinearregressionMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states
 */
export interface PlotLinearregressionMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.hover
     */
    hover?: PlotLinearregressionMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.normal
     */
    normal?: PlotLinearregressionMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.select
     */
    select?: PlotLinearregressionMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.select
 */
export interface PlotLinearregressionMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Linear regression indicator. This series requires `linkedTo`
 * option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `linearregression` series are defined in
 * plotOptions.linearregression.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression
 */
export interface PlotLinearregressionOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.connectors
     */
    connectors?: PlotLinearregressionConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataGrouping
     */
    dataGrouping?: PlotLinearregressionDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dataLabels
     */
    dataLabels?: PlotLinearregressionDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.dragDrop
     */
    dragDrop?: PlotLinearregressionDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.events
     */
    events?: PlotLinearregressionEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.label
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.label
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.label
     */
    label?: PlotLinearregressionLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.lastPrice
     */
    lastPrice?: PlotLinearregressionLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.lastVisiblePrice
     */
    lastVisiblePrice?: PlotLinearregressionLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.marker
     */
    marker?: PlotLinearregressionMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.params
     */
    params?: PlotLinearregressionParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point
     */
    point?: PlotLinearregressionPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states
     */
    states?: PlotLinearregressionStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.step
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip
     */
    tooltip?: PlotLinearregressionTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.zones
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.zones
     */
    zones?: Array<PlotLinearregressionZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.params
 */
export interface PlotLinearregressionParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.params.period
     */
    period?: number;
    /**
     * (Highstock) Unit (in milliseconds) for the x axis distances used to
     * compute the regression line paramters (slope & intercept) for every
     * range. In Highstock the x axis values are always represented in
     * milliseconds which may cause that distances between points are "big"
     * integer numbers.
     *
     * Highstock's linear regression algorithm (least squares method) will
     * utilize these "big" integers for finding the slope and the intercept of
     * the regression line for each period. In consequence, this value may be a
     * very "small" decimal number that's hard to interpret by a human.
     *
     * For instance: `xAxisUnit` equealed to `86400000` ms (1 day) forces the
     * algorithm to treat `86400000` as `1` while computing the slope and the
     * intercept. This may enchance the legiblitity of the indicator's values.
     *
     * Default value is the closest distance between two data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.params.xAxisUnit
     */
    xAxisUnit?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events
 */
export interface PlotLinearregressionPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point
 */
export interface PlotLinearregressionPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.point.events
     */
    events?: PlotLinearregressionPointEventsOptions;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.animation
 */
export interface PlotLinearregressionslopeAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker
 */
export interface PlotLinearregressionslopeConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker
 */
export interface PlotLinearregressionslopeConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors
 */
export interface PlotLinearregressionslopeConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.endMarker
     */
    endMarker?: PlotLinearregressionslopeConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.marker
     */
    marker?: PlotLinearregressionslopeConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker
     */
    startMarker?: PlotLinearregressionslopeConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker
 */
export interface PlotLinearregressionslopeConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataGrouping
 */
export interface PlotLinearregressionslopeDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.filter
 */
export interface PlotLinearregressionslopeDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels
 */
export interface PlotLinearregressionslopeDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.filter
     */
    filter?: PlotLinearregressionslopeDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragHandle
 */
export interface PlotLinearregressionslopeDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.guideBox.default
 */
export interface PlotLinearregressionslopeDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.guideBox
 */
export interface PlotLinearregressionslopeDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.guideBox.default
     */
    default?: PlotLinearregressionslopeDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop
 */
export interface PlotLinearregressionslopeDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragHandle
     */
    dragHandle?: PlotLinearregressionslopeDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.guideBox
     */
    guideBox?: (PlotLinearregressionslopeDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.events
 */
export interface PlotLinearregressionslopeEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.label
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.label
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.label
 */
export interface PlotLinearregressionslopeLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.lastPrice
 */
export interface PlotLinearregressionslopeLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotLinearregressionslopeLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.lastVisiblePrice
 */
export interface PlotLinearregressionslopeLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotLinearregressionslopeLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker
 */
export interface PlotLinearregressionslopeMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states
     */
    states?: PlotLinearregressionslopeMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover.animation
 */
export interface PlotLinearregressionslopeMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover
 */
export interface PlotLinearregressionslopeMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionslopeMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.normal
 */
export interface PlotLinearregressionslopeMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states
 */
export interface PlotLinearregressionslopeMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.hover
     */
    hover?: PlotLinearregressionslopeMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.normal
     */
    normal?: PlotLinearregressionslopeMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.select
     */
    select?: PlotLinearregressionslopeMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.select
 */
export interface PlotLinearregressionslopeMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Linear regression slope indicator. This series requires
 * `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `linearregressionslope` series are defined in
 * plotOptions.linearregressionslope.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope
 */
export interface PlotLinearregressionslopeOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionslopeAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.connectors
     */
    connectors?: PlotLinearregressionslopeConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataGrouping
     */
    dataGrouping?: PlotLinearregressionslopeDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dataLabels
     */
    dataLabels?: PlotLinearregressionslopeDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.dragDrop
     */
    dragDrop?: PlotLinearregressionslopeDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.events
     */
    events?: PlotLinearregressionslopeEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.label
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.label
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.label
     */
    label?: PlotLinearregressionslopeLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.lastPrice
     */
    lastPrice?: PlotLinearregressionslopeLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.lastVisiblePrice
     */
    lastVisiblePrice?: PlotLinearregressionslopeLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.marker
     */
    marker?: PlotLinearregressionslopeMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.params
     */
    params?: PlotLinearregressionslopeParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point
     */
    point?: PlotLinearregressionslopePointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states
     */
    states?: PlotLinearregressionslopeStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.step
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip
     */
    tooltip?: PlotLinearregressionslopeTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.zones
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.zones
     */
    zones?: Array<PlotLinearregressionslopeZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.params
 */
export interface PlotLinearregressionslopeParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.params.period
     */
    period?: number;
    /**
     * (Highstock) Unit (in milliseconds) for the x axis distances used to
     * compute the regression line paramters (slope & intercept) for every
     * range. In Highstock the x axis values are always represented in
     * milliseconds which may cause that distances between points are "big"
     * integer numbers.
     *
     * Highstock's linear regression algorithm (least squares method) will
     * utilize these "big" integers for finding the slope and the intercept of
     * the regression line for each period. In consequence, this value may be a
     * very "small" decimal number that's hard to interpret by a human.
     *
     * For instance: `xAxisUnit` equealed to `86400000` ms (1 day) forces the
     * algorithm to treat `86400000` as `1` while computing the slope and the
     * intercept. This may enchance the legiblitity of the indicator's values.
     *
     * Default value is the closest distance between two data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.params.xAxisUnit
     */
    xAxisUnit?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events
 */
export interface PlotLinearregressionslopePointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point
 */
export interface PlotLinearregressionslopePointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.point.events
     */
    events?: PlotLinearregressionslopePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.animation
 */
export interface PlotLinearregressionslopeStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.halo
 */
export interface PlotLinearregressionslopeStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker
 */
export interface PlotLinearregressionslopeStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states
     */
    states?: PlotLinearregressionslopeStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover.animation
 */
export interface PlotLinearregressionslopeStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover
 */
export interface PlotLinearregressionslopeStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionslopeStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.normal
 */
export interface PlotLinearregressionslopeStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states
 */
export interface PlotLinearregressionslopeStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.hover
     */
    hover?: PlotLinearregressionslopeStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.normal
     */
    normal?: PlotLinearregressionslopeStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.select
     */
    select?: PlotLinearregressionslopeStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.select
 */
export interface PlotLinearregressionslopeStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover
 */
export interface PlotLinearregressionslopeStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionslopeStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.halo
     */
    halo?: PlotLinearregressionslopeStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover.marker
     */
    marker?: PlotLinearregressionslopeStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.normal
 */
export interface PlotLinearregressionslopeStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states
 */
export interface PlotLinearregressionslopeStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.hover
     */
    hover?: PlotLinearregressionslopeStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.normal
     */
    normal?: PlotLinearregressionslopeStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.select
     */
    select?: PlotLinearregressionslopeStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.animation
 */
export interface PlotLinearregressionslopeStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.halo
 */
export interface PlotLinearregressionslopeStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker
 */
export interface PlotLinearregressionslopeStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states
     */
    states?: PlotLinearregressionslopeStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover.animation
 */
export interface PlotLinearregressionslopeStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover
 */
export interface PlotLinearregressionslopeStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionslopeStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.normal
 */
export interface PlotLinearregressionslopeStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states
 */
export interface PlotLinearregressionslopeStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.hover
     */
    hover?: PlotLinearregressionslopeStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.normal
     */
    normal?: PlotLinearregressionslopeStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.select
     */
    select?: PlotLinearregressionslopeStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.select
 */
export interface PlotLinearregressionslopeStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.select
 */
export interface PlotLinearregressionslopeStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionslopeStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregressionslope.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.halo
     */
    halo?: PlotLinearregressionslopeStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.states.select.marker
     */
    marker?: PlotLinearregressionslopeStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.tooltip.dateTimeLabelFormats
 */
export interface PlotLinearregressionslopeTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip
 */
export interface PlotLinearregressionslopeTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotLinearregressionslopeTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.linearregressionslope.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.zones
 * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.zones
 */
export interface PlotLinearregressionslopeZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregressionslope.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.animation
 */
export interface PlotLinearregressionStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.halo
 */
export interface PlotLinearregressionStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker
 */
export interface PlotLinearregressionStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states
     */
    states?: PlotLinearregressionStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover.animation
 */
export interface PlotLinearregressionStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover
 */
export interface PlotLinearregressionStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.normal
 */
export interface PlotLinearregressionStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states
 */
export interface PlotLinearregressionStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.hover
     */
    hover?: PlotLinearregressionStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.normal
     */
    normal?: PlotLinearregressionStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.select
     */
    select?: PlotLinearregressionStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.select
 */
export interface PlotLinearregressionStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover
 */
export interface PlotLinearregressionStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.halo
     */
    halo?: PlotLinearregressionStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover.marker
     */
    marker?: PlotLinearregressionStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.normal
 */
export interface PlotLinearregressionStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states
 */
export interface PlotLinearregressionStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.hover
     */
    hover?: PlotLinearregressionStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.normal
     */
    normal?: PlotLinearregressionStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.select
     */
    select?: PlotLinearregressionStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.animation
 */
export interface PlotLinearregressionStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.halo
 */
export interface PlotLinearregressionStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker
 */
export interface PlotLinearregressionStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states
     */
    states?: PlotLinearregressionStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover.animation
 */
export interface PlotLinearregressionStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover
 */
export interface PlotLinearregressionStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.normal
 */
export interface PlotLinearregressionStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states
 */
export interface PlotLinearregressionStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.hover
     */
    hover?: PlotLinearregressionStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.normal
     */
    normal?: PlotLinearregressionStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.select
     */
    select?: PlotLinearregressionStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.select
 */
export interface PlotLinearregressionStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.select
 */
export interface PlotLinearregressionStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLinearregressionStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.linearregression.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.halo
     */
    halo?: PlotLinearregressionStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.states.select.marker
     */
    marker?: PlotLinearregressionStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.linearregression.tooltip.dateTimeLabelFormats
 */
export interface PlotLinearregressionTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip
 */
export interface PlotLinearregressionTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotLinearregressionTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.linearregression.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.zones
 * @see https://api.highcharts.com/highstock/plotOptions.linearregression.zones
 */
export interface PlotLinearregressionZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.linearregression.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression.zones.value
     */
    value?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker
 */
export interface PlotLineConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker
 */
export interface PlotLineConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.line.connectors
 */
export interface PlotLineConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.endMarker
     */
    endMarker?: PlotLineConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.marker
     */
    marker?: PlotLineConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker
     */
    startMarker?: PlotLineConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker
 */
export interface PlotLineConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.line.dataGrouping
 */
export interface PlotLineDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.filter
 */
export interface PlotLineDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels
 */
export interface PlotLineDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.line.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.filter
     */
    filter?: PlotLineDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragHandle
 */
export interface PlotLineDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.guideBox.default
 */
export interface PlotLineDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.guideBox
 */
export interface PlotLineDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.guideBox.default
     */
    default?: PlotLineDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop
 */
export interface PlotLineDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragHandle
     */
    dragHandle?: PlotLineDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.guideBox
     */
    guideBox?: (PlotLineDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.events
 * @see https://api.highcharts.com/highstock/plotOptions.line.events
 */
export interface PlotLineEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.line.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.line.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.line.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.line.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.line.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.line.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.line.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.line.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.line.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.label
 * @see https://api.highcharts.com/highstock/plotOptions.line.label
 * @see https://api.highcharts.com/gantt/plotOptions.line.label
 */
export interface PlotLineLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.line.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.line.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.line.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.line.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.line.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.line.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.line.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.line.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.line.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.line.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.line.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.line.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.line.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.line.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.line.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.line.lastPrice
 */
export interface PlotLineLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotLineLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.line.lastVisiblePrice
 */
export interface PlotLineLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotLineLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.marker
 * @see https://api.highcharts.com/highstock/plotOptions.line.marker
 */
export interface PlotLineMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states
     */
    states?: PlotLineMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover.animation
 */
export interface PlotLineMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover
 */
export interface PlotLineMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLineMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.normal
 */
export interface PlotLineMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states
 */
export interface PlotLineMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.hover
     */
    hover?: PlotLineMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.normal
     */
    normal?: PlotLineMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.select
     */
    select?: PlotLineMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.select
 */
export interface PlotLineMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) A line series displays information as a series of
 * data points connected by straight line segments.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `line` series are defined in plotOptions.line.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line
 * @see https://api.highcharts.com/highstock/plotOptions.line
 */
export interface PlotLineOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.line.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.animation
     * @see https://api.highcharts.com/highstock/plotOptions.line.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLineAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.line.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.line.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.className
     * @see https://api.highcharts.com/highstock/plotOptions.line.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.clip
     * @see https://api.highcharts.com/highstock/plotOptions.line.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.color
     * @see https://api.highcharts.com/highstock/plotOptions.line.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.line.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.line.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.line.connectors
     */
    connectors?: PlotLineConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.line.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.line.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph,
     * or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.line.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataGrouping
     */
    dataGrouping?: PlotLineDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.line.dataLabels
     */
    dataLabels?: PlotLineDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.description
     * @see https://api.highcharts.com/highstock/plotOptions.line.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.line.dragDrop
     */
    dragDrop?: PlotLineDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.line.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.events
     * @see https://api.highcharts.com/highstock/plotOptions.line.events
     */
    events?: PlotLineEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.line.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.line.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.line.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.line.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.keys
     * @see https://api.highcharts.com/highstock/plotOptions.line.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.label
     * @see https://api.highcharts.com/highstock/plotOptions.line.label
     * @see https://api.highcharts.com/gantt/plotOptions.line.label
     */
    label?: PlotLineLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.lastPrice
     */
    lastPrice?: PlotLineLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.lastVisiblePrice
     */
    lastVisiblePrice?: PlotLineLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.line.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.line.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.line.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.marker
     * @see https://api.highcharts.com/highstock/plotOptions.line.marker
     */
    marker?: PlotLineMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point
     * @see https://api.highcharts.com/highstock/plotOptions.line.point
     */
    point?: PlotLinePointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.line.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.line.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.line.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.line.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.line.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.line.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.line.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.line.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.line.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.selected
     * @see https://api.highcharts.com/highstock/plotOptions.line.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) Whether to apply a drop shadow to the graph line.
     * Since 2.3 the shadow can be an object configuration containing `color`,
     * `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.line.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.line.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.line.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.line.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.line.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.line.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states
     * @see https://api.highcharts.com/highstock/plotOptions.line.states
     */
    states?: PlotLineStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.step
     * @see https://api.highcharts.com/highstock/plotOptions.line.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.line.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.line.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip
     */
    tooltip?: PlotLineTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.line.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.line.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) The parameter allows setting line series type and use OHLC
     * indicators. Data in OHLC format is required.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.useOhlcData
     */
    useOhlcData?: boolean;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.visible
     * @see https://api.highcharts.com/highstock/plotOptions.line.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.line.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.zones
     * @see https://api.highcharts.com/highstock/plotOptions.line.zones
     */
    zones?: Array<PlotLineZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.line.point.events
 */
export interface PlotLinePointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.point
 * @see https://api.highcharts.com/highstock/plotOptions.line.point
 */
export interface PlotLinePointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.line.point.events
     */
    events?: PlotLinePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.animation
 */
export interface PlotLineStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.halo
 */
export interface PlotLineStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker
 */
export interface PlotLineStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states
     */
    states?: PlotLineStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover.animation
 */
export interface PlotLineStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover
 */
export interface PlotLineStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLineStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.normal
 */
export interface PlotLineStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states
 */
export interface PlotLineStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.hover
     */
    hover?: PlotLineStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.normal
     */
    normal?: PlotLineStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.select
     */
    select?: PlotLineStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.select
 */
export interface PlotLineStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover
 */
export interface PlotLineStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLineStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.halo
     */
    halo?: PlotLineStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover.marker
     */
    marker?: PlotLineStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.line.states.normal
 */
export interface PlotLineStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states
 * @see https://api.highcharts.com/highstock/plotOptions.line.states
 */
export interface PlotLineStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.hover
     */
    hover?: PlotLineStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.normal
     */
    normal?: PlotLineStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.select
     */
    select?: PlotLineStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.animation
 */
export interface PlotLineStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.halo
 */
export interface PlotLineStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker
 */
export interface PlotLineStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states
     */
    states?: PlotLineStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover.animation
 */
export interface PlotLineStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover
 */
export interface PlotLineStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLineStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.normal
 */
export interface PlotLineStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states
 */
export interface PlotLineStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.hover
     */
    hover?: PlotLineStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.normal
     */
    normal?: PlotLineStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.select
     */
    select?: PlotLineStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.select
 */
export interface PlotLineStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.line.states.select
 */
export interface PlotLineStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotLineStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.line.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.halo
     */
    halo?: PlotLineStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.line.states.select.marker
     */
    marker?: PlotLineStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.line.tooltip.dateTimeLabelFormats
 */
export interface PlotLineTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip
 */
export interface PlotLineTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.line.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotLineTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.line.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.line.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.line.zones
 * @see https://api.highcharts.com/highstock/plotOptions.line.zones
 */
export interface PlotLineZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.line.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.line.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.line.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.line.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.line.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.animation
 */
export interface PlotMacdAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker
 */
export interface PlotMacdConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker
 */
export interface PlotMacdConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors
 */
export interface PlotMacdConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.endMarker
     */
    endMarker?: PlotMacdConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.marker
     */
    marker?: PlotMacdConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker
     */
    startMarker?: PlotMacdConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker
 */
export interface PlotMacdConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.dataGrouping
 */
export interface PlotMacdDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.filter
 */
export interface PlotMacdDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels
 */
export interface PlotMacdDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.macd.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.filter
     */
    filter?: PlotMacdDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragHandle
 */
export interface PlotMacdDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.guideBox.default
 */
export interface PlotMacdDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.guideBox
 */
export interface PlotMacdDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.guideBox.default
     */
    default?: PlotMacdDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop
 */
export interface PlotMacdDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragHandle
     */
    dragHandle?: PlotMacdDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.guideBox
     */
    guideBox?: (PlotMacdDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.events
 */
export interface PlotMacdEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.macd.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.macd.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.label
 * @see https://api.highcharts.com/highstock/plotOptions.macd.label
 * @see https://api.highcharts.com/gantt/plotOptions.macd.label
 */
export interface PlotMacdLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.macd.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.macd.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.macd.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.macd.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.macd.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.macd.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.macd.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.macd.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.macd.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.macd.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.macd.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.macd.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.macd.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.macd.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.macd.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.macd.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.lastPrice
 */
export interface PlotMacdLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotMacdLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.lastVisiblePrice
 */
export interface PlotMacdLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotMacdLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) The styles for macd line
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine
 */
export interface PlotMacdMacdLineOptions {
    styles?: PlotMacdMacdLineStylesOptions;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.macdLine.zones
     * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine.zones
     */
    zones?: Array<PlotMacdMacdLineZonesOptions>;
}
export interface PlotMacdMacdLineStylesOptions {
    /**
     * (Highstock) Color of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.macdLine.zones
 * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine.zones
 */
export interface PlotMacdMacdLineZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.macdLine.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.macdLine.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.macdLine.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.macdLine.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.macdLine.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.marker
 */
export interface PlotMacdMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states
     */
    states?: PlotMacdMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover.animation
 */
export interface PlotMacdMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover
 */
export interface PlotMacdMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMacdMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.normal
 */
export interface PlotMacdMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states
 */
export interface PlotMacdMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.hover
     */
    hover?: PlotMacdMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.normal
     */
    normal?: PlotMacdMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.select
     */
    select?: PlotMacdMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.select
 */
export interface PlotMacdMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Moving Average Convergence Divergence (MACD). This series
 * requires `linkedTo` option to be set and should be loaded after the
 * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `macd` series are defined in plotOptions.macd.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd
 */
export interface PlotMacdOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMacdAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.macd.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.macd.connectors
     */
    connectors?: PlotMacdConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.macd.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataGrouping
     */
    dataGrouping?: PlotMacdDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dataLabels
     */
    dataLabels?: PlotMacdDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.dragDrop
     */
    dragDrop?: PlotMacdDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.events
     */
    events?: PlotMacdEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.macd.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.macd.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    groupPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.label
     * @see https://api.highcharts.com/highstock/plotOptions.macd.label
     * @see https://api.highcharts.com/gantt/plotOptions.macd.label
     */
    label?: PlotMacdLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.lastPrice
     */
    lastPrice?: PlotMacdLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.lastVisiblePrice
     */
    lastVisiblePrice?: PlotMacdLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.macd.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.macd.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.macd.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.macd.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) The styles for macd line
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.macdLine
     */
    macdLine?: PlotMacdMacdLineOptions;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.marker
     */
    marker?: PlotMacdMarkerOptions;
    minPointLength?: number;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.params
     */
    params?: PlotMacdParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point
     */
    point?: PlotMacdPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    pointPadding?: number;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) The styles for signal line
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine
     */
    signalLine?: PlotMacdSignalLineOptions;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.macd.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states
     */
    states?: PlotMacdStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.step
     * @see https://api.highcharts.com/highstock/plotOptions.macd.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.macd.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip
     */
    tooltip?: PlotMacdTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.macd.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.macd.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.macd.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.zones
     * @see https://api.highcharts.com/highstock/plotOptions.macd.zones
     */
    zones?: Array<PlotMacdZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.params
 */
export interface PlotMacdParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.params.index
     */
    index?: number;
    /**
     * (Highstock) The long period for indicator calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.params.longPeriod
     */
    longPeriod?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.params.period
     */
    period?: number;
    /**
     * (Highstock) The short period for indicator calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.params.shortPeriod
     */
    shortPeriod?: number;
    /**
     * (Highstock) The base period for signal calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.params.signalPeriod
     */
    signalPeriod?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events
 */
export interface PlotMacdPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.point
 */
export interface PlotMacdPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.point.events
     */
    events?: PlotMacdPointEventsOptions;
}
/**
 * (Highstock) The styles for signal line
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine
 */
export interface PlotMacdSignalLineOptions {
    styles?: PlotMacdSignalLineStylesOptions;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.signalLine.zones
     * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine.zones
     */
    zones?: Array<PlotMacdSignalLineZonesOptions>;
}
export interface PlotMacdSignalLineStylesOptions {
    /**
     * (Highstock) Color of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.signalLine.zones
 * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine.zones
 */
export interface PlotMacdSignalLineZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.signalLine.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.signalLine.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.signalLine.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.signalLine.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.signalLine.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.macd.signalLine.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.animation
 */
export interface PlotMacdStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.halo
 */
export interface PlotMacdStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker
 */
export interface PlotMacdStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states
     */
    states?: PlotMacdStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover.animation
 */
export interface PlotMacdStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover
 */
export interface PlotMacdStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMacdStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.normal
 */
export interface PlotMacdStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states
 */
export interface PlotMacdStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.hover
     */
    hover?: PlotMacdStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.normal
     */
    normal?: PlotMacdStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.select
     */
    select?: PlotMacdStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.select
 */
export interface PlotMacdStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover
 */
export interface PlotMacdStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMacdStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.halo
     */
    halo?: PlotMacdStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover.marker
     */
    marker?: PlotMacdStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.normal
 */
export interface PlotMacdStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states
 */
export interface PlotMacdStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.hover
     */
    hover?: PlotMacdStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.normal
     */
    normal?: PlotMacdStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.select
     */
    select?: PlotMacdStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.animation
 */
export interface PlotMacdStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.halo
 */
export interface PlotMacdStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker
 */
export interface PlotMacdStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states
     */
    states?: PlotMacdStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover.animation
 */
export interface PlotMacdStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover
 */
export interface PlotMacdStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMacdStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.normal
 */
export interface PlotMacdStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states
 */
export interface PlotMacdStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.hover
     */
    hover?: PlotMacdStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.normal
     */
    normal?: PlotMacdStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.select
     */
    select?: PlotMacdStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.select
 */
export interface PlotMacdStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.select
 */
export interface PlotMacdStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMacdStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.macd.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.halo
     */
    halo?: PlotMacdStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.macd.states.select.marker
     */
    marker?: PlotMacdStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.macd.tooltip.dateTimeLabelFormats
 */
export interface PlotMacdTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip
 */
export interface PlotMacdTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.macd.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotMacdTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.macd.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.macd.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.macd.zones
 * @see https://api.highcharts.com/highstock/plotOptions.macd.zones
 */
export interface PlotMacdZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.macd.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.macd.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.macd.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.macd.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.macd.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.macd.zones.value
     */
    value?: number;
}
/**
 * (Highmaps) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.animation
 */
export interface PlotMapAnimationOptions {
    duration?: number;
}
/**
 * (Highmaps) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.animation
 */
export interface PlotMapbubbleAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker
 */
export interface PlotMapbubbleConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker
 */
export interface PlotMapbubbleConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors
 */
export interface PlotMapbubbleConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.endMarker
     */
    endMarker?: PlotMapbubbleConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.marker
     */
    marker?: PlotMapbubbleConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker
     */
    startMarker?: PlotMapbubbleConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker
 */
export interface PlotMapbubbleConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataGrouping
 */
export interface PlotMapbubbleDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highmaps) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.filter
 */
export interface PlotMapbubbleDataLabelsFilterOptions {
    /**
     * (Highmaps) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highmaps) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highmaps) The value to compare against.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highmaps) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels
 */
export interface PlotMapbubbleDataLabelsOptions {
    /**
     * (Highmaps) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highmaps) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highmaps) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highmaps) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.className
     */
    className?: string;
    /**
     * (Highmaps) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Whether to hide data labels that are outside the plot area. By
     * default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highmaps) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highmaps) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.filter
     */
    filter?: PlotMapbubbleDataLabelsFilterOptions;
    /**
     * (Highmaps) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.format
     */
    format?: string;
    /**
     * (Highmaps) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highmaps) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highmaps) How to handle data labels that flow outside the plot area. The
     * default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highmaps) When either the `borderWidth` or the `backgroundColor` is set,
     * this is the padding within the box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highmaps) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highmaps) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highmaps) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highmaps) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highmaps) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highmaps) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highmaps) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.x
     */
    x?: number;
    /**
     * (Highmaps) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.y
     */
    y?: number;
    /**
     * (Highmaps) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragHandle
 */
export interface PlotMapbubbleDragDropDragHandleOptions {
    /**
     * (Highmaps) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highmaps) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highmaps) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highmaps) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highmaps) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.guideBox.default
 */
export interface PlotMapbubbleDragDropGuideBoxDefaultOptions {
    /**
     * (Highmaps) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highmaps) Guide box fill color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Guide box cursor.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highmaps) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.guideBox
 */
export interface PlotMapbubbleDragDropGuideBoxOptions {
    /**
     * (Highmaps) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.guideBox.default
     */
    default?: PlotMapbubbleDragDropGuideBoxDefaultOptions;
}
/**
 * (Highmaps) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop
 */
export interface PlotMapbubbleDragDropOptions {
    /**
     * (Highmaps) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highmaps) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highmaps) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragHandle
     */
    dragHandle?: PlotMapbubbleDragDropDragHandleOptions;
    /**
     * (Highmaps) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highmaps) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highmaps) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highmaps) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highmaps) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highmaps) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highmaps) The amount of pixels to drag the pointer before it counts as a
     * drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highmaps) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highmaps) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.guideBox
     */
    guideBox?: (PlotMapbubbleDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highmaps) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highmaps) General event handlers for the series items. These event hooks can
 * also be attached to the series at run time using the `Highcharts.addEvent`
 * function.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.events
 */
export interface PlotMapbubbleEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highmaps) Fires when the checkbox next to the series' name in the legend
     * is clicked. One parameter, `event`, is passed to the function. The state
     * of the checkbox is found by `event.checked`. The checked item is found by
     * `event.item`. Return `false` to prevent the default action which is to
     * toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highmaps) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highmaps) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.events.hide
     */
    hide?: () => void;
    /**
     * (Highmaps) Fires when the legend item belonging to the series is clicked.
     * One parameter, `event`, is passed to the function. The default action is
     * to toggle the visibility of the series. This can be prevented by
     * returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highmaps) Fires when the mouse leaves the graph. One parameter, `event`,
     * is passed to the function, containing common event information. If the
     * stickyTracking option is true, `mouseOut` doesn't happen before the mouse
     * enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highmaps) Fires when the mouse enters the graph. One parameter, `event`,
     * is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highmaps) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.label
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.label
 * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.label
 */
export interface PlotMapbubbleLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.lastPrice
 */
export interface PlotMapbubbleLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotMapbubbleLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.lastVisiblePrice
 */
export interface PlotMapbubbleLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotMapbubbleLastVisiblePriceLabelOptions;
}
/**
 * (Highmaps) Options for the point markers of line-like series. Properties like
 * `fillColor`, `lineColor` and `lineWidth` define the visual appearance of the
 * markers. Other series types, like column series, don't have markers, but have
 * visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker
 */
export interface PlotMapbubbleMarkerOptions {
    /**
     * (Highmaps) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The fill opacity of the bubble markers.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.fillOpacity
     */
    fillOpacity?: number;
    /**
     * (Highmaps) The color of the point marker's outline. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.lineColor
     */
    lineColor?: any;
    /**
     * (Highmaps) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) States for a single point marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states
     */
    states?: PlotMapbubbleMarkerStatesOptions;
    /**
     * (Highmaps) A predefined shape or symbol for the marker. Possible values
     * are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on the form
     * `url(graphic.png)`. Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.symbol
     */
    symbol?: ("circle"|"diamond"|"square"|"triangle"|"triangle-down");
}
/**
 * (Highmaps) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover.animation
 */
export interface PlotMapbubbleMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highmaps) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover
 */
export interface PlotMapbubbleMarkerStatesHoverOptions {
    /**
     * (Highmaps) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMapbubbleMarkerStatesHoverAnimationOptions);
    /**
     * (Highmaps) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highmaps) The fill color of the marker in hover state. When `undefined`,
     * the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The color of the point marker's outline. When `undefined`, the
     * series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) The width of the point marker's outline. When `undefined`, the
     * series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highmaps) The radius of the point marker. In hover state, it defaults to
     * the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highmaps) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highmaps) The normal state of a single point marker. Currently only used for
 * setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.normal
 */
export interface PlotMapbubbleMarkerStatesNormalOptions {
    /**
     * (Highmaps) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highmaps) States for a single point marker.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states
 */
export interface PlotMapbubbleMarkerStatesOptions {
    /**
     * (Highmaps) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.hover
     */
    hover?: PlotMapbubbleMarkerStatesHoverOptions;
    /**
     * (Highmaps) The normal state of a single point marker. Currently only used
     * for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.normal
     */
    normal?: PlotMapbubbleMarkerStatesNormalOptions;
    /**
     * (Highmaps) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.select
     */
    select?: PlotMapbubbleMarkerStatesSelectOptions;
}
/**
 * (Highmaps) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.select
 */
export interface PlotMapbubbleMarkerStatesSelectOptions {
    /**
     * (Highmaps) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highmaps) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The color of the point marker's outline. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) The radius of the point marker. In hover state, it defaults to
     * the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) A map bubble series is a bubble series laid out on top of a map
 * series, where each bubble is tied to a specific map area.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `mapbubble` series are defined in plotOptions.mapbubble.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble
 */
export interface PlotMapbubbleOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highmaps) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highmaps) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMapbubbleAnimationOptions);
    /**
     * (Highmaps) If there are more points in the series than the
     * `animationLimit`, the animation won't run. Animation affects overall
     * performance and doesn't work well with heavy data series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highmaps) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.className
     */
    className?: string;
    /**
     * (Highmaps) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.clip
     */
    clip?: boolean;
    /**
     * (Highmaps) The main color of the series. This color affects both the fill
     * and the stroke of the bubble. For enhanced control, use `marker` options.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highmaps) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.connectors
     */
    connectors?: PlotMapbubbleConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highmaps) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highmaps) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.dataGrouping
     */
    dataGrouping?: PlotMapbubbleDataGroupingOptions;
    /**
     * (Highmaps) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dataLabels
     */
    dataLabels?: PlotMapbubbleDataLabelsOptions;
    /**
     * (Highmaps) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.description
     */
    description?: string;
    /**
     * (Highmaps) Whether to display negative sized bubbles. The threshold is
     * given by the zThreshold option, and negative bubbles can be visualized by
     * setting negativeColor.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.displayNegative
     */
    displayNegative?: boolean;
    /**
     * (Highmaps) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.dragDrop
     */
    dragDrop?: PlotMapbubbleDragDropOptions;
    /**
     * (Highmaps) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highmaps) General event handlers for the series items. These event hooks
     * can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.events
     */
    events?: PlotMapbubbleEventsOptions;
    /**
     * (Highmaps) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highmaps) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highmaps) An array specifying which option maps to which key in the data
     * point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.label
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.label
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.label
     */
    label?: PlotMapbubbleLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.lastPrice
     */
    lastPrice?: PlotMapbubbleLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.lastVisiblePrice
     */
    lastVisiblePrice?: PlotMapbubbleLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) The width of the line connecting the data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highmaps) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.marker
     */
    marker?: PlotMapbubbleMarkerOptions;
    /**
     * (Highcharts, Highstock) Maximum bubble size. Bubbles will automatically
     * size between the `minSize` and `maxSize` to reflect the `z` value of each
     * bubble. Can be either pixels (when no unit is given), or a percentage of
     * the smallest one of the plot width and height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.maxSize
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.maxSize
     */
    maxSize?: (number|string);
    /**
     * (Highcharts, Highstock) Minimum bubble size. Bubbles will automatically
     * size between the `minSize` and `maxSize` to reflect the `z` value of each
     * bubble. Can be either pixels (when no unit is given), or a percentage of
     * the smallest one of the plot width and height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.minSize
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.minSize
     */
    minSize?: (number|string);
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) When a point's Z value is below the zThreshold setting, this
     * color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.negativeColor
     */
    negativeColor?: ColorString;
    /**
     * (Highmaps) Properties for each single point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point
     */
    point?: PlotMapbubblePointOptions;
    /**
     * (Highmaps) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.pointStart
     */
    pointStart?: number;
    /**
     * (Highmaps) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.selected
     */
    selected?: boolean;
    /**
     * (Highmaps) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highmaps) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highmaps) Whether the bubble's value should be represented by the area
     * or the width of the bubble. The default, `area`, corresponds best to the
     * human perception of the size of each bubble.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.sizeBy
     */
    sizeBy?: ("area"|"width");
    /**
     * (Highcharts) When this is true, the absolute value of z determines the
     * size of the bubble. This means that with the default `zThreshold` of 0, a
     * bubble of value -1 will have the same size as a bubble of value 1, while
     * a bubble of value 0 will have a smaller size according to `minSize`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.sizeByAbsoluteValue
     */
    sizeByAbsoluteValue?: boolean;
    /**
     * (Highmaps) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) When this is true, the series will not cause the Y axis to
     * cross the zero plane (or threshold option) unless the data actually
     * crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highmaps) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states
     */
    states?: PlotMapbubbleStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.step
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip
     */
    tooltip?: PlotMapbubbleTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highmaps) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts) The minimum for the Z value range. Defaults to the highest Z
     * value in the data.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zMax
     */
    zMax?: number;
    /**
     * (Highcharts) The minimum for the Z value range. Defaults to the lowest Z
     * value in the data.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zMin
     */
    zMin?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zones
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.zones
     */
    zones?: Array<PlotMapbubbleZonesOptions>;
    /**
     * (Highcharts) When displayNegative is `false`, bubbles with lower Z values
     * are skipped. When `displayNegative` is `true` and a negativeColor is
     * given, points with lower Z is colored.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zThreshold
     */
    zThreshold?: number;
}
/**
 * (Highmaps) Events for each single point.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events
 */
export interface PlotMapbubblePointEventsOptions {
    /**
     * (Highmaps) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highmaps) Callback that fires while dragging a point. The mouse event is
     * passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highmaps) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highmaps) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highmaps) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highmaps) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highmaps) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highmaps) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events.select
     */
    select?: () => void;
    /**
     * (Highmaps) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highmaps) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events.update
     */
    update?: () => void;
}
/**
 * (Highmaps) Properties for each single point.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point
 */
export interface PlotMapbubblePointOptions {
    /**
     * (Highmaps) Events for each single point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.point.events
     */
    events?: PlotMapbubblePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.animation
 */
export interface PlotMapbubbleStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.halo
 */
export interface PlotMapbubbleStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker
 */
export interface PlotMapbubbleStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states
     */
    states?: PlotMapbubbleStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover.animation
 */
export interface PlotMapbubbleStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover
 */
export interface PlotMapbubbleStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMapbubbleStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.normal
 */
export interface PlotMapbubbleStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states
 */
export interface PlotMapbubbleStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.hover
     */
    hover?: PlotMapbubbleStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.normal
     */
    normal?: PlotMapbubbleStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.select
     */
    select?: PlotMapbubbleStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.select
 */
export interface PlotMapbubbleStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Options for the hovered series. These settings override the normal
 * state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.hover
 */
export interface PlotMapbubbleStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMapbubbleStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.halo
     */
    halo?: PlotMapbubbleStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.hover.marker
     */
    marker?: PlotMapbubbleStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.normal
 */
export interface PlotMapbubbleStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highmaps) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states
 */
export interface PlotMapbubbleStatesOptions {
    /**
     * (Highmaps) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.hover
     */
    hover?: PlotMapbubbleStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.normal
     */
    normal?: PlotMapbubbleStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.select
     */
    select?: PlotMapbubbleStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.animation
 */
export interface PlotMapbubbleStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.halo
 */
export interface PlotMapbubbleStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker
 */
export interface PlotMapbubbleStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states
     */
    states?: PlotMapbubbleStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover.animation
 */
export interface PlotMapbubbleStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover
 */
export interface PlotMapbubbleStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMapbubbleStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.normal
 */
export interface PlotMapbubbleStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states
 */
export interface PlotMapbubbleStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.hover
     */
    hover?: PlotMapbubbleStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.normal
     */
    normal?: PlotMapbubbleStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.select
     */
    select?: PlotMapbubbleStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.select
 */
export interface PlotMapbubbleStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.select
 */
export interface PlotMapbubbleStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMapbubbleStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.halo
     */
    halo?: PlotMapbubbleStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.states.select.marker
     */
    marker?: PlotMapbubbleStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.tooltip.dateTimeLabelFormats
 */
export interface PlotMapbubbleTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip
 */
export interface PlotMapbubbleTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotMapbubbleTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.mapbubble.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zones
 * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.zones
 */
export interface PlotMapbubbleZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapbubble.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.mapbubble.zones.value
     */
    value?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker
 */
export interface PlotMapConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker
 */
export interface PlotMapConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.map.connectors
 */
export interface PlotMapConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.endMarker
     */
    endMarker?: PlotMapConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.marker
     */
    marker?: PlotMapConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker
     */
    startMarker?: PlotMapConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker
 */
export interface PlotMapConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.map.dataGrouping
 */
export interface PlotMapDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highmaps) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.filter
 */
export interface PlotMapDataLabelsFilterOptions {
    /**
     * (Highmaps) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highmaps) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highmaps) The value to compare against.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highmaps) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels
 */
export interface PlotMapDataLabelsOptions {
    /**
     * (Highmaps) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highmaps) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highmaps) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highmaps) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.className
     */
    className?: string;
    /**
     * (Highmaps) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Whether to hide data labels that are outside the plot area. By
     * default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.map.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.map.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highmaps) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highmaps) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.filter
     */
    filter?: PlotMapDataLabelsFilterOptions;
    /**
     * (Highmaps) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.format
     */
    format?: string;
    /**
     * (Highmaps) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highmaps) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highmaps) How to handle data labels that flow outside the plot area. The
     * default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highmaps) When either the `borderWidth` or the `backgroundColor` is set,
     * this is the padding within the box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highmaps) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highmaps) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highmaps) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highmaps) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highmaps) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highmaps) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highmaps) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.x
     */
    x?: number;
    /**
     * (Highmaps) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.y
     */
    y?: number;
    /**
     * (Highmaps) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragHandle
 */
export interface PlotMapDragDropDragHandleOptions {
    /**
     * (Highmaps) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highmaps) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highmaps) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highmaps) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highmaps) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.guideBox.default
 */
export interface PlotMapDragDropGuideBoxDefaultOptions {
    /**
     * (Highmaps) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highmaps) Guide box fill color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Guide box cursor.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highmaps) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.guideBox
 */
export interface PlotMapDragDropGuideBoxOptions {
    /**
     * (Highmaps) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.guideBox.default
     */
    default?: PlotMapDragDropGuideBoxDefaultOptions;
}
/**
 * (Highmaps) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop
 */
export interface PlotMapDragDropOptions {
    /**
     * (Highmaps) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highmaps) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highmaps) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragHandle
     */
    dragHandle?: PlotMapDragDropDragHandleOptions;
    /**
     * (Highmaps) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highmaps) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highmaps) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highmaps) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highmaps) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highmaps) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highmaps) The amount of pixels to drag the pointer before it counts as a
     * drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highmaps) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highmaps) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.guideBox
     */
    guideBox?: (PlotMapDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highmaps) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highmaps) General event handlers for the series items. These event hooks can
 * also be attached to the series at run time using the `Highcharts.addEvent`
 * function.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.events
 */
export interface PlotMapEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.map.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.map.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highmaps) Fires when the checkbox next to the series' name in the legend
     * is clicked. One parameter, `event`, is passed to the function. The state
     * of the checkbox is found by `event.checked`. The checked item is found by
     * `event.item`. Return `false` to prevent the default action which is to
     * toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highmaps) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highmaps) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.events.hide
     */
    hide?: () => void;
    /**
     * (Highmaps) Fires when the legend item belonging to the series is clicked.
     * One parameter, `event`, is passed to the function. The default action is
     * to toggle the visibility of the series. This can be prevented by
     * returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highmaps) Fires when the mouse leaves the graph. One parameter, `event`,
     * is passed to the function, containing common event information. If the
     * stickyTracking option is true, `mouseOut` doesn't happen before the mouse
     * enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highmaps) Fires when the mouse enters the graph. One parameter, `event`,
     * is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highmaps) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.label
 * @see https://api.highcharts.com/highstock/plotOptions.map.label
 * @see https://api.highcharts.com/gantt/plotOptions.map.label
 */
export interface PlotMapLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.map.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.map.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.map.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.map.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.map.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.map.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.map.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.map.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.map.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.map.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.map.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.map.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.map.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.map.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.map.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.map.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.map.lastPrice
 */
export interface PlotMapLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotMapLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.map.lastVisiblePrice
 */
export interface PlotMapLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotMapLastVisiblePriceLabelOptions;
}
/**
 * (Highmaps) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.animation
 */
export interface PlotMaplineAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker
 */
export interface PlotMaplineConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker
 */
export interface PlotMaplineConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors
 */
export interface PlotMaplineConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.endMarker
     */
    endMarker?: PlotMaplineConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.marker
     */
    marker?: PlotMaplineConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker
     */
    startMarker?: PlotMaplineConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker
 */
export interface PlotMaplineConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataGrouping
 */
export interface PlotMaplineDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highmaps) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.filter
 */
export interface PlotMaplineDataLabelsFilterOptions {
    /**
     * (Highmaps) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highmaps) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highmaps) The value to compare against.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highmaps) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels
 */
export interface PlotMaplineDataLabelsOptions {
    /**
     * (Highmaps) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highmaps) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highmaps) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highmaps) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.className
     */
    className?: string;
    /**
     * (Highmaps) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Whether to hide data labels that are outside the plot area. By
     * default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highmaps) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highmaps) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.filter
     */
    filter?: PlotMaplineDataLabelsFilterOptions;
    /**
     * (Highmaps) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.format
     */
    format?: string;
    /**
     * (Highmaps) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highmaps) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highmaps) How to handle data labels that flow outside the plot area. The
     * default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highmaps) When either the `borderWidth` or the `backgroundColor` is set,
     * this is the padding within the box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highmaps) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highmaps) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highmaps) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highmaps) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highmaps) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highmaps) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highmaps) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.x
     */
    x?: number;
    /**
     * (Highmaps) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.y
     */
    y?: number;
    /**
     * (Highmaps) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragHandle
 */
export interface PlotMaplineDragDropDragHandleOptions {
    /**
     * (Highmaps) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highmaps) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highmaps) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highmaps) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highmaps) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.guideBox.default
 */
export interface PlotMaplineDragDropGuideBoxDefaultOptions {
    /**
     * (Highmaps) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highmaps) Guide box fill color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Guide box cursor.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highmaps) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.guideBox
 */
export interface PlotMaplineDragDropGuideBoxOptions {
    /**
     * (Highmaps) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.guideBox.default
     */
    default?: PlotMaplineDragDropGuideBoxDefaultOptions;
}
/**
 * (Highmaps) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop
 */
export interface PlotMaplineDragDropOptions {
    /**
     * (Highmaps) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highmaps) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highmaps) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragHandle
     */
    dragHandle?: PlotMaplineDragDropDragHandleOptions;
    /**
     * (Highmaps) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highmaps) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highmaps) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highmaps) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highmaps) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highmaps) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highmaps) The amount of pixels to drag the pointer before it counts as a
     * drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highmaps) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highmaps) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.guideBox
     */
    guideBox?: (PlotMaplineDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highmaps) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highmaps) General event handlers for the series items. These event hooks can
 * also be attached to the series at run time using the `Highcharts.addEvent`
 * function.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.events
 */
export interface PlotMaplineEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highmaps) Fires when the checkbox next to the series' name in the legend
     * is clicked. One parameter, `event`, is passed to the function. The state
     * of the checkbox is found by `event.checked`. The checked item is found by
     * `event.item`. Return `false` to prevent the default action which is to
     * toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highmaps) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highmaps) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.events.hide
     */
    hide?: () => void;
    /**
     * (Highmaps) Fires when the legend item belonging to the series is clicked.
     * One parameter, `event`, is passed to the function. The default action is
     * to toggle the visibility of the series. This can be prevented by
     * returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highmaps) Fires when the mouse leaves the graph. One parameter, `event`,
     * is passed to the function, containing common event information. If the
     * stickyTracking option is true, `mouseOut` doesn't happen before the mouse
     * enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highmaps) Fires when the mouse enters the graph. One parameter, `event`,
     * is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highmaps) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.label
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.label
 * @see https://api.highcharts.com/gantt/plotOptions.mapline.label
 */
export interface PlotMaplineLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.lastPrice
 */
export interface PlotMaplineLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotMaplineLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.lastVisiblePrice
 */
export interface PlotMaplineLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotMaplineLastVisiblePriceLabelOptions;
}
/**
 * (Highmaps) A mapline series is a special case of the map series where the
 * value colors are applied to the strokes rather than the fills. It can also be
 * used for freeform drawing, like dividers, in the map.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `mapline` series are defined in plotOptions.mapline.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline
 */
export interface PlotMaplineOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highmaps) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highmaps) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.animation
     */
    animation?: (boolean|PlotMaplineAnimationOptions);
    /**
     * (Highmaps) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highmaps) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.borderColor
     */
    borderColor?: string;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.className
     */
    className?: string;
    /**
     * (Highmaps) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.clip
     */
    clip?: boolean;
    /**
     * (Highmaps) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highmaps) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.connectors
     */
    connectors?: PlotMaplineConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highmaps) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highmaps) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.dataGrouping
     */
    dataGrouping?: PlotMaplineDataGroupingOptions;
    /**
     * (Highmaps) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dataLabels
     */
    dataLabels?: PlotMaplineDataLabelsOptions;
    /**
     * (Highmaps) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.description
     */
    description?: string;
    /**
     * (Highmaps) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.dragDrop
     */
    dragDrop?: PlotMaplineDragDropOptions;
    /**
     * (Highmaps) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highmaps) General event handlers for the series items. These event hooks
     * can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.events
     */
    events?: PlotMaplineEventsOptions;
    /**
     * (Highmaps) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highmaps) Fill color for the map line shapes
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.fillColor
     */
    fillColor?: ColorString;
    /**
     * (Highmaps) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.joinBy
     */
    joinBy?: string;
    /**
     * (Highmaps) An array specifying which option maps to which key in the data
     * point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.label
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.label
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.label
     */
    label?: PlotMaplineLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.lastPrice
     */
    lastPrice?: PlotMaplineLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.lastVisiblePrice
     */
    lastVisiblePrice?: PlotMaplineLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) The width of the map line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highmaps) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The color to apply to null points.
     *
     * In styled mode, the null point fill is set in the
     * `.highcharts-null-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.nullColor
     */
    nullColor?: ColorString;
    /**
     * (Highmaps) Whether to allow pointer interaction like tooltips and mouse
     * events on null points.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.nullInteraction
     */
    nullInteraction?: boolean;
    /**
     * (Highmaps) Properties for each single point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point
     */
    point?: PlotMaplinePointOptions;
    /**
     * (Highmaps) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.pointStart
     */
    pointStart?: number;
    /**
     * (Highmaps) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.selected
     */
    selected?: boolean;
    /**
     * (Highmaps) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highmaps) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highmaps) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highmaps) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states
     */
    states?: PlotMaplineStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.step
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip
     */
    tooltip?: PlotMaplineTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highmaps) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.zones
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.zones
     */
    zones?: Array<PlotMaplineZonesOptions>;
}
/**
 * (Highmaps) Events for each single point.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events
 */
export interface PlotMaplinePointEventsOptions {
    /**
     * (Highmaps) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highmaps) Callback that fires while dragging a point. The mouse event is
     * passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highmaps) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highmaps) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highmaps) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highmaps) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highmaps) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highmaps) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events.select
     */
    select?: () => void;
    /**
     * (Highmaps) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highmaps) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events.update
     */
    update?: () => void;
}
/**
 * (Highmaps) Properties for each single point.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point
 */
export interface PlotMaplinePointOptions {
    /**
     * (Highmaps) Events for each single point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.point.events
     */
    events?: PlotMaplinePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.animation
 */
export interface PlotMaplineStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.halo
 */
export interface PlotMaplineStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker
 */
export interface PlotMaplineStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states
     */
    states?: PlotMaplineStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover.animation
 */
export interface PlotMaplineStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover
 */
export interface PlotMaplineStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMaplineStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.normal
 */
export interface PlotMaplineStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states
 */
export interface PlotMaplineStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.hover
     */
    hover?: PlotMaplineStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.normal
     */
    normal?: PlotMaplineStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.select
     */
    select?: PlotMaplineStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.select
 */
export interface PlotMaplineStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Options for the hovered series. These settings override the normal
 * state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.hover
 */
export interface PlotMaplineStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMaplineStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.halo
     */
    halo?: PlotMaplineStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.hover.marker
     */
    marker?: PlotMaplineStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.normal
 */
export interface PlotMaplineStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.normal.animation
     */
    animation?: boolean;
}
/**
 * (Highmaps) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states
 */
export interface PlotMaplineStatesOptions {
    /**
     * (Highmaps) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.hover
     */
    hover?: PlotMaplineStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.normal
     */
    normal?: PlotMaplineStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.select
     */
    select?: PlotMaplineStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.animation
 */
export interface PlotMaplineStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.halo
 */
export interface PlotMaplineStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker
 */
export interface PlotMaplineStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states
     */
    states?: PlotMaplineStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover.animation
 */
export interface PlotMaplineStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover
 */
export interface PlotMaplineStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMaplineStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.normal
 */
export interface PlotMaplineStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states
 */
export interface PlotMaplineStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.hover
     */
    hover?: PlotMaplineStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.normal
     */
    normal?: PlotMaplineStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.select
     */
    select?: PlotMaplineStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.select
 */
export interface PlotMaplineStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.select
 */
export interface PlotMaplineStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMaplineStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.select.color
     */
    color?: string;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.halo
     */
    halo?: PlotMaplineStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.states.select.marker
     */
    marker?: PlotMaplineStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.mapline.tooltip.dateTimeLabelFormats
 */
export interface PlotMaplineTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip
 */
export interface PlotMaplineTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotMaplineTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.mapline.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mapline.zones
 * @see https://api.highcharts.com/highstock/plotOptions.mapline.zones
 */
export interface PlotMaplineZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mapline.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.mapline.zones.value
     */
    value?: number;
}
/**
 * (Highmaps) The map series is used for basic choropleth maps, where each map
 * area has a color based on its value.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `map` series are defined in plotOptions.map.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map
 */
export interface PlotMapOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highmaps) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highmaps) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.animation
     */
    animation?: (boolean|PlotMapAnimationOptions);
    /**
     * (Highmaps) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highmaps) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.borderColor
     */
    borderColor?: string;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.className
     */
    className?: string;
    /**
     * (Highmaps) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.clip
     */
    clip?: boolean;
    /**
     * (Highmaps) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highmaps) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.map.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.map.connectors
     */
    connectors?: PlotMapConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.map.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highmaps) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highmaps) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.dataGrouping
     */
    dataGrouping?: PlotMapDataGroupingOptions;
    /**
     * (Highmaps) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dataLabels
     */
    dataLabels?: PlotMapDataLabelsOptions;
    /**
     * (Highmaps) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.description
     */
    description?: string;
    /**
     * (Highmaps) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.dragDrop
     */
    dragDrop?: PlotMapDragDropOptions;
    /**
     * (Highmaps) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highmaps) General event handlers for the series items. These event hooks
     * can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.events
     */
    events?: PlotMapEventsOptions;
    /**
     * (Highmaps) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highmaps) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.map.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.map.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.joinBy
     */
    joinBy?: string;
    /**
     * (Highmaps) An array specifying which option maps to which key in the data
     * point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.label
     * @see https://api.highcharts.com/highstock/plotOptions.map.label
     * @see https://api.highcharts.com/gantt/plotOptions.map.label
     */
    label?: PlotMapLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.lastPrice
     */
    lastPrice?: PlotMapLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.lastVisiblePrice
     */
    lastVisiblePrice?: PlotMapLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.map.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) The width of the line connecting the data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.map.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.map.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.map.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highmaps) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The color to apply to null points.
     *
     * In styled mode, the null point fill is set in the
     * `.highcharts-null-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.nullColor
     */
    nullColor?: ColorString;
    /**
     * (Highmaps) Whether to allow pointer interaction like tooltips and mouse
     * events on null points.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.nullInteraction
     */
    nullInteraction?: boolean;
    /**
     * (Highmaps) Properties for each single point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point
     */
    point?: PlotMapPointOptions;
    /**
     * (Highmaps) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.map.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.map.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.map.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.map.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.map.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.map.pointStart
     */
    pointStart?: number;
    /**
     * (Highmaps) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.selected
     */
    selected?: boolean;
    /**
     * (Highmaps) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highmaps) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highmaps) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.map.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.map.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highmaps) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states
     */
    states?: PlotMapStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.step
     * @see https://api.highcharts.com/highstock/plotOptions.map.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.map.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.map.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip
     */
    tooltip?: PlotMapTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.map.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.map.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highmaps) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.map.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.zones
     * @see https://api.highcharts.com/highstock/plotOptions.map.zones
     */
    zones?: Array<PlotMapZonesOptions>;
}
/**
 * (Highmaps) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.animation
 */
export interface PlotMappointAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker
 */
export interface PlotMappointConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker
 */
export interface PlotMappointConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors
 */
export interface PlotMappointConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.endMarker
     */
    endMarker?: PlotMappointConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.marker
     */
    marker?: PlotMappointConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker
     */
    startMarker?: PlotMappointConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker
 */
export interface PlotMappointConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataGrouping
 */
export interface PlotMappointDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highmaps) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.filter
 */
export interface PlotMappointDataLabelsFilterOptions {
    /**
     * (Highmaps) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highmaps) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highmaps) The value to compare against.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highmaps) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels
 */
export interface PlotMappointDataLabelsOptions {
    /**
     * (Highmaps) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highmaps) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highmaps) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highmaps) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.className
     */
    className?: string;
    /**
     * (Highmaps) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Whether to hide data labels that are outside the plot area. By
     * default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highmaps) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highmaps) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.filter
     */
    filter?: PlotMappointDataLabelsFilterOptions;
    /**
     * (Highmaps) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.format
     */
    format?: string;
    /**
     * (Highmaps) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highmaps) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highmaps) How to handle data labels that flow outside the plot area. The
     * default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highmaps) When either the `borderWidth` or the `backgroundColor` is set,
     * this is the padding within the box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highmaps) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highmaps) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highmaps) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highmaps) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.style
     */
    style?: PlotMappointDataLabelsStyleOptions;
    /**
     * (Highmaps) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highmaps) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highmaps) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.x
     */
    x?: number;
    /**
     * (Highmaps) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.y
     */
    y?: number;
    /**
     * (Highmaps) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Styles for the label. The default `color` setting is `"contrast"`,
 * which is a pseudo color that Highcharts picks up and applies the maximum
 * contrast to the underlying point item, for example the bar in a bar chart.
 *
 * The `textOutline` is a pseudo property that applies an outline of the given
 * width with the given color, which by default is the maximum contrast to the
 * text. So a bright text color will result in a black text outline for maximum
 * readability on a mixed background. In some cases, especially with grayscale
 * text, the text outline doesn't work well, in which cases it can be disabled
 * by setting it to `"none"`. When `useHTML` is true, the `textOutline` will not
 * be picked up. In this, case, the same effect can be acheived through the
 * `text-shadow` CSS property.
 *
 * For some series types, where each point has an extent, like for example tree
 * maps, the data label may overflow the point. There are two strategies for
 * handling overflow. By default, the text will wrap to multiple lines. The
 * other strategy is to set `style.textOverflow` to `ellipsis`, which will keep
 * the text on one line plus it will break inside long words.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels.style
 */
export interface PlotMappointDataLabelsStyleOptions {
    color?: string;
}
/**
 * (Highmaps) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragHandle
 */
export interface PlotMappointDragDropDragHandleOptions {
    /**
     * (Highmaps) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highmaps) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highmaps) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highmaps) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highmaps) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.guideBox.default
 */
export interface PlotMappointDragDropGuideBoxDefaultOptions {
    /**
     * (Highmaps) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highmaps) Guide box fill color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Guide box cursor.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highmaps) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highmaps) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.guideBox
 */
export interface PlotMappointDragDropGuideBoxOptions {
    /**
     * (Highmaps) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.guideBox.default
     */
    default?: PlotMappointDragDropGuideBoxDefaultOptions;
}
/**
 * (Highmaps) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop
 */
export interface PlotMappointDragDropOptions {
    /**
     * (Highmaps) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highmaps) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highmaps) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragHandle
     */
    dragHandle?: PlotMappointDragDropDragHandleOptions;
    /**
     * (Highmaps) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highmaps) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highmaps) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highmaps) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highmaps) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highmaps) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highmaps) The amount of pixels to drag the pointer before it counts as a
     * drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highmaps) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highmaps) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.guideBox
     */
    guideBox?: (PlotMappointDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highmaps) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highmaps) Events for each single point.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events
 */
export interface PlotMapPointEventsOptions {
    /**
     * (Highmaps) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highmaps) Callback that fires while dragging a point. The mouse event is
     * passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highmaps) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highmaps) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highmaps) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highmaps) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highmaps) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highmaps) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events.select
     */
    select?: () => void;
    /**
     * (Highmaps) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highmaps) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events.update
     */
    update?: () => void;
}
/**
 * (Highmaps) General event handlers for the series items. These event hooks can
 * also be attached to the series at run time using the `Highcharts.addEvent`
 * function.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.events
 */
export interface PlotMappointEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highmaps) Fires when the checkbox next to the series' name in the legend
     * is clicked. One parameter, `event`, is passed to the function. The state
     * of the checkbox is found by `event.checked`. The checked item is found by
     * `event.item`. Return `false` to prevent the default action which is to
     * toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highmaps) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highmaps) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.events.hide
     */
    hide?: () => void;
    /**
     * (Highmaps) Fires when the legend item belonging to the series is clicked.
     * One parameter, `event`, is passed to the function. The default action is
     * to toggle the visibility of the series. This can be prevented by
     * returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highmaps) Fires when the mouse leaves the graph. One parameter, `event`,
     * is passed to the function, containing common event information. If the
     * stickyTracking option is true, `mouseOut` doesn't happen before the mouse
     * enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highmaps) Fires when the mouse enters the graph. One parameter, `event`,
     * is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highmaps) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.label
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.label
 * @see https://api.highcharts.com/gantt/plotOptions.mappoint.label
 */
export interface PlotMappointLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.lastPrice
 */
export interface PlotMappointLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotMappointLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.lastVisiblePrice
 */
export interface PlotMappointLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotMappointLastVisiblePriceLabelOptions;
}
/**
 * (Highmaps) Options for the point markers of line-like series. Properties like
 * `fillColor`, `lineColor` and `lineWidth` define the visual appearance of the
 * markers. Other series types, like column series, don't have markers, but have
 * visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker
 */
export interface PlotMappointMarkerOptions {
    /**
     * (Highmaps) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highmaps) The threshold for how dense the point markers should be before
     * they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highmaps) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Image markers only. Set the image width explicitly. When using
     * this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.height
     */
    height?: number;
    /**
     * (Highmaps) The color of the point marker's outline. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.radius
     */
    radius?: number;
    /**
     * (Highmaps) States for a single point marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states
     */
    states?: PlotMappointMarkerStatesOptions;
    /**
     * (Highmaps) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.symbol
     */
    symbol?: string;
    /**
     * (Highmaps) Image markers only. Set the image width explicitly. When using
     * this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.width
     */
    width?: number;
}
/**
 * (Highmaps) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover.animation
 */
export interface PlotMappointMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highmaps) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover
 */
export interface PlotMappointMarkerStatesHoverOptions {
    /**
     * (Highmaps) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMappointMarkerStatesHoverAnimationOptions);
    /**
     * (Highmaps) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highmaps) The fill color of the marker in hover state. When `undefined`,
     * the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The color of the point marker's outline. When `undefined`, the
     * series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) The width of the point marker's outline. When `undefined`, the
     * series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highmaps) The radius of the point marker. In hover state, it defaults to
     * the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highmaps) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highmaps) The normal state of a single point marker. Currently only used for
 * setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.normal
 */
export interface PlotMappointMarkerStatesNormalOptions {
    /**
     * (Highmaps) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highmaps) States for a single point marker.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states
 */
export interface PlotMappointMarkerStatesOptions {
    /**
     * (Highmaps) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.hover
     */
    hover?: PlotMappointMarkerStatesHoverOptions;
    /**
     * (Highmaps) The normal state of a single point marker. Currently only used
     * for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.normal
     */
    normal?: PlotMappointMarkerStatesNormalOptions;
    /**
     * (Highmaps) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.select
     */
    select?: PlotMappointMarkerStatesSelectOptions;
}
/**
 * (Highmaps) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.select
 */
export interface PlotMappointMarkerStatesSelectOptions {
    /**
     * (Highmaps) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highmaps) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) The color of the point marker's outline. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highmaps) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highmaps) The radius of the point marker. In hover state, it defaults to
     * the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Properties for each single point.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.point
 */
export interface PlotMapPointOptions {
    /**
     * (Highmaps) Events for each single point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.point.events
     */
    events?: PlotMapPointEventsOptions;
}
/**
 * (Highmaps) A mappoint series is a special form of scatter series where the
 * points can be laid out in map coordinates on top of a map.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `mappoint` series are defined in plotOptions.mappoint.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint
 */
export interface PlotMappointOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highmaps) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highmaps) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMappointAnimationOptions);
    /**
     * (Highmaps) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highmaps) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.className
     */
    className?: string;
    /**
     * (Highmaps) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.clip
     */
    clip?: boolean;
    /**
     * (Highmaps) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highmaps) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.connectors
     */
    connectors?: PlotMappointConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highmaps) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highmaps) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.dataGrouping
     */
    dataGrouping?: PlotMappointDataGroupingOptions;
    /**
     * (Highmaps) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dataLabels
     */
    dataLabels?: PlotMappointDataLabelsOptions;
    /**
     * (Highmaps) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.description
     */
    description?: string;
    /**
     * (Highmaps) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.dragDrop
     */
    dragDrop?: PlotMappointDragDropOptions;
    /**
     * (Highmaps) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highmaps) General event handlers for the series items. These event hooks
     * can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.events
     */
    events?: PlotMappointEventsOptions;
    /**
     * (Highmaps) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highmaps) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highmaps) An array specifying which option maps to which key in the data
     * point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.label
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.label
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.label
     */
    label?: PlotMappointLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.lastPrice
     */
    lastPrice?: PlotMappointLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.lastVisiblePrice
     */
    lastVisiblePrice?: PlotMappointLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) The width of the line connecting the data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highmaps) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.marker
     */
    marker?: PlotMappointMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highmaps) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Properties for each single point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point
     */
    point?: PlotMappointPointOptions;
    /**
     * (Highmaps) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.pointStart
     */
    pointStart?: number;
    /**
     * (Highmaps) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.selected
     */
    selected?: boolean;
    /**
     * (Highmaps) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highmaps) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highmaps) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highmaps) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states
     */
    states?: PlotMappointStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.step
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip
     */
    tooltip?: PlotMappointTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highmaps) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.zones
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.zones
     */
    zones?: Array<PlotMappointZonesOptions>;
}
/**
 * (Highmaps) Events for each single point.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events
 */
export interface PlotMappointPointEventsOptions {
    /**
     * (Highmaps) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highmaps) Callback that fires while dragging a point. The mouse event is
     * passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highmaps) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highmaps) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highmaps) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highmaps) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highmaps) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highmaps) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events.select
     */
    select?: () => void;
    /**
     * (Highmaps) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highmaps) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events.update
     */
    update?: () => void;
}
/**
 * (Highmaps) Properties for each single point.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point
 */
export interface PlotMappointPointOptions {
    /**
     * (Highmaps) Events for each single point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.point.events
     */
    events?: PlotMappointPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.animation
 */
export interface PlotMappointStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.halo
 */
export interface PlotMappointStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker
 */
export interface PlotMappointStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states
     */
    states?: PlotMappointStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover.animation
 */
export interface PlotMappointStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover
 */
export interface PlotMappointStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMappointStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.normal
 */
export interface PlotMappointStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states
 */
export interface PlotMappointStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.hover
     */
    hover?: PlotMappointStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.normal
     */
    normal?: PlotMappointStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.select
     */
    select?: PlotMappointStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.select
 */
export interface PlotMappointStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Options for the hovered series. These settings override the normal
 * state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.hover
 */
export interface PlotMappointStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMappointStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.halo
     */
    halo?: PlotMappointStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.hover.marker
     */
    marker?: PlotMappointStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.normal
 */
export interface PlotMappointStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highmaps) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states
 */
export interface PlotMappointStatesOptions {
    /**
     * (Highmaps) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.hover
     */
    hover?: PlotMappointStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.normal
     */
    normal?: PlotMappointStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.select
     */
    select?: PlotMappointStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.animation
 */
export interface PlotMappointStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.halo
 */
export interface PlotMappointStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker
 */
export interface PlotMappointStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states
     */
    states?: PlotMappointStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover.animation
 */
export interface PlotMappointStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover
 */
export interface PlotMappointStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMappointStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.normal
 */
export interface PlotMappointStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states
 */
export interface PlotMappointStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.hover
     */
    hover?: PlotMappointStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.normal
     */
    normal?: PlotMappointStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.select
     */
    select?: PlotMappointStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.select
 */
export interface PlotMappointStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.select
 */
export interface PlotMappointStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMappointStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.halo
     */
    halo?: PlotMappointStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.states.select.marker
     */
    marker?: PlotMappointStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.mappoint.tooltip.dateTimeLabelFormats
 */
export interface PlotMappointTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip
 */
export interface PlotMappointTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotMappointTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.mappoint.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.zones
 * @see https://api.highcharts.com/highstock/plotOptions.mappoint.zones
 */
export interface PlotMappointZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mappoint.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.mappoint.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.animation
 */
export interface PlotMapStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.halo
 */
export interface PlotMapStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker
 */
export interface PlotMapStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states
     */
    states?: PlotMapStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover.animation
 */
export interface PlotMapStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover
 */
export interface PlotMapStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMapStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.normal
 */
export interface PlotMapStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states
 */
export interface PlotMapStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.hover
     */
    hover?: PlotMapStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.normal
     */
    normal?: PlotMapStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.select
     */
    select?: PlotMapStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.select
 */
export interface PlotMapStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Options for the hovered series. These settings override the normal
 * state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.states.hover
 */
export interface PlotMapStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMapStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.halo
     */
    halo?: PlotMapStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.hover.marker
     */
    marker?: PlotMapStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.states.normal
 */
export interface PlotMapStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.normal.animation
     */
    animation?: boolean;
}
/**
 * (Highmaps) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.states
 */
export interface PlotMapStatesOptions {
    /**
     * (Highmaps) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.hover
     */
    hover?: PlotMapStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.normal
     */
    normal?: PlotMapStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.select
     */
    select?: PlotMapStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.animation
 */
export interface PlotMapStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.halo
 */
export interface PlotMapStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker
 */
export interface PlotMapStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states
     */
    states?: PlotMapStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover.animation
 */
export interface PlotMapStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover
 */
export interface PlotMapStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMapStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.normal
 */
export interface PlotMapStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states
 */
export interface PlotMapStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.hover
     */
    hover?: PlotMapStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.normal
     */
    normal?: PlotMapStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.select
     */
    select?: PlotMapStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.select
 */
export interface PlotMapStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.map.states.select
 */
export interface PlotMapStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMapStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.select.color
     */
    color?: string;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.halo
     */
    halo?: PlotMapStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.map.states.select.marker
     */
    marker?: PlotMapStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.map.tooltip.dateTimeLabelFormats
 */
export interface PlotMapTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip
 */
export interface PlotMapTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.map.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotMapTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.map.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.map.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.map.zones
 * @see https://api.highcharts.com/highstock/plotOptions.map.zones
 */
export interface PlotMapZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.map.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.map.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.map.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.map.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.map.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.map.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.animation
 */
export interface PlotMfiAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker
 */
export interface PlotMfiConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker
 */
export interface PlotMfiConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors
 */
export interface PlotMfiConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.endMarker
     */
    endMarker?: PlotMfiConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.marker
     */
    marker?: PlotMfiConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker
     */
    startMarker?: PlotMfiConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker
 */
export interface PlotMfiConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataGrouping
 */
export interface PlotMfiDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.filter
 */
export interface PlotMfiDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels
 */
export interface PlotMfiDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.filter
     */
    filter?: PlotMfiDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragHandle
 */
export interface PlotMfiDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.guideBox.default
 */
export interface PlotMfiDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.guideBox
 */
export interface PlotMfiDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.guideBox.default
     */
    default?: PlotMfiDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop
 */
export interface PlotMfiDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragHandle
     */
    dragHandle?: PlotMfiDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.guideBox
     */
    guideBox?: (PlotMfiDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.events
 */
export interface PlotMfiEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.label
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.label
 * @see https://api.highcharts.com/gantt/plotOptions.mfi.label
 */
export interface PlotMfiLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.lastPrice
 */
export interface PlotMfiLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotMfiLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.lastVisiblePrice
 */
export interface PlotMfiLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotMfiLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker
 */
export interface PlotMfiMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states
     */
    states?: PlotMfiMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover.animation
 */
export interface PlotMfiMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover
 */
export interface PlotMfiMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMfiMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.normal
 */
export interface PlotMfiMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states
 */
export interface PlotMfiMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.hover
     */
    hover?: PlotMfiMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.normal
     */
    normal?: PlotMfiMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.select
     */
    select?: PlotMfiMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.select
 */
export interface PlotMfiMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Money Flow Index. This series requires `linkedTo` option to be
 * set and should be loaded after the `stock/indicators/indicators.js` file.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `mfi` series are defined in plotOptions.mfi.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi
 */
export interface PlotMfiOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMfiAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.connectors
     */
    connectors?: PlotMfiConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataGrouping
     */
    dataGrouping?: PlotMfiDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dataLabels
     */
    dataLabels?: PlotMfiDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.dragDrop
     */
    dragDrop?: PlotMfiDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.events
     */
    events?: PlotMfiEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.label
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.label
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.label
     */
    label?: PlotMfiLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.lastPrice
     */
    lastPrice?: PlotMfiLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.lastVisiblePrice
     */
    lastVisiblePrice?: PlotMfiLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.marker
     */
    marker?: PlotMfiMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.params
     */
    params?: PlotMfiParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point
     */
    point?: PlotMfiPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states
     */
    states?: PlotMfiStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.step
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip
     */
    tooltip?: PlotMfiTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.zones
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.zones
     */
    zones?: Array<PlotMfiZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.params
 */
export interface PlotMfiParamsOptions {
    /**
     * (Highstock) Number of maximum decimals that are used in MFI calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.params.decimals
     */
    decimals?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.params.period
     */
    period?: number;
    /**
     * (Highstock) The id of volume series which is mandatory. For example using
     * OHLC data, volumeSeriesID='volume' means the indicator will be calculated
     * using OHLC and volume values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.params.volumeSeriesID
     */
    volumeSeriesID?: string;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events
 */
export interface PlotMfiPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.point
 */
export interface PlotMfiPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.point.events
     */
    events?: PlotMfiPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.animation
 */
export interface PlotMfiStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.halo
 */
export interface PlotMfiStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker
 */
export interface PlotMfiStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states
     */
    states?: PlotMfiStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover.animation
 */
export interface PlotMfiStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover
 */
export interface PlotMfiStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMfiStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.normal
 */
export interface PlotMfiStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states
 */
export interface PlotMfiStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.hover
     */
    hover?: PlotMfiStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.normal
     */
    normal?: PlotMfiStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.select
     */
    select?: PlotMfiStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.select
 */
export interface PlotMfiStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover
 */
export interface PlotMfiStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMfiStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.halo
     */
    halo?: PlotMfiStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover.marker
     */
    marker?: PlotMfiStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.normal
 */
export interface PlotMfiStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states
 */
export interface PlotMfiStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.hover
     */
    hover?: PlotMfiStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.normal
     */
    normal?: PlotMfiStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.select
     */
    select?: PlotMfiStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.animation
 */
export interface PlotMfiStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.halo
 */
export interface PlotMfiStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker
 */
export interface PlotMfiStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states
     */
    states?: PlotMfiStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover.animation
 */
export interface PlotMfiStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover
 */
export interface PlotMfiStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMfiStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.normal
 */
export interface PlotMfiStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states
 */
export interface PlotMfiStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.hover
     */
    hover?: PlotMfiStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.normal
     */
    normal?: PlotMfiStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.select
     */
    select?: PlotMfiStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.select
 */
export interface PlotMfiStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.select
 */
export interface PlotMfiStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMfiStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mfi.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.halo
     */
    halo?: PlotMfiStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.states.select.marker
     */
    marker?: PlotMfiStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.mfi.tooltip.dateTimeLabelFormats
 */
export interface PlotMfiTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip
 */
export interface PlotMfiTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotMfiTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.mfi.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.mfi.zones
 * @see https://api.highcharts.com/highstock/plotOptions.mfi.zones
 */
export interface PlotMfiZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.mfi.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.mfi.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.animation
 */
export interface PlotMomentumAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker
 */
export interface PlotMomentumConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker
 */
export interface PlotMomentumConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors
 */
export interface PlotMomentumConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.endMarker
     */
    endMarker?: PlotMomentumConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.marker
     */
    marker?: PlotMomentumConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker
     */
    startMarker?: PlotMomentumConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker
 */
export interface PlotMomentumConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataGrouping
 */
export interface PlotMomentumDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.filter
 */
export interface PlotMomentumDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels
 */
export interface PlotMomentumDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.filter
     */
    filter?: PlotMomentumDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragHandle
 */
export interface PlotMomentumDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.guideBox.default
 */
export interface PlotMomentumDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.guideBox
 */
export interface PlotMomentumDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.guideBox.default
     */
    default?: PlotMomentumDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop
 */
export interface PlotMomentumDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragHandle
     */
    dragHandle?: PlotMomentumDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.guideBox
     */
    guideBox?: (PlotMomentumDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.events
 */
export interface PlotMomentumEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.label
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.label
 * @see https://api.highcharts.com/gantt/plotOptions.momentum.label
 */
export interface PlotMomentumLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.lastPrice
 */
export interface PlotMomentumLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotMomentumLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.lastVisiblePrice
 */
export interface PlotMomentumLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotMomentumLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker
 */
export interface PlotMomentumMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states
     */
    states?: PlotMomentumMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover.animation
 */
export interface PlotMomentumMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover
 */
export interface PlotMomentumMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMomentumMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.normal
 */
export interface PlotMomentumMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states
 */
export interface PlotMomentumMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.hover
     */
    hover?: PlotMomentumMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.normal
     */
    normal?: PlotMomentumMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.select
     */
    select?: PlotMomentumMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.select
 */
export interface PlotMomentumMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Momentum. This series requires `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `momentum` series are defined in plotOptions.momentum.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum
 */
export interface PlotMomentumOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMomentumAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.connectors
     */
    connectors?: PlotMomentumConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataGrouping
     */
    dataGrouping?: PlotMomentumDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dataLabels
     */
    dataLabels?: PlotMomentumDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.dragDrop
     */
    dragDrop?: PlotMomentumDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.events
     */
    events?: PlotMomentumEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.label
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.label
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.label
     */
    label?: PlotMomentumLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.lastPrice
     */
    lastPrice?: PlotMomentumLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.lastVisiblePrice
     */
    lastVisiblePrice?: PlotMomentumLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.marker
     */
    marker?: PlotMomentumMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.params
     */
    params?: PlotMomentumParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point
     */
    point?: PlotMomentumPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states
     */
    states?: PlotMomentumStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.step
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip
     */
    tooltip?: PlotMomentumTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.zones
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.zones
     */
    zones?: Array<PlotMomentumZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.params
 */
export interface PlotMomentumParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events
 */
export interface PlotMomentumPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.point
 */
export interface PlotMomentumPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.point.events
     */
    events?: PlotMomentumPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.animation
 */
export interface PlotMomentumStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.halo
 */
export interface PlotMomentumStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker
 */
export interface PlotMomentumStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states
     */
    states?: PlotMomentumStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover.animation
 */
export interface PlotMomentumStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover
 */
export interface PlotMomentumStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMomentumStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.normal
 */
export interface PlotMomentumStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states
 */
export interface PlotMomentumStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.hover
     */
    hover?: PlotMomentumStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.normal
     */
    normal?: PlotMomentumStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.select
     */
    select?: PlotMomentumStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.select
 */
export interface PlotMomentumStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover
 */
export interface PlotMomentumStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMomentumStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.halo
     */
    halo?: PlotMomentumStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover.marker
     */
    marker?: PlotMomentumStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.normal
 */
export interface PlotMomentumStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states
 */
export interface PlotMomentumStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.hover
     */
    hover?: PlotMomentumStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.normal
     */
    normal?: PlotMomentumStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.select
     */
    select?: PlotMomentumStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.animation
 */
export interface PlotMomentumStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.halo
 */
export interface PlotMomentumStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker
 */
export interface PlotMomentumStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states
     */
    states?: PlotMomentumStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover.animation
 */
export interface PlotMomentumStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover
 */
export interface PlotMomentumStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMomentumStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.normal
 */
export interface PlotMomentumStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states
 */
export interface PlotMomentumStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.hover
     */
    hover?: PlotMomentumStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.normal
     */
    normal?: PlotMomentumStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.select
     */
    select?: PlotMomentumStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.select
 */
export interface PlotMomentumStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.select
 */
export interface PlotMomentumStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotMomentumStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.momentum.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.halo
     */
    halo?: PlotMomentumStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.states.select.marker
     */
    marker?: PlotMomentumStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.momentum.tooltip.dateTimeLabelFormats
 */
export interface PlotMomentumTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip
 */
export interface PlotMomentumTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotMomentumTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.momentum.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.momentum.zones
 * @see https://api.highcharts.com/highstock/plotOptions.momentum.zones
 */
export interface PlotMomentumZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.momentum.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.momentum.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.animation
 */
export interface PlotNatrAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker
 */
export interface PlotNatrConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker
 */
export interface PlotNatrConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors
 */
export interface PlotNatrConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.endMarker
     */
    endMarker?: PlotNatrConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.marker
     */
    marker?: PlotNatrConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker
     */
    startMarker?: PlotNatrConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker
 */
export interface PlotNatrConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.dataGrouping
 */
export interface PlotNatrDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.filter
 */
export interface PlotNatrDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels
 */
export interface PlotNatrDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.natr.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.filter
     */
    filter?: PlotNatrDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragHandle
 */
export interface PlotNatrDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.guideBox.default
 */
export interface PlotNatrDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.guideBox
 */
export interface PlotNatrDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.guideBox.default
     */
    default?: PlotNatrDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop
 */
export interface PlotNatrDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragHandle
     */
    dragHandle?: PlotNatrDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.guideBox
     */
    guideBox?: (PlotNatrDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.events
 */
export interface PlotNatrEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.natr.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.natr.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.label
 * @see https://api.highcharts.com/highstock/plotOptions.natr.label
 * @see https://api.highcharts.com/gantt/plotOptions.natr.label
 */
export interface PlotNatrLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.natr.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.natr.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.natr.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.natr.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.natr.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.natr.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.natr.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.natr.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.natr.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.natr.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.natr.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.natr.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.natr.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.natr.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.natr.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.natr.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.lastPrice
 */
export interface PlotNatrLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotNatrLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.lastVisiblePrice
 */
export interface PlotNatrLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotNatrLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.marker
 */
export interface PlotNatrMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states
     */
    states?: PlotNatrMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover.animation
 */
export interface PlotNatrMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover
 */
export interface PlotNatrMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNatrMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.normal
 */
export interface PlotNatrMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states
 */
export interface PlotNatrMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.hover
     */
    hover?: PlotNatrMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.normal
     */
    normal?: PlotNatrMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.select
     */
    select?: PlotNatrMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.select
 */
export interface PlotNatrMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Normalized average true range indicator (NATR). This series
 * requires `linkedTo` option to be set and should be loaded after the
 * `stock/indicators/indicators.js` and `stock/indicators/atr.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `natr` series are defined in plotOptions.natr.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr
 */
export interface PlotNatrOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNatrAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.natr.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.natr.connectors
     */
    connectors?: PlotNatrConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.natr.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataGrouping
     */
    dataGrouping?: PlotNatrDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dataLabels
     */
    dataLabels?: PlotNatrDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.dragDrop
     */
    dragDrop?: PlotNatrDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.events
     */
    events?: PlotNatrEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.natr.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.natr.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.label
     * @see https://api.highcharts.com/highstock/plotOptions.natr.label
     * @see https://api.highcharts.com/gantt/plotOptions.natr.label
     */
    label?: PlotNatrLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.lastPrice
     */
    lastPrice?: PlotNatrLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.lastVisiblePrice
     */
    lastVisiblePrice?: PlotNatrLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.natr.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.natr.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.natr.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.natr.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.marker
     */
    marker?: PlotNatrMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.params
     */
    params?: PlotNatrParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point
     */
    point?: PlotNatrPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.natr.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states
     */
    states?: PlotNatrStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.step
     * @see https://api.highcharts.com/highstock/plotOptions.natr.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.natr.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip
     */
    tooltip?: PlotNatrTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.natr.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.natr.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.natr.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.zones
     * @see https://api.highcharts.com/highstock/plotOptions.natr.zones
     */
    zones?: Array<PlotNatrZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.params
 */
export interface PlotNatrParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events
 */
export interface PlotNatrPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.point
 */
export interface PlotNatrPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.point.events
     */
    events?: PlotNatrPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.animation
 */
export interface PlotNatrStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.halo
 */
export interface PlotNatrStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker
 */
export interface PlotNatrStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states
     */
    states?: PlotNatrStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover.animation
 */
export interface PlotNatrStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover
 */
export interface PlotNatrStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNatrStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.normal
 */
export interface PlotNatrStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states
 */
export interface PlotNatrStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.hover
     */
    hover?: PlotNatrStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.normal
     */
    normal?: PlotNatrStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.select
     */
    select?: PlotNatrStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.select
 */
export interface PlotNatrStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover
 */
export interface PlotNatrStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNatrStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.halo
     */
    halo?: PlotNatrStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover.marker
     */
    marker?: PlotNatrStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.normal
 */
export interface PlotNatrStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states
 */
export interface PlotNatrStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.hover
     */
    hover?: PlotNatrStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.normal
     */
    normal?: PlotNatrStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.select
     */
    select?: PlotNatrStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.animation
 */
export interface PlotNatrStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.halo
 */
export interface PlotNatrStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker
 */
export interface PlotNatrStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states
     */
    states?: PlotNatrStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover.animation
 */
export interface PlotNatrStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover
 */
export interface PlotNatrStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNatrStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.normal
 */
export interface PlotNatrStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states
 */
export interface PlotNatrStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.hover
     */
    hover?: PlotNatrStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.normal
     */
    normal?: PlotNatrStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.select
     */
    select?: PlotNatrStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.select
 */
export interface PlotNatrStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.select
 */
export interface PlotNatrStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNatrStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.natr.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.halo
     */
    halo?: PlotNatrStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.natr.states.select.marker
     */
    marker?: PlotNatrStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.natr.tooltip.dateTimeLabelFormats
 */
export interface PlotNatrTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip
 */
export interface PlotNatrTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.natr.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotNatrTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.natr.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.natr.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.natr.zones
 * @see https://api.highcharts.com/highstock/plotOptions.natr.zones
 */
export interface PlotNatrZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.natr.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.natr.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.natr.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.natr.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.natr.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.natr.zones.value
     */
    value?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker
 */
export interface PlotNetworkgraphConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker
 */
export interface PlotNetworkgraphConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors
 */
export interface PlotNetworkgraphConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.endMarker
     */
    endMarker?: PlotNetworkgraphConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.marker
     */
    marker?: PlotNetworkgraphConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker
     */
    startMarker?: PlotNetworkgraphConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker
 */
export interface PlotNetworkgraphConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataGrouping
 */
export interface PlotNetworkgraphDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.filter
 */
export interface PlotNetworkgraphDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels
 */
export interface PlotNetworkgraphDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.filter
     */
    filter?: PlotNetworkgraphDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.events
 */
export interface PlotNetworkgraphEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.events.show
     */
    show?: () => void;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.lastPrice
 */
export interface PlotNetworkgraphLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotNetworkgraphLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.lastVisiblePrice
 */
export interface PlotNetworkgraphLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotNetworkgraphLastVisiblePriceLabelOptions;
}
export interface PlotNetworkgraphLayoutAlgorithmOptions {
    /**
     * (Highcharts) Attraction force applied on a node which is conected to
     * another node by a link. Passed are two arguments:
     *
     * - `d` - which is current distance between two nodes
     *
     * - `k` - which is desired distance between two nodes
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.layoutAlgorithm.attractiveForce
     */
    attractiveForce?: () => void;
    /**
     * (Highcharts) Experimental. Enables live simulation of the algorithm
     * implementation. All nodes are animated as the forces applies on them.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.layoutAlgorithm.enableSimulation
     */
    enableSimulation?: boolean;
    /**
     * (Highcharts) Friction applied on forces to prevent nodes rushing to fast
     * to the desired positions.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.layoutAlgorithm.friction
     */
    friction?: number;
    /**
     * (Highcharts) Gravitational const used in the barycenter force of the
     * algorithm.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.layoutAlgorithm.gravitationalConstant
     */
    gravitationalConstant?: number;
    /**
     * (Highcharts) Initial layout algorithm for positioning nodes. Can be one
     * of built-in options ("circle", "random") or a function where positions
     * should be set on each node (`this.nodes`) as `node.plotX` and
     * `node.plotY`
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.layoutAlgorithm.initialPositions
     */
    initialPositions?: ("circle"|"random");
    /**
     * (Highcharts) Max number of iterations before algorithm will stop. In
     * general, algorithm should find positions sooner, but when rendering huge
     * number of nodes, it is recommended to increase this value as finding
     * perfect graph positions can require more time.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.layoutAlgorithm.maxIterations
     */
    maxIterations?: number;
    /**
     * (Highcharts) Repulsive force applied on a node. Passed are two arguments:
     *
     * - `d` - which is current distance between two nodes
     *
     * - `k` - which is desired distance between two nodes
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.layoutAlgorithm.repulsiveForce
     */
    repulsiveForce?: () => void;
    /**
     * (Highcharts) Type of the algorithm used when positioning nodes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.layoutAlgorithm.type
     */
    type?: "reingold-fruchterman";
}
/**
 * (Highcharts) Link style options
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.link
 */
export interface PlotNetworkgraphLinkOptions {
    /**
     * (Highcharts) Color of the link between two nodes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.link.color
     */
    color?: string;
    /**
     * (Highcharts) A name for the dash style to use for links.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.link.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts) Width (px) of the link between two nodes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.link.width
     */
    width?: number;
}
/**
 * (Highcharts) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker
 */
export interface PlotNetworkgraphMarkerOptions {
    /**
     * (Highcharts) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.height
     */
    height?: number;
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states
     */
    states?: PlotNetworkgraphMarkerStatesOptions;
    /**
     * (Highcharts) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.width
     */
    width?: number;
}
/**
 * (Highcharts) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover.animation
 */
export interface PlotNetworkgraphMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover
 */
export interface PlotNetworkgraphMarkerStatesHoverOptions {
    /**
     * (Highcharts) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNetworkgraphMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.normal
 */
export interface PlotNetworkgraphMarkerStatesNormalOptions {
    /**
     * (Highcharts) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states
 */
export interface PlotNetworkgraphMarkerStatesOptions {
    /**
     * (Highcharts) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.hover
     */
    hover?: PlotNetworkgraphMarkerStatesHoverOptions;
    /**
     * (Highcharts) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.normal
     */
    normal?: PlotNetworkgraphMarkerStatesNormalOptions;
    /**
     * (Highcharts) The appearance of the point marker when selected. In order
     * to allow a point to be selected, set the `series.allowPointSelect` option
     * to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.select
     */
    select?: PlotNetworkgraphMarkerStatesSelectOptions;
}
/**
 * (Highcharts) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.select
 */
export interface PlotNetworkgraphMarkerStatesSelectOptions {
    /**
     * (Highcharts) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) A networkgraph is a type of relationship chart, where
 * connnections (links) attracts nodes (points) and other nodes repulse each
 * other.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `networkgraph` series are defined in
 * plotOptions.networkgraph.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph
 */
export interface PlotNetworkgraphOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.connectors
     */
    connectors?: PlotNetworkgraphConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.dataGrouping
     */
    dataGrouping?: PlotNetworkgraphDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.dataLabels
     */
    dataLabels?: PlotNetworkgraphDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.description
     */
    description?: string;
    /**
     * (Highcharts) Flag to determine if nodes are draggable or not.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.draggable
     */
    draggable?: boolean;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.events
     */
    events?: PlotNetworkgraphEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.keys
     */
    keys?: Array<string>;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.lastPrice
     */
    lastPrice?: PlotNetworkgraphLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.lastVisiblePrice
     */
    lastVisiblePrice?: PlotNetworkgraphLastVisiblePriceOptions;
    layoutAlgorithm?: PlotNetworkgraphLayoutAlgorithmOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Link style options
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.link
     */
    link?: PlotNetworkgraphLinkOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) Options for the point markers of line-like series.
     * Properties like `fillColor`, `lineColor` and `lineWidth` define the
     * visual appearance of the markers. Other series types, like column series,
     * don't have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.marker
     */
    marker?: PlotNetworkgraphMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point
     */
    point?: PlotNetworkgraphPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states
     */
    states?: PlotNetworkgraphStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip
     */
    tooltip?: PlotNetworkgraphTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) The parameter allows setting line series type and use OHLC
     * indicators. Data in OHLC format is required.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.useOhlcData
     */
    useOhlcData?: boolean;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.zones
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.zones
     */
    zones?: Array<PlotNetworkgraphZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events
 */
export interface PlotNetworkgraphPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point
 */
export interface PlotNetworkgraphPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.point.events
     */
    events?: PlotNetworkgraphPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.animation
 */
export interface PlotNetworkgraphStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.halo
 */
export interface PlotNetworkgraphStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker
 */
export interface PlotNetworkgraphStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states
     */
    states?: PlotNetworkgraphStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover.animation
 */
export interface PlotNetworkgraphStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover
 */
export interface PlotNetworkgraphStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNetworkgraphStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.normal
 */
export interface PlotNetworkgraphStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states
 */
export interface PlotNetworkgraphStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.hover
     */
    hover?: PlotNetworkgraphStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.normal
     */
    normal?: PlotNetworkgraphStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.select
     */
    select?: PlotNetworkgraphStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.select
 */
export interface PlotNetworkgraphStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover
 */
export interface PlotNetworkgraphStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNetworkgraphStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.halo
     */
    halo?: PlotNetworkgraphStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.hover.marker
     */
    marker?: PlotNetworkgraphStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.normal
 */
export interface PlotNetworkgraphStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states
 */
export interface PlotNetworkgraphStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.hover
     */
    hover?: PlotNetworkgraphStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.normal
     */
    normal?: PlotNetworkgraphStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.select
     */
    select?: PlotNetworkgraphStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.animation
 */
export interface PlotNetworkgraphStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.halo
 */
export interface PlotNetworkgraphStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker
 */
export interface PlotNetworkgraphStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states
     */
    states?: PlotNetworkgraphStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover.animation
 */
export interface PlotNetworkgraphStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover
 */
export interface PlotNetworkgraphStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNetworkgraphStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.normal
 */
export interface PlotNetworkgraphStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states
 */
export interface PlotNetworkgraphStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.hover
     */
    hover?: PlotNetworkgraphStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.normal
     */
    normal?: PlotNetworkgraphStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.select
     */
    select?: PlotNetworkgraphStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.select
 */
export interface PlotNetworkgraphStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.select
 */
export interface PlotNetworkgraphStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotNetworkgraphStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.networkgraph.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.halo
     */
    halo?: PlotNetworkgraphStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.states.select.marker
     */
    marker?: PlotNetworkgraphStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.tooltip.dateTimeLabelFormats
 */
export interface PlotNetworkgraphTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip
 */
export interface PlotNetworkgraphTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotNetworkgraphTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.networkgraph.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.zones
 * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.zones
 */
export interface PlotNetworkgraphZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.networkgraph.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.animation
 */
export interface PlotOhlcAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker
 */
export interface PlotOhlcConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker
 */
export interface PlotOhlcConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors
 */
export interface PlotOhlcConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.endMarker
     */
    endMarker?: PlotOhlcConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.marker
     */
    marker?: PlotOhlcConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker
     */
    startMarker?: PlotOhlcConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker
 */
export interface PlotOhlcConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataGrouping
 */
export interface PlotOhlcDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `5`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.filter
 */
export interface PlotOhlcDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels
 */
export interface PlotOhlcDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.filter
     */
    filter?: PlotOhlcDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragHandle
 */
export interface PlotOhlcDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.guideBox.default
 */
export interface PlotOhlcDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.guideBox
 */
export interface PlotOhlcDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.guideBox.default
     */
    default?: PlotOhlcDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop
 */
export interface PlotOhlcDragDropOptions {
    /**
     * (Highstock) Allow close value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.draggableClose
     */
    draggableClose?: boolean;
    /**
     * (Highstock) Allow high value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.draggableHigh
     */
    draggableHigh?: boolean;
    /**
     * (Highstock) Allow low value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.draggableLow
     */
    draggableLow?: boolean;
    /**
     * (Highstock) Allow open value to be dragged individually. Requires
     * `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.draggableOpen
     */
    draggableOpen?: boolean;
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragHandle
     */
    dragHandle?: PlotOhlcDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.guideBox
     */
    guideBox?: (PlotOhlcDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.events
 */
export interface PlotOhlcEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.label
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.label
 * @see https://api.highcharts.com/gantt/plotOptions.ohlc.label
 */
export interface PlotOhlcLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.lastPrice
 */
export interface PlotOhlcLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotOhlcLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.lastVisiblePrice
 */
export interface PlotOhlcLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotOhlcLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) An OHLC chart is a style of financial chart used to describe
 * price movements over time. It displays open, high, low and close values per
 * data point.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ohlc` series are defined in plotOptions.ohlc.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc
 */
export interface PlotOhlcOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ohlc.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotOhlcAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ohlc.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.colors
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.colors
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.connectors
     */
    connectors?: PlotOhlcConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataGrouping
     */
    dataGrouping?: PlotOhlcDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dataLabels
     */
    dataLabels?: PlotOhlcDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.depth
     */
    depth?: number;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.dragDrop
     */
    dragDrop?: PlotOhlcDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.events
     */
    events?: PlotOhlcEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ohlc.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highstock) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.label
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.label
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.label
     */
    label?: PlotOhlcLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.lastPrice
     */
    lastPrice?: PlotOhlcLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.lastVisiblePrice
     */
    lastVisiblePrice?: PlotOhlcLastVisiblePriceOptions;
    /**
     * (Highstock) The pixel width of the line/border. Defaults to `1`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point
     */
    point?: PlotOhlcPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.pointStart
     */
    pointStart?: number;
    /**
     * (Highstock) Determines which one of `open`, `high`, `low`, `close` values
     * should be represented as `point.y`, which is later used to set dataLabel
     * position.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.pointValKey
     */
    pointValKey?: ("close"|"high"|"low"|"open");
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states
     */
    states?: PlotOhlcStatesOptions;
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.threshold
     */
    threshold?: any;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip
     */
    tooltip?: PlotOhlcTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Line color for up points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.upColor
     */
    upColor?: ColorString;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ohlc.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.zones
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.zones
     */
    zones?: Array<PlotOhlcZonesOptions>;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events
 */
export interface PlotOhlcPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point
 */
export interface PlotOhlcPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.point.events
     */
    events?: PlotOhlcPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.hover.animation
 */
export interface PlotOhlcStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highstock) Options for the hovered point. These settings override the normal
 * state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states.hover
 */
export interface PlotOhlcStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotOhlcStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ohlc.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The pixel width of the line representing the OHLC point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states.hover.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ohlc.states.normal
 */
export interface PlotOhlcStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ohlc.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states
 */
export interface PlotOhlcStatesOptions {
    /**
     * (Highstock) Options for the hovered point. These settings override the
     * normal state options when a point is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states.hover
     */
    hover?: PlotOhlcStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ohlc.states.normal
     */
    normal?: PlotOhlcStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.states.select
     */
    select?: PlotOhlcStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.select.animation
 */
export interface PlotOhlcStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.ohlc.states.select
 */
export interface PlotOhlcStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotOhlcStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ohlc.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.ohlc.tooltip.dateTimeLabelFormats
 */
export interface PlotOhlcTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip
 */
export interface PlotOhlcTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotOhlcTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.ohlc.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.zones
 * @see https://api.highcharts.com/highstock/plotOptions.ohlc.zones
 */
export interface PlotOhlcZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ohlc.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The plotOptions is a wrapper object
 * for config objects for each series type. The config objects for each series
 * can also be overridden for each series item as given in the series array.
 *
 * Configuration options for the series are given in three levels. Options for
 * all series in a chart are given in the plotOptions.series object. Then
 * options for all series of a specific type are given in the plotOptions of
 * that type, for example `plotOptions.line`. Next, options for one single
 * series are given in the series array.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions
 * @see https://api.highcharts.com/highstock/plotOptions
 * @see https://api.highcharts.com/highmaps/plotOptions
 * @see https://api.highcharts.com/gantt/plotOptions
 */
export interface PlotOptions {
    /**
     * (Highstock) Acceleration bands (ABANDS). This series requires the
     * `linkedTo` option to be set and should be loaded after the
     * `stock/indicators/indicators.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `abands` series are defined in plotOptions.abands.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.abands
     */
    abands?: PlotAbandsOptions;
    /**
     * (Highstock) Accumulation Distribution (AD). This series requires
     * `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `ad` series are defined in plotOptions.ad.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ad
     */
    ad?: PlotAdOptions;
    /**
     * (Highstock) Awesome Oscillator. This series requires the `linkedTo`
     * option to be set and should be loaded after the
     * `stock/indicators/indicators.js`
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `ao` series are defined in plotOptions.ao.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ao
     */
    ao?: PlotAoOptions;
    /**
     * (Highstock) Absolute Price Oscillator. This series requires the
     * `linkedTo` option to be set and should be loaded after the
     * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `apo` series are defined in plotOptions.apo.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.apo
     */
    apo?: PlotApoOptions;
    /**
     * (Highcharts, Highstock) The area series type.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `area` series are defined in plotOptions.area.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.area
     * @see https://api.highcharts.com/highstock/plotOptions.area
     */
    area?: PlotAreaOptions;
    /**
     * (Highcharts, Highstock) The area range series is a carteseian series with
     * higher and lower values for each point along an X axis, where the area
     * between the values is shaded. Requires `highcharts-more.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `arearange` series are defined in
     * plotOptions.arearange.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.arearange
     * @see https://api.highcharts.com/highstock/plotOptions.arearange
     */
    arearange?: PlotArearangeOptions;
    /**
     * (Highcharts, Highstock) The area spline series is an area series where
     * the graph between the points is smoothed into a spline.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `areaspline` series are defined in
     * plotOptions.areaspline.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areaspline
     * @see https://api.highcharts.com/highstock/plotOptions.areaspline
     */
    areaspline?: PlotAreasplineOptions;
    /**
     * (Highcharts, Highstock) The area spline range is a cartesian series type
     * with higher and lower Y values along an X axis. The area inside the range
     * is colored, and the graph outlining the area is a smoothed spline.
     * Requires `highcharts-more.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `areasplinerange` series are defined in
     * plotOptions.areasplinerange.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.areasplinerange
     * @see https://api.highcharts.com/highstock/plotOptions.areasplinerange
     */
    areasplinerange?: PlotAreasplinerangeOptions;
    /**
     * (Highstock) Aroon. This series requires the `linkedTo` option to be set
     * and should be loaded after the `stock/indicators/indicators.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `aroon` series are defined in plotOptions.aroon.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroon
     */
    aroon?: PlotAroonOptions;
    /**
     * (Highstock) Aroon Oscillator. This series requires the `linkedTo` option
     * to be set and should be loaded after the `stock/indicators/indicators.js`
     * and `stock/indicators/aroon.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `aroonoscillator` series are defined in
     * plotOptions.aroonoscillator.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.aroonoscillator
     */
    aroonoscillator?: PlotAroonoscillatorOptions;
    /**
     * (Highstock) Average true range indicator (ATR). This series requires
     * `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `atr` series are defined in plotOptions.atr.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.atr
     */
    atr?: PlotAtrOptions;
    /**
     * (Highcharts) A bar series is a special type of column series where the
     * columns are horizontal.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `bar` series are defined in plotOptions.bar.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bar
     */
    bar?: PlotBarOptions;
    /**
     * (Highstock) Bollinger bands (BB). This series requires the `linkedTo`
     * option to be set and should be loaded after the
     * `stock/indicators/indicators.js` file.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `bb` series are defined in plotOptions.bb.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.bb
     */
    bb?: PlotBbOptions;
    /**
     * (Highcharts) A bell curve is an areaspline series which represents the
     * probability density function of the normal distribution. It calculates
     * mean and standard deviation of the base series data and plots the curve
     * according to the calculated parameters.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `bellcurve` series are defined in
     * plotOptions.bellcurve.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bellcurve
     */
    bellcurve?: PlotBellcurveOptions;
    /**
     * (Highcharts) A box plot is a convenient way of depicting groups of data
     * through their five-number summaries: the smallest observation (sample
     * minimum), lower quartile (Q1), median (Q2), upper quartile (Q3), and
     * largest observation (sample maximum).
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `boxplot` series are defined in plotOptions.boxplot.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.boxplot
     */
    boxplot?: PlotBoxplotOptions;
    /**
     * (Highcharts, Highstock) A bubble series is a three dimensional series
     * type where each point renders an X, Y and Z value. Each points is drawn
     * as a bubble where the position along the X and Y axes mark the X and Y
     * values, and the size of the bubble relates to the Z value. Requires
     * `highcharts-more.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `bubble` series are defined in plotOptions.bubble.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bubble
     * @see https://api.highcharts.com/highstock/plotOptions.bubble
     */
    bubble?: PlotBubbleOptions;
    /**
     * (Highcharts) A bullet graph is a variation of a bar graph. The bullet
     * graph features a single measure, compares it to a target, and displays it
     * in the context of qualitative ranges of performance that could be set
     * using plotBands on yAxis.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `bullet` series are defined in plotOptions.bullet.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.bullet
     */
    bullet?: PlotBulletOptions;
    /**
     * (Highstock) A candlestick chart is a style of financial chart used to
     * describe price movements over time.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `candlestick` series are defined in
     * plotOptions.candlestick.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.candlestick
     */
    candlestick?: PlotCandlestickOptions;
    /**
     * (Highstock) Commodity Channel Index (CCI). This series requires
     * `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `cci` series are defined in plotOptions.cci.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cci
     */
    cci?: PlotCciOptions;
    /**
     * (Highstock) Chaikin Oscillator. This series requires the `linkedTo`
     * option to be set and should be loaded after the
     * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `chaikin` series are defined in plotOptions.chaikin.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.chaikin
     */
    chaikin?: PlotChaikinOptions;
    /**
     * (Highstock) Chaikin Money Flow indicator (cmf).
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `cmf` series are defined in plotOptions.cmf.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.cmf
     */
    cmf?: PlotCmfOptions;
    /**
     * (Highcharts, Highstock) Column series display one column per value along
     * an X axis.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `column` series are defined in plotOptions.column.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.column
     * @see https://api.highcharts.com/highstock/plotOptions.column
     */
    column?: PlotColumnOptions;
    /**
     * (Highcharts, Highstock) Column pyramid series display one pyramid per
     * value along an X axis. Requires `highcharts-more.js`. To display
     * horizontal pyramids, set chart.inverted to `true`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `columnpyramid` series are defined in
     * plotOptions.columnpyramid.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnpyramid
     * @see https://api.highcharts.com/highstock/plotOptions.columnpyramid
     */
    columnpyramid?: PlotColumnpyramidOptions;
    /**
     * (Highcharts, Highstock) The column range is a cartesian series type with
     * higher and lower Y values along an X axis. Requires `highcharts-more.js`.
     * To display horizontal bars, set chart.inverted to `true`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `columnrange` series are defined in
     * plotOptions.columnrange.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.columnrange
     * @see https://api.highcharts.com/highstock/plotOptions.columnrange
     */
    columnrange?: PlotColumnrangeOptions;
    /**
     * (Highcharts) A cylinder graph is a variation of a 3d column graph. The
     * cylinder graph features cylindrical points.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `cylinder` series are defined in plotOptions.cylinder.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.cylinder
     */
    cylinder?: PlotCylinderOptions;
    /**
     * (Highstock) Normalized average true range indicator (NATR). This series
     * requires `linkedTo` option to be set and should be loaded after the
     * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `dema` series are defined in plotOptions.dema.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dema
     */
    dema?: PlotDemaOptions;
    /**
     * (Highstock) Detrended Price Oscillator. This series requires the
     * `linkedTo` option to be set and should be loaded after the
     * `stock/indicators/indicators.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `dpo` series are defined in plotOptions.dpo.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.dpo
     */
    dpo?: PlotDpoOptions;
    /**
     * (Highstock) Exponential moving average indicator (EMA). This series
     * requires the `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `ema` series are defined in plotOptions.ema.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ema
     */
    ema?: PlotEmaOptions;
    /**
     * (Highcharts, Highstock) Error bars are a graphical representation of the
     * variability of data and are used on graphs to indicate the error, or
     * uncertainty in a reported measurement.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `errorbar` series are defined in plotOptions.errorbar.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.errorbar
     * @see https://api.highcharts.com/highstock/plotOptions.errorbar
     */
    errorbar?: PlotErrorbarOptions;
    /**
     * (Highstock) Flags are used to mark events in stock charts. They can be
     * added on the timeline, or attached to a specific series.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `flags` series are defined in plotOptions.flags.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.flags
     */
    flags?: PlotFlagsOptions;
    /**
     * (Highcharts) Funnel charts are a type of chart often used to visualize
     * stages in a sales project, where the top are the initial stages with the
     * most clients. It requires that the modules/funnel.js file is loaded.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `funnel` series are defined in plotOptions.funnel.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.funnel
     */
    funnel?: PlotFunnelOptions;
    /**
     * (Gantt) A `gantt` series. If the type option is not specified, it is
     * inherited from chart.type.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `gantt` series are defined in plotOptions.gantt.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/gantt/plotOptions.gantt
     */
    gantt?: PlotGanttOptions;
    /**
     * (Highcharts) Gauges are circular plots displaying one or more values with
     * a dial pointing to values along the perimeter.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `gauge` series are defined in plotOptions.gauge.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.gauge
     */
    gauge?: PlotGaugeOptions;
    /**
     * (Highcharts, Highmaps) A heatmap is a graphical representation of data
     * where the individual values contained in a matrix are represented as
     * colors.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `heatmap` series are defined in plotOptions.heatmap.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.heatmap
     * @see https://api.highcharts.com/highmaps/plotOptions.heatmap
     */
    heatmap?: PlotHeatmapOptions;
    /**
     * (Highcharts) A histogram is a column series which represents the
     * distribution of the data set in the base series. Histogram splits data
     * into bins and shows their frequencies.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `histogram` series are defined in
     * plotOptions.histogram.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.histogram
     */
    histogram?: PlotHistogramOptions;
    /**
     * (Highstock) Ichimoku Kinko Hyo (IKH). This series requires `linkedTo`
     * option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `ikh` series are defined in plotOptions.ikh.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ikh
     */
    ikh?: PlotIkhOptions;
    /**
     * (Highstock) Keltner Channels. This series requires the `linkedTo` option
     * to be set and should be loaded after the
     * `stock/indicators/indicators.js`, `stock/indicators/atr.js`, and
     * `stock/ema/.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `keltnerchannels` series are defined in
     * plotOptions.keltnerchannels.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.keltnerchannels
     */
    keltnerchannels?: PlotKeltnerchannelsOptions;
    /**
     * (Highcharts, Highstock) A line series displays information as a series of
     * data points connected by straight line segments.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `line` series are defined in plotOptions.line.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.line
     * @see https://api.highcharts.com/highstock/plotOptions.line
     */
    line?: PlotLineOptions;
    /**
     * (Highstock) Linear regression indicator. This series requires `linkedTo`
     * option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `linearregression` series are defined in
     * plotOptions.linearregression.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregression
     */
    linearregression?: PlotLinearregressionOptions;
    /**
     * (Highstock) Linear regression angle indicator. This series requires
     * `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `linearregressionangle` series are defined in
     * plotOptions.linearregressionangle.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionangle
     */
    linearregressionangle?: PlotLinearregressionangleOptions;
    /**
     * (Highstock) Linear regression intercept indicator. This series requires
     * `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `linearregressionintercept` series are defined in
     * plotOptions.linearregressionintercept.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionintercept
     */
    linearregressionintercept?: PlotLinearregressioninterceptOptions;
    /**
     * (Highstock) Linear regression slope indicator. This series requires
     * `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `linearregressionslope` series are defined in
     * plotOptions.linearregressionslope.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.linearregressionslope
     */
    linearregressionslope?: PlotLinearregressionslopeOptions;
    /**
     * (Highstock) Moving Average Convergence Divergence (MACD). This series
     * requires `linkedTo` option to be set and should be loaded after the
     * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `macd` series are defined in plotOptions.macd.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.macd
     */
    macd?: PlotMacdOptions;
    /**
     * (Highmaps) The map series is used for basic choropleth maps, where each
     * map area has a color based on its value.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `map` series are defined in plotOptions.map.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.map
     */
    map?: PlotMapOptions;
    /**
     * (Highmaps) A map bubble series is a bubble series laid out on top of a
     * map series, where each bubble is tied to a specific map area.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `mapbubble` series are defined in
     * plotOptions.mapbubble.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapbubble
     */
    mapbubble?: PlotMapbubbleOptions;
    /**
     * (Highmaps) A mapline series is a special case of the map series where the
     * value colors are applied to the strokes rather than the fills. It can
     * also be used for freeform drawing, like dividers, in the map.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `mapline` series are defined in plotOptions.mapline.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mapline
     */
    mapline?: PlotMaplineOptions;
    /**
     * (Highmaps) A mappoint series is a special form of scatter series where
     * the points can be laid out in map coordinates on top of a map.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `mappoint` series are defined in plotOptions.mappoint.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.mappoint
     */
    mappoint?: PlotMappointOptions;
    /**
     * (Highstock) Money Flow Index. This series requires `linkedTo` option to
     * be set and should be loaded after the `stock/indicators/indicators.js`
     * file.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `mfi` series are defined in plotOptions.mfi.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.mfi
     */
    mfi?: PlotMfiOptions;
    /**
     * (Highstock) Momentum. This series requires `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `momentum` series are defined in plotOptions.momentum.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.momentum
     */
    momentum?: PlotMomentumOptions;
    /**
     * (Highstock) Normalized average true range indicator (NATR). This series
     * requires `linkedTo` option to be set and should be loaded after the
     * `stock/indicators/indicators.js` and `stock/indicators/atr.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `natr` series are defined in plotOptions.natr.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.natr
     */
    natr?: PlotNatrOptions;
    /**
     * (Highcharts) A networkgraph is a type of relationship chart, where
     * connnections (links) attracts nodes (points) and other nodes repulse each
     * other.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `networkgraph` series are defined in
     * plotOptions.networkgraph.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.networkgraph
     */
    networkgraph?: PlotNetworkgraphOptions;
    /**
     * (Highstock) An OHLC chart is a style of financial chart used to describe
     * price movements over time. It displays open, high, low and close values
     * per data point.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `ohlc` series are defined in plotOptions.ohlc.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ohlc
     */
    ohlc?: PlotOhlcOptions;
    /**
     * (Highcharts) A packed bubble series is a two dimensional series type,
     * where each point renders a value in X, Y position. Each point is drawn as
     * a bubble where the bubbles don't overlap with each other and the radius
     * of the bubble related to the value. Requires `highcharts-more.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `packedbubble` series are defined in
     * plotOptions.packedbubble.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble
     */
    packedbubble?: PlotPackedbubbleOptions;
    /**
     * (Highcharts) A pareto diagram is a type of chart that contains both bars
     * and a line graph, where individual values are represented in descending
     * order by bars, and the cumulative total is represented by the line.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `pareto` series are defined in plotOptions.pareto.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto
     */
    pareto?: PlotParetoOptions;
    /**
     * (Highstock) Price channel (PC). This series requires the `linkedTo`
     * option to be set and should be loaded after the
     * `stock/indicators/indicators.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `pc` series are defined in plotOptions.pc.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc
     */
    pc?: PlotPcOptions;
    /**
     * (Highcharts) A pie chart is a circular graphic which is divided into
     * slices to illustrate numerical proportion.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `pie` series are defined in plotOptions.pie.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie
     */
    pie?: PlotPieOptions;
    /**
     * (Highstock) Pivot points indicator. This series requires the `linkedTo`
     * option to be set and should be loaded after
     * `stock/indicators/indicators.js` file.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `pivotpoints` series are defined in
     * plotOptions.pivotpoints.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints
     */
    pivotpoints?: PlotPivotpointsOptions;
    /**
     * (Highcharts, Highstock) A polygon series can be used to draw any freeform
     * shape in the cartesian coordinate system. A fill is applied with the
     * `color` option, and stroke is applied through `lineWidth` and `lineColor`
     * options. Requires the `highcharts-more.js` file.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `polygon` series are defined in plotOptions.polygon.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon
     * @see https://api.highcharts.com/highstock/plotOptions.polygon
     */
    polygon?: PlotPolygonOptions;
    /**
     * (Highstock) Percentage Price Oscillator. This series requires the
     * `linkedTo` option to be set and should be loaded after the
     * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `ppo` series are defined in plotOptions.ppo.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo
     */
    ppo?: PlotPpoOptions;
    /**
     * (Highstock) Price envelopes indicator based on SMA calculations. This
     * series requires the `linkedTo` option to be set and should be loaded
     * after the `stock/indicators/indicators.js` file.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `priceenvelopes` series are defined in
     * plotOptions.priceenvelopes.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes
     */
    priceenvelopes?: PlotPriceenvelopesOptions;
    /**
     * (Highstock) Parabolic SAR. This series requires `linkedTo` option to be
     * set and should be loaded after `stock/indicators/indicators.js` file.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `psar` series are defined in plotOptions.psar.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar
     */
    psar?: PlotPsarOptions;
    /**
     * (Highcharts) A pyramid series is a special type of funnel, without neck
     * and reversed by default. Requires the funnel module.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `pyramid` series are defined in plotOptions.pyramid.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid
     */
    pyramid?: PlotPyramidOptions;
    /**
     * (Highstock) Rate of change indicator (ROC). The indicator value for each
     * point is defined as:
     *
     * `(C - Cn) / Cn * 100`
     *
     * where: `C` is the close value of the point of the same x in the linked
     * series and `Cn` is the close value of the point `n` periods ago. `n` is
     * set through period.
     *
     * This series requires `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `roc` series are defined in plotOptions.roc.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc
     */
    roc?: PlotRocOptions;
    /**
     * (Highstock) Relative strength index (RSI) technical indicator. This
     * series requires the `linkedTo` option to be set and should be loaded
     * after the `stock/indicators/indicators.js` file.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `rsi` series are defined in plotOptions.rsi.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi
     */
    rsi?: PlotRsiOptions;
    /**
     * (Highcharts) A sankey diagram is a type of flow diagram, in which the
     * width of the link between two nodes is shown proportionally to the flow
     * quantity.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `sankey` series are defined in plotOptions.sankey.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey
     */
    sankey?: PlotSankeyOptions;
    /**
     * (Highcharts, Highstock) A scatter plot uses cartesian coordinates to
     * display values for two variables for a set of data.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `scatter` series are defined in plotOptions.scatter.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter
     * @see https://api.highcharts.com/highstock/plotOptions.scatter
     */
    scatter?: PlotScatterOptions;
    /**
     * (Highcharts) A 3D scatter plot uses x, y and z coordinates to display
     * values for three variables for a set of data.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `scatter3d` series are defined in
     * plotOptions.scatter3d.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d
     */
    scatter3d?: PlotScatter3dOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) General options for all series
     * types.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `line` series are defined in plotOptions.line.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series
     * @see https://api.highcharts.com/highstock/plotOptions.series
     * @see https://api.highcharts.com/highmaps/plotOptions.series
     * @see https://api.highcharts.com/gantt/plotOptions.series
     */
    series?: PlotSeriesOptions;
    /**
     * (Highstock) Simple moving average indicator (SMA). This series requires
     * `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `sma` series are defined in plotOptions.sma.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma
     */
    sma?: PlotSmaOptions;
    /**
     * (Highcharts) A solid gauge is a circular gauge where the value is
     * indicated by a filled arc, and the color of the arc may variate with the
     * value.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `solidgauge` series are defined in
     * plotOptions.solidgauge.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge
     */
    solidgauge?: PlotSolidgaugeOptions;
    /**
     * (Highcharts, Highstock) A spline series is a special type of line series,
     * where the segments between the data points are smoothed.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `spline` series are defined in plotOptions.spline.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline
     * @see https://api.highcharts.com/highstock/plotOptions.spline
     */
    spline?: PlotSplineOptions;
    /**
     * (Highstock) Stochastic oscillator. This series requires the `linkedTo`
     * option to be set and should be loaded after the
     * `stock/indicators/indicators.js` file.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `stochastic` series are defined in
     * plotOptions.stochastic.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic
     */
    stochastic?: PlotStochasticOptions;
    /**
     * (Highcharts, Highstock) A streamgraph is a type of stacked area graph
     * which is displaced around a central axis, resulting in a flowing, organic
     * shape.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `streamgraph` series are defined in
     * plotOptions.streamgraph.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph
     */
    streamgraph?: PlotStreamgraphOptions;
    /**
     * (Highcharts) A Sunburst displays hierarchical data, where a level in the
     * hierarchy is represented by a circle. The center represents the root node
     * of the tree. The visualization bears a resemblance to both treemap and
     * pie charts.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `sunburst` series are defined in plotOptions.sunburst.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst
     */
    sunburst?: PlotSunburstOptions;
    /**
     * (Highstock) Supertrend indicator. This series requires the `linkedTo`
     * option to be set and should be loaded after the
     * `stock/indicators/indicators.js` and `stock/indicators/sma.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `supertrend` series are defined in
     * plotOptions.supertrend.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend
     */
    supertrend?: PlotSupertrendOptions;
    /**
     * (Highstock) Normalized average true range indicator (NATR). This series
     * requires `linkedTo` option to be set and should be loaded after the
     * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
     *
     * Requires `https://code.highcharts.com/stock/indicators/ema.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `tema` series are defined in plotOptions.tema.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema
     */
    tema?: PlotTemaOptions;
    /**
     * (Highcharts, Highmaps) A tilemap series is a type of heatmap where the
     * tile shapes are configurable.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `tilemap` series are defined in plotOptions.tilemap.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap
     */
    tilemap?: PlotTilemapOptions;
    /**
     * (Highcharts) A treemap displays hierarchical data using nested
     * rectangles. The data can be laid out in varying ways depending on
     * options.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `treemap` series are defined in plotOptions.treemap.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap
     */
    treemap?: PlotTreemapOptions;
    /**
     * (Highstock) Normalized average true range indicator (NATR). This series
     * requires `linkedTo` option to be set.
     *
     * Requires https://code.highcharts.com/stock/indicators/ema.js and
     * https://code.highcharts.com/stock/indicators/tema.js.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `trix` series are defined in plotOptions.trix.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix
     */
    trix?: PlotTrixOptions;
    /**
     * (Highcharts) A variable pie series is a two dimensional series type,
     * where each point renders an Y and Z value. Each point is drawn as a pie
     * slice where the size (arc) of the slice relates to the Y value and the
     * radius of pie slice relates to the Z value. Requires
     * `highcharts-more.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `variablepie` series are defined in
     * plotOptions.variablepie.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie
     */
    variablepie?: PlotVariablepieOptions;
    /**
     * (Highcharts) A variwide chart (related to marimekko chart) is a column
     * chart with a variable width expressing a third dimension.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `variwide` series are defined in plotOptions.variwide.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide
     */
    variwide?: PlotVariwideOptions;
    /**
     * (Highstock) Volume By Price indicator.
     *
     * This series requires `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `vbp` series are defined in plotOptions.vbp.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp
     */
    vbp?: PlotVbpOptions;
    /**
     * (Highcharts, Highstock) A vector plot is a type of cartesian chart where
     * each point has an X and Y position, a length and a direction. Vectors are
     * drawn as arrows.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `vector` series are defined in plotOptions.vector.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector
     * @see https://api.highcharts.com/highstock/plotOptions.vector
     */
    vector?: PlotVectorOptions;
    /**
     * (Highcharts) A Venn diagram displays all possible logical relations
     * between a collection of different sets. The sets are represented by
     * circles, and the relation between the sets are displayed by the overlap
     * or lack of overlap between them. The venn diagram is a special case of
     * Euler diagrams, which can also be displayed by this series type.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `venn` series are defined in plotOptions.venn.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn
     */
    venn?: PlotVennOptions;
    /**
     * (Highstock) Volume Weighted Average Price indicator.
     *
     * This series requires `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `vwap` series are defined in plotOptions.vwap.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap
     */
    vwap?: PlotVwapOptions;
    /**
     * (Highcharts) A waterfall chart displays sequentially introduced positive
     * or negative values in cumulative columns.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `waterfall` series are defined in
     * plotOptions.waterfall.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall
     */
    waterfall?: PlotWaterfallOptions;
    /**
     * (Highstock) Williams %R. This series requires the `linkedTo` option to be
     * set and should be loaded after the `stock/indicators/indicators.js`.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `williamsr` series are defined in
     * plotOptions.williamsr.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr
     */
    williamsr?: PlotWilliamsrOptions;
    /**
     * (Highcharts, Highstock) Wind barbs are a convenient way to represent wind
     * speed and direction in one graphical form. Wind direction is given by the
     * stem direction, and wind speed by the number and shape of barbs.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `windbarb` series are defined in plotOptions.windbarb.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb
     */
    windbarb?: PlotWindbarbOptions;
    /**
     * (Highstock) Weighted moving average indicator (WMA). This series requires
     * `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `wma` series are defined in plotOptions.wma.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma
     */
    wma?: PlotWmaOptions;
    /**
     * (Highcharts) A word cloud is a visualization of a set of words, where the
     * size and placement of a word is determined by how it is weighted.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `wordcloud` series are defined in
     * plotOptions.wordcloud.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud
     */
    wordcloud?: PlotWordcloudOptions;
    /**
     * (Highcharts, Highstock, Gantt) The X-range series displays ranges on the
     * X axis, typically time intervals with a start and end date.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `xrange` series are defined in plotOptions.xrange.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange
     * @see https://api.highcharts.com/highstock/plotOptions.xrange
     * @see https://api.highcharts.com/gantt/plotOptions.xrange
     */
    xrange?: PlotXrangeOptions;
    /**
     * (Highstock) Zig Zag indicator.
     *
     * This series requires `linkedTo` option to be set.
     *
     * Configuration options for the series are given in three levels:
     *
     * 1. Options for all series in a chart are defined in the
     * plotOptions.series object.
     *
     * 2. Options for all `zigzag` series are defined in plotOptions.zigzag.
     *
     * 3. Options for one single series are given in the series instance array.
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag
     */
    zigzag?: PlotZigzagOptions;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.animation
 */
export interface PlotPackedbubbleAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker
 */
export interface PlotPackedbubbleConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker
 */
export interface PlotPackedbubbleConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors
 */
export interface PlotPackedbubbleConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.endMarker
     */
    endMarker?: PlotPackedbubbleConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.marker
     */
    marker?: PlotPackedbubbleConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker
     */
    startMarker?: PlotPackedbubbleConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker
 */
export interface PlotPackedbubbleConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataGrouping
 */
export interface PlotPackedbubbleDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.filter
 */
export interface PlotPackedbubbleDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels
 */
export interface PlotPackedbubbleDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.filter
     */
    filter?: PlotPackedbubbleDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragHandle
 */
export interface PlotPackedbubbleDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.guideBox.default
 */
export interface PlotPackedbubbleDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.guideBox
 */
export interface PlotPackedbubbleDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.guideBox.default
     */
    default?: PlotPackedbubbleDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop
 */
export interface PlotPackedbubbleDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragHandle
     */
    dragHandle?: PlotPackedbubbleDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.guideBox
     */
    guideBox?: (PlotPackedbubbleDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.events
 */
export interface PlotPackedbubbleEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.label
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.label
 * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.label
 */
export interface PlotPackedbubbleLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.lastPrice
 */
export interface PlotPackedbubbleLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotPackedbubbleLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.lastVisiblePrice
 */
export interface PlotPackedbubbleLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotPackedbubbleLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker
 */
export interface PlotPackedbubbleMarkerOptions {
    /**
     * (Highcharts) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The fill opacity of the bubble markers.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.fillOpacity
     */
    fillOpacity?: number;
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.lineColor
     */
    lineColor?: any;
    /**
     * (Highcharts) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states
     */
    states?: PlotPackedbubbleMarkerStatesOptions;
    /**
     * (Highcharts) A predefined shape or symbol for the marker. Possible values
     * are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on the form
     * `url(graphic.png)`. Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.symbol
     */
    symbol?: ("circle"|"diamond"|"square"|"triangle"|"triangle-down");
}
/**
 * (Highcharts) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover.animation
 */
export interface PlotPackedbubbleMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover
 */
export interface PlotPackedbubbleMarkerStatesHoverOptions {
    /**
     * (Highcharts) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPackedbubbleMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.normal
 */
export interface PlotPackedbubbleMarkerStatesNormalOptions {
    /**
     * (Highcharts) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states
 */
export interface PlotPackedbubbleMarkerStatesOptions {
    /**
     * (Highcharts) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.hover
     */
    hover?: PlotPackedbubbleMarkerStatesHoverOptions;
    /**
     * (Highcharts) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.normal
     */
    normal?: PlotPackedbubbleMarkerStatesNormalOptions;
    /**
     * (Highcharts) The appearance of the point marker when selected. In order
     * to allow a point to be selected, set the `series.allowPointSelect` option
     * to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.select
     */
    select?: PlotPackedbubbleMarkerStatesSelectOptions;
}
/**
 * (Highcharts) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.select
 */
export interface PlotPackedbubbleMarkerStatesSelectOptions {
    /**
     * (Highcharts) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) A packed bubble series is a two dimensional series type, where
 * each point renders a value in X, Y position. Each point is drawn as a bubble
 * where the bubbles don't overlap with each other and the radius of the bubble
 * related to the value. Requires `highcharts-more.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `packedbubble` series are defined in
 * plotOptions.packedbubble.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble
 */
export interface PlotPackedbubbleOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPackedbubbleAnimationOptions);
    /**
     * (Highcharts) If there are more points in the series than the
     * `animationLimit`, the animation won't run. Animation affects overall
     * performance and doesn't work well with heavy data series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.connectors
     */
    connectors?: PlotPackedbubbleConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.dataGrouping
     */
    dataGrouping?: PlotPackedbubbleDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dataLabels
     */
    dataLabels?: PlotPackedbubbleDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.description
     */
    description?: string;
    /**
     * (Highcharts) Whether to display negative sized bubbles. The threshold is
     * given by the zThreshold option, and negative bubbles can be visualized by
     * setting negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.displayNegative
     */
    displayNegative?: boolean;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.dragDrop
     */
    dragDrop?: PlotPackedbubbleDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.events
     */
    events?: PlotPackedbubbleEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.label
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.label
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.label
     */
    label?: PlotPackedbubbleLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.lastPrice
     */
    lastPrice?: PlotPackedbubbleLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.lastVisiblePrice
     */
    lastVisiblePrice?: PlotPackedbubbleLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) The width of the line connecting the data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) Options for the point markers of line-like series.
     * Properties like `fillColor`, `lineColor` and `lineWidth` define the
     * visual appearance of the markers. Other series types, like column series,
     * don't have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.marker
     */
    marker?: PlotPackedbubbleMarkerOptions;
    /**
     * (Highcharts, Highstock) Maximum bubble size. Bubbles will automatically
     * size between the `minSize` and `maxSize` to reflect the value of each
     * bubble. Can be either pixels (when no unit is given), or a percentage of
     * the smallest one of the plot width and height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.maxSize
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.maxSize
     */
    maxSize?: (number|string);
    /**
     * (Highcharts, Highstock) Minimum bubble size. Bubbles will automatically
     * size between the `minSize` and `maxSize` to reflect the value of each
     * bubble. Can be either pixels (when no unit is given), or a percentage of
     * the smallest one of the plot width and height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.minSize
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.minSize
     */
    minSize?: (number|string);
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) When a point's Z value is below the zThreshold setting, this
     * color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point
     */
    point?: PlotPackedbubblePointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) Whether the bubble's value should be represented by the area
     * or the width of the bubble. The default, `area`, corresponds best to the
     * human perception of the size of each bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.sizeBy
     */
    sizeBy?: ("area"|"width");
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) When this is true, the series will not cause the Y axis to
     * cross the zero plane (or threshold option) unless the data actually
     * crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states
     */
    states?: PlotPackedbubbleStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip
     */
    tooltip?: PlotPackedbubbleTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.zones
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.zones
     */
    zones?: Array<PlotPackedbubbleZonesOptions>;
    /**
     * (Highcharts) When displayNegative is `false`, bubbles with lower Z values
     * are skipped. When `displayNegative` is `true` and a negativeColor is
     * given, points with lower Z is colored.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.zThreshold
     */
    zThreshold?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events
 */
export interface PlotPackedbubblePointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point
 */
export interface PlotPackedbubblePointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.point.events
     */
    events?: PlotPackedbubblePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.animation
 */
export interface PlotPackedbubbleStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.halo
 */
export interface PlotPackedbubbleStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker
 */
export interface PlotPackedbubbleStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states
     */
    states?: PlotPackedbubbleStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover.animation
 */
export interface PlotPackedbubbleStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover
 */
export interface PlotPackedbubbleStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPackedbubbleStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.normal
 */
export interface PlotPackedbubbleStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states
 */
export interface PlotPackedbubbleStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.hover
     */
    hover?: PlotPackedbubbleStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.normal
     */
    normal?: PlotPackedbubbleStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.select
     */
    select?: PlotPackedbubbleStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.select
 */
export interface PlotPackedbubbleStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover
 */
export interface PlotPackedbubbleStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPackedbubbleStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.halo
     */
    halo?: PlotPackedbubbleStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.hover.marker
     */
    marker?: PlotPackedbubbleStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.normal
 */
export interface PlotPackedbubbleStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states
 */
export interface PlotPackedbubbleStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.hover
     */
    hover?: PlotPackedbubbleStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.normal
     */
    normal?: PlotPackedbubbleStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.select
     */
    select?: PlotPackedbubbleStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.animation
 */
export interface PlotPackedbubbleStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.halo
 */
export interface PlotPackedbubbleStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker
 */
export interface PlotPackedbubbleStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states
     */
    states?: PlotPackedbubbleStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover.animation
 */
export interface PlotPackedbubbleStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover
 */
export interface PlotPackedbubbleStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPackedbubbleStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.normal
 */
export interface PlotPackedbubbleStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states
 */
export interface PlotPackedbubbleStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.hover
     */
    hover?: PlotPackedbubbleStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.normal
     */
    normal?: PlotPackedbubbleStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.select
     */
    select?: PlotPackedbubbleStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.select
 */
export interface PlotPackedbubbleStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.select
 */
export interface PlotPackedbubbleStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPackedbubbleStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.packedbubble.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.halo
     */
    halo?: PlotPackedbubbleStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.states.select.marker
     */
    marker?: PlotPackedbubbleStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.tooltip.dateTimeLabelFormats
 */
export interface PlotPackedbubbleTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip
 */
export interface PlotPackedbubbleTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotPackedbubbleTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.packedbubble.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.zones
 * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.zones
 */
export interface PlotPackedbubbleZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.packedbubble.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.packedbubble.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.animation
 */
export interface PlotParetoAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker
 */
export interface PlotParetoConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker
 */
export interface PlotParetoConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors
 */
export interface PlotParetoConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.endMarker
     */
    endMarker?: PlotParetoConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.marker
     */
    marker?: PlotParetoConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker
     */
    startMarker?: PlotParetoConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker
 */
export interface PlotParetoConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataGrouping
 */
export interface PlotParetoDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.filter
 */
export interface PlotParetoDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels
 */
export interface PlotParetoDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.filter
     */
    filter?: PlotParetoDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragHandle
 */
export interface PlotParetoDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.guideBox.default
 */
export interface PlotParetoDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.guideBox
 */
export interface PlotParetoDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.guideBox.default
     */
    default?: PlotParetoDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop
 */
export interface PlotParetoDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragHandle
     */
    dragHandle?: PlotParetoDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.guideBox
     */
    guideBox?: (PlotParetoDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.events
 */
export interface PlotParetoEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.label
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.label
 * @see https://api.highcharts.com/gantt/plotOptions.pareto.label
 */
export interface PlotParetoLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.lastPrice
 */
export interface PlotParetoLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotParetoLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.lastVisiblePrice
 */
export interface PlotParetoLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotParetoLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker
 */
export interface PlotParetoMarkerOptions {
    /**
     * (Highcharts) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.height
     */
    height?: number;
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states
     */
    states?: PlotParetoMarkerStatesOptions;
    /**
     * (Highcharts) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.width
     */
    width?: number;
}
/**
 * (Highcharts) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover.animation
 */
export interface PlotParetoMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover
 */
export interface PlotParetoMarkerStatesHoverOptions {
    /**
     * (Highcharts) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotParetoMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.normal
 */
export interface PlotParetoMarkerStatesNormalOptions {
    /**
     * (Highcharts) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states
 */
export interface PlotParetoMarkerStatesOptions {
    /**
     * (Highcharts) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.hover
     */
    hover?: PlotParetoMarkerStatesHoverOptions;
    /**
     * (Highcharts) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.normal
     */
    normal?: PlotParetoMarkerStatesNormalOptions;
    /**
     * (Highcharts) The appearance of the point marker when selected. In order
     * to allow a point to be selected, set the `series.allowPointSelect` option
     * to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.select
     */
    select?: PlotParetoMarkerStatesSelectOptions;
}
/**
 * (Highcharts) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.select
 */
export interface PlotParetoMarkerStatesSelectOptions {
    /**
     * (Highcharts) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) A pareto diagram is a type of chart that contains both bars and
 * a line graph, where individual values are represented in descending order by
 * bars, and the cumulative total is represented by the line.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `pareto` series are defined in plotOptions.pareto.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto
 */
export interface PlotParetoOptions {
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotParetoAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.connectors
     */
    connectors?: PlotParetoConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.dataGrouping
     */
    dataGrouping?: PlotParetoDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dataLabels
     */
    dataLabels?: PlotParetoDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.dragDrop
     */
    dragDrop?: PlotParetoDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.events
     */
    events?: PlotParetoEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.label
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.label
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.label
     */
    label?: PlotParetoLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.lastPrice
     */
    lastPrice?: PlotParetoLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.lastVisiblePrice
     */
    lastVisiblePrice?: PlotParetoLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) Options for the point markers of line-like series.
     * Properties like `fillColor`, `lineColor` and `lineWidth` define the
     * visual appearance of the markers. Other series types, like column series,
     * don't have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.marker
     */
    marker?: PlotParetoMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point
     */
    point?: PlotParetoPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states
     */
    states?: PlotParetoStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip
     */
    tooltip?: PlotParetoTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) The parameter allows setting line series type and use OHLC
     * indicators. Data in OHLC format is required.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.useOhlcData
     */
    useOhlcData?: boolean;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Higher zIndex than column series to draw line above shapes.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events
 */
export interface PlotParetoPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point
 */
export interface PlotParetoPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.point.events
     */
    events?: PlotParetoPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.animation
 */
export interface PlotParetoStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.halo
 */
export interface PlotParetoStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker
 */
export interface PlotParetoStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states
     */
    states?: PlotParetoStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover.animation
 */
export interface PlotParetoStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover
 */
export interface PlotParetoStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotParetoStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.normal
 */
export interface PlotParetoStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states
 */
export interface PlotParetoStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.hover
     */
    hover?: PlotParetoStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.normal
     */
    normal?: PlotParetoStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.select
     */
    select?: PlotParetoStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.select
 */
export interface PlotParetoStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover
 */
export interface PlotParetoStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotParetoStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.halo
     */
    halo?: PlotParetoStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.hover.marker
     */
    marker?: PlotParetoStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.normal
 */
export interface PlotParetoStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states
 */
export interface PlotParetoStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.hover
     */
    hover?: PlotParetoStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.normal
     */
    normal?: PlotParetoStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.select
     */
    select?: PlotParetoStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.animation
 */
export interface PlotParetoStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.halo
 */
export interface PlotParetoStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker
 */
export interface PlotParetoStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states
     */
    states?: PlotParetoStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover.animation
 */
export interface PlotParetoStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover
 */
export interface PlotParetoStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotParetoStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.normal
 */
export interface PlotParetoStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states
 */
export interface PlotParetoStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.hover
     */
    hover?: PlotParetoStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.normal
     */
    normal?: PlotParetoStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.select
     */
    select?: PlotParetoStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.select
 */
export interface PlotParetoStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.select
 */
export interface PlotParetoStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotParetoStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pareto.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.halo
     */
    halo?: PlotParetoStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.states.select.marker
     */
    marker?: PlotParetoStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.pareto.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.pareto.tooltip.dateTimeLabelFormats
 */
export interface PlotParetoTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip
 */
export interface PlotParetoTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotParetoTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pareto.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.pareto.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.pareto.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.animation
 */
export interface PlotPcAnimationOptions {
    duration?: number;
}
export interface PlotPcBottomLineOptions {
    styles?: PlotPcBottomLineStylesOptions;
}
export interface PlotPcBottomLineStylesOptions {
    /**
     * (Highstock) Color of the bottom line. If not set, it's inherited from
     * plotOptions.pc.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.bottomLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.bottomLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker
 */
export interface PlotPcConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker
 */
export interface PlotPcConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors
 */
export interface PlotPcConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.endMarker
     */
    endMarker?: PlotPcConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.marker
     */
    marker?: PlotPcConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker
     */
    startMarker?: PlotPcConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker
 */
export interface PlotPcConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.dataGrouping
 */
export interface PlotPcDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.filter
 */
export interface PlotPcDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels
 */
export interface PlotPcDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.pc.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.filter
     */
    filter?: PlotPcDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragHandle
 */
export interface PlotPcDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.guideBox.default
 */
export interface PlotPcDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.guideBox
 */
export interface PlotPcDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.guideBox.default
     */
    default?: PlotPcDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop
 */
export interface PlotPcDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragHandle
     */
    dragHandle?: PlotPcDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.guideBox
     */
    guideBox?: (PlotPcDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.events
 */
export interface PlotPcEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.pc.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.pc.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.label
 * @see https://api.highcharts.com/highstock/plotOptions.pc.label
 * @see https://api.highcharts.com/gantt/plotOptions.pc.label
 */
export interface PlotPcLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.pc.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.pc.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.pc.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.pc.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.pc.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.pc.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pc.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.pc.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.pc.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.pc.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.pc.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.pc.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.pc.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.pc.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.pc.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.pc.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.lastPrice
 */
export interface PlotPcLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotPcLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.lastVisiblePrice
 */
export interface PlotPcLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotPcLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.marker
 */
export interface PlotPcMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states
     */
    states?: PlotPcMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover.animation
 */
export interface PlotPcMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover
 */
export interface PlotPcMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPcMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.normal
 */
export interface PlotPcMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states
 */
export interface PlotPcMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.hover
     */
    hover?: PlotPcMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.normal
     */
    normal?: PlotPcMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.select
     */
    select?: PlotPcMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.select
 */
export interface PlotPcMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Price channel (PC). This series requires the `linkedTo` option to
 * be set and should be loaded after the `stock/indicators/indicators.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `pc` series are defined in plotOptions.pc.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc
 */
export interface PlotPcOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPcAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.borderWidth
     */
    borderWidth?: number;
    bottomLine?: PlotPcBottomLineOptions;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.pc.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pc.connectors
     */
    connectors?: PlotPcConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pc.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataGrouping
     */
    dataGrouping?: PlotPcDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dataLabels
     */
    dataLabels?: PlotPcDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.dragDrop
     */
    dragDrop?: PlotPcDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.events
     */
    events?: PlotPcEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.pc.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.pc.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.label
     * @see https://api.highcharts.com/highstock/plotOptions.pc.label
     * @see https://api.highcharts.com/gantt/plotOptions.pc.label
     */
    label?: PlotPcLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.lastPrice
     */
    lastPrice?: PlotPcLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.lastVisiblePrice
     */
    lastVisiblePrice?: PlotPcLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.pc.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pc.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.pc.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.pc.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.marker
     */
    marker?: PlotPcMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.params
     */
    params?: PlotPcParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point
     */
    point?: PlotPcPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pc.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states
     */
    states?: PlotPcStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.step
     * @see https://api.highcharts.com/highstock/plotOptions.pc.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.pc.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip
     */
    tooltip?: PlotPcTooltipOptions;
    topLine?: PlotPcTopLineOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pc.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.pc.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.pc.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.zones
     * @see https://api.highcharts.com/highstock/plotOptions.pc.zones
     */
    zones?: Array<PlotPcZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.params
 */
export interface PlotPcParamsOptions {
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events
 */
export interface PlotPcPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.point
 */
export interface PlotPcPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.point.events
     */
    events?: PlotPcPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.animation
 */
export interface PlotPcStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.halo
 */
export interface PlotPcStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker
 */
export interface PlotPcStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states
     */
    states?: PlotPcStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover.animation
 */
export interface PlotPcStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover
 */
export interface PlotPcStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPcStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.normal
 */
export interface PlotPcStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states
 */
export interface PlotPcStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.hover
     */
    hover?: PlotPcStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.normal
     */
    normal?: PlotPcStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.select
     */
    select?: PlotPcStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.select
 */
export interface PlotPcStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover
 */
export interface PlotPcStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPcStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.halo
     */
    halo?: PlotPcStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover.marker
     */
    marker?: PlotPcStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.normal
 */
export interface PlotPcStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states
 */
export interface PlotPcStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.hover
     */
    hover?: PlotPcStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.normal
     */
    normal?: PlotPcStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.select
     */
    select?: PlotPcStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.animation
 */
export interface PlotPcStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.halo
 */
export interface PlotPcStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker
 */
export interface PlotPcStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states
     */
    states?: PlotPcStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover.animation
 */
export interface PlotPcStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover
 */
export interface PlotPcStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPcStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.normal
 */
export interface PlotPcStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states
 */
export interface PlotPcStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.hover
     */
    hover?: PlotPcStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.normal
     */
    normal?: PlotPcStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.select
     */
    select?: PlotPcStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.select
 */
export interface PlotPcStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.select
 */
export interface PlotPcStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPcStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pc.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.halo
     */
    halo?: PlotPcStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.pc.states.select.marker
     */
    marker?: PlotPcStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.pc.tooltip.dateTimeLabelFormats
 */
export interface PlotPcTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip
 */
export interface PlotPcTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.pc.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotPcTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.pc.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.pc.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
export interface PlotPcTopLineOptions {
    styles?: PlotPcTopLineStylesOptions;
}
export interface PlotPcTopLineStylesOptions {
    /**
     * (Highstock) Color of the top line. If not set, it's inherited from
     * plotOptions.pc.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.topLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pc.topLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pc.zones
 * @see https://api.highcharts.com/highstock/plotOptions.pc.zones
 */
export interface PlotPcZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.pc.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.pc.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.pc.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pc.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pc.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.pc.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.animation
 */
export interface PlotPieAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker
 */
export interface PlotPieConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker
 */
export interface PlotPieConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors
 */
export interface PlotPieConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.endMarker
     */
    endMarker?: PlotPieConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.marker
     */
    marker?: PlotPieConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker
     */
    startMarker?: PlotPieConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker
 */
export interface PlotPieConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pie.dataGrouping
 */
export interface PlotPieDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.filter
 */
export interface PlotPieDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels
 */
export interface PlotPieDataLabelsOptions {
    /**
     * (Highcharts) Alignment method for data labels. Possible values are:
     * `'toPlotEdges'` (each label touches the nearest vertical edge of the plot
     * area) or `'connectors'` (connectors have the same x position and the
     * widest label of each half (left & right) touches the nearest vertical
     * edge of the plot area).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.alignTo
     */
    alignTo?: string;
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The color of the line connecting the data label to the pie
     * slice. The default color is the same as the point's color.
     *
     * In styled mode, the connector stroke is given in the
     * `.highcharts-data-label-connector` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.connectorColor
     */
    connectorColor?: ColorString;
    /**
     * (Highcharts) The distance from the data label to the connector. Note that
     * data labels also have a default `padding`, so in order for the connector
     * to touch the text, the `padding` must also be 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.connectorPadding
     */
    connectorPadding?: number;
    /**
     * (Highcharts) Specifies the method that is used to generate the connector
     * path. Highcharts provides 3 built-in connector shapes: `'fixedOffset'`
     * (default), `'straight'` and `'crookedLine'`. Using `'crookedLine'` has
     * the most sense (in most of the cases) when `'alignTo'` is set.
     *
     * Users can provide their own method by passing a function instead of a
     * String. 3 arguments are passed to the callback:
     *
     * (see online documentation for example)
     *
     * The function has to return an SVG path definition in array form (see the
     * example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.connectorShape
     */
    connectorShape?: (() => void|string);
    /**
     * (Highcharts) The width of the line connecting the data label to the pie
     * slice.
     *
     * In styled mode, the connector stroke width is given in the
     * `.highcharts-data-label-connector` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.connectorWidth
     */
    connectorWidth?: number;
    /**
     * (Highcharts) Works only if `connectorShape` is `'crookedLine'`. It
     * defines how far from the vertical plot edge the coonnector path should be
     * crooked.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.crookDistance
     */
    crookDistance?: string;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.pie.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.pie.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) The distance of the data label from the pie's edge. Negative
     * numbers put the data label on top of the pie slices. Connectors are only
     * shown for data labels outside the pie.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.distance
     */
    distance?: number;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.filter
     */
    filter?: PlotPieDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Whether to render the connector as a soft arc or a line with
     * sharp break. Works only if `connectorShape` equals to `fixedOffset`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.softConnector
     */
    softConnector?: number;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragHandle
 */
export interface PlotPieDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.guideBox.default
 */
export interface PlotPieDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.guideBox
 */
export interface PlotPieDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.guideBox.default
     */
    default?: PlotPieDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop
 */
export interface PlotPieDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragHandle
     */
    dragHandle?: PlotPieDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.guideBox
     */
    guideBox?: (PlotPieDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.events
 */
export interface PlotPieEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.pie.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.pie.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the point name in the legend
     * is clicked. One parameter, event, is passed to the function. The state of
     * the checkbox is found by event.checked. The checked item is found by
     * event.item. Return false to prevent the default action which is to toggle
     * the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.events.checkboxClick
     */
    checkboxClick?: () => void;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.label
 * @see https://api.highcharts.com/highstock/plotOptions.pie.label
 * @see https://api.highcharts.com/gantt/plotOptions.pie.label
 */
export interface PlotPieLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.pie.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.pie.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.pie.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.pie.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.pie.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.pie.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pie.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.pie.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.pie.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.pie.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.pie.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.pie.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.pie.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.pie.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.pie.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.pie.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pie.lastPrice
 */
export interface PlotPieLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotPieLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pie.lastVisiblePrice
 */
export interface PlotPieLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotPieLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A pie chart is a circular graphic which is divided into slices
 * to illustrate numerical proportion.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `pie` series are defined in plotOptions.pie.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie
 */
export interface PlotPieOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPieAnimationOptions);
    /**
     * (Highcharts) The color of the border surrounding each slice. When `null`,
     * the border takes the same color as the slice fill. This can be used
     * together with a `borderWidth` to fill drawing gaps created by
     * antialiazing artefacts in borderless pies.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The width of the border surrounding each slice.
     *
     * When setting the border width to 0, there may be small gaps between the
     * slices due to SVG antialiasing artefacts. To work around this, keep the
     * border width at 0.5 or 1, but set the `borderColor` to `null` instead.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) The center of the pie chart relative to the plot area. Can
     * be percentages or pixel values. The default behaviour (as of 3.0) is to
     * center the pie so that all slices and data labels are within the plot
     * area. As a consequence, the pie may actually jump around in a chart with
     * dynamic values, as the data labels move. In that case, the center should
     * be explicitly set, for example to `["50%", "50%"]`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.center
     */
    center?: Array<(number|string|null)>;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts) A series specific or series type specific color set to use
     * instead of the global colors.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pie.connectors
     */
    connectors?: PlotPieConnectorsOptions;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.dataGrouping
     */
    dataGrouping?: PlotPieDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dataLabels
     */
    dataLabels?: PlotPieDataLabelsOptions;
    /**
     * (Highcharts) The thickness of a 3D pie. Requires `highcharts-3d.js`
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.depth
     */
    depth?: number;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.dragDrop
     */
    dragDrop?: PlotPieDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) The end angle of the pie in degrees where 0 is top and 90 is
     * right. Defaults to `startAngle` plus 360.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.endAngle
     */
    endAngle?: number;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.events
     */
    events?: PlotPieEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts) Equivalent to chart.ignoreHiddenSeries, this option tells
     * whether the series shall be redrawn as if the hidden point were `null`.
     *
     * The default value changed from `false` to `true` with Highcharts 3.0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.ignoreHiddenPoint
     */
    ignoreHiddenPoint?: boolean;
    /**
     * (Highcharts) The size of the inner diameter for the pie. A size greater
     * than 0 renders a donut chart. Can be a percentage or pixel value.
     * Percentages are relative to the pie size. Pixel values are given as
     * integers.
     *
     * Note: in Highcharts < 4.1.2, the percentage was relative to the plot
     * area, not the pie size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.innerSize
     */
    innerSize?: (number|string);
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.label
     * @see https://api.highcharts.com/highstock/plotOptions.pie.label
     * @see https://api.highcharts.com/gantt/plotOptions.pie.label
     */
    label?: PlotPieLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.lastPrice
     */
    lastPrice?: PlotPieLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.lastVisiblePrice
     */
    lastVisiblePrice?: PlotPieLastVisiblePriceOptions;
    legendType?: string;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.pie.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.pie.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.pie.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) The minimum size for a pie in response to auto margins. The
     * pie will try to shrink to make room for data labels in side the plot
     * area, but only to this size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.minSize
     */
    minSize?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point
     */
    point?: PlotPiePointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. Since 2.1, pies are not shown in the legend by default.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) The diameter of the pie relative to the plot area. Can be a
     * percentage or pixel value. Pixel values are given as integers. The
     * default behaviour (as of 3.0) is to scale to the plot area and give room
     * for data labels within the plot area. slicedOffset is also included in
     * the default size calculation. As a consequence, the size of the pie may
     * vary when points are updated and data labels more around. In that case it
     * is best to set a fixed value, for example `"75%"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.size
     */
    size?: (number|string|null);
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) If a point is sliced, moved out from the center, how many
     * pixels should it be moved?.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.slicedOffset
     */
    slicedOffset?: number;
    /**
     * (Highcharts) The start angle of the pie slices in degrees where 0 is top
     * and 90 right.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.startAngle
     */
    startAngle?: number;
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states
     */
    states?: PlotPieStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip. When `stickyTracking` is
     * false and `tooltip.shared` is false, the tooltip will be hidden when
     * moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip
     */
    tooltip?: PlotPieTooltipOptions;
    /**
     * (Highstock) The parameter allows setting line series type and use OHLC
     * indicators. Data in OHLC format is required.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.useOhlcData
     */
    useOhlcData?: boolean;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events
 */
export interface PlotPiePointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the legend item belonging to the pie point
     * (slice) is clicked. The `this` keyword refers to the point itself. One
     * parameter, `event`, is passed to the function, containing common event
     * information. The default action is to toggle the visibility of the point.
     * This can be prevented by calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.point
 */
export interface PlotPiePointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.point.events
     */
    events?: PlotPiePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover.animation
 */
export interface PlotPieStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.pie.states.hover.halo
 */
export interface PlotPieStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover
 */
export interface PlotPieStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPieStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) How much to brighten the point on interaction. Requires the
     * main color to be defined in hex or rgb(a) format.
     *
     * In styled mode, the hover brightness is by default replaced by a
     * fill-opacity given in the `.highcharts-point-hover` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.hover.halo
     */
    halo?: PlotPieStatesHoverHaloOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.normal
 */
export interface PlotPieStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states
 */
export interface PlotPieStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.hover
     */
    hover?: PlotPieStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.normal
     */
    normal?: PlotPieStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.select
     */
    select?: PlotPieStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.animation
 */
export interface PlotPieStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.halo
 */
export interface PlotPieStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker
 */
export interface PlotPieStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states
     */
    states?: PlotPieStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover.animation
 */
export interface PlotPieStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover
 */
export interface PlotPieStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPieStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.normal
 */
export interface PlotPieStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states
 */
export interface PlotPieStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.hover
     */
    hover?: PlotPieStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.normal
     */
    normal?: PlotPieStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.select
     */
    select?: PlotPieStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.select
 */
export interface PlotPieStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.select
 */
export interface PlotPieStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPieStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pie.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.halo
     */
    halo?: PlotPieStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.pie.states.select.marker
     */
    marker?: PlotPieStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.pie.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.pie.tooltip.dateTimeLabelFormats
 */
export interface PlotPieTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip
 */
export interface PlotPieTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pie.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.pie.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.pie.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotPieTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.pie.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pie.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.pie.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.pie.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.animation
 */
export interface PlotPivotpointsAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker
 */
export interface PlotPivotpointsConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker
 */
export interface PlotPivotpointsConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors
 */
export interface PlotPivotpointsConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.endMarker
     */
    endMarker?: PlotPivotpointsConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.marker
     */
    marker?: PlotPivotpointsConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker
     */
    startMarker?: PlotPivotpointsConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker
 */
export interface PlotPivotpointsConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataGrouping
 */
export interface PlotPivotpointsDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.filter
 */
export interface PlotPivotpointsDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels
 */
export interface PlotPivotpointsDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.filter
     */
    filter?: PlotPivotpointsDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragHandle
 */
export interface PlotPivotpointsDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.guideBox.default
 */
export interface PlotPivotpointsDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.guideBox
 */
export interface PlotPivotpointsDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.guideBox.default
     */
    default?: PlotPivotpointsDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop
 */
export interface PlotPivotpointsDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragHandle
     */
    dragHandle?: PlotPivotpointsDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.guideBox
     */
    guideBox?: (PlotPivotpointsDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.events
 */
export interface PlotPivotpointsEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.label
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.label
 * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.label
 */
export interface PlotPivotpointsLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.lastPrice
 */
export interface PlotPivotpointsLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotPivotpointsLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.lastVisiblePrice
 */
export interface PlotPivotpointsLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotPivotpointsLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker
 */
export interface PlotPivotpointsMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states
     */
    states?: PlotPivotpointsMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover.animation
 */
export interface PlotPivotpointsMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover
 */
export interface PlotPivotpointsMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPivotpointsMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.normal
 */
export interface PlotPivotpointsMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states
 */
export interface PlotPivotpointsMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.hover
     */
    hover?: PlotPivotpointsMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.normal
     */
    normal?: PlotPivotpointsMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.select
     */
    select?: PlotPivotpointsMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.select
 */
export interface PlotPivotpointsMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Pivot points indicator. This series requires the `linkedTo`
 * option to be set and should be loaded after `stock/indicators/indicators.js`
 * file.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `pivotpoints` series are defined in
 * plotOptions.pivotpoints.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints
 */
export interface PlotPivotpointsOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPivotpointsAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.connectors
     */
    connectors?: PlotPivotpointsConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataGrouping
     */
    dataGrouping?: PlotPivotpointsDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dataLabels
     */
    dataLabels?: PlotPivotpointsDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.dragDrop
     */
    dragDrop?: PlotPivotpointsDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.events
     */
    events?: PlotPivotpointsEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.label
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.label
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.label
     */
    label?: PlotPivotpointsLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.lastPrice
     */
    lastPrice?: PlotPivotpointsLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.lastVisiblePrice
     */
    lastVisiblePrice?: PlotPivotpointsLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.marker
     */
    marker?: PlotPivotpointsMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.params
     */
    params?: PlotPivotpointsParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point
     */
    point?: PlotPivotpointsPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states
     */
    states?: PlotPivotpointsStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.step
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip
     */
    tooltip?: PlotPivotpointsTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.zones
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.zones
     */
    zones?: Array<PlotPivotpointsZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.params
 */
export interface PlotPivotpointsParamsOptions {
    /**
     * (Highstock) Algorithm used to calculate ressistance and support lines
     * based on pivot points. Implemented algorithms: `'standard'`,
     * `'fibonacci'` and `'camarilla'`
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.params.algorithm
     */
    algorithm?: string;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events
 */
export interface PlotPivotpointsPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point
 */
export interface PlotPivotpointsPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.point.events
     */
    events?: PlotPivotpointsPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.animation
 */
export interface PlotPivotpointsStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.halo
 */
export interface PlotPivotpointsStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker
 */
export interface PlotPivotpointsStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states
     */
    states?: PlotPivotpointsStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover.animation
 */
export interface PlotPivotpointsStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover
 */
export interface PlotPivotpointsStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPivotpointsStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.normal
 */
export interface PlotPivotpointsStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states
 */
export interface PlotPivotpointsStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.hover
     */
    hover?: PlotPivotpointsStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.normal
     */
    normal?: PlotPivotpointsStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.select
     */
    select?: PlotPivotpointsStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.select
 */
export interface PlotPivotpointsStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover
 */
export interface PlotPivotpointsStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPivotpointsStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.halo
     */
    halo?: PlotPivotpointsStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover.marker
     */
    marker?: PlotPivotpointsStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.normal
 */
export interface PlotPivotpointsStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states
 */
export interface PlotPivotpointsStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.hover
     */
    hover?: PlotPivotpointsStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.normal
     */
    normal?: PlotPivotpointsStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.select
     */
    select?: PlotPivotpointsStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.animation
 */
export interface PlotPivotpointsStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.halo
 */
export interface PlotPivotpointsStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker
 */
export interface PlotPivotpointsStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states
     */
    states?: PlotPivotpointsStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover.animation
 */
export interface PlotPivotpointsStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover
 */
export interface PlotPivotpointsStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPivotpointsStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.normal
 */
export interface PlotPivotpointsStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states
 */
export interface PlotPivotpointsStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.hover
     */
    hover?: PlotPivotpointsStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.normal
     */
    normal?: PlotPivotpointsStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.select
     */
    select?: PlotPivotpointsStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.select
 */
export interface PlotPivotpointsStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.select
 */
export interface PlotPivotpointsStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPivotpointsStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pivotpoints.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.halo
     */
    halo?: PlotPivotpointsStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.states.select.marker
     */
    marker?: PlotPivotpointsStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.tooltip.dateTimeLabelFormats
 */
export interface PlotPivotpointsTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip
 */
export interface PlotPivotpointsTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotPivotpointsTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.pivotpoints.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.zones
 * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.zones
 */
export interface PlotPivotpointsZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pivotpoints.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.pivotpoints.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.animation
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.animation
 */
export interface PlotPolygonAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker
 */
export interface PlotPolygonConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker
 */
export interface PlotPolygonConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors
 */
export interface PlotPolygonConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.endMarker
     */
    endMarker?: PlotPolygonConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.marker
     */
    marker?: PlotPolygonConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker
     */
    startMarker?: PlotPolygonConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker
 */
export interface PlotPolygonConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataGrouping
 */
export interface PlotPolygonDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.filter
 */
export interface PlotPolygonDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels
 */
export interface PlotPolygonDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.filter
     */
    filter?: PlotPolygonDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragHandle
 */
export interface PlotPolygonDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.guideBox.default
 */
export interface PlotPolygonDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.guideBox
 */
export interface PlotPolygonDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.guideBox.default
     */
    default?: PlotPolygonDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop
 */
export interface PlotPolygonDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragHandle
     */
    dragHandle?: PlotPolygonDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.guideBox
     */
    guideBox?: (PlotPolygonDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.events
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.events
 */
export interface PlotPolygonEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.label
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.label
 * @see https://api.highcharts.com/gantt/plotOptions.polygon.label
 */
export interface PlotPolygonLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.lastPrice
 */
export interface PlotPolygonLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotPolygonLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.lastVisiblePrice
 */
export interface PlotPolygonLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotPolygonLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker
 */
export interface PlotPolygonMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states
     */
    states?: PlotPolygonMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover.animation
 */
export interface PlotPolygonMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover
 */
export interface PlotPolygonMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPolygonMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.normal
 */
export interface PlotPolygonMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states
 */
export interface PlotPolygonMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.hover
     */
    hover?: PlotPolygonMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.normal
     */
    normal?: PlotPolygonMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.select
     */
    select?: PlotPolygonMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.select
 */
export interface PlotPolygonMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) A polygon series can be used to draw any freeform
 * shape in the cartesian coordinate system. A fill is applied with the `color`
 * option, and stroke is applied through `lineWidth` and `lineColor` options.
 * Requires the `highcharts-more.js` file.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `polygon` series are defined in plotOptions.polygon.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon
 * @see https://api.highcharts.com/highstock/plotOptions.polygon
 */
export interface PlotPolygonOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.animation
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPolygonAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.className
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.clip
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.color
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.connectors
     */
    connectors?: PlotPolygonConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph,
     * or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataGrouping
     */
    dataGrouping?: PlotPolygonDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dataLabels
     */
    dataLabels?: PlotPolygonDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.description
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.dragDrop
     */
    dragDrop?: PlotPolygonDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.events
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.events
     */
    events?: PlotPolygonEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.keys
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.label
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.label
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.label
     */
    label?: PlotPolygonLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.lastPrice
     */
    lastPrice?: PlotPolygonLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.lastVisiblePrice
     */
    lastVisiblePrice?: PlotPolygonLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) The width of the line connecting the data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.marker
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.marker
     */
    marker?: PlotPolygonMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point
     */
    point?: PlotPolygonPointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.selected
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states
     */
    states?: PlotPolygonStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.step
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip
     */
    tooltip?: PlotPolygonTooltipOptions;
    trackByArea?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.visible
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.zones
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.zones
     */
    zones?: Array<PlotPolygonZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events
 */
export interface PlotPolygonPointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.point
 */
export interface PlotPolygonPointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.point.events
     */
    events?: PlotPolygonPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.animation
 */
export interface PlotPolygonStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.halo
 */
export interface PlotPolygonStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker
 */
export interface PlotPolygonStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states
     */
    states?: PlotPolygonStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover.animation
 */
export interface PlotPolygonStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover
 */
export interface PlotPolygonStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPolygonStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.normal
 */
export interface PlotPolygonStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states
 */
export interface PlotPolygonStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.hover
     */
    hover?: PlotPolygonStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.normal
     */
    normal?: PlotPolygonStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.select
     */
    select?: PlotPolygonStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.select
 */
export interface PlotPolygonStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover
 */
export interface PlotPolygonStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPolygonStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.halo
     */
    halo?: PlotPolygonStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover.marker
     */
    marker?: PlotPolygonStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.normal
 */
export interface PlotPolygonStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states
 */
export interface PlotPolygonStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.hover
     */
    hover?: PlotPolygonStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.normal
     */
    normal?: PlotPolygonStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.select
     */
    select?: PlotPolygonStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.animation
 */
export interface PlotPolygonStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.halo
 */
export interface PlotPolygonStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker
 */
export interface PlotPolygonStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states
     */
    states?: PlotPolygonStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover.animation
 */
export interface PlotPolygonStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover
 */
export interface PlotPolygonStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPolygonStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.normal
 */
export interface PlotPolygonStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states
 */
export interface PlotPolygonStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.hover
     */
    hover?: PlotPolygonStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.normal
     */
    normal?: PlotPolygonStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.select
     */
    select?: PlotPolygonStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.select
 */
export interface PlotPolygonStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.select
 */
export interface PlotPolygonStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPolygonStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.polygon.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.halo
     */
    halo?: PlotPolygonStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.states.select.marker
     */
    marker?: PlotPolygonStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.polygon.tooltip.dateTimeLabelFormats
 */
export interface PlotPolygonTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip
 */
export interface PlotPolygonTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotPolygonTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.polygon.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.polygon.zones
 * @see https://api.highcharts.com/highstock/plotOptions.polygon.zones
 */
export interface PlotPolygonZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.polygon.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.polygon.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.animation
 */
export interface PlotPpoAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker
 */
export interface PlotPpoConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker
 */
export interface PlotPpoConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors
 */
export interface PlotPpoConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.endMarker
     */
    endMarker?: PlotPpoConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.marker
     */
    marker?: PlotPpoConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker
     */
    startMarker?: PlotPpoConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker
 */
export interface PlotPpoConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataGrouping
 */
export interface PlotPpoDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.filter
 */
export interface PlotPpoDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels
 */
export interface PlotPpoDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.filter
     */
    filter?: PlotPpoDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragHandle
 */
export interface PlotPpoDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.guideBox.default
 */
export interface PlotPpoDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.guideBox
 */
export interface PlotPpoDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.guideBox.default
     */
    default?: PlotPpoDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop
 */
export interface PlotPpoDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragHandle
     */
    dragHandle?: PlotPpoDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.guideBox
     */
    guideBox?: (PlotPpoDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.events
 */
export interface PlotPpoEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.label
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.label
 * @see https://api.highcharts.com/gantt/plotOptions.ppo.label
 */
export interface PlotPpoLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.lastPrice
 */
export interface PlotPpoLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotPpoLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.lastVisiblePrice
 */
export interface PlotPpoLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotPpoLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker
 */
export interface PlotPpoMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states
     */
    states?: PlotPpoMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover.animation
 */
export interface PlotPpoMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover
 */
export interface PlotPpoMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPpoMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.normal
 */
export interface PlotPpoMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states
 */
export interface PlotPpoMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.hover
     */
    hover?: PlotPpoMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.normal
     */
    normal?: PlotPpoMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.select
     */
    select?: PlotPpoMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.select
 */
export interface PlotPpoMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Percentage Price Oscillator. This series requires the `linkedTo`
 * option to be set and should be loaded after the
 * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ppo` series are defined in plotOptions.ppo.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo
 */
export interface PlotPpoOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPpoAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.connectors
     */
    connectors?: PlotPpoConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataGrouping
     */
    dataGrouping?: PlotPpoDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dataLabels
     */
    dataLabels?: PlotPpoDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.dragDrop
     */
    dragDrop?: PlotPpoDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.events
     */
    events?: PlotPpoEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.label
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.label
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.label
     */
    label?: PlotPpoLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.lastPrice
     */
    lastPrice?: PlotPpoLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.lastVisiblePrice
     */
    lastVisiblePrice?: PlotPpoLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.marker
     */
    marker?: PlotPpoMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of Percentage Price Oscillator
     * series points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.params
     */
    params?: PlotPpoParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point
     */
    point?: PlotPpoPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states
     */
    states?: PlotPpoStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.step
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip
     */
    tooltip?: PlotPpoTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.zones
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.zones
     */
    zones?: Array<PlotPpoZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of Percentage Price Oscillator
 * series points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.params
 */
export interface PlotPpoParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * By default index value used to be set to 0. Since Highstock 7 by default
     * index is set to 3 which means that the ema indicator will be calculated
     * using Close values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.params.index
     */
    index?: number;
    /**
     * (Highstock) Periods for Percentage Price Oscillator calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.params.periods
     */
    periods?: Array<number>;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events
 */
export interface PlotPpoPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.point
 */
export interface PlotPpoPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.point.events
     */
    events?: PlotPpoPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.animation
 */
export interface PlotPpoStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.halo
 */
export interface PlotPpoStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker
 */
export interface PlotPpoStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states
     */
    states?: PlotPpoStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover.animation
 */
export interface PlotPpoStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover
 */
export interface PlotPpoStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPpoStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.normal
 */
export interface PlotPpoStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states
 */
export interface PlotPpoStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.hover
     */
    hover?: PlotPpoStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.normal
     */
    normal?: PlotPpoStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.select
     */
    select?: PlotPpoStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.select
 */
export interface PlotPpoStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover
 */
export interface PlotPpoStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPpoStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.halo
     */
    halo?: PlotPpoStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover.marker
     */
    marker?: PlotPpoStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.normal
 */
export interface PlotPpoStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states
 */
export interface PlotPpoStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.hover
     */
    hover?: PlotPpoStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.normal
     */
    normal?: PlotPpoStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.select
     */
    select?: PlotPpoStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.animation
 */
export interface PlotPpoStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.halo
 */
export interface PlotPpoStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker
 */
export interface PlotPpoStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states
     */
    states?: PlotPpoStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover.animation
 */
export interface PlotPpoStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover
 */
export interface PlotPpoStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPpoStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.normal
 */
export interface PlotPpoStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states
 */
export interface PlotPpoStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.hover
     */
    hover?: PlotPpoStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.normal
     */
    normal?: PlotPpoStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.select
     */
    select?: PlotPpoStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.select
 */
export interface PlotPpoStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.select
 */
export interface PlotPpoStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPpoStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.ppo.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.halo
     */
    halo?: PlotPpoStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.states.select.marker
     */
    marker?: PlotPpoStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.ppo.tooltip.dateTimeLabelFormats
 */
export interface PlotPpoTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip
 */
export interface PlotPpoTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotPpoTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.ppo.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.ppo.zones
 * @see https://api.highcharts.com/highstock/plotOptions.ppo.zones
 */
export interface PlotPpoZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.ppo.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.ppo.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.animation
 */
export interface PlotPriceenvelopesAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) Bottom line options.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.bottomLine
 */
export interface PlotPriceenvelopesBottomLineOptions {
    styles?: PlotPriceenvelopesBottomLineStylesOptions;
}
export interface PlotPriceenvelopesBottomLineStylesOptions {
    /**
     * (Highstock) Color of the line. If not set, it's inherited from
     * plotOptions.priceenvelopes.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.bottomLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.bottomLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker
 */
export interface PlotPriceenvelopesConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker
 */
export interface PlotPriceenvelopesConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors
 */
export interface PlotPriceenvelopesConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.endMarker
     */
    endMarker?: PlotPriceenvelopesConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.marker
     */
    marker?: PlotPriceenvelopesConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker
     */
    startMarker?: PlotPriceenvelopesConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker
 */
export interface PlotPriceenvelopesConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataGrouping
 */
export interface PlotPriceenvelopesDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.filter
 */
export interface PlotPriceenvelopesDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels
 */
export interface PlotPriceenvelopesDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.filter
     */
    filter?: PlotPriceenvelopesDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragHandle
 */
export interface PlotPriceenvelopesDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.guideBox.default
 */
export interface PlotPriceenvelopesDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.guideBox
 */
export interface PlotPriceenvelopesDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.guideBox.default
     */
    default?: PlotPriceenvelopesDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop
 */
export interface PlotPriceenvelopesDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragHandle
     */
    dragHandle?: PlotPriceenvelopesDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.guideBox
     */
    guideBox?: (PlotPriceenvelopesDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.events
 */
export interface PlotPriceenvelopesEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.label
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.label
 * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.label
 */
export interface PlotPriceenvelopesLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.lastPrice
 */
export interface PlotPriceenvelopesLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotPriceenvelopesLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.lastVisiblePrice
 */
export interface PlotPriceenvelopesLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotPriceenvelopesLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker
 */
export interface PlotPriceenvelopesMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states
     */
    states?: PlotPriceenvelopesMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover.animation
 */
export interface PlotPriceenvelopesMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover
 */
export interface PlotPriceenvelopesMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPriceenvelopesMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.normal
 */
export interface PlotPriceenvelopesMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states
 */
export interface PlotPriceenvelopesMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.hover
     */
    hover?: PlotPriceenvelopesMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.normal
     */
    normal?: PlotPriceenvelopesMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.select
     */
    select?: PlotPriceenvelopesMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.select
 */
export interface PlotPriceenvelopesMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Price envelopes indicator based on SMA calculations. This series
 * requires the `linkedTo` option to be set and should be loaded after the
 * `stock/indicators/indicators.js` file.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `priceenvelopes` series are defined in
 * plotOptions.priceenvelopes.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes
 */
export interface PlotPriceenvelopesOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPriceenvelopesAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) Bottom line options.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.bottomLine
     */
    bottomLine?: PlotPriceenvelopesBottomLineOptions;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.connectors
     */
    connectors?: PlotPriceenvelopesConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataGrouping
     */
    dataGrouping?: PlotPriceenvelopesDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dataLabels
     */
    dataLabels?: PlotPriceenvelopesDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.dragDrop
     */
    dragDrop?: PlotPriceenvelopesDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.events
     */
    events?: PlotPriceenvelopesEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.label
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.label
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.label
     */
    label?: PlotPriceenvelopesLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.lastPrice
     */
    lastPrice?: PlotPriceenvelopesLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.lastVisiblePrice
     */
    lastVisiblePrice?: PlotPriceenvelopesLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.marker
     */
    marker?: PlotPriceenvelopesMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.params
     */
    params?: PlotPriceenvelopesParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point
     */
    point?: PlotPriceenvelopesPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states
     */
    states?: PlotPriceenvelopesStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.step
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip
     */
    tooltip?: PlotPriceenvelopesTooltipOptions;
    /**
     * (Highstock) Top line options.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.topLine
     */
    topLine?: PlotPriceenvelopesTopLineOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.zones
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.zones
     */
    zones?: Array<PlotPriceenvelopesZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.params
 */
export interface PlotPriceenvelopesParamsOptions {
    /**
     * (Highstock) Percentage below the moving average that should be displayed.
     * 0.1 means 90%. Relative to the calculated value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.params.bottomBand
     */
    bottomBand?: number;
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.params.period
     */
    period?: number;
    /**
     * (Highstock) Percentage above the moving average that should be displayed.
     * 0.1 means 110%. Relative to the calculated value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.params.topBand
     */
    topBand?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events
 */
export interface PlotPriceenvelopesPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point
 */
export interface PlotPriceenvelopesPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.point.events
     */
    events?: PlotPriceenvelopesPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.animation
 */
export interface PlotPriceenvelopesStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.halo
 */
export interface PlotPriceenvelopesStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker
 */
export interface PlotPriceenvelopesStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states
     */
    states?: PlotPriceenvelopesStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover.animation
 */
export interface PlotPriceenvelopesStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover
 */
export interface PlotPriceenvelopesStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPriceenvelopesStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.normal
 */
export interface PlotPriceenvelopesStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states
 */
export interface PlotPriceenvelopesStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.hover
     */
    hover?: PlotPriceenvelopesStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.normal
     */
    normal?: PlotPriceenvelopesStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.select
     */
    select?: PlotPriceenvelopesStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.select
 */
export interface PlotPriceenvelopesStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover
 */
export interface PlotPriceenvelopesStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPriceenvelopesStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.halo
     */
    halo?: PlotPriceenvelopesStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover.marker
     */
    marker?: PlotPriceenvelopesStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.normal
 */
export interface PlotPriceenvelopesStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states
 */
export interface PlotPriceenvelopesStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.hover
     */
    hover?: PlotPriceenvelopesStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.normal
     */
    normal?: PlotPriceenvelopesStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.select
     */
    select?: PlotPriceenvelopesStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.animation
 */
export interface PlotPriceenvelopesStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.halo
 */
export interface PlotPriceenvelopesStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker
 */
export interface PlotPriceenvelopesStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states
     */
    states?: PlotPriceenvelopesStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover.animation
 */
export interface PlotPriceenvelopesStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover
 */
export interface PlotPriceenvelopesStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPriceenvelopesStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.normal
 */
export interface PlotPriceenvelopesStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states
 */
export interface PlotPriceenvelopesStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.hover
     */
    hover?: PlotPriceenvelopesStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.normal
     */
    normal?: PlotPriceenvelopesStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.select
     */
    select?: PlotPriceenvelopesStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.select
 */
export interface PlotPriceenvelopesStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.select
 */
export interface PlotPriceenvelopesStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPriceenvelopesStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.priceenvelopes.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.halo
     */
    halo?: PlotPriceenvelopesStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.states.select.marker
     */
    marker?: PlotPriceenvelopesStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.tooltip.dateTimeLabelFormats
 */
export interface PlotPriceenvelopesTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip
 */
export interface PlotPriceenvelopesTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotPriceenvelopesTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.priceenvelopes.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highstock) Top line options.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.topLine
 */
export interface PlotPriceenvelopesTopLineOptions {
    styles?: PlotPriceenvelopesTopLineStylesOptions;
}
export interface PlotPriceenvelopesTopLineStylesOptions {
    /**
     * (Highstock) Color of the line. If not set, it's inherited from
     * plotOptions.priceenvelopes.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.topLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.topLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.zones
 * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.zones
 */
export interface PlotPriceenvelopesZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.priceenvelopes.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.priceenvelopes.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.animation
 */
export interface PlotPsarAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker
 */
export interface PlotPsarConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker
 */
export interface PlotPsarConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors
 */
export interface PlotPsarConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.endMarker
     */
    endMarker?: PlotPsarConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.marker
     */
    marker?: PlotPsarConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker
     */
    startMarker?: PlotPsarConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker
 */
export interface PlotPsarConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.dataGrouping
 */
export interface PlotPsarDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.filter
 */
export interface PlotPsarDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels
 */
export interface PlotPsarDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.psar.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.filter
     */
    filter?: PlotPsarDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragHandle
 */
export interface PlotPsarDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.guideBox.default
 */
export interface PlotPsarDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.guideBox
 */
export interface PlotPsarDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.guideBox.default
     */
    default?: PlotPsarDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop
 */
export interface PlotPsarDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragHandle
     */
    dragHandle?: PlotPsarDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.guideBox
     */
    guideBox?: (PlotPsarDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.events
 */
export interface PlotPsarEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.psar.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.psar.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.label
 * @see https://api.highcharts.com/highstock/plotOptions.psar.label
 * @see https://api.highcharts.com/gantt/plotOptions.psar.label
 */
export interface PlotPsarLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.psar.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.psar.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.psar.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.psar.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.psar.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.psar.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.psar.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.psar.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.psar.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.psar.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.psar.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.psar.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.psar.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.psar.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.psar.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.psar.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.lastPrice
 */
export interface PlotPsarLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotPsarLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.lastVisiblePrice
 */
export interface PlotPsarLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotPsarLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.marker
 */
export interface PlotPsarMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states
     */
    states?: PlotPsarMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover.animation
 */
export interface PlotPsarMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover
 */
export interface PlotPsarMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPsarMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.normal
 */
export interface PlotPsarMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states
 */
export interface PlotPsarMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.hover
     */
    hover?: PlotPsarMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.normal
     */
    normal?: PlotPsarMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.select
     */
    select?: PlotPsarMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.select
 */
export interface PlotPsarMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Parabolic SAR. This series requires `linkedTo` option to be set
 * and should be loaded after `stock/indicators/indicators.js` file.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `psar` series are defined in plotOptions.psar.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar
 */
export interface PlotPsarOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPsarAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.psar.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.psar.connectors
     */
    connectors?: PlotPsarConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.psar.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataGrouping
     */
    dataGrouping?: PlotPsarDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dataLabels
     */
    dataLabels?: PlotPsarDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.dragDrop
     */
    dragDrop?: PlotPsarDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.events
     */
    events?: PlotPsarEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.psar.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.psar.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.label
     * @see https://api.highcharts.com/highstock/plotOptions.psar.label
     * @see https://api.highcharts.com/gantt/plotOptions.psar.label
     */
    label?: PlotPsarLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.lastPrice
     */
    lastPrice?: PlotPsarLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.lastVisiblePrice
     */
    lastVisiblePrice?: PlotPsarLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.psar.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.psar.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.psar.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.psar.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.marker
     */
    marker?: PlotPsarMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.params
     */
    params?: PlotPsarParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point
     */
    point?: PlotPsarPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.psar.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states
     */
    states?: PlotPsarStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.step
     * @see https://api.highcharts.com/highstock/plotOptions.psar.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.psar.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip
     */
    tooltip?: PlotPsarTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.psar.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.psar.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.psar.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.zones
     * @see https://api.highcharts.com/highstock/plotOptions.psar.zones
     */
    zones?: Array<PlotPsarZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.params
 */
export interface PlotPsarParamsOptions {
    /**
     * (Highstock) Number of maximum decimals that are used in PSAR
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.params.decimals
     */
    decimals?: number;
    /**
     * (Highstock) Acceleration factor increases by increment each time the
     * extreme point makes a new high.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.params.increment
     */
    increment?: number;
    /**
     * (Highstock) Index from which PSAR is starting calculation
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.params.index
     */
    index?: number;
    /**
     * (Highstock) The initial value for acceleration factor. Acceleration
     * factor is starting with this value and increases by specified increment
     * each time the extreme point makes a new high. AF can reach a maximum of
     * maxAccelerationFactor, no matter how long the uptrend extends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.params.initialAccelerationFactor
     */
    initialAccelerationFactor?: number;
    /**
     * (Highstock) The Maximum value for acceleration factor. AF can reach a
     * maximum of maxAccelerationFactor, no matter how long the uptrend extends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.params.maxAccelerationFactor
     */
    maxAccelerationFactor?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events
 */
export interface PlotPsarPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.point
 */
export interface PlotPsarPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.point.events
     */
    events?: PlotPsarPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.animation
 */
export interface PlotPsarStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.halo
 */
export interface PlotPsarStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker
 */
export interface PlotPsarStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states
     */
    states?: PlotPsarStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover.animation
 */
export interface PlotPsarStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover
 */
export interface PlotPsarStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPsarStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.normal
 */
export interface PlotPsarStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states
 */
export interface PlotPsarStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.hover
     */
    hover?: PlotPsarStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.normal
     */
    normal?: PlotPsarStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.select
     */
    select?: PlotPsarStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.select
 */
export interface PlotPsarStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover
 */
export interface PlotPsarStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPsarStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.halo
     */
    halo?: PlotPsarStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover.marker
     */
    marker?: PlotPsarStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.normal
 */
export interface PlotPsarStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states
 */
export interface PlotPsarStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.hover
     */
    hover?: PlotPsarStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.normal
     */
    normal?: PlotPsarStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.select
     */
    select?: PlotPsarStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.animation
 */
export interface PlotPsarStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.halo
 */
export interface PlotPsarStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker
 */
export interface PlotPsarStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states
     */
    states?: PlotPsarStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover.animation
 */
export interface PlotPsarStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover
 */
export interface PlotPsarStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPsarStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.normal
 */
export interface PlotPsarStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states
 */
export interface PlotPsarStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.hover
     */
    hover?: PlotPsarStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.normal
     */
    normal?: PlotPsarStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.select
     */
    select?: PlotPsarStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.select
 */
export interface PlotPsarStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.select
 */
export interface PlotPsarStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPsarStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.psar.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.halo
     */
    halo?: PlotPsarStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.psar.states.select.marker
     */
    marker?: PlotPsarStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.psar.tooltip.dateTimeLabelFormats
 */
export interface PlotPsarTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip
 */
export interface PlotPsarTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.psar.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotPsarTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.psar.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.psar.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.psar.zones
 * @see https://api.highcharts.com/highstock/plotOptions.psar.zones
 */
export interface PlotPsarZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.psar.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.psar.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.psar.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.psar.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.psar.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.psar.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Initial animation is by default disabled for the funnel chart.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.animation
 */
export interface PlotPyramidAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker
 */
export interface PlotPyramidConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker
 */
export interface PlotPyramidConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors
 */
export interface PlotPyramidConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.endMarker
     */
    endMarker?: PlotPyramidConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.marker
     */
    marker?: PlotPyramidConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker
     */
    startMarker?: PlotPyramidConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker
 */
export interface PlotPyramidConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataGrouping
 */
export interface PlotPyramidDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.filter
 */
export interface PlotPyramidDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels
 */
export interface PlotPyramidDataLabelsOptions {
    /**
     * (Highcharts) Alignment method for data labels. Possible values are:
     * `'toPlotEdges'` (each label touches the nearest vertical edge of the plot
     * area) or `'connectors'` (connectors have the same x position and the
     * widest label of each half (left & right) touches the nearest vertical
     * edge of the plot area).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.alignTo
     */
    alignTo?: string;
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The color of the line connecting the data label to the pie
     * slice. The default color is the same as the point's color.
     *
     * In styled mode, the connector stroke is given in the
     * `.highcharts-data-label-connector` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.connectorColor
     */
    connectorColor?: ColorString;
    /**
     * (Highcharts) The distance from the data label to the connector. Note that
     * data labels also have a default `padding`, so in order for the connector
     * to touch the text, the `padding` must also be 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.connectorPadding
     */
    connectorPadding?: number;
    /**
     * (Highcharts) Specifies the method that is used to generate the connector
     * path. Highcharts provides 3 built-in connector shapes: `'fixedOffset'`
     * (default), `'straight'` and `'crookedLine'`. Using `'crookedLine'` has
     * the most sense (in most of the cases) when `'alignTo'` is set.
     *
     * Users can provide their own method by passing a function instead of a
     * String. 3 arguments are passed to the callback:
     *
     * (see online documentation for example)
     *
     * The function has to return an SVG path definition in array form (see the
     * example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.connectorShape
     */
    connectorShape?: (() => void|string);
    /**
     * (Highcharts) The width of the line connecting the data label to the pie
     * slice.
     *
     * In styled mode, the connector stroke width is given in the
     * `.highcharts-data-label-connector` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.connectorWidth
     */
    connectorWidth?: number;
    /**
     * (Highcharts) Works only if `connectorShape` is `'crookedLine'`. It
     * defines how far from the vertical plot edge the coonnector path should be
     * crooked.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.crookDistance
     */
    crookDistance?: string;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) The distance of the data label from the pie's edge. Negative
     * numbers put the data label on top of the pie slices. Connectors are only
     * shown for data labels outside the pie.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.distance
     */
    distance?: number;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.filter
     */
    filter?: PlotPyramidDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Whether to render the connector as a soft arc or a line with
     * sharp break. Works only if `connectorShape` equals to `fixedOffset`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.softConnector
     */
    softConnector?: number;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragHandle
 */
export interface PlotPyramidDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.guideBox.default
 */
export interface PlotPyramidDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.guideBox
 */
export interface PlotPyramidDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.guideBox.default
     */
    default?: PlotPyramidDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop
 */
export interface PlotPyramidDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragHandle
     */
    dragHandle?: PlotPyramidDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.guideBox
     */
    guideBox?: (PlotPyramidDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.events
 */
export interface PlotPyramidEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the point name in the legend
     * is clicked. One parameter, event, is passed to the function. The state of
     * the checkbox is found by event.checked. The checked item is found by
     * event.item. Return false to prevent the default action which is to toggle
     * the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.events.checkboxClick
     */
    checkboxClick?: () => void;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.label
 * @see https://api.highcharts.com/highstock/plotOptions.pyramid.label
 * @see https://api.highcharts.com/gantt/plotOptions.pyramid.label
 */
export interface PlotPyramidLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pyramid.lastPrice
 */
export interface PlotPyramidLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotPyramidLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.pyramid.lastVisiblePrice
 */
export interface PlotPyramidLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotPyramidLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A pyramid series is a special type of funnel, without neck and
 * reversed by default. Requires the funnel module.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `pyramid` series are defined in plotOptions.pyramid.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid
 */
export interface PlotPyramidOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Initial animation is by default disabled for the funnel
     * chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.animation
     */
    animation?: (boolean|PlotPyramidAnimationOptions);
    /**
     * (Highcharts) The color of the border surrounding each slice. When `null`,
     * the border takes the same color as the slice fill. This can be used
     * together with a `borderWidth` to fill drawing gaps created by
     * antialiazing artefacts in borderless pies.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The width of the border surrounding each slice.
     *
     * When setting the border width to 0, there may be small gaps between the
     * slices due to SVG antialiasing artefacts. To work around this, keep the
     * border width at 0.5 or 1, but set the `borderColor` to `null` instead.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) The center of the series. By default, it is centered in the
     * middle of the plot area, so it fills the plot area height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.center
     */
    center?: Array<(number|string)>;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts) A series specific or series type specific color set to use
     * instead of the global colors.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.connectors
     */
    connectors?: PlotPyramidConnectorsOptions;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.dataGrouping
     */
    dataGrouping?: PlotPyramidDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dataLabels
     */
    dataLabels?: PlotPyramidDataLabelsOptions;
    /**
     * (Highcharts) The thickness of a 3D pie. Requires `highcharts-3d.js`
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.depth
     */
    depth?: number;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.dragDrop
     */
    dragDrop?: PlotPyramidDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) The end angle of the pie in degrees where 0 is top and 90 is
     * right. Defaults to `startAngle` plus 360.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.endAngle
     */
    endAngle?: number;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.events
     */
    events?: PlotPyramidEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts) The height of the funnel or pyramid. If it is a number it
     * defines the pixel height, if it is a percentage string it is the
     * percentage of the plot area height.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.height
     */
    height?: (number|string);
    /**
     * (Highcharts) Equivalent to chart.ignoreHiddenSeries, this option tells
     * whether the series shall be redrawn as if the hidden point were `null`.
     *
     * The default value changed from `false` to `true` with Highcharts 3.0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.ignoreHiddenPoint
     */
    ignoreHiddenPoint?: boolean;
    /**
     * (Highcharts) The size of the inner diameter for the pie. A size greater
     * than 0 renders a donut chart. Can be a percentage or pixel value.
     * Percentages are relative to the pie size. Pixel values are given as
     * integers.
     *
     * Note: in Highcharts < 4.1.2, the percentage was relative to the plot
     * area, not the pie size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.innerSize
     */
    innerSize?: (number|string);
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.label
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.label
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.label
     */
    label?: PlotPyramidLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.lastPrice
     */
    lastPrice?: PlotPyramidLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.lastVisiblePrice
     */
    lastVisiblePrice?: PlotPyramidLastVisiblePriceOptions;
    legendType?: string;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) The minimum size for a pie in response to auto margins. The
     * pie will try to shrink to make room for data labels in side the plot
     * area, but only to this size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.minSize
     */
    minSize?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The pyramid neck width is zero by default, as opposed to the
     * funnel, which shares the same layout logic.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.neckHeight
     */
    neckHeight?: string;
    /**
     * (Highcharts) The pyramid neck width is zero by default, as opposed to the
     * funnel, which shares the same layout logic.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.neckWidth
     */
    neckWidth?: string;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point
     */
    point?: PlotPyramidPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts) The pyramid is reversed by default, as opposed to the
     * funnel, which shares the layout engine, and is not reversed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.reversed
     */
    reversed?: boolean;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. Since 2.1, pies are not shown in the legend by default.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) If a point is sliced, moved out from the center, how many
     * pixels should it be moved?.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.slicedOffset
     */
    slicedOffset?: number;
    /**
     * (Highcharts) The start angle of the pie slices in degrees where 0 is top
     * and 90 right.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.startAngle
     */
    startAngle?: number;
    /**
     * (Highcharts) Options for the series states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states
     */
    states?: PlotPyramidStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip. When `stickyTracking` is
     * false and `tooltip.shared` is false, the tooltip will be hidden when
     * moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip
     */
    tooltip?: PlotPyramidTooltipOptions;
    /**
     * (Highstock) The parameter allows setting line series type and use OHLC
     * indicators. Data in OHLC format is required.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.useOhlcData
     */
    useOhlcData?: boolean;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.visible
     */
    visible?: boolean;
    /**
     * (Highcharts) The width of the funnel compared to the width of the plot
     * area, or the pixel width if it is a number.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.width
     */
    width?: (number|string);
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events
 */
export interface PlotPyramidPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the legend item belonging to the pie point
     * (slice) is clicked. The `this` keyword refers to the point itself. One
     * parameter, `event`, is passed to the function, containing common event
     * information. The default action is to toggle the visibility of the point.
     * This can be prevented by calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point
 */
export interface PlotPyramidPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.point.events
     */
    events?: PlotPyramidPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states.hover.animation
 */
export interface PlotPyramidStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states.hover
 */
export interface PlotPyramidStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPyramidStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) How much to brighten the point on interaction. Requires the
     * main color to be defined in hex or rgb(a) format.
     *
     * In styled mode, the hover brightness is by default replaced by a
     * fill-opacity given in the `.highcharts-point-hover` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.normal
 */
export interface PlotPyramidStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) Options for the series states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states
 */
export interface PlotPyramidStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states.hover
     */
    hover?: PlotPyramidStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.normal
     */
    normal?: PlotPyramidStatesNormalOptions;
    /**
     * (Highmaps) Options for a selected funnel item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.select
     */
    select?: PlotPyramidStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states.select.animation
 */
export interface PlotPyramidStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highmaps) Options for a selected funnel item.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.select
 */
export interface PlotPyramidStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotPyramidStatesSelectAnimationOptions);
    /**
     * (Highmaps) A specific border color for the selected point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.select.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.pyramid.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.pyramid.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.pyramid.tooltip.dateTimeLabelFormats
 */
export interface PlotPyramidTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip
 */
export interface PlotPyramidTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotPyramidTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.pyramid.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.pyramid.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.pyramid.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.animation
 */
export interface PlotRocAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker
 */
export interface PlotRocConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker
 */
export interface PlotRocConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors
 */
export interface PlotRocConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.endMarker
     */
    endMarker?: PlotRocConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.marker
     */
    marker?: PlotRocConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker
     */
    startMarker?: PlotRocConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker
 */
export interface PlotRocConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.dataGrouping
 */
export interface PlotRocDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.filter
 */
export interface PlotRocDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels
 */
export interface PlotRocDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.roc.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.filter
     */
    filter?: PlotRocDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragHandle
 */
export interface PlotRocDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.guideBox.default
 */
export interface PlotRocDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.guideBox
 */
export interface PlotRocDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.guideBox.default
     */
    default?: PlotRocDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop
 */
export interface PlotRocDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragHandle
     */
    dragHandle?: PlotRocDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.guideBox
     */
    guideBox?: (PlotRocDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.events
 */
export interface PlotRocEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.roc.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.roc.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.label
 * @see https://api.highcharts.com/highstock/plotOptions.roc.label
 * @see https://api.highcharts.com/gantt/plotOptions.roc.label
 */
export interface PlotRocLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.roc.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.roc.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.roc.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.roc.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.roc.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.roc.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.roc.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.roc.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.roc.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.roc.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.roc.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.roc.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.roc.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.roc.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.roc.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.roc.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.lastPrice
 */
export interface PlotRocLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotRocLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.lastVisiblePrice
 */
export interface PlotRocLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotRocLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.marker
 */
export interface PlotRocMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states
     */
    states?: PlotRocMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover.animation
 */
export interface PlotRocMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover
 */
export interface PlotRocMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRocMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.normal
 */
export interface PlotRocMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states
 */
export interface PlotRocMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.hover
     */
    hover?: PlotRocMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.normal
     */
    normal?: PlotRocMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.select
     */
    select?: PlotRocMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.select
 */
export interface PlotRocMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Rate of change indicator (ROC). The indicator value for each
 * point is defined as:
 *
 * `(C - Cn) / Cn * 100`
 *
 * where: `C` is the close value of the point of the same x in the linked series
 * and `Cn` is the close value of the point `n` periods ago. `n` is set through
 * period.
 *
 * This series requires `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `roc` series are defined in plotOptions.roc.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc
 */
export interface PlotRocOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRocAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.roc.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.roc.connectors
     */
    connectors?: PlotRocConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.roc.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataGrouping
     */
    dataGrouping?: PlotRocDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dataLabels
     */
    dataLabels?: PlotRocDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.dragDrop
     */
    dragDrop?: PlotRocDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.events
     */
    events?: PlotRocEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.roc.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.roc.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.label
     * @see https://api.highcharts.com/highstock/plotOptions.roc.label
     * @see https://api.highcharts.com/gantt/plotOptions.roc.label
     */
    label?: PlotRocLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.lastPrice
     */
    lastPrice?: PlotRocLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.lastVisiblePrice
     */
    lastVisiblePrice?: PlotRocLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.roc.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.roc.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.roc.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.roc.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.marker
     */
    marker?: PlotRocMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.params
     */
    params?: PlotRocParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point
     */
    point?: PlotRocPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.roc.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states
     */
    states?: PlotRocStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.step
     * @see https://api.highcharts.com/highstock/plotOptions.roc.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.roc.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip
     */
    tooltip?: PlotRocTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.roc.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.roc.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.roc.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.zones
     * @see https://api.highcharts.com/highstock/plotOptions.roc.zones
     */
    zones?: Array<PlotRocZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.params
 */
export interface PlotRocParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events
 */
export interface PlotRocPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.point
 */
export interface PlotRocPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.point.events
     */
    events?: PlotRocPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.animation
 */
export interface PlotRocStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.halo
 */
export interface PlotRocStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker
 */
export interface PlotRocStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states
     */
    states?: PlotRocStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover.animation
 */
export interface PlotRocStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover
 */
export interface PlotRocStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRocStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.normal
 */
export interface PlotRocStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states
 */
export interface PlotRocStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.hover
     */
    hover?: PlotRocStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.normal
     */
    normal?: PlotRocStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.select
     */
    select?: PlotRocStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.select
 */
export interface PlotRocStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover
 */
export interface PlotRocStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRocStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.halo
     */
    halo?: PlotRocStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover.marker
     */
    marker?: PlotRocStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.normal
 */
export interface PlotRocStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states
 */
export interface PlotRocStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.hover
     */
    hover?: PlotRocStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.normal
     */
    normal?: PlotRocStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.select
     */
    select?: PlotRocStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.animation
 */
export interface PlotRocStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.halo
 */
export interface PlotRocStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker
 */
export interface PlotRocStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states
     */
    states?: PlotRocStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover.animation
 */
export interface PlotRocStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover
 */
export interface PlotRocStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRocStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.normal
 */
export interface PlotRocStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states
 */
export interface PlotRocStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.hover
     */
    hover?: PlotRocStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.normal
     */
    normal?: PlotRocStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.select
     */
    select?: PlotRocStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.select
 */
export interface PlotRocStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.select
 */
export interface PlotRocStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRocStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.roc.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.halo
     */
    halo?: PlotRocStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.roc.states.select.marker
     */
    marker?: PlotRocStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.roc.tooltip.dateTimeLabelFormats
 */
export interface PlotRocTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip
 */
export interface PlotRocTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.roc.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotRocTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.roc.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.roc.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.roc.zones
 * @see https://api.highcharts.com/highstock/plotOptions.roc.zones
 */
export interface PlotRocZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.roc.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.roc.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.roc.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.roc.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.roc.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.roc.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.animation
 */
export interface PlotRsiAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker
 */
export interface PlotRsiConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker
 */
export interface PlotRsiConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors
 */
export interface PlotRsiConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.endMarker
     */
    endMarker?: PlotRsiConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.marker
     */
    marker?: PlotRsiConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker
     */
    startMarker?: PlotRsiConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker
 */
export interface PlotRsiConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataGrouping
 */
export interface PlotRsiDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.filter
 */
export interface PlotRsiDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels
 */
export interface PlotRsiDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.filter
     */
    filter?: PlotRsiDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragHandle
 */
export interface PlotRsiDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.guideBox.default
 */
export interface PlotRsiDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.guideBox
 */
export interface PlotRsiDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.guideBox.default
     */
    default?: PlotRsiDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop
 */
export interface PlotRsiDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragHandle
     */
    dragHandle?: PlotRsiDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.guideBox
     */
    guideBox?: (PlotRsiDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.events
 */
export interface PlotRsiEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.label
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.label
 * @see https://api.highcharts.com/gantt/plotOptions.rsi.label
 */
export interface PlotRsiLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.lastPrice
 */
export interface PlotRsiLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotRsiLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.lastVisiblePrice
 */
export interface PlotRsiLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotRsiLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker
 */
export interface PlotRsiMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states
     */
    states?: PlotRsiMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover.animation
 */
export interface PlotRsiMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover
 */
export interface PlotRsiMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRsiMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.normal
 */
export interface PlotRsiMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states
 */
export interface PlotRsiMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.hover
     */
    hover?: PlotRsiMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.normal
     */
    normal?: PlotRsiMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.select
     */
    select?: PlotRsiMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.select
 */
export interface PlotRsiMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Relative strength index (RSI) technical indicator. This series
 * requires the `linkedTo` option to be set and should be loaded after the
 * `stock/indicators/indicators.js` file.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `rsi` series are defined in plotOptions.rsi.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi
 */
export interface PlotRsiOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRsiAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.connectors
     */
    connectors?: PlotRsiConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataGrouping
     */
    dataGrouping?: PlotRsiDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dataLabels
     */
    dataLabels?: PlotRsiDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.dragDrop
     */
    dragDrop?: PlotRsiDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.events
     */
    events?: PlotRsiEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.label
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.label
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.label
     */
    label?: PlotRsiLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.lastPrice
     */
    lastPrice?: PlotRsiLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.lastVisiblePrice
     */
    lastVisiblePrice?: PlotRsiLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.marker
     */
    marker?: PlotRsiMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.params
     */
    params?: PlotRsiParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point
     */
    point?: PlotRsiPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states
     */
    states?: PlotRsiStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.step
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip
     */
    tooltip?: PlotRsiTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.zones
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.zones
     */
    zones?: Array<PlotRsiZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.params
 */
export interface PlotRsiParamsOptions {
    /**
     * (Highstock) Number of maximum decimals that are used in RSI calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.params.decimals
     */
    decimals?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events
 */
export interface PlotRsiPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.point
 */
export interface PlotRsiPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.point.events
     */
    events?: PlotRsiPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.animation
 */
export interface PlotRsiStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.halo
 */
export interface PlotRsiStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker
 */
export interface PlotRsiStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states
     */
    states?: PlotRsiStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover.animation
 */
export interface PlotRsiStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover
 */
export interface PlotRsiStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRsiStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.normal
 */
export interface PlotRsiStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states
 */
export interface PlotRsiStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.hover
     */
    hover?: PlotRsiStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.normal
     */
    normal?: PlotRsiStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.select
     */
    select?: PlotRsiStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.select
 */
export interface PlotRsiStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover
 */
export interface PlotRsiStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRsiStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.halo
     */
    halo?: PlotRsiStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover.marker
     */
    marker?: PlotRsiStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.normal
 */
export interface PlotRsiStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states
 */
export interface PlotRsiStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.hover
     */
    hover?: PlotRsiStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.normal
     */
    normal?: PlotRsiStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.select
     */
    select?: PlotRsiStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.animation
 */
export interface PlotRsiStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.halo
 */
export interface PlotRsiStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker
 */
export interface PlotRsiStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states
     */
    states?: PlotRsiStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover.animation
 */
export interface PlotRsiStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover
 */
export interface PlotRsiStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRsiStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.normal
 */
export interface PlotRsiStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states
 */
export interface PlotRsiStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.hover
     */
    hover?: PlotRsiStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.normal
     */
    normal?: PlotRsiStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.select
     */
    select?: PlotRsiStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.select
 */
export interface PlotRsiStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.select
 */
export interface PlotRsiStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotRsiStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.rsi.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.halo
     */
    halo?: PlotRsiStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.states.select.marker
     */
    marker?: PlotRsiStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.rsi.tooltip.dateTimeLabelFormats
 */
export interface PlotRsiTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip
 */
export interface PlotRsiTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotRsiTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.rsi.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.rsi.zones
 * @see https://api.highcharts.com/highstock/plotOptions.rsi.zones
 */
export interface PlotRsiZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.rsi.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.rsi.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.animation
 */
export interface PlotSankeyAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker
 */
export interface PlotSankeyConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker
 */
export interface PlotSankeyConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors
 */
export interface PlotSankeyConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.endMarker
     */
    endMarker?: PlotSankeyConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.marker
     */
    marker?: PlotSankeyConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker
     */
    startMarker?: PlotSankeyConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker
 */
export interface PlotSankeyConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataGrouping
 */
export interface PlotSankeyDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.filter
 */
export interface PlotSankeyDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the data labels appearing on top of the nodes and
 * links. For sankey charts, data labels are visible for the nodes by default,
 * but hidden for links. This is controlled by modifying the `nodeFormat`, and
 * the `format` that applies to links and is an empty string by default.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels
 */
export interface PlotSankeyDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.backgroundColor
     */
    backgroundColor?: string;
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.filter
     */
    filter?: PlotSankeyDataLabelsFilterOptions;
    /**
     * (Highcharts) The format string specifying what to show for _links_ in the
     * sankey diagram. Defaults to an empty string returned from the
     * `formatter`, in effect disabling the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback to format data labels for _links_ in the sankey
     * diagram. The `format` option takes precedence over the `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) The format string specifying what to show for _nodes_ in the
     * sankey diagram. By default the `nodeFormatter` returns `{point.name}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.nodeFormat
     */
    nodeFormat?: string;
    /**
     * (Highcharts) Callback to format data labels for _nodes_ in the sankey
     * diagram. The `nodeFormat` option takes precedence over the
     * `nodeFormatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.nodeFormatter
     */
    nodeFormatter?: FormatterCallbackFunction<object>;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragHandle
 */
export interface PlotSankeyDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.guideBox.default
 */
export interface PlotSankeyDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.guideBox
 */
export interface PlotSankeyDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.guideBox.default
     */
    default?: PlotSankeyDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop
 */
export interface PlotSankeyDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragHandle
     */
    dragHandle?: PlotSankeyDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.guideBox
     */
    guideBox?: (PlotSankeyDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.events
 */
export interface PlotSankeyEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.label
 * @see https://api.highcharts.com/highstock/plotOptions.sankey.label
 * @see https://api.highcharts.com/gantt/plotOptions.sankey.label
 */
export interface PlotSankeyLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sankey.lastPrice
 */
export interface PlotSankeyLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotSankeyLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sankey.lastVisiblePrice
 */
export interface PlotSankeyLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotSankeyLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A sankey diagram is a type of flow diagram, in which the width
 * of the link between two nodes is shown proportionally to the flow quantity.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `sankey` series are defined in plotOptions.sankey.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey
 */
export interface PlotSankeyOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sankey.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSankeyAnimationOptions);
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sankey.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.colors
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.colors
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.connectors
     */
    connectors?: PlotSankeyConnectorsOptions;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) Higher numbers makes the links in a sankey diagram render
     * more curved. A `curveFactor` of 0 makes the lines straight.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.curveFactor
     */
    curveFactor?: number;
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.dataGrouping
     */
    dataGrouping?: PlotSankeyDataGroupingOptions;
    /**
     * (Highcharts) Options for the data labels appearing on top of the nodes
     * and links. For sankey charts, data labels are visible for the nodes by
     * default, but hidden for links. This is controlled by modifying the
     * `nodeFormat`, and the `format` that applies to links and is an empty
     * string by default.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dataLabels
     */
    dataLabels?: PlotSankeyDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.dragDrop
     */
    dragDrop?: PlotSankeyDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.events
     */
    events?: PlotSankeyEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sankey.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.label
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.label
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.label
     */
    label?: PlotSankeyLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.lastPrice
     */
    lastPrice?: PlotSankeyLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.lastVisiblePrice
     */
    lastVisiblePrice?: PlotSankeyLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) Opacity for the links between nodes in the sankey diagram.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.linkOpacity
     */
    linkOpacity?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The padding between nodes in a sankey diagram, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.nodePadding
     */
    nodePadding?: number;
    /**
     * (Highcharts) The pixel width of each node in a sankey diagram, or the
     * height in case the chart is inverted.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.nodeWidth
     */
    nodeWidth?: number;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point
     */
    point?: PlotSankeyPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states
     */
    states?: PlotSankeyStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip
     */
    tooltip?: PlotSankeyTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sankey.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events
 */
export interface PlotSankeyPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point
 */
export interface PlotSankeyPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.point.events
     */
    events?: PlotSankeyPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.hover.animation
 */
export interface PlotSankeyStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.sankey.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.hover
 */
export interface PlotSankeyStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSankeyStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sankey.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Opacity for the links between nodes in the
     * sankey diagram in hover mode.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.hover.linkOpacity
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.states.hover.linkOpacity
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.hover.linkOpacity
     */
    linkOpacity?: number;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.sankey.states.normal
 */
export interface PlotSankeyStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sankey.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states
 */
export interface PlotSankeyStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.hover
     */
    hover?: PlotSankeyStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sankey.states.normal
     */
    normal?: PlotSankeyStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.select
     */
    select?: PlotSankeyStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.select.animation
 */
export interface PlotSankeyStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.sankey.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.select
 */
export interface PlotSankeyStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSankeyStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sankey.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.sankey.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.sankey.tooltip.dateTimeLabelFormats
 */
export interface PlotSankeyTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip
 */
export interface PlotSankeyTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotSankeyTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts) Whether the tooltip should follow the pointer or stay fixed
     * on the item.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) The format string specifying what to show for _nodes_ in
     * tooltip of a sankey diagram series, as opposed to links.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.nodeFormat
     */
    nodeFormat?: string;
    /**
     * (Highcharts) A callback for defining the format for _nodes_ in the sankey
     * chart's tooltip, as opposed to links.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.nodeFormatter
     */
    nodeFormatter?: FormatterCallbackFunction<object>;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sankey.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.sankey.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.sankey.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.animation
 */
export interface PlotScatter3dAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker
 */
export interface PlotScatter3dConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker
 */
export interface PlotScatter3dConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors
 */
export interface PlotScatter3dConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.endMarker
     */
    endMarker?: PlotScatter3dConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.marker
     */
    marker?: PlotScatter3dConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker
     */
    startMarker?: PlotScatter3dConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker
 */
export interface PlotScatter3dConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataGrouping
 */
export interface PlotScatter3dDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.filter
 */
export interface PlotScatter3dDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels
 */
export interface PlotScatter3dDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.filter
     */
    filter?: PlotScatter3dDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragHandle
 */
export interface PlotScatter3dDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.guideBox.default
 */
export interface PlotScatter3dDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.guideBox
 */
export interface PlotScatter3dDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.guideBox.default
     */
    default?: PlotScatter3dDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop
 */
export interface PlotScatter3dDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragHandle
     */
    dragHandle?: PlotScatter3dDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.guideBox
     */
    guideBox?: (PlotScatter3dDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.events
 */
export interface PlotScatter3dEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.label
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.label
 * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.label
 */
export interface PlotScatter3dLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.lastPrice
 */
export interface PlotScatter3dLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotScatter3dLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.lastVisiblePrice
 */
export interface PlotScatter3dLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotScatter3dLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker
 */
export interface PlotScatter3dMarkerOptions {
    /**
     * (Highcharts) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.height
     */
    height?: number;
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states
     */
    states?: PlotScatter3dMarkerStatesOptions;
    /**
     * (Highcharts) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.width
     */
    width?: number;
}
/**
 * (Highcharts) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover.animation
 */
export interface PlotScatter3dMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover
 */
export interface PlotScatter3dMarkerStatesHoverOptions {
    /**
     * (Highcharts) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatter3dMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.normal
 */
export interface PlotScatter3dMarkerStatesNormalOptions {
    /**
     * (Highcharts) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states
 */
export interface PlotScatter3dMarkerStatesOptions {
    /**
     * (Highcharts) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.hover
     */
    hover?: PlotScatter3dMarkerStatesHoverOptions;
    /**
     * (Highcharts) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.normal
     */
    normal?: PlotScatter3dMarkerStatesNormalOptions;
    /**
     * (Highcharts) The appearance of the point marker when selected. In order
     * to allow a point to be selected, set the `series.allowPointSelect` option
     * to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.select
     */
    select?: PlotScatter3dMarkerStatesSelectOptions;
}
/**
 * (Highcharts) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.select
 */
export interface PlotScatter3dMarkerStatesSelectOptions {
    /**
     * (Highcharts) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) A 3D scatter plot uses x, y and z coordinates to display values
 * for three variables for a set of data.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `scatter3d` series are defined in plotOptions.scatter3d.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d
 */
export interface PlotScatter3dOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatter3dAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.connectors
     */
    connectors?: PlotScatter3dConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.dataGrouping
     */
    dataGrouping?: PlotScatter3dDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dataLabels
     */
    dataLabels?: PlotScatter3dDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.dragDrop
     */
    dragDrop?: PlotScatter3dDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.events
     */
    events?: PlotScatter3dEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.label
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.label
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.label
     */
    label?: PlotScatter3dLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.lastPrice
     */
    lastPrice?: PlotScatter3dLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.lastVisiblePrice
     */
    lastVisiblePrice?: PlotScatter3dLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) The width of the line connecting the data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) Options for the point markers of line-like series.
     * Properties like `fillColor`, `lineColor` and `lineWidth` define the
     * visual appearance of the markers. Other series types, like column series,
     * don't have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.marker
     */
    marker?: PlotScatter3dMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The color for the parts of the graph or points that are
     * below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point
     */
    point?: PlotScatter3dPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states
     */
    states?: PlotScatter3dStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.step
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip
     */
    tooltip?: PlotScatter3dTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.zones
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.zones
     */
    zones?: Array<PlotScatter3dZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events
 */
export interface PlotScatter3dPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point
 */
export interface PlotScatter3dPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.point.events
     */
    events?: PlotScatter3dPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.animation
 */
export interface PlotScatter3dStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.halo
 */
export interface PlotScatter3dStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker
 */
export interface PlotScatter3dStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states
     */
    states?: PlotScatter3dStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover.animation
 */
export interface PlotScatter3dStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover
 */
export interface PlotScatter3dStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatter3dStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.normal
 */
export interface PlotScatter3dStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states
 */
export interface PlotScatter3dStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.hover
     */
    hover?: PlotScatter3dStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.normal
     */
    normal?: PlotScatter3dStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.select
     */
    select?: PlotScatter3dStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.select
 */
export interface PlotScatter3dStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover
 */
export interface PlotScatter3dStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatter3dStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.halo
     */
    halo?: PlotScatter3dStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.hover.marker
     */
    marker?: PlotScatter3dStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.normal
 */
export interface PlotScatter3dStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states
 */
export interface PlotScatter3dStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.hover
     */
    hover?: PlotScatter3dStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.normal
     */
    normal?: PlotScatter3dStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.select
     */
    select?: PlotScatter3dStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.animation
 */
export interface PlotScatter3dStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.halo
 */
export interface PlotScatter3dStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker
 */
export interface PlotScatter3dStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states
     */
    states?: PlotScatter3dStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover.animation
 */
export interface PlotScatter3dStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover
 */
export interface PlotScatter3dStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatter3dStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.normal
 */
export interface PlotScatter3dStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states
 */
export interface PlotScatter3dStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.hover
     */
    hover?: PlotScatter3dStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.normal
     */
    normal?: PlotScatter3dStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.select
     */
    select?: PlotScatter3dStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.select
 */
export interface PlotScatter3dStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.select
 */
export interface PlotScatter3dStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatter3dStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter3d.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.halo
     */
    halo?: PlotScatter3dStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.states.select.marker
     */
    marker?: PlotScatter3dStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.tooltip.dateTimeLabelFormats
 */
export interface PlotScatter3dTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip
 */
export interface PlotScatter3dTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotScatter3dTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.scatter3d.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.zones
 * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.zones
 */
export interface PlotScatter3dZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter3d.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.scatter3d.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.animation
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.animation
 */
export interface PlotScatterAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker
 */
export interface PlotScatterConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker
 */
export interface PlotScatterConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors
 */
export interface PlotScatterConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.endMarker
     */
    endMarker?: PlotScatterConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.marker
     */
    marker?: PlotScatterConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker
     */
    startMarker?: PlotScatterConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker
 */
export interface PlotScatterConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataGrouping
 */
export interface PlotScatterDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.filter
 */
export interface PlotScatterDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels
 */
export interface PlotScatterDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.filter
     */
    filter?: PlotScatterDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragHandle
 */
export interface PlotScatterDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.guideBox.default
 */
export interface PlotScatterDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.guideBox
 */
export interface PlotScatterDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.guideBox.default
     */
    default?: PlotScatterDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop
 */
export interface PlotScatterDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragHandle
     */
    dragHandle?: PlotScatterDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.guideBox
     */
    guideBox?: (PlotScatterDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.events
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.events
 */
export interface PlotScatterEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.label
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.label
 * @see https://api.highcharts.com/gantt/plotOptions.scatter.label
 */
export interface PlotScatterLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.lastPrice
 */
export interface PlotScatterLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotScatterLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.lastVisiblePrice
 */
export interface PlotScatterLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotScatterLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker
 */
export interface PlotScatterMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states
     */
    states?: PlotScatterMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover.animation
 */
export interface PlotScatterMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover
 */
export interface PlotScatterMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatterMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.normal
 */
export interface PlotScatterMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states
 */
export interface PlotScatterMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.hover
     */
    hover?: PlotScatterMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.normal
     */
    normal?: PlotScatterMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.select
     */
    select?: PlotScatterMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.select
 */
export interface PlotScatterMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) A scatter plot uses cartesian coordinates to display
 * values for two variables for a set of data.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `scatter` series are defined in plotOptions.scatter.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter
 * @see https://api.highcharts.com/highstock/plotOptions.scatter
 */
export interface PlotScatterOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatterAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.className
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.clip
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.color
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.connectors
     */
    connectors?: PlotScatterConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph,
     * or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataGrouping
     */
    dataGrouping?: PlotScatterDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dataLabels
     */
    dataLabels?: PlotScatterDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.description
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.dragDrop
     */
    dragDrop?: PlotScatterDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.events
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.events
     */
    events?: PlotScatterEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.keys
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.label
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.label
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.label
     */
    label?: PlotScatterLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.lastPrice
     */
    lastPrice?: PlotScatterLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.lastVisiblePrice
     */
    lastVisiblePrice?: PlotScatterLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) The width of the line connecting the data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.marker
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.marker
     */
    marker?: PlotScatterMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point
     */
    point?: PlotScatterPointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.selected
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states
     */
    states?: PlotScatterStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.step
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip
     */
    tooltip?: PlotScatterTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.visible
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.zones
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.zones
     */
    zones?: Array<PlotScatterZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events
 */
export interface PlotScatterPointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.point
 */
export interface PlotScatterPointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.point.events
     */
    events?: PlotScatterPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.animation
 */
export interface PlotScatterStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.halo
 */
export interface PlotScatterStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker
 */
export interface PlotScatterStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states
     */
    states?: PlotScatterStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover.animation
 */
export interface PlotScatterStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover
 */
export interface PlotScatterStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatterStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.normal
 */
export interface PlotScatterStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states
 */
export interface PlotScatterStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.hover
     */
    hover?: PlotScatterStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.normal
     */
    normal?: PlotScatterStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.select
     */
    select?: PlotScatterStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.select
 */
export interface PlotScatterStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover
 */
export interface PlotScatterStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatterStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.halo
     */
    halo?: PlotScatterStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover.marker
     */
    marker?: PlotScatterStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.normal
 */
export interface PlotScatterStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states
 */
export interface PlotScatterStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.hover
     */
    hover?: PlotScatterStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.normal
     */
    normal?: PlotScatterStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.select
     */
    select?: PlotScatterStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.animation
 */
export interface PlotScatterStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.halo
 */
export interface PlotScatterStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker
 */
export interface PlotScatterStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states
     */
    states?: PlotScatterStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover.animation
 */
export interface PlotScatterStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover
 */
export interface PlotScatterStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatterStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.normal
 */
export interface PlotScatterStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states
 */
export interface PlotScatterStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.hover
     */
    hover?: PlotScatterStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.normal
     */
    normal?: PlotScatterStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.select
     */
    select?: PlotScatterStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.select
 */
export interface PlotScatterStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.select
 */
export interface PlotScatterStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotScatterStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.scatter.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.halo
     */
    halo?: PlotScatterStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.states.select.marker
     */
    marker?: PlotScatterStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.scatter.tooltip.dateTimeLabelFormats
 */
export interface PlotScatterTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip
 */
export interface PlotScatterTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotScatterTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.scatter.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.scatter.zones
 * @see https://api.highcharts.com/highstock/plotOptions.scatter.zones
 */
export interface PlotScatterZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.scatter.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.scatter.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the initial
 * animation when a series is displayed. The animation can also be set as a
 * configuration object. Please note that this option only applies to the
 * initial animation of the series itself. For other animations, see
 * chart.animation and the animation parameter under the API methods. The
 * following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.animation
 * @see https://api.highcharts.com/highstock/plotOptions.series.animation
 * @see https://api.highcharts.com/highmaps/plotOptions.series.animation
 * @see https://api.highcharts.com/gantt/plotOptions.series.animation
 */
export interface PlotSeriesAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker
 */
export interface PlotSeriesConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker
 */
export interface PlotSeriesConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.series.connectors
 */
export interface PlotSeriesConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.endMarker
     */
    endMarker?: PlotSeriesConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.marker
     */
    marker?: PlotSeriesConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker
     */
    startMarker?: PlotSeriesConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker
 */
export interface PlotSeriesConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.series.dataGrouping
 */
export interface PlotSeriesDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) A declarative filter for which data
 * labels to display. The declarative filter is designed for use when callback
 * functions are not available, like when the chart options require a pure JSON
 * structure or for use with graphical editors. For programmatic control, use
 * the `formatter` instead, and return `undefined` to disable a single data
 * label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.filter
 * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.filter
 * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.filter
 */
export interface PlotSeriesDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The operator to compare by. Can
     * be one of `>`, `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.filter.operator
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.filter.operator
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The point property to filter by.
     * Point options are passed directly to properties, additionally there are
     * `y` value, `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.filter.property
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.filter.property
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.filter.value
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.filter.value
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the series data labels,
 * appearing next to each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels
 * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels
 * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels
 */
export interface PlotSeriesDataLabelsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The alignment of the data label
     * compared to the point. If `right`, the right side of the label should be
     * touching the point. For points with an extent, like columns, the
     * alignments also dictates how to align it inside the box, as given with
     * the inside option. Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.align
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.align
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to allow data labels to
     * overlap. To make the labels less sensitive for overlapping, the
     * dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.allowOverlap
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The background color or gradient
     * for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.backgroundColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border color for the data
     * label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.borderColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border radius in pixels for
     * the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.borderRadius
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The border width in pixels for
     * the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.borderWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A class name for the data label.
     * Particularly in styled mode, this can be used to give each series' or
     * point's data label unique styling. In addition to this option, a default
     * color class name is added so that we can give the labels a contrast text
     * shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.className
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.className
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The text color for the data
     * labels. Defaults to `undefined`. For certain series types, like column or
     * map, the data labels can be drawn inside the points. In this case the
     * data label will be drawn with maximum contrast by default. Additionally,
     * it will be given a `text-outline` style with the opposite color, to
     * further increase the contrast. This can be overridden by setting the
     * `text-outline` style to `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.color
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.color
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to hide data labels that
     * are outside the plot area. By default, the data label is moved inside the
     * plot area according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.crop
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.crop
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the data
     * labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A declarative filter for which
     * data labels to display. The declarative filter is designed for use when
     * callback functions are not available, like when the chart options require
     * a pure JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.filter
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.filter
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.filter
     */
    filter?: PlotSeriesDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A format string for the data
     * label. Available variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.format
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.format
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback JavaScript function to
     * format the data label. Note that if a `format` is defined, the format
     * takes precedence and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.formatter
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.formatter
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) For points with an extent, like
     * columns or map areas, whether to align the data label inside the box or
     * to the actual value point. Defaults to `false` in most cases, `true` in
     * stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.inside
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.inside
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) How to handle data labels that
     * flow outside the plot area. The default is `"justify"`, which aligns them
     * inside the plot area. For columns and bars, this means it will be moved
     * inside the bar. To display data labels outside the plot area, set `crop`
     * to `false` and `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.overflow
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.overflow
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When either the `borderWidth` or
     * the `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.padding
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.padding
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Text rotation in degrees. Note
     * that due to a more complex structure, backgrounds, borders and padding
     * will be lost on a rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.rotation
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.rotation
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The shadow of the box. Works
     * best with `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be
     * an object configuration containing `color`, `offsetX`, `offsetY`,
     * `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.shadow
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.shadow
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The name of a symbol to use for
     * the border around the label. Symbols are predefined functions on the
     * Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.shape
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.shape
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Styles for the label. The
     * default `color` setting is `"contrast"`, which is a pseudo color that
     * Highcharts picks up and applies the maximum contrast to the underlying
     * point item, for example the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.style
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.style
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render
     * the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.useHTML
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.useHTML
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical alignment of a data
     * label. Can be one of `top`, `middle` or `bottom`. The default value
     * depends on the data, for instance in a column chart, the label is above
     * positive values and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.verticalAlign
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position offset of the
     * label relative to the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.x
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.x
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position offset of the
     * label relative to the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.y
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.y
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Z index of the data labels.
     * The default Z index puts it above the series. Use a Z index of 2 to
     * display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels.zIndex
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragHandle
 */
export interface PlotSeriesDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.guideBox.default
 */
export interface PlotSeriesDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.guideBox
 */
export interface PlotSeriesDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.guideBox.default
     */
    default?: PlotSeriesDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The draggable-points module allows
 * points to be moved around or modified in the chart. In addition to the
 * options mentioned under the `dragDrop` API structure, the module fires three
 * events, point.dragStart, point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop
 * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop
 * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop
 */
export interface PlotSeriesDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragHandle
     */
    dragHandle?: PlotSeriesDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.guideBox
     */
    guideBox?: (PlotSeriesDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) General event handlers for the
 * series items. These event hooks can also be attached to the series at run
 * time using the `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.events
 * @see https://api.highcharts.com/highstock/plotOptions.series.events
 * @see https://api.highcharts.com/highmaps/plotOptions.series.events
 * @see https://api.highcharts.com/gantt/plotOptions.series.events
 */
export interface PlotSeriesEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.series.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.series.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the checkbox next to
     * the series' name in the legend is clicked. One parameter, `event`, is
     * passed to the function. The state of the checkbox is found by
     * `event.checked`. The checked item is found by `event.item`. Return
     * `false` to prevent the default action which is to toggle the select state
     * of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.series.events.checkboxClick
     * @see https://api.highcharts.com/highmaps/plotOptions.series.events.checkboxClick
     * @see https://api.highcharts.com/gantt/plotOptions.series.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the series is
     * clicked. One parameter, `event`, is passed to the function, containing
     * common event information. Additionally, `event.point` holds a pointer to
     * the nearest point on the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.series.events.click
     * @see https://api.highcharts.com/highmaps/plotOptions.series.events.click
     * @see https://api.highcharts.com/gantt/plotOptions.series.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the series is hidden
     * after chart generation time, either by clicking the legend item or by
     * calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.series.events.hide
     * @see https://api.highcharts.com/highmaps/plotOptions.series.events.hide
     * @see https://api.highcharts.com/gantt/plotOptions.series.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the legend item
     * belonging to the series is clicked. One parameter, `event`, is passed to
     * the function. The default action is to toggle the visibility of the
     * series. This can be prevented by returning `false` or calling
     * `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.series.events.legendItemClick
     * @see https://api.highcharts.com/highmaps/plotOptions.series.events.legendItemClick
     * @see https://api.highcharts.com/gantt/plotOptions.series.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * graph. One parameter, `event`, is passed to the function, containing
     * common event information. If the stickyTracking option is true,
     * `mouseOut` doesn't happen before the mouse enters another graph or leaves
     * the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.series.events.mouseOut
     * @see https://api.highcharts.com/highmaps/plotOptions.series.events.mouseOut
     * @see https://api.highcharts.com/gantt/plotOptions.series.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * graph. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.series.events.mouseOver
     * @see https://api.highcharts.com/highmaps/plotOptions.series.events.mouseOver
     * @see https://api.highcharts.com/gantt/plotOptions.series.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the series is shown
     * after chart generation time, either by clicking the legend item or by
     * calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.series.events.show
     * @see https://api.highcharts.com/highmaps/plotOptions.series.events.show
     * @see https://api.highcharts.com/gantt/plotOptions.series.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.label
 * @see https://api.highcharts.com/highstock/plotOptions.series.label
 * @see https://api.highcharts.com/gantt/plotOptions.series.label
 */
export interface PlotSeriesLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.series.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.series.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.series.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.series.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.series.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.series.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.series.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.series.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.series.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.series.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.series.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.series.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.series.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.series.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.series.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.series.lastPrice
 */
export interface PlotSeriesLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotSeriesLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.series.lastVisiblePrice
 */
export interface PlotSeriesLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotSeriesLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the point markers of
 * line-like series. Properties like `fillColor`, `lineColor` and `lineWidth`
 * define the visual appearance of the markers. Other series types, like column
 * series, don't have markers, but have visual options on the series level
 * instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.marker
 * @see https://api.highcharts.com/highstock/plotOptions.series.marker
 * @see https://api.highcharts.com/highmaps/plotOptions.series.marker
 * @see https://api.highcharts.com/gantt/plotOptions.series.marker
 */
export interface PlotSeriesMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.fillColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.fillColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.height
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.height
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.lineColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.lineColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.lineWidth
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.radius
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.radius
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states
     */
    states?: PlotSeriesMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.symbol
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.symbol
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.width
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.width
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover.animation
 */
export interface PlotSeriesMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover
 * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover
 */
export interface PlotSeriesMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSeriesMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.normal
 * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.normal
 * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.normal
 */
export interface PlotSeriesMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states
 * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states
 * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states
 */
export interface PlotSeriesMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.hover
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.hover
     */
    hover?: PlotSeriesMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.normal
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.normal
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.normal
     */
    normal?: PlotSeriesMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.select
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.select
     */
    select?: PlotSeriesMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.select
 * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.select
 */
export interface PlotSeriesMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) General options for all series
 * types.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `line` series are defined in plotOptions.line.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series
 * @see https://api.highcharts.com/highstock/plotOptions.series
 * @see https://api.highcharts.com/highmaps/plotOptions.series
 * @see https://api.highcharts.com/gantt/plotOptions.series
 */
export interface PlotSeriesOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Allow this series' points to be
     * selected by clicking on the graphic (columns, point markers, pie slices,
     * map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.series.allowPointSelect
     * @see https://api.highcharts.com/highmaps/plotOptions.series.allowPointSelect
     * @see https://api.highcharts.com/gantt/plotOptions.series.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the initial
     * animation when a series is displayed. The animation can also be set as a
     * configuration object. Please note that this option only applies to the
     * initial animation of the series itself. For other animations, see
     * chart.animation and the animation parameter under the API methods. The
     * following properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.animation
     * @see https://api.highcharts.com/highstock/plotOptions.series.animation
     * @see https://api.highcharts.com/highmaps/plotOptions.series.animation
     * @see https://api.highcharts.com/gantt/plotOptions.series.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSeriesAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) For some series, there is a
     * limit that shuts down initial animation by default when the total number
     * of points in the chart is too high. For example, for a column chart and
     * its derivatives, animation doesn't run if there is more than 250 points
     * totally. To disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.series.animationLimit
     * @see https://api.highcharts.com/highmaps/plotOptions.series.animationLimit
     * @see https://api.highcharts.com/gantt/plotOptions.series.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the point threshold for when
     * a series should enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.series.boostThreshold
     * @see https://api.highcharts.com/highmaps/plotOptions.series.boostThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.series.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An additional class name to
     * apply to the series' graphical elements. This option does not replace
     * default class names of the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.className
     * @see https://api.highcharts.com/highstock/plotOptions.series.className
     * @see https://api.highcharts.com/highmaps/plotOptions.series.className
     * @see https://api.highcharts.com/gantt/plotOptions.series.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Disable this option to allow
     * series rendering in the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.clip
     * @see https://api.highcharts.com/highstock/plotOptions.series.clip
     * @see https://api.highcharts.com/highmaps/plotOptions.series.clip
     * @see https://api.highcharts.com/gantt/plotOptions.series.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The main color of the series. In
     * line type series it applies to the line and the point markers unless
     * otherwise specified. In bar type series it applies to the bars unless a
     * color is specified per point. The default value is pulled from the
     * `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.color
     * @see https://api.highcharts.com/highstock/plotOptions.series.color
     * @see https://api.highcharts.com/highmaps/plotOptions.series.color
     * @see https://api.highcharts.com/gantt/plotOptions.series.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Styled mode only. A specific
     * color index to use for the series, so its graphic representations are
     * given the class name `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.series.colorIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.series.colorIndex
     * @see https://api.highcharts.com/gantt/plotOptions.series.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.series.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.series.connectors
     */
    connectors?: PlotSeriesConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.series.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) You can set the cursor to
     * "pointer" if you have click events attached to the series, to signal to
     * the user that the points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.series.cursor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.cursor
     * @see https://api.highcharts.com/gantt/plotOptions.series.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A name for the dash style to use
     * for the graph, or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.series.dashStyle
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dashStyle
     * @see https://api.highcharts.com/gantt/plotOptions.series.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataGrouping
     */
    dataGrouping?: PlotSeriesDataGroupingOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the series data
     * labels, appearing next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.series.dataLabels
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dataLabels
     * @see https://api.highcharts.com/gantt/plotOptions.series.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Requires the Accessibility
     * module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.description
     * @see https://api.highcharts.com/highstock/plotOptions.series.description
     * @see https://api.highcharts.com/highmaps/plotOptions.series.description
     * @see https://api.highcharts.com/gantt/plotOptions.series.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The draggable-points module
     * allows points to be moved around or modified in the chart. In addition to
     * the options mentioned under the `dragDrop` API structure, the module
     * fires three events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.series.dragDrop
     * @see https://api.highcharts.com/highmaps/plotOptions.series.dragDrop
     * @see https://api.highcharts.com/gantt/plotOptions.series.dragDrop
     */
    dragDrop?: PlotSeriesDragDropOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the mouse
     * tracking for a specific series. This includes point tooltips and click
     * events on graphs and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.series.enableMouseTracking
     * @see https://api.highcharts.com/highmaps/plotOptions.series.enableMouseTracking
     * @see https://api.highcharts.com/gantt/plotOptions.series.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) General event handlers for the
     * series items. These event hooks can also be attached to the series at run
     * time using the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.events
     * @see https://api.highcharts.com/highstock/plotOptions.series.events
     * @see https://api.highcharts.com/highmaps/plotOptions.series.events
     * @see https://api.highcharts.com/gantt/plotOptions.series.events
     */
    events?: PlotSeriesEventsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) By default, series are exposed
     * to screen readers as regions. By enabling this option, the series element
     * itself will be exposed in the same way as the data points. This is useful
     * if the series is not used as a grouping entity in the chart, but you
     * still want to attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.series.exposeElementToA11y
     * @see https://api.highcharts.com/highmaps/plotOptions.series.exposeElementToA11y
     * @see https://api.highcharts.com/gantt/plotOptions.series.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Determines whether the series
     * should look for the nearest point in both dimensions or just the
     * x-dimension when hovering the series. Defaults to `'xy'` for scatter
     * series and `'x'` for most other series. If the data has duplicate
     * x-values, it is recommended to set this to `'xy'` to allow hovering over
     * all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.series.findNearestPointBy
     * @see https://api.highcharts.com/highmaps/plotOptions.series.findNearestPointBy
     * @see https://api.highcharts.com/gantt/plotOptions.series.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.series.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.series.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array specifying which option
     * maps to which key in the data point array. This makes it convenient to
     * work with unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.keys
     * @see https://api.highcharts.com/highstock/plotOptions.series.keys
     * @see https://api.highcharts.com/highmaps/plotOptions.series.keys
     * @see https://api.highcharts.com/gantt/plotOptions.series.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.label
     * @see https://api.highcharts.com/highstock/plotOptions.series.label
     * @see https://api.highcharts.com/gantt/plotOptions.series.label
     */
    label?: PlotSeriesLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.lastPrice
     */
    lastPrice?: PlotSeriesLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.lastVisiblePrice
     */
    lastVisiblePrice?: PlotSeriesLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The line cap used for line ends and line joins on
     * the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.series.linecap
     */
    linecap?: ("round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.series.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.series.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the point markers of
     * line-like series. Properties like `fillColor`, `lineColor` and
     * `lineWidth` define the visual appearance of the markers. Other series
     * types, like column series, don't have markers, but have visual options on
     * the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.marker
     * @see https://api.highcharts.com/highstock/plotOptions.series.marker
     * @see https://api.highcharts.com/highmaps/plotOptions.series.marker
     * @see https://api.highcharts.com/gantt/plotOptions.series.marker
     */
    marker?: PlotSeriesMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color for the parts of the
     * graph or points that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.negativeColor
     * @see https://api.highcharts.com/highmaps/plotOptions.series.negativeColor
     * @see https://api.highcharts.com/gantt/plotOptions.series.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Properties for each single
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point
     * @see https://api.highcharts.com/highstock/plotOptions.series.point
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point
     * @see https://api.highcharts.com/gantt/plotOptions.series.point
     */
    point?: PlotSeriesPointOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Same as
     * accessibility.pointDescriptionFormatter, but for an individual series.
     * Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.series.pointDescriptionFormatter
     * @see https://api.highcharts.com/highmaps/plotOptions.series.pointDescriptionFormatter
     * @see https://api.highcharts.com/gantt/plotOptions.series.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.series.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.series.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.series.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.series.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.series.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.series.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.series.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.series.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to select the series
     * initially. If `showCheckbox` is true, the checkbox next to the series
     * name in the legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.selected
     * @see https://api.highcharts.com/highstock/plotOptions.series.selected
     * @see https://api.highcharts.com/highmaps/plotOptions.series.selected
     * @see https://api.highcharts.com/gantt/plotOptions.series.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to apply a drop shadow
     * to the graph line. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.series.shadow
     * @see https://api.highcharts.com/highmaps/plotOptions.series.shadow
     * @see https://api.highcharts.com/gantt/plotOptions.series.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) If true, a checkbox is displayed
     * next to the legend item to allow selecting the series. The state of the
     * checkbox is determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.series.showCheckbox
     * @see https://api.highcharts.com/highmaps/plotOptions.series.showCheckbox
     * @see https://api.highcharts.com/gantt/plotOptions.series.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to display this
     * particular series or series type in the legend. The default value is
     * `true` for standalone series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.series.showInLegend
     * @see https://api.highcharts.com/highmaps/plotOptions.series.showInLegend
     * @see https://api.highcharts.com/gantt/plotOptions.series.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) If set to `true`, the
     * accessibility module will skip past the points in this series for
     * keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.series.skipKeyboardNavigation
     * @see https://api.highcharts.com/highmaps/plotOptions.series.skipKeyboardNavigation
     * @see https://api.highcharts.com/gantt/plotOptions.series.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.series.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.series.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A wrapper object for all the
     * series options in specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states
     * @see https://api.highcharts.com/highstock/plotOptions.series.states
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states
     * @see https://api.highcharts.com/gantt/plotOptions.series.states
     */
    states?: PlotSeriesStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.step
     * @see https://api.highcharts.com/highstock/plotOptions.series.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Sticky tracking of mouse events.
     * When true, the `mouseOut` event on a series isn't triggered until the
     * mouse moves over another series, or out of the plot area. When false, the
     * `mouseOut` event on a series is triggered when the mouse leaves the area
     * around the series' graph or markers. This also implies the tooltip when
     * not shared. When `stickyTracking` is false and `tooltip.shared` is false,
     * the tooltip will be hidden when moving the mouse between series. Defaults
     * to true for line and area type series, but to false for columns, pies
     * etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.series.stickyTracking
     * @see https://api.highcharts.com/highmaps/plotOptions.series.stickyTracking
     * @see https://api.highcharts.com/gantt/plotOptions.series.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.series.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A configuration object for the
     * tooltip rendering of each single series. Properties are inherited from
     * tooltip, but only the following properties can be defined on a series
     * level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip
     */
    tooltip?: PlotSeriesTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.series.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.series.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the initial visibility of
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.visible
     * @see https://api.highcharts.com/highstock/plotOptions.series.visible
     * @see https://api.highcharts.com/highmaps/plotOptions.series.visible
     * @see https://api.highcharts.com/gantt/plotOptions.series.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.series.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.zones
     * @see https://api.highcharts.com/highstock/plotOptions.series.zones
     */
    zones?: Array<PlotSeriesZonesOptions>;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.series.point.events
 * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events
 * @see https://api.highcharts.com/gantt/plotOptions.series.point.events
 */
export interface PlotSeriesPointEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events.click
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events.click
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events.drag
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events.drag
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events.dragStart
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events.dragStart
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events.drop
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events.drop
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events.mouseOut
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events.mouseOut
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events.mouseOver
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events.mouseOver
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events.remove
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events.remove
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events.select
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events.select
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events.unselect
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events.unselect
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events.update
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events.update
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.point
 * @see https://api.highcharts.com/highstock/plotOptions.series.point
 * @see https://api.highcharts.com/highmaps/plotOptions.series.point
 * @see https://api.highcharts.com/gantt/plotOptions.series.point
 */
export interface PlotSeriesPointOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.series.point.events
     * @see https://api.highcharts.com/highmaps/plotOptions.series.point.events
     * @see https://api.highcharts.com/gantt/plotOptions.series.point.events
     */
    events?: PlotSeriesPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.animation
 */
export interface PlotSeriesStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.halo
 */
export interface PlotSeriesStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker
 */
export interface PlotSeriesStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states
     */
    states?: PlotSeriesStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover.animation
 */
export interface PlotSeriesStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover
 */
export interface PlotSeriesStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSeriesStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.normal
 */
export interface PlotSeriesStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states
 */
export interface PlotSeriesStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.hover
     */
    hover?: PlotSeriesStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.normal
     */
    normal?: PlotSeriesStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.select
     */
    select?: PlotSeriesStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.select
 */
export interface PlotSeriesStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the hovered series.
 * These settings override the normal state options when a series is moused over
 * or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover
 * @see https://api.highcharts.com/highmaps/plotOptions.series.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.series.states.hover
 */
export interface PlotSeriesStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSeriesStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable separate styles for the
     * hovered series to visualize that the user hovers either the series itself
     * or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.series.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.halo
     */
    halo?: PlotSeriesStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover.marker
     */
    marker?: PlotSeriesStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.series.states.normal
 */
export interface PlotSeriesStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) A wrapper object for all the series
 * options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states
 * @see https://api.highcharts.com/highstock/plotOptions.series.states
 * @see https://api.highcharts.com/highmaps/plotOptions.series.states
 * @see https://api.highcharts.com/gantt/plotOptions.series.states
 */
export interface PlotSeriesStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the hovered series.
     * These settings override the normal state options when a series is moused
     * over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.hover
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.series.states.hover
     */
    hover?: PlotSeriesStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.normal
     */
    normal?: PlotSeriesStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.select
     */
    select?: PlotSeriesStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.animation
 */
export interface PlotSeriesStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.halo
 */
export interface PlotSeriesStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker
 */
export interface PlotSeriesStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states
     */
    states?: PlotSeriesStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover.animation
 */
export interface PlotSeriesStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover
 */
export interface PlotSeriesStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSeriesStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.normal
 */
export interface PlotSeriesStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states
 */
export interface PlotSeriesStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.hover
     */
    hover?: PlotSeriesStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.normal
     */
    normal?: PlotSeriesStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.select
     */
    select?: PlotSeriesStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.select
 */
export interface PlotSeriesStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.series.states.select
 */
export interface PlotSeriesStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSeriesStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.series.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.halo
     */
    halo?: PlotSeriesStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.series.states.select.marker
     */
    marker?: PlotSeriesStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.dateTimeLabelFormats
 */
export interface PlotSeriesTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) A configuration object for the
 * tooltip rendering of each single series. Properties are inherited from
 * tooltip, but only the following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip
 * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip
 * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip
 */
export interface PlotSeriesTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotSeriesTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether the tooltip should
     * follow the mouse as it moves across columns, pie slices and other point
     * types with an extent. By default it behaves this way for scatter, bubble
     * and pie series by override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.followPointer
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.followPointer
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether the tooltip should
     * update as the finger moves on a touch device. If this is `true` and
     * chart.panning is set,`followTouchMove` will take over one-finger touches,
     * so the user needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.followTouchMove
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.followTouchMove
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A string to append to the
     * tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.footerFormat
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.footerFormat
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The HTML of the tooltip header
     * line. Variables are enclosed by curly brackets. Available variables are
     * `point.key`, `series.name`, `series.color` and other members from the
     * `point` and `series` objects. The `point.key` variable contains the
     * category name, x value or datetime string depending on the type of axis.
     * For datetime axes, the `point.key` date format can be set using
     * `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.headerFormat
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.headerFormat
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The name of a symbol to use for
     * the border around the tooltip header. Applies only when tooltip.split is
     * enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.headerShape
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.headerShape
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of milliseconds to
     * wait until the tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.hideDelay
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.hideDelay
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to allow the tooltip to
     * render outside the chart's SVG element box. By default (`false`), the
     * tooltip is rendered within the chart's SVG element, which results in the
     * tooltip being aligned inside the chart area. For small charts, this may
     * result in clipping or overlapping. When `true`, a separate SVG element is
     * created and overlaid on the page, allowing the tooltip to be aligned
     * inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.outside
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.outside
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Padding inside the tooltip, in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.padding
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.padding
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The HTML of the point's line in
     * the tooltip. Variables are enclosed by curly brackets. Available
     * variables are point.x, point.y, series. name and series.color and other
     * properties on the same form. Furthermore, `point.y` can be extended by
     * the `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can
     * also be overridden for each series, which makes it a good hook for
     * displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.pointFormat
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.pointFormat
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A callback function for
     * formatting the HTML output for a single point in the tooltip. Like the
     * `pointFormat` string, but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.pointFormatter
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.pointFormatter
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) How many decimals to show in
     * each series' y value. This is overridable in each series' tooltip options
     * object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.valueDecimals
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.valueDecimals
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A string to prepend to each
     * series' y value. Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.valuePrefix
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.valuePrefix
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A string to append to each
     * series' y value. Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.valueSuffix
     * @see https://api.highcharts.com/highmaps/plotOptions.series.tooltip.valueSuffix
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.series.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.series.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.series.zones
 * @see https://api.highcharts.com/highstock/plotOptions.series.zones
 */
export interface PlotSeriesZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.series.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.series.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.series.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.series.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.series.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.series.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.animation
 */
export interface PlotSmaAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker
 */
export interface PlotSmaConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker
 */
export interface PlotSmaConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors
 */
export interface PlotSmaConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.endMarker
     */
    endMarker?: PlotSmaConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.marker
     */
    marker?: PlotSmaConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker
     */
    startMarker?: PlotSmaConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker
 */
export interface PlotSmaConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.dataGrouping
 */
export interface PlotSmaDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.filter
 */
export interface PlotSmaDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels
 */
export interface PlotSmaDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.sma.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.filter
     */
    filter?: PlotSmaDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragHandle
 */
export interface PlotSmaDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.guideBox.default
 */
export interface PlotSmaDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.guideBox
 */
export interface PlotSmaDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.guideBox.default
     */
    default?: PlotSmaDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop
 */
export interface PlotSmaDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragHandle
     */
    dragHandle?: PlotSmaDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.guideBox
     */
    guideBox?: (PlotSmaDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.events
 */
export interface PlotSmaEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.sma.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.sma.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.label
 * @see https://api.highcharts.com/highstock/plotOptions.sma.label
 * @see https://api.highcharts.com/gantt/plotOptions.sma.label
 */
export interface PlotSmaLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.sma.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.sma.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.sma.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.sma.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.sma.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.sma.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sma.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.sma.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.sma.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.sma.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.sma.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.sma.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.sma.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.sma.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.sma.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.sma.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.lastPrice
 */
export interface PlotSmaLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotSmaLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.lastVisiblePrice
 */
export interface PlotSmaLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotSmaLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.marker
 */
export interface PlotSmaMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states
     */
    states?: PlotSmaMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover.animation
 */
export interface PlotSmaMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover
 */
export interface PlotSmaMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSmaMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.normal
 */
export interface PlotSmaMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states
 */
export interface PlotSmaMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.hover
     */
    hover?: PlotSmaMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.normal
     */
    normal?: PlotSmaMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.select
     */
    select?: PlotSmaMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.select
 */
export interface PlotSmaMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Simple moving average indicator (SMA). This series requires
 * `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `sma` series are defined in plotOptions.sma.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma
 */
export interface PlotSmaOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSmaAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.sma.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sma.connectors
     */
    connectors?: PlotSmaConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.sma.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataGrouping
     */
    dataGrouping?: PlotSmaDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dataLabels
     */
    dataLabels?: PlotSmaDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.dragDrop
     */
    dragDrop?: PlotSmaDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.events
     */
    events?: PlotSmaEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.sma.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.sma.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.label
     * @see https://api.highcharts.com/highstock/plotOptions.sma.label
     * @see https://api.highcharts.com/gantt/plotOptions.sma.label
     */
    label?: PlotSmaLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.lastPrice
     */
    lastPrice?: PlotSmaLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.lastVisiblePrice
     */
    lastVisiblePrice?: PlotSmaLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.sma.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sma.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.sma.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.sma.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.marker
     */
    marker?: PlotSmaMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.params
     */
    params?: PlotSmaParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point
     */
    point?: PlotSmaPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.sma.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states
     */
    states?: PlotSmaStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.step
     * @see https://api.highcharts.com/highstock/plotOptions.sma.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.sma.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip
     */
    tooltip?: PlotSmaTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.sma.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.sma.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.sma.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.zones
     * @see https://api.highcharts.com/highstock/plotOptions.sma.zones
     */
    zones?: Array<PlotSmaZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.params
 */
export interface PlotSmaParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events
 */
export interface PlotSmaPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.point
 */
export interface PlotSmaPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.point.events
     */
    events?: PlotSmaPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.animation
 */
export interface PlotSmaStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.halo
 */
export interface PlotSmaStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker
 */
export interface PlotSmaStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states
     */
    states?: PlotSmaStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover.animation
 */
export interface PlotSmaStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover
 */
export interface PlotSmaStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSmaStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.normal
 */
export interface PlotSmaStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states
 */
export interface PlotSmaStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.hover
     */
    hover?: PlotSmaStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.normal
     */
    normal?: PlotSmaStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.select
     */
    select?: PlotSmaStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.select
 */
export interface PlotSmaStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover
 */
export interface PlotSmaStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSmaStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.halo
     */
    halo?: PlotSmaStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover.marker
     */
    marker?: PlotSmaStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.normal
 */
export interface PlotSmaStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states
 */
export interface PlotSmaStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.hover
     */
    hover?: PlotSmaStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.normal
     */
    normal?: PlotSmaStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.select
     */
    select?: PlotSmaStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.animation
 */
export interface PlotSmaStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.halo
 */
export interface PlotSmaStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker
 */
export interface PlotSmaStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states
     */
    states?: PlotSmaStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover.animation
 */
export interface PlotSmaStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover
 */
export interface PlotSmaStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSmaStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.normal
 */
export interface PlotSmaStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states
 */
export interface PlotSmaStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.hover
     */
    hover?: PlotSmaStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.normal
     */
    normal?: PlotSmaStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.select
     */
    select?: PlotSmaStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.select
 */
export interface PlotSmaStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.select
 */
export interface PlotSmaStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSmaStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sma.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.halo
     */
    halo?: PlotSmaStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.sma.states.select.marker
     */
    marker?: PlotSmaStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.sma.tooltip.dateTimeLabelFormats
 */
export interface PlotSmaTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip
 */
export interface PlotSmaTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.sma.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotSmaTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.sma.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.sma.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sma.zones
 * @see https://api.highcharts.com/highstock/plotOptions.sma.zones
 */
export interface PlotSmaZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.sma.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.sma.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.sma.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.sma.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sma.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.sma.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.animation
 */
export interface PlotSolidgaugeAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker
 */
export interface PlotSolidgaugeConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker
 */
export interface PlotSolidgaugeConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors
 */
export interface PlotSolidgaugeConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.endMarker
     */
    endMarker?: PlotSolidgaugeConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.marker
     */
    marker?: PlotSolidgaugeConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker
     */
    startMarker?: PlotSolidgaugeConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker
 */
export interface PlotSolidgaugeConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataGrouping
 */
export interface PlotSolidgaugeDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.filter
 */
export interface PlotSolidgaugeDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Data labels for the gauge. For gauges, the data labels are
 * enabled by default and shown in a bordered box below the point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels
 */
export interface PlotSolidgaugeDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highmaps) The border color for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.borderColor
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highmaps) The border radius in pixels for the gauge's data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.borderRadius
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highmaps) The border width in pixels for the gauge data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.borderWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highmaps) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.filter
     */
    filter?: PlotSolidgaugeDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highmaps) The vertical alignment of the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highmaps) The y position offset of the label relative to the
     * center of the gauge.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.y
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highmaps) The Z index of the data labels. A value of 2
     * display them behind the dial.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragHandle
 */
export interface PlotSolidgaugeDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.guideBox.default
 */
export interface PlotSolidgaugeDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.guideBox
 */
export interface PlotSolidgaugeDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.guideBox.default
     */
    default?: PlotSolidgaugeDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop
 */
export interface PlotSolidgaugeDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragHandle
     */
    dragHandle?: PlotSolidgaugeDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.guideBox
     */
    guideBox?: (PlotSolidgaugeDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.events
 */
export interface PlotSolidgaugeEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.label
 * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.label
 * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.label
 */
export interface PlotSolidgaugeLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.lastPrice
 */
export interface PlotSolidgaugeLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotSolidgaugeLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.lastVisiblePrice
 */
export interface PlotSolidgaugeLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotSolidgaugeLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A solid gauge is a circular gauge where the value is indicated
 * by a filled arc, and the color of the arc may variate with the value.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `solidgauge` series are defined in plotOptions.solidgauge.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge
 */
export interface PlotSolidgaugeOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSolidgaugeAnimationOptions);
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) Whether to give each point an individual color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.connectors
     */
    connectors?: PlotSolidgaugeConnectorsOptions;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.dataGrouping
     */
    dataGrouping?: PlotSolidgaugeDataGroupingOptions;
    /**
     * (Highcharts) Data labels for the gauge. For gauges, the data labels are
     * enabled by default and shown in a bordered box below the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dataLabels
     */
    dataLabels?: PlotSolidgaugeDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.dragDrop
     */
    dragDrop?: PlotSolidgaugeDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.events
     */
    events?: PlotSolidgaugeEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.label
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.label
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.label
     */
    label?: PlotSolidgaugeLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.lastPrice
     */
    lastPrice?: PlotSolidgaugeLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.lastVisiblePrice
     */
    lastVisiblePrice?: PlotSolidgaugeLastVisiblePriceOptions;
    /**
     * (Highcharts) Whether the strokes of the solid gauge should be `round` or
     * `square`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.linecap
     */
    linecap?: ("round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) Allow the gauge to overshoot the end of the perimeter axis
     * by this many degrees. Say if the gauge axis goes from 0 to 60, a value of
     * 100, or 1000, will show 5 degrees beyond the end of the axis when this
     * option is set to 5.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.overshoot
     */
    overshoot?: number;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point
     */
    point?: PlotSolidgaugePointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts) Wether to draw rounded edges on the gauge.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.rounded
     */
    rounded?: boolean;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. Defaults to false for gauge series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The threshold or base level for the gauge.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.threshold
     */
    threshold?: number;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip
     */
    tooltip?: PlotSolidgaugeTooltipOptions;
    /**
     * (Highstock) The parameter allows setting line series type and use OHLC
     * indicators. Data in OHLC format is required.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.useOhlcData
     */
    useOhlcData?: boolean;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.solidgauge.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events
 */
export interface PlotSolidgaugePointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point
 */
export interface PlotSolidgaugePointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.point.events
     */
    events?: PlotSolidgaugePointEventsOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.tooltip.dateTimeLabelFormats
 */
export interface PlotSolidgaugeTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip
 */
export interface PlotSolidgaugeTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotSolidgaugeTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.solidgauge.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.solidgauge.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.solidgauge.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.animation
 * @see https://api.highcharts.com/highstock/plotOptions.spline.animation
 */
export interface PlotSplineAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker
 */
export interface PlotSplineConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker
 */
export interface PlotSplineConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors
 */
export interface PlotSplineConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.endMarker
     */
    endMarker?: PlotSplineConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.marker
     */
    marker?: PlotSplineConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker
     */
    startMarker?: PlotSplineConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker
 */
export interface PlotSplineConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.spline.dataGrouping
 */
export interface PlotSplineDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.filter
 */
export interface PlotSplineDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels
 */
export interface PlotSplineDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.spline.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.filter
     */
    filter?: PlotSplineDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragHandle
 */
export interface PlotSplineDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.guideBox.default
 */
export interface PlotSplineDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.guideBox
 */
export interface PlotSplineDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.guideBox.default
     */
    default?: PlotSplineDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop
 */
export interface PlotSplineDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragHandle
     */
    dragHandle?: PlotSplineDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.guideBox
     */
    guideBox?: (PlotSplineDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.events
 * @see https://api.highcharts.com/highstock/plotOptions.spline.events
 */
export interface PlotSplineEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.spline.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.spline.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.spline.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.spline.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.spline.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.spline.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.spline.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.spline.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.spline.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.label
 * @see https://api.highcharts.com/highstock/plotOptions.spline.label
 * @see https://api.highcharts.com/gantt/plotOptions.spline.label
 */
export interface PlotSplineLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.spline.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.spline.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.spline.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.spline.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.spline.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.spline.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.spline.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.spline.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.spline.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.spline.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.spline.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.spline.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.spline.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.spline.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.spline.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.spline.lastPrice
 */
export interface PlotSplineLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotSplineLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.spline.lastVisiblePrice
 */
export interface PlotSplineLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotSplineLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker
 * @see https://api.highcharts.com/highstock/plotOptions.spline.marker
 */
export interface PlotSplineMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states
     */
    states?: PlotSplineMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover.animation
 */
export interface PlotSplineMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover
 */
export interface PlotSplineMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSplineMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.normal
 */
export interface PlotSplineMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states
 */
export interface PlotSplineMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.hover
     */
    hover?: PlotSplineMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.normal
     */
    normal?: PlotSplineMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.select
     */
    select?: PlotSplineMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.select
 */
export interface PlotSplineMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) A spline series is a special type of line series,
 * where the segments between the data points are smoothed.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `spline` series are defined in plotOptions.spline.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline
 * @see https://api.highcharts.com/highstock/plotOptions.spline
 */
export interface PlotSplineOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.spline.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.animation
     * @see https://api.highcharts.com/highstock/plotOptions.spline.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSplineAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.spline.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.spline.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.className
     * @see https://api.highcharts.com/highstock/plotOptions.spline.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.clip
     * @see https://api.highcharts.com/highstock/plotOptions.spline.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.color
     * @see https://api.highcharts.com/highstock/plotOptions.spline.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.spline.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.spline.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.spline.connectors
     */
    connectors?: PlotSplineConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.spline.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph,
     * or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataGrouping
     */
    dataGrouping?: PlotSplineDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dataLabels
     */
    dataLabels?: PlotSplineDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.description
     * @see https://api.highcharts.com/highstock/plotOptions.spline.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.spline.dragDrop
     */
    dragDrop?: PlotSplineDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.spline.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.events
     * @see https://api.highcharts.com/highstock/plotOptions.spline.events
     */
    events?: PlotSplineEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.spline.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.spline.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.spline.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.spline.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.keys
     * @see https://api.highcharts.com/highstock/plotOptions.spline.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.label
     * @see https://api.highcharts.com/highstock/plotOptions.spline.label
     * @see https://api.highcharts.com/gantt/plotOptions.spline.label
     */
    label?: PlotSplineLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.lastPrice
     */
    lastPrice?: PlotSplineLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.lastVisiblePrice
     */
    lastVisiblePrice?: PlotSplineLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The line cap used for line ends and line joins on
     * the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.spline.linecap
     */
    linecap?: ("round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.spline.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.spline.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.marker
     * @see https://api.highcharts.com/highstock/plotOptions.spline.marker
     */
    marker?: PlotSplineMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point
     */
    point?: PlotSplinePointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.spline.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.spline.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.spline.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.spline.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.spline.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.spline.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.spline.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.spline.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.spline.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.selected
     * @see https://api.highcharts.com/highstock/plotOptions.spline.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) Whether to apply a drop shadow to the graph line.
     * Since 2.3 the shadow can be an object configuration containing `color`,
     * `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.spline.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.spline.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.spline.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.spline.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.spline.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.spline.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states
     */
    states?: PlotSplineStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.spline.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.spline.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip
     */
    tooltip?: PlotSplineTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.spline.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.spline.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.visible
     * @see https://api.highcharts.com/highstock/plotOptions.spline.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.spline.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.zones
     * @see https://api.highcharts.com/highstock/plotOptions.spline.zones
     */
    zones?: Array<PlotSplineZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events
 */
export interface PlotSplinePointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.point
 * @see https://api.highcharts.com/highstock/plotOptions.spline.point
 */
export interface PlotSplinePointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.spline.point.events
     */
    events?: PlotSplinePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.animation
 */
export interface PlotSplineStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.halo
 */
export interface PlotSplineStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker
 */
export interface PlotSplineStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states
     */
    states?: PlotSplineStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover.animation
 */
export interface PlotSplineStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover
 */
export interface PlotSplineStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSplineStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.normal
 */
export interface PlotSplineStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states
 */
export interface PlotSplineStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.hover
     */
    hover?: PlotSplineStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.normal
     */
    normal?: PlotSplineStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.select
     */
    select?: PlotSplineStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.select
 */
export interface PlotSplineStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover
 */
export interface PlotSplineStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSplineStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.halo
     */
    halo?: PlotSplineStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover.marker
     */
    marker?: PlotSplineStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.normal
 */
export interface PlotSplineStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states
 */
export interface PlotSplineStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.hover
     */
    hover?: PlotSplineStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.normal
     */
    normal?: PlotSplineStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.select
     */
    select?: PlotSplineStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.animation
 */
export interface PlotSplineStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.halo
 */
export interface PlotSplineStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker
 */
export interface PlotSplineStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states
     */
    states?: PlotSplineStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover.animation
 */
export interface PlotSplineStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover
 */
export interface PlotSplineStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSplineStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.normal
 */
export interface PlotSplineStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states
 */
export interface PlotSplineStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.hover
     */
    hover?: PlotSplineStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.normal
     */
    normal?: PlotSplineStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.select
     */
    select?: PlotSplineStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.select
 */
export interface PlotSplineStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.select
 */
export interface PlotSplineStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSplineStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.spline.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.halo
     */
    halo?: PlotSplineStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.spline.states.select.marker
     */
    marker?: PlotSplineStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.spline.tooltip.dateTimeLabelFormats
 */
export interface PlotSplineTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip
 */
export interface PlotSplineTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.spline.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotSplineTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.spline.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.spline.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.spline.zones
 * @see https://api.highcharts.com/highstock/plotOptions.spline.zones
 */
export interface PlotSplineZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.spline.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.spline.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.spline.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.spline.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.spline.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.spline.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.animation
 */
export interface PlotStochasticAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker
 */
export interface PlotStochasticConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker
 */
export interface PlotStochasticConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors
 */
export interface PlotStochasticConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.endMarker
     */
    endMarker?: PlotStochasticConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.marker
     */
    marker?: PlotStochasticConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker
     */
    startMarker?: PlotStochasticConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker
 */
export interface PlotStochasticConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataGrouping
 */
export interface PlotStochasticDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.filter
 */
export interface PlotStochasticDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels
 */
export interface PlotStochasticDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.filter
     */
    filter?: PlotStochasticDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragHandle
 */
export interface PlotStochasticDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.guideBox.default
 */
export interface PlotStochasticDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.guideBox
 */
export interface PlotStochasticDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.guideBox.default
     */
    default?: PlotStochasticDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop
 */
export interface PlotStochasticDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragHandle
     */
    dragHandle?: PlotStochasticDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.guideBox
     */
    guideBox?: (PlotStochasticDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.events
 */
export interface PlotStochasticEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.label
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.label
 * @see https://api.highcharts.com/gantt/plotOptions.stochastic.label
 */
export interface PlotStochasticLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.lastPrice
 */
export interface PlotStochasticLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotStochasticLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.lastVisiblePrice
 */
export interface PlotStochasticLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotStochasticLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker
 */
export interface PlotStochasticMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states
     */
    states?: PlotStochasticMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover.animation
 */
export interface PlotStochasticMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover
 */
export interface PlotStochasticMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStochasticMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.normal
 */
export interface PlotStochasticMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states
 */
export interface PlotStochasticMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.hover
     */
    hover?: PlotStochasticMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.normal
     */
    normal?: PlotStochasticMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.select
     */
    select?: PlotStochasticMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.select
 */
export interface PlotStochasticMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Stochastic oscillator. This series requires the `linkedTo` option
 * to be set and should be loaded after the `stock/indicators/indicators.js`
 * file.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `stochastic` series are defined in plotOptions.stochastic.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic
 */
export interface PlotStochasticOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStochasticAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.connectors
     */
    connectors?: PlotStochasticConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataGrouping
     */
    dataGrouping?: PlotStochasticDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dataLabels
     */
    dataLabels?: PlotStochasticDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.dragDrop
     */
    dragDrop?: PlotStochasticDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.events
     */
    events?: PlotStochasticEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.label
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.label
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.label
     */
    label?: PlotStochasticLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.lastPrice
     */
    lastPrice?: PlotStochasticLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.lastVisiblePrice
     */
    lastVisiblePrice?: PlotStochasticLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.marker
     */
    marker?: PlotStochasticMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.params
     */
    params?: PlotStochasticParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point
     */
    point?: PlotStochasticPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highstock) Smoothed line options.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.smoothedLine
     */
    smoothedLine?: PlotStochasticSmoothedLineOptions;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states
     */
    states?: PlotStochasticStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.step
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip
     */
    tooltip?: PlotStochasticTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.zones
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.zones
     */
    zones?: Array<PlotStochasticZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.params
 */
export interface PlotStochasticParamsOptions {
    /**
     * (Highstock) Periods for Stochastic oscillator: [%K, %D].
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.params.periods
     */
    periods?: [number, number];
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events
 */
export interface PlotStochasticPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point
 */
export interface PlotStochasticPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.point.events
     */
    events?: PlotStochasticPointEventsOptions;
}
/**
 * (Highstock) Smoothed line options.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.smoothedLine
 */
export interface PlotStochasticSmoothedLineOptions {
    /**
     * (Highstock) Styles for a smoothed line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.smoothedLine.styles
     */
    styles?: PlotStochasticSmoothedLineStylesOptions;
}
/**
 * (Highstock) Styles for a smoothed line.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.smoothedLine.styles
 */
export interface PlotStochasticSmoothedLineStylesOptions {
    /**
     * (Highstock) Color of the line. If not set, it's inherited from
     * plotOptions.stochastic.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.smoothedLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.smoothedLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.animation
 */
export interface PlotStochasticStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.halo
 */
export interface PlotStochasticStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker
 */
export interface PlotStochasticStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states
     */
    states?: PlotStochasticStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover.animation
 */
export interface PlotStochasticStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover
 */
export interface PlotStochasticStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStochasticStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.normal
 */
export interface PlotStochasticStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states
 */
export interface PlotStochasticStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.hover
     */
    hover?: PlotStochasticStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.normal
     */
    normal?: PlotStochasticStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.select
     */
    select?: PlotStochasticStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.select
 */
export interface PlotStochasticStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover
 */
export interface PlotStochasticStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStochasticStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.halo
     */
    halo?: PlotStochasticStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover.marker
     */
    marker?: PlotStochasticStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.normal
 */
export interface PlotStochasticStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states
 */
export interface PlotStochasticStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.hover
     */
    hover?: PlotStochasticStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.normal
     */
    normal?: PlotStochasticStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.select
     */
    select?: PlotStochasticStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.animation
 */
export interface PlotStochasticStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.halo
 */
export interface PlotStochasticStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker
 */
export interface PlotStochasticStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states
     */
    states?: PlotStochasticStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover.animation
 */
export interface PlotStochasticStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover
 */
export interface PlotStochasticStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStochasticStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.normal
 */
export interface PlotStochasticStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states
 */
export interface PlotStochasticStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.hover
     */
    hover?: PlotStochasticStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.normal
     */
    normal?: PlotStochasticStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.select
     */
    select?: PlotStochasticStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.select
 */
export interface PlotStochasticStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.select
 */
export interface PlotStochasticStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStochasticStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.stochastic.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.halo
     */
    halo?: PlotStochasticStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.states.select.marker
     */
    marker?: PlotStochasticStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.stochastic.tooltip.dateTimeLabelFormats
 */
export interface PlotStochasticTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip
 */
export interface PlotStochasticTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotStochasticTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.stochastic.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.zones
 * @see https://api.highcharts.com/highstock/plotOptions.stochastic.zones
 */
export interface PlotStochasticZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.stochastic.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.stochastic.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.animation
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.animation
 */
export interface PlotStreamgraphAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker
 */
export interface PlotStreamgraphConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker
 */
export interface PlotStreamgraphConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors
 */
export interface PlotStreamgraphConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.endMarker
     */
    endMarker?: PlotStreamgraphConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.marker
     */
    marker?: PlotStreamgraphConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker
     */
    startMarker?: PlotStreamgraphConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker
 */
export interface PlotStreamgraphConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataGrouping
 */
export interface PlotStreamgraphDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.filter
 */
export interface PlotStreamgraphDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels
 */
export interface PlotStreamgraphDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.filter
     */
    filter?: PlotStreamgraphDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragHandle
 */
export interface PlotStreamgraphDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.guideBox.default
 */
export interface PlotStreamgraphDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.guideBox
 */
export interface PlotStreamgraphDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.guideBox.default
     */
    default?: PlotStreamgraphDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop
 */
export interface PlotStreamgraphDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragHandle
     */
    dragHandle?: PlotStreamgraphDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.guideBox
     */
    guideBox?: (PlotStreamgraphDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.events
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.events
 */
export interface PlotStreamgraphEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.label
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.label
 * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.label
 */
export interface PlotStreamgraphLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.lastPrice
 */
export interface PlotStreamgraphLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotStreamgraphLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.lastVisiblePrice
 */
export interface PlotStreamgraphLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotStreamgraphLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker
 */
export interface PlotStreamgraphMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states
     */
    states?: PlotStreamgraphMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover.animation
 */
export interface PlotStreamgraphMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover
 */
export interface PlotStreamgraphMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStreamgraphMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.normal
 */
export interface PlotStreamgraphMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states
 */
export interface PlotStreamgraphMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.hover
     */
    hover?: PlotStreamgraphMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.normal
     */
    normal?: PlotStreamgraphMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.select
     */
    select?: PlotStreamgraphMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.select
 */
export interface PlotStreamgraphMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) A streamgraph is a type of stacked area graph which
 * is displaced around a central axis, resulting in a flowing, organic shape.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `streamgraph` series are defined in
 * plotOptions.streamgraph.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph
 */
export interface PlotStreamgraphOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.animation
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStreamgraphAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.boostThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.className
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.clip
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.color
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.connectors
     */
    connectors?: PlotStreamgraphConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph,
     * or for some series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataGrouping
     */
    dataGrouping?: PlotStreamgraphDataGroupingOptions;
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dataLabels
     */
    dataLabels?: PlotStreamgraphDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.description
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.dragDrop
     */
    dragDrop?: PlotStreamgraphDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.events
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.events
     */
    events?: PlotStreamgraphEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Fill color or gradient for the area. When `null`,
     * the series' `color` is used with the series' `fillOpacity`.
     *
     * In styled mode, the fill color can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.fillColor
     */
    fillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Fill opacity for the area. When you set an
     * explicit `fillColor`, the `fillOpacity` is not applied. Instead, you
     * should define the opacity in the `fillColor` with an rgba color
     * definition. The `fillOpacity` setting, also the default setting,
     * overrides the alpha component of the `color` setting.
     *
     * In styled mode, the fill opacity can be set with the `.highcharts-area`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.fillOpacity
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.fillOpacity
     */
    fillOpacity?: number;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.keys
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.label
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.label
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.label
     */
    label?: PlotStreamgraphLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.lastPrice
     */
    lastPrice?: PlotStreamgraphLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.lastVisiblePrice
     */
    lastVisiblePrice?: PlotStreamgraphLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) A separate color for the graph line. By default
     * the line takes the `color` of the series, but the lineColor setting
     * allows setting a separate color for the line without altering the
     * `fillColor`.
     *
     * In styled mode, the line stroke can be set with the `.highcharts-graph`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.marker
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.marker
     */
    marker?: PlotStreamgraphMarkerOptions;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) A separate color for the negative part of the area.
     *
     * In styled mode, a negative color is set with the `.highcharts-negative`
     * class name.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.negativeFillColor
     */
    negativeFillColor?: ColorString;
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point
     */
    point?: PlotStreamgraphPointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.selected
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) Whether to apply a drop shadow to the graph line.
     * Since 2.3 the shadow can be an object configuration containing `color`,
     * `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states
     */
    states?: PlotStreamgraphStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The Y axis value to serve as the base for the
     * area, for distinguishing between values above and below a threshold. The
     * area between the graph and the threshold is filled.
     *
     * * If a number is given, the Y axis will scale to the threshold.
     *
     * * If `null`, the scaling behaves like a line series with fill between the
     * graph and the Y axis minimum.
     *
     * * If `Infinity` or `-Infinity`, the area between the graph and the
     * corresponing Y axis extreme is filled (since v6.1.0).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip
     */
    tooltip?: PlotStreamgraphTooltipOptions;
    /**
     * (Highcharts, Highstock) Whether the whole area or just the line should
     * respond to mouseover tooltips and other mouse or touch events.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.trackByArea
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.trackByArea
     */
    trackByArea?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.visible
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.zones
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.zones
     */
    zones?: Array<PlotStreamgraphZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events
 */
export interface PlotStreamgraphPointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point
 */
export interface PlotStreamgraphPointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.point.events
     */
    events?: PlotStreamgraphPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.animation
 */
export interface PlotStreamgraphStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.halo
 */
export interface PlotStreamgraphStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker
 */
export interface PlotStreamgraphStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states
     */
    states?: PlotStreamgraphStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover.animation
 */
export interface PlotStreamgraphStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover
 */
export interface PlotStreamgraphStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStreamgraphStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.normal
 */
export interface PlotStreamgraphStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states
 */
export interface PlotStreamgraphStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.hover
     */
    hover?: PlotStreamgraphStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.normal
     */
    normal?: PlotStreamgraphStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.select
     */
    select?: PlotStreamgraphStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.select
 */
export interface PlotStreamgraphStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover
 */
export interface PlotStreamgraphStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStreamgraphStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.halo
     */
    halo?: PlotStreamgraphStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover.marker
     */
    marker?: PlotStreamgraphStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.normal
 */
export interface PlotStreamgraphStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states
 */
export interface PlotStreamgraphStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.hover
     */
    hover?: PlotStreamgraphStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.normal
     */
    normal?: PlotStreamgraphStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.select
     */
    select?: PlotStreamgraphStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.animation
 */
export interface PlotStreamgraphStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.halo
 */
export interface PlotStreamgraphStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker
 */
export interface PlotStreamgraphStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states
     */
    states?: PlotStreamgraphStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover.animation
 */
export interface PlotStreamgraphStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover
 */
export interface PlotStreamgraphStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStreamgraphStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.normal
 */
export interface PlotStreamgraphStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states
 */
export interface PlotStreamgraphStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.hover
     */
    hover?: PlotStreamgraphStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.normal
     */
    normal?: PlotStreamgraphStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.select
     */
    select?: PlotStreamgraphStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.select
 */
export interface PlotStreamgraphStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.select
 */
export interface PlotStreamgraphStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotStreamgraphStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.streamgraph.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.halo
     */
    halo?: PlotStreamgraphStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.states.select.marker
     */
    marker?: PlotStreamgraphStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.tooltip.dateTimeLabelFormats
 */
export interface PlotStreamgraphTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip
 */
export interface PlotStreamgraphTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotStreamgraphTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.streamgraph.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.zones
 * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.zones
 */
export interface PlotStreamgraphZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.streamgraph.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.streamgraph.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.animation
 */
export interface PlotSunburstAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker
 */
export interface PlotSunburstConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker
 */
export interface PlotSunburstConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors
 */
export interface PlotSunburstConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.endMarker
     */
    endMarker?: PlotSunburstConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.marker
     */
    marker?: PlotSunburstConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker
     */
    startMarker?: PlotSunburstConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker
 */
export interface PlotSunburstConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.filter
 */
export interface PlotSunburstDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels
 */
export interface PlotSunburstDataLabelsOptions {
    /**
     * (Highcharts) Alignment method for data labels. Possible values are:
     * `'toPlotEdges'` (each label touches the nearest vertical edge of the plot
     * area) or `'connectors'` (connectors have the same x position and the
     * widest label of each half (left & right) touches the nearest vertical
     * edge of the plot area).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.alignTo
     */
    alignTo?: string;
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The color of the line connecting the data label to the pie
     * slice. The default color is the same as the point's color.
     *
     * In styled mode, the connector stroke is given in the
     * `.highcharts-data-label-connector` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.connectorColor
     */
    connectorColor?: ColorString;
    /**
     * (Highcharts) The distance from the data label to the connector. Note that
     * data labels also have a default `padding`, so in order for the connector
     * to touch the text, the `padding` must also be 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.connectorPadding
     */
    connectorPadding?: number;
    /**
     * (Highcharts) Specifies the method that is used to generate the connector
     * path. Highcharts provides 3 built-in connector shapes: `'fixedOffset'`
     * (default), `'straight'` and `'crookedLine'`. Using `'crookedLine'` has
     * the most sense (in most of the cases) when `'alignTo'` is set.
     *
     * Users can provide their own method by passing a function instead of a
     * String. 3 arguments are passed to the callback:
     *
     * (see online documentation for example)
     *
     * The function has to return an SVG path definition in array form (see the
     * example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.connectorShape
     */
    connectorShape?: (() => void|string);
    /**
     * (Highcharts) The width of the line connecting the data label to the pie
     * slice.
     *
     * In styled mode, the connector stroke width is given in the
     * `.highcharts-data-label-connector` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.connectorWidth
     */
    connectorWidth?: number;
    /**
     * (Highcharts) Works only if `connectorShape` is `'crookedLine'`. It
     * defines how far from the vertical plot edge the coonnector path should be
     * crooked.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.crookDistance
     */
    crookDistance?: string;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.filter
     */
    filter?: PlotSunburstDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) Decides how the data label will be rotated relative to the
     * perimeter of the sunburst. Valid values are `auto`, `parallel` and
     * `perpendicular`. When `auto`, the best fit will be computed for the
     * point.
     *
     * The `series.rotation` option takes precedence over `rotationMode`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.rotationMode
     */
    rotationMode?: ("auto"|"parallel"|"perpendicular");
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Whether to render the connector as a soft arc or a line with
     * sharp break. Works only if `connectorShape` equals to `fixedOffset`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.softConnector
     */
    softConnector?: number;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.style
     */
    style?: PlotSunburstDataLabelsStyleOptions;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Styles for the label. The default `color` setting is
 * `"contrast"`, which is a pseudo color that Highcharts picks up and applies
 * the maximum contrast to the underlying point item, for example the bar in a
 * bar chart.
 *
 * The `textOutline` is a pseudo property that applies an outline of the given
 * width with the given color, which by default is the maximum contrast to the
 * text. So a bright text color will result in a black text outline for maximum
 * readability on a mixed background. In some cases, especially with grayscale
 * text, the text outline doesn't work well, in which cases it can be disabled
 * by setting it to `"none"`. When `useHTML` is true, the `textOutline` will not
 * be picked up. In this, case, the same effect can be acheived through the
 * `text-shadow` CSS property.
 *
 * For some series types, where each point has an extent, like for example tree
 * maps, the data label may overflow the point. There are two strategies for
 * handling overflow. By default, the text will wrap to multiple lines. The
 * other strategy is to set `style.textOverflow` to `ellipsis`, which will keep
 * the text on one line plus it will break inside long words.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels.style
 */
export interface PlotSunburstDataLabelsStyleOptions {
    textOverflow?: string;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragHandle
 */
export interface PlotSunburstDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.guideBox.default
 */
export interface PlotSunburstDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.guideBox
 */
export interface PlotSunburstDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.guideBox.default
     */
    default?: PlotSunburstDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop
 */
export interface PlotSunburstDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragHandle
     */
    dragHandle?: PlotSunburstDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.guideBox
     */
    guideBox?: (PlotSunburstDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.events
 */
export interface PlotSunburstEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the point name in the legend
     * is clicked. One parameter, event, is passed to the function. The state of
     * the checkbox is found by event.checked. The checked item is found by
     * event.item. Return false to prevent the default action which is to toggle
     * the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.events.checkboxClick
     */
    checkboxClick?: () => void;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.label
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.label
 * @see https://api.highcharts.com/gantt/plotOptions.sunburst.label
 */
export interface PlotSunburstLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.lastPrice
 */
export interface PlotSunburstLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotSunburstLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.lastVisiblePrice
 */
export interface PlotSunburstLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotSunburstLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) Can set a `colorVariation` on all points which lies on the same
 * level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.colorVariation
 */
export interface PlotSunburstLevelsColorVariationOptions {
    /**
     * (Highcharts) The key of a color variation. Currently supports
     * `brightness` only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.colorVariation.key
     */
    key?: string;
    /**
     * (Highcharts) The ending value of a color variation. The last sibling will
     * receive this value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.colorVariation.to
     */
    to?: number;
}
/**
 * (Highcharts) Determines the width of the ring per level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levelSize
 */
export interface PlotSunburstLevelSizeOptions {
    /**
     * (Highcharts) How to interpret `levelSize.value`.
     *
     * - `percentage` gives a width relative to result of outer radius minus
     * inner radius.
     *
     * - `pixels` gives the ring a fixed width in pixels.
     *
     * - `weight` takes the remaining width after percentage and pixels, and
     * distributes it accross all "weighted" levels. The value relative to the
     * sum of all weights determines the width.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levelSize.unit
     */
    unit?: ("percentage"|"pixels"|"weight");
    /**
     * (Highcharts) The value used for calculating the width of the ring. Its'
     * affect is determined by `levelSize.unit`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levelSize.value
     */
    value?: number;
}
/**
 * (Highcharts) Set options on specific levels. Takes precedence over series
 * options, but not point options.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels
 */
export interface PlotSunburstLevelsOptions {
    /**
     * (Highcharts) Can set a `borderColor` on all points which lies on the same
     * level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) Can set a `borderDashStyle` on all points which lies on the
     * same level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.borderDashStyle
     */
    borderDashStyle?: string;
    /**
     * (Highcharts) Can set a `borderWidth` on all points which lies on the same
     * level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) Can set a `color` on all points which lies on the same
     * level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Can set a `colorVariation` on all points which lies on the
     * same level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.colorVariation
     */
    colorVariation?: PlotSunburstLevelsColorVariationOptions;
    /**
     * (Highcharts) Can set `dataLabels` on all points which lies on the same
     * level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.dataLabels
     */
    dataLabels?: object;
    /**
     * (Highcharts) Can set a `levelSize` on all points which lies on the same
     * level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.levelSize
     */
    levelSize?: object;
    /**
     * (Highcharts) Can set a `rotation` on all points which lies on the same
     * level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) Can set a `rotationMode` on all points which lies on the
     * same level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels.rotationMode
     */
    rotationMode?: string;
}
/**
 * (Highcharts) A Sunburst displays hierarchical data, where a level in the
 * hierarchy is represented by a circle. The center represents the root node of
 * the tree. The visualization bears a resemblance to both treemap and pie
 * charts.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `sunburst` series are defined in plotOptions.sunburst.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst
 */
export interface PlotSunburstOptions {
    /**
     * (Highcharts) When enabled the user can click on a point which is a parent
     * and zoom in on its children.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.allowDrillToNode
     */
    allowDrillToNode?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSunburstAnimationOptions);
    /**
     * (Highcharts) The color of the border surrounding each slice. When `null`,
     * the border takes the same color as the slice fill. This can be used
     * together with a `borderWidth` to fill drawing gaps created by
     * antialiazing artefacts in borderless pies.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The width of the border surrounding each slice.
     *
     * When setting the border width to 0, there may be small gaps between the
     * slices due to SVG antialiasing artefacts. To work around this, keep the
     * border width at 0.5 or 1, but set the `borderColor` to `null` instead.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) The center of the sunburst chart relative to the plot area.
     * Can be percentages or pixel values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.center
     */
    center?: Array<(number|string)>;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.className
     */
    className?: string;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts) A series specific or series type specific color set to use
     * instead of the global colors.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.connectors
     */
    connectors?: PlotSunburstConnectorsOptions;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dataLabels
     */
    dataLabels?: PlotSunburstDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.dragDrop
     */
    dragDrop?: PlotSunburstDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.events
     */
    events?: PlotSunburstEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.label
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.label
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.label
     */
    label?: PlotSunburstLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.lastPrice
     */
    lastPrice?: PlotSunburstLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.lastVisiblePrice
     */
    lastVisiblePrice?: PlotSunburstLastVisiblePriceOptions;
    /**
     * (Highcharts) Used together with the levels and `allowDrillToNode`
     * options. When set to false the first level visible when drilling is
     * considered to be level one. Otherwise the level will be the same as the
     * tree structure.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levelIsConstant
     */
    levelIsConstant?: boolean;
    /**
     * (Highcharts) Set options on specific levels. Takes precedence over series
     * options, but not point options.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levels
     */
    levels?: Array<PlotSunburstLevelsOptions>;
    /**
     * (Highcharts) Determines the width of the ring per level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.levelSize
     */
    levelSize?: PlotSunburstLevelSizeOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point
     */
    point?: PlotSunburstPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts) Which point to use as a root in the visualization.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.rootId
     */
    rootId?: string;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. Since 2.1, pies are not shown in the legend by default.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) The diameter of the pie relative to the plot area. Can be a
     * percentage or pixel value. Pixel values are given as integers. The
     * default behaviour (as of 3.0) is to scale to the plot area and give room
     * for data labels within the plot area. slicedOffset is also included in
     * the default size calculation. As a consequence, the size of the pie may
     * vary when points are updated and data labels more around. In that case it
     * is best to set a fixed value, for example `"75%"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.size
     */
    size?: (number|string|null);
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) If a point is sliced, moved out from the center, how many
     * pixels should it be moved?.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.slicedOffset
     */
    slicedOffset?: number;
    /**
     * (Highcharts) The start angle of the pie slices in degrees where 0 is top
     * and 90 right.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.startAngle
     */
    startAngle?: number;
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states
     */
    states?: PlotSunburstStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip. When `stickyTracking` is
     * false and `tooltip.shared` is false, the tooltip will be hidden when
     * moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip
     */
    tooltip?: PlotSunburstTooltipOptions;
    /**
     * (Highstock) The parameter allows setting line series type and use OHLC
     * indicators. Data in OHLC format is required.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.useOhlcData
     */
    useOhlcData?: boolean;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events
 */
export interface PlotSunburstPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the legend item belonging to the pie point
     * (slice) is clicked. The `this` keyword refers to the point itself. One
     * parameter, `event`, is passed to the function, containing common event
     * information. The default action is to toggle the visibility of the point.
     * This can be prevented by calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point
 */
export interface PlotSunburstPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.point.events
     */
    events?: PlotSunburstPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover.animation
 */
export interface PlotSunburstStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.hover.halo
 */
export interface PlotSunburstStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover
 */
export interface PlotSunburstStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSunburstStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) How much to brighten the point on interaction. Requires the
     * main color to be defined in hex or rgb(a) format.
     *
     * In styled mode, the hover brightness is by default replaced by a
     * fill-opacity given in the `.highcharts-point-hover` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.hover.halo
     */
    halo?: PlotSunburstStatesHoverHaloOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.normal
 */
export interface PlotSunburstStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states
 */
export interface PlotSunburstStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.hover
     */
    hover?: PlotSunburstStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.normal
     */
    normal?: PlotSunburstStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.select
     */
    select?: PlotSunburstStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.animation
 */
export interface PlotSunburstStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.halo
 */
export interface PlotSunburstStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker
 */
export interface PlotSunburstStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states
     */
    states?: PlotSunburstStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover.animation
 */
export interface PlotSunburstStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover
 */
export interface PlotSunburstStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSunburstStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.normal
 */
export interface PlotSunburstStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states
 */
export interface PlotSunburstStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.hover
     */
    hover?: PlotSunburstStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.normal
     */
    normal?: PlotSunburstStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.select
     */
    select?: PlotSunburstStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.select
 */
export interface PlotSunburstStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.select
 */
export interface PlotSunburstStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSunburstStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.sunburst.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.halo
     */
    halo?: PlotSunburstStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.states.select.marker
     */
    marker?: PlotSunburstStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.sunburst.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.sunburst.tooltip.dateTimeLabelFormats
 */
export interface PlotSunburstTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip
 */
export interface PlotSunburstTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotSunburstTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.sunburst.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.sunburst.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.sunburst.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.animation
 */
export interface PlotSupertrendAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The styles for the Supertrend line that intersect main series.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.changeTrendLine
 */
export interface PlotSupertrendChangeTrendLineOptions {
    styles?: PlotSupertrendChangeTrendLineStylesOptions;
}
export interface PlotSupertrendChangeTrendLineStylesOptions {
    /**
     * (Highstock) The dash or dot style of the grid lines. For possible values,
     * see this demonstration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.changeTrendLine.styles.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Color of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.changeTrendLine.styles.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Pixel width of the line.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.changeTrendLine.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker
 */
export interface PlotSupertrendConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker
 */
export interface PlotSupertrendConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors
 */
export interface PlotSupertrendConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.endMarker
     */
    endMarker?: PlotSupertrendConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.marker
     */
    marker?: PlotSupertrendConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker
     */
    startMarker?: PlotSupertrendConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker
 */
export interface PlotSupertrendConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataGrouping
 */
export interface PlotSupertrendDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.filter
 */
export interface PlotSupertrendDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels
 */
export interface PlotSupertrendDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.filter
     */
    filter?: PlotSupertrendDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragHandle
 */
export interface PlotSupertrendDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.guideBox.default
 */
export interface PlotSupertrendDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.guideBox
 */
export interface PlotSupertrendDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.guideBox.default
     */
    default?: PlotSupertrendDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop
 */
export interface PlotSupertrendDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragHandle
     */
    dragHandle?: PlotSupertrendDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.guideBox
     */
    guideBox?: (PlotSupertrendDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.events
 */
export interface PlotSupertrendEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.label
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.label
 * @see https://api.highcharts.com/gantt/plotOptions.supertrend.label
 */
export interface PlotSupertrendLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.lastPrice
 */
export interface PlotSupertrendLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotSupertrendLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.lastVisiblePrice
 */
export interface PlotSupertrendLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotSupertrendLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker
 */
export interface PlotSupertrendMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states
     */
    states?: PlotSupertrendMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover.animation
 */
export interface PlotSupertrendMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover
 */
export interface PlotSupertrendMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSupertrendMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.normal
 */
export interface PlotSupertrendMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states
 */
export interface PlotSupertrendMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.hover
     */
    hover?: PlotSupertrendMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.normal
     */
    normal?: PlotSupertrendMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.select
     */
    select?: PlotSupertrendMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.select
 */
export interface PlotSupertrendMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Supertrend indicator. This series requires the `linkedTo` option
 * to be set and should be loaded after the `stock/indicators/indicators.js` and
 * `stock/indicators/sma.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `supertrend` series are defined in plotOptions.supertrend.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend
 */
export interface PlotSupertrendOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSupertrendAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) The styles for the Supertrend line that intersect main
     * series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.changeTrendLine
     */
    changeTrendLine?: PlotSupertrendChangeTrendLineOptions;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.clip
     */
    clip?: boolean;
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.connectors
     */
    connectors?: PlotSupertrendConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataGrouping
     */
    dataGrouping?: PlotSupertrendDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dataLabels
     */
    dataLabels?: PlotSupertrendDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.dragDrop
     */
    dragDrop?: PlotSupertrendDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.events
     */
    events?: PlotSupertrendEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Color of the Supertrend series line that is above the main
     * series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.fallingTrendColor
     */
    fallingTrendColor?: ColorString;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.label
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.label
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.label
     */
    label?: PlotSupertrendLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.lastPrice
     */
    lastPrice?: PlotSupertrendLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.lastVisiblePrice
     */
    lastVisiblePrice?: PlotSupertrendLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.marker
     */
    marker?: PlotSupertrendMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.name
     */
    name?: string;
    /**
     * (Highstock) Paramters used in calculation of Supertrend indicator series
     * points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.params
     */
    params?: PlotSupertrendParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point
     */
    point?: PlotSupertrendPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Color of the Supertrend series line that is beneath the main
     * series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.risingTrendColor
     */
    risingTrendColor?: ColorString;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states
     */
    states?: PlotSupertrendStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.step
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip
     */
    tooltip?: PlotSupertrendTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.zones
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.zones
     */
    zones?: Array<PlotSupertrendZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of Supertrend indicator series
 * points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.params
 */
export interface PlotSupertrendParamsOptions {
    /**
     * (Highstock) Multiplier for Supertrend Indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.params.multiplier
     */
    multiplier?: number;
    /**
     * (Highstock) The base period for indicator Supertrend Indicator
     * calculations. This is the number of data points which are taken into
     * account for the indicator calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events
 */
export interface PlotSupertrendPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point
 */
export interface PlotSupertrendPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.point.events
     */
    events?: PlotSupertrendPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.animation
 */
export interface PlotSupertrendStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.halo
 */
export interface PlotSupertrendStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker
 */
export interface PlotSupertrendStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states
     */
    states?: PlotSupertrendStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover.animation
 */
export interface PlotSupertrendStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover
 */
export interface PlotSupertrendStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSupertrendStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.normal
 */
export interface PlotSupertrendStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states
 */
export interface PlotSupertrendStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.hover
     */
    hover?: PlotSupertrendStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.normal
     */
    normal?: PlotSupertrendStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.select
     */
    select?: PlotSupertrendStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.select
 */
export interface PlotSupertrendStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover
 */
export interface PlotSupertrendStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSupertrendStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.halo
     */
    halo?: PlotSupertrendStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover.marker
     */
    marker?: PlotSupertrendStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.normal
 */
export interface PlotSupertrendStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states
 */
export interface PlotSupertrendStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.hover
     */
    hover?: PlotSupertrendStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.normal
     */
    normal?: PlotSupertrendStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.select
     */
    select?: PlotSupertrendStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.animation
 */
export interface PlotSupertrendStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.halo
 */
export interface PlotSupertrendStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker
 */
export interface PlotSupertrendStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states
     */
    states?: PlotSupertrendStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover.animation
 */
export interface PlotSupertrendStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover
 */
export interface PlotSupertrendStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSupertrendStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.normal
 */
export interface PlotSupertrendStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states
 */
export interface PlotSupertrendStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.hover
     */
    hover?: PlotSupertrendStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.normal
     */
    normal?: PlotSupertrendStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.select
     */
    select?: PlotSupertrendStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.select
 */
export interface PlotSupertrendStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.select
 */
export interface PlotSupertrendStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotSupertrendStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.supertrend.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.halo
     */
    halo?: PlotSupertrendStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.states.select.marker
     */
    marker?: PlotSupertrendStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.supertrend.tooltip.dateTimeLabelFormats
 */
export interface PlotSupertrendTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip
 */
export interface PlotSupertrendTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotSupertrendTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.supertrend.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.zones
 * @see https://api.highcharts.com/highstock/plotOptions.supertrend.zones
 */
export interface PlotSupertrendZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.supertrend.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.supertrend.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.animation
 */
export interface PlotTemaAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker
 */
export interface PlotTemaConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker
 */
export interface PlotTemaConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors
 */
export interface PlotTemaConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.endMarker
     */
    endMarker?: PlotTemaConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.marker
     */
    marker?: PlotTemaConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker
     */
    startMarker?: PlotTemaConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker
 */
export interface PlotTemaConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.dataGrouping
 */
export interface PlotTemaDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.filter
 */
export interface PlotTemaDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels
 */
export interface PlotTemaDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.tema.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.filter
     */
    filter?: PlotTemaDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragHandle
 */
export interface PlotTemaDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.guideBox.default
 */
export interface PlotTemaDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.guideBox
 */
export interface PlotTemaDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.guideBox.default
     */
    default?: PlotTemaDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop
 */
export interface PlotTemaDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragHandle
     */
    dragHandle?: PlotTemaDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.guideBox
     */
    guideBox?: (PlotTemaDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.events
 */
export interface PlotTemaEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.tema.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.tema.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.label
 * @see https://api.highcharts.com/highstock/plotOptions.tema.label
 * @see https://api.highcharts.com/gantt/plotOptions.tema.label
 */
export interface PlotTemaLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.tema.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.tema.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.tema.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.tema.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.tema.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.tema.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tema.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.tema.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.tema.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.tema.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.tema.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.tema.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.tema.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.tema.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.tema.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.tema.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.lastPrice
 */
export interface PlotTemaLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotTemaLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.lastVisiblePrice
 */
export interface PlotTemaLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotTemaLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.marker
 */
export interface PlotTemaMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states
     */
    states?: PlotTemaMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover.animation
 */
export interface PlotTemaMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover
 */
export interface PlotTemaMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTemaMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.normal
 */
export interface PlotTemaMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states
 */
export interface PlotTemaMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.hover
     */
    hover?: PlotTemaMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.normal
     */
    normal?: PlotTemaMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.select
     */
    select?: PlotTemaMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.select
 */
export interface PlotTemaMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Normalized average true range indicator (NATR). This series
 * requires `linkedTo` option to be set and should be loaded after the
 * `stock/indicators/indicators.js` and `stock/indicators/ema.js`.
 *
 * Requires `https://code.highcharts.com/stock/indicators/ema.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `tema` series are defined in plotOptions.tema.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema
 */
export interface PlotTemaOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTemaAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.tema.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tema.connectors
     */
    connectors?: PlotTemaConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.tema.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataGrouping
     */
    dataGrouping?: PlotTemaDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dataLabels
     */
    dataLabels?: PlotTemaDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.dragDrop
     */
    dragDrop?: PlotTemaDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.events
     */
    events?: PlotTemaEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.tema.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.tema.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.label
     * @see https://api.highcharts.com/highstock/plotOptions.tema.label
     * @see https://api.highcharts.com/gantt/plotOptions.tema.label
     */
    label?: PlotTemaLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.lastPrice
     */
    lastPrice?: PlotTemaLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.lastVisiblePrice
     */
    lastVisiblePrice?: PlotTemaLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.tema.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tema.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.tema.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.tema.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.marker
     */
    marker?: PlotTemaMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.params
     */
    params?: PlotTemaParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point
     */
    point?: PlotTemaPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.tema.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states
     */
    states?: PlotTemaStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.step
     * @see https://api.highcharts.com/highstock/plotOptions.tema.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.tema.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip
     */
    tooltip?: PlotTemaTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.tema.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.tema.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.tema.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.zones
     * @see https://api.highcharts.com/highstock/plotOptions.tema.zones
     */
    zones?: Array<PlotTemaZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.params
 */
export interface PlotTemaParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * By default index value used to be set to 0. Since Highstock 7 by default
     * index is set to 3 which means that the ema indicator will be calculated
     * using Close values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events
 */
export interface PlotTemaPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.point
 */
export interface PlotTemaPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.point.events
     */
    events?: PlotTemaPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.animation
 */
export interface PlotTemaStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.halo
 */
export interface PlotTemaStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker
 */
export interface PlotTemaStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states
     */
    states?: PlotTemaStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover.animation
 */
export interface PlotTemaStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover
 */
export interface PlotTemaStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTemaStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.normal
 */
export interface PlotTemaStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states
 */
export interface PlotTemaStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.hover
     */
    hover?: PlotTemaStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.normal
     */
    normal?: PlotTemaStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.select
     */
    select?: PlotTemaStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.select
 */
export interface PlotTemaStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover
 */
export interface PlotTemaStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTemaStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.halo
     */
    halo?: PlotTemaStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover.marker
     */
    marker?: PlotTemaStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.normal
 */
export interface PlotTemaStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states
 */
export interface PlotTemaStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.hover
     */
    hover?: PlotTemaStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.normal
     */
    normal?: PlotTemaStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.select
     */
    select?: PlotTemaStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.animation
 */
export interface PlotTemaStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.halo
 */
export interface PlotTemaStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker
 */
export interface PlotTemaStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states
     */
    states?: PlotTemaStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover.animation
 */
export interface PlotTemaStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover
 */
export interface PlotTemaStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTemaStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.normal
 */
export interface PlotTemaStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states
 */
export interface PlotTemaStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.hover
     */
    hover?: PlotTemaStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.normal
     */
    normal?: PlotTemaStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.select
     */
    select?: PlotTemaStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.select
 */
export interface PlotTemaStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.select
 */
export interface PlotTemaStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTemaStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tema.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.halo
     */
    halo?: PlotTemaStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.tema.states.select.marker
     */
    marker?: PlotTemaStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.tema.tooltip.dateTimeLabelFormats
 */
export interface PlotTemaTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip
 */
export interface PlotTemaTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.tema.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotTemaTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.tema.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.tema.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tema.zones
 * @see https://api.highcharts.com/highstock/plotOptions.tema.zones
 */
export interface PlotTemaZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.tema.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.tema.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.tema.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tema.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tema.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.tema.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highmaps) Animation is disabled by default on the heatmap
 * series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.animation
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.animation
 */
export interface PlotTilemapAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker
 */
export interface PlotTilemapConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker
 */
export interface PlotTilemapConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors
 */
export interface PlotTilemapConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.endMarker
     */
    endMarker?: PlotTilemapConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.marker
     */
    marker?: PlotTilemapConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker
     */
    startMarker?: PlotTilemapConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker
 */
export interface PlotTilemapConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataGrouping
 */
export interface PlotTilemapDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highmaps) A declarative filter for which data labels to display.
 * The declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.filter
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.filter
 */
export interface PlotTilemapDataLabelsFilterOptions {
    /**
     * (Highcharts, Highmaps) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.filter.operator
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highmaps) The point property to filter by. Point options are
     * passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.filter.property
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highmaps) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.filter.value
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highmaps) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels
 */
export interface PlotTilemapDataLabelsOptions {
    /**
     * (Highcharts, Highmaps) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.align
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highmaps) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highmaps) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highmaps) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.borderColor
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highmaps) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.borderRadius
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highmaps) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.borderWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highmaps) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.className
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.color
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highmaps) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.crop
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highmaps) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highmaps) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.filter
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.filter
     */
    filter?: PlotTilemapDataLabelsFilterOptions;
    /**
     * (Highcharts, Highmaps) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.format
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highmaps) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.formatter
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highmaps) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.inside
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highmaps) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.overflow
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highmaps) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.padding
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highmaps) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.rotation
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highmaps) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.shadow
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highmaps) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.shape
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highmaps) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.style
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highmaps) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.useHTML
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highmaps) The vertical alignment of a data label. Can be one
     * of `top`, `middle` or `bottom`. The default value depends on the data,
     * for instance in a column chart, the label is above positive values and
     * below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highmaps) The x position offset of the label relative to the
     * point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.x
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highmaps) The y position offset of the label relative to the
     * point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.y
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highmaps) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highmaps) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragHandle
 */
export interface PlotTilemapDragDropDragHandleOptions {
    /**
     * (Highcharts, Highmaps) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highmaps) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highmaps) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highmaps) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highmaps) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highmaps) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highmaps) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.guideBox.default
 */
export interface PlotTilemapDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highmaps) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highmaps) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highmaps) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highmaps) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highmaps) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highmaps) Style options for the guide box. The guide box has one
 * state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.guideBox
 */
export interface PlotTilemapDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highmaps) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.guideBox.default
     */
    default?: PlotTilemapDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highmaps) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop
 */
export interface PlotTilemapDragDropOptions {
    /**
     * (Highcharts, Highmaps) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highmaps) Enable dragging in the Y dimension. Note that this
     * is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highmaps) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragHandle
     */
    dragHandle?: PlotTilemapDragDropDragHandleOptions;
    /**
     * (Highcharts, Highmaps) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highmaps) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highmaps) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highmaps) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highmaps) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highmaps) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highmaps) The amount of pixels to drag the pointer before it
     * counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highmaps) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highmaps) Style options for the guide box. The guide box has
     * one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.guideBox
     */
    guideBox?: (PlotTilemapDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highmaps) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highmaps) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.events
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.events
 */
export interface PlotTilemapEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highmaps) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.events.checkboxClick
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highmaps) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.events.click
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highmaps) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.events.hide
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the legend item belonging to the series
     * is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.events.legendItemClick
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.events.mouseOut
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.events.mouseOver
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.events.show
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.label
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.label
 * @see https://api.highcharts.com/gantt/plotOptions.tilemap.label
 */
export interface PlotTilemapLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.lastPrice
 */
export interface PlotTilemapLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotTilemapLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.lastVisiblePrice
 */
export interface PlotTilemapLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotTilemapLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highmaps) A tilemap series is a type of heatmap where the tile
 * shapes are configurable.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `tilemap` series are defined in plotOptions.tilemap.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap
 */
export interface PlotTilemapOptions {
    /**
     * (Highcharts, Highmaps) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.allowPointSelect
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highmaps) Animation is disabled by default on the heatmap
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.animation
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.animation
     */
    animation?: (boolean|PlotTilemapAnimationOptions);
    /**
     * (Highcharts, Highmaps) Set the point threshold for when a series should
     * enter boost mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.boostThreshold
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width for each heat map item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highmaps) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.className
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.clip
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In heat maps this color is
     * rarely used, as we mostly use the color to denote the value of each
     * point. Unless options are set in the colorAxis, the default value is
     * pulled from the options.colors array.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highmaps) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.colorIndex
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highmaps) The column size - how many X axis units each
     * column in the tilemap should span. Works as in Heatmaps.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.colsize
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.colsize
     */
    colsize?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.connectors
     */
    connectors?: PlotTilemapConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts, Highmaps) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.cursor
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.dataGrouping
     */
    dataGrouping?: PlotTilemapDataGroupingOptions;
    /**
     * (Highcharts, Highmaps) Options for the series data labels, appearing next
     * to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dataLabels
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dataLabels
     */
    dataLabels?: PlotTilemapDataLabelsOptions;
    /**
     * (Highcharts, Highmaps) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.description
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.description
     */
    description?: string;
    /**
     * (Highcharts, Highmaps) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.dragDrop
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.dragDrop
     */
    dragDrop?: PlotTilemapDragDropOptions;
    /**
     * (Highcharts, Highmaps) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.enableMouseTracking
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highmaps) General event handlers for the series items. These
     * event hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.events
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.events
     */
    events?: PlotTilemapEventsOptions;
    /**
     * (Highcharts, Highmaps) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.exposeElementToA11y
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highmaps) An array specifying which option maps to which key
     * in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.keys
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.label
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.label
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.label
     */
    label?: PlotTilemapLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.lastPrice
     */
    lastPrice?: PlotTilemapLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.lastVisiblePrice
     */
    lastVisiblePrice?: PlotTilemapLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highmaps) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.negativeColor
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highmaps) The color applied to null points. In styled mode,
     * a general CSS class is applied instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.nullColor
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.nullColor
     */
    nullColor?: ColorString;
    /**
     * (Highcharts, Highmaps) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point
     */
    point?: PlotTilemapPointOptions;
    /**
     * (Highcharts, Highmaps) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.pointDescriptionFormatter
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highmaps) The padding between points in the tilemap.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.pointPadding
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highmaps) The row size - how many Y axis units each tilemap
     * row should span. Analogous to colsize.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.rowsize
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.rowsize
     */
    rowsize?: number;
    /**
     * (Highcharts, Highmaps) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.selected
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highmaps) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.showCheckbox
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highmaps) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.showInLegend
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highmaps) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.skipKeyboardNavigation
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highmaps) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states
     */
    states?: PlotTilemapStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highmaps) The shape of the tiles in the tilemap. Possible
     * values are `hexagon`, `circle`, `diamond`, and `square`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tileShape
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.tileShape
     */
    tileShape?: ("circle"|"diamond"|"hexagon"|"square");
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip
     */
    tooltip?: PlotTilemapTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highmaps) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.visible
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.zones
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.zones
     */
    zones?: Array<PlotTilemapZonesOptions>;
}
/**
 * (Highcharts, Highmaps) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events
 */
export interface PlotTilemapPointEventsOptions {
    /**
     * (Highcharts, Highmaps) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events.click
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highmaps) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events.drag
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highmaps) Callback that fires when starting to drag a point.
     * The mouse event object is passed in as an argument. If a drag handle is
     * used, `e.updateProp` is set to the data property being dragged. The
     * `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events.dragStart
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highmaps) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events.drop
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highmaps) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events.mouseOut
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events.mouseOver
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events.remove
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events.select
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events.unselect
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highmaps) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events.update
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highmaps) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point
 */
export interface PlotTilemapPointOptions {
    /**
     * (Highcharts, Highmaps) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.point.events
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.point.events
     */
    events?: PlotTilemapPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.animation
 */
export interface PlotTilemapStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) A collection of SVG attributes to override the
 * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.halo.attributes
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.halo.attributes
 */
export interface PlotTilemapStatesHoverHaloAttributesOptions {
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.halo
 */
export interface PlotTilemapStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.halo.attributes
     */
    attributes?: PlotTilemapStatesHoverHaloAttributesOptions;
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker
 */
export interface PlotTilemapStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states
     */
    states?: PlotTilemapStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover.animation
 */
export interface PlotTilemapStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover
 */
export interface PlotTilemapStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTilemapStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.normal
 */
export interface PlotTilemapStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states
 */
export interface PlotTilemapStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.hover
     */
    hover?: PlotTilemapStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.normal
     */
    normal?: PlotTilemapStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.select
     */
    select?: PlotTilemapStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.select
 */
export interface PlotTilemapStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highmaps) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.hover
 */
export interface PlotTilemapStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTilemapStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) How much to brighten the point on interaction. Requires the
     * main color to be defined in hex or rgb(a) format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highmaps) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.halo
     */
    halo?: PlotTilemapStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.hover.marker
     */
    marker?: PlotTilemapStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.normal
 */
export interface PlotTilemapStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highmaps) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states
 */
export interface PlotTilemapStatesOptions {
    /**
     * (Highcharts, Highmaps) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.hover
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.hover
     */
    hover?: PlotTilemapStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.normal
     */
    normal?: PlotTilemapStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.select
     */
    select?: PlotTilemapStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.animation
 */
export interface PlotTilemapStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.halo
 */
export interface PlotTilemapStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker
 */
export interface PlotTilemapStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states
     */
    states?: PlotTilemapStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover.animation
 */
export interface PlotTilemapStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover
 */
export interface PlotTilemapStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTilemapStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.normal
 */
export interface PlotTilemapStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states
 */
export interface PlotTilemapStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.hover
     */
    hover?: PlotTilemapStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.normal
     */
    normal?: PlotTilemapStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.select
     */
    select?: PlotTilemapStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.select
 */
export interface PlotTilemapStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.select
 */
export interface PlotTilemapStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTilemapStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.tilemap.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.halo
     */
    halo?: PlotTilemapStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.states.select.marker
     */
    marker?: PlotTilemapStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.tilemap.tooltip.dateTimeLabelFormats
 */
export interface PlotTilemapTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip
 */
export interface PlotTilemapTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotTilemapTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.tilemap.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.zones
 * @see https://api.highcharts.com/highstock/plotOptions.tilemap.zones
 */
export interface PlotTilemapZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.tilemap.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.tilemap.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.animation
 */
export interface PlotTreemapAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker
 */
export interface PlotTreemapConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker
 */
export interface PlotTreemapConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors
 */
export interface PlotTreemapConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.endMarker
     */
    endMarker?: PlotTreemapConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.marker
     */
    marker?: PlotTreemapConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker
     */
    startMarker?: PlotTreemapConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker
 */
export interface PlotTreemapConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataGrouping
 */
export interface PlotTreemapDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.filter
 */
export interface PlotTreemapDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels
 */
export interface PlotTreemapDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.filter
     */
    filter?: PlotTreemapDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragHandle
 */
export interface PlotTreemapDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.guideBox.default
 */
export interface PlotTreemapDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.guideBox
 */
export interface PlotTreemapDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.guideBox.default
     */
    default?: PlotTreemapDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop
 */
export interface PlotTreemapDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragHandle
     */
    dragHandle?: PlotTreemapDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.guideBox
     */
    guideBox?: (PlotTreemapDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) Options for the button appearing when drilling down in a
 * treemap.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.drillUpButton
 */
export interface PlotTreemapDrillUpButtonOptions {
    /**
     * (Highcharts) The position of the button.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.drillUpButton.position
     */
    position?: PlotTreemapDrillUpButtonPositionOptions;
}
/**
 * (Highcharts) The position of the button.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.drillUpButton.position
 */
export interface PlotTreemapDrillUpButtonPositionOptions {
    /**
     * (Highcharts) Horizontal alignment of the button.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.drillUpButton.position.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Vertical alignment of the button.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.drillUpButton.position.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) Horizontal offset of the button.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.drillUpButton.position.x
     */
    x?: number;
    /**
     * (Highcharts) Vertical offset of the button.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.drillUpButton.position.y
     */
    y?: number;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.events
 */
export interface PlotTreemapEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.label
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.label
 * @see https://api.highcharts.com/gantt/plotOptions.treemap.label
 */
export interface PlotTreemapLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.lastPrice
 */
export interface PlotTreemapLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotTreemapLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.lastVisiblePrice
 */
export interface PlotTreemapLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotTreemapLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A configuration object to define how the color of a child varies
 * from the parent's color. The variation is distributed among the children of
 * node. For example when setting brightness, the brightness change will range
 * from the parent's original brightness on the first child, to the amount set
 * in the `to` setting on the last node. This allows a gradient-like color
 * scheme that sets children out from each other while highlighting the grouping
 * on treemaps and sectors on sunburst charts.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.colorVariation
 */
export interface PlotTreemapLevelsColorVariationOptions {
    /**
     * (Highcharts) The key of a color variation. Currently supports
     * `brightness` only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.colorVariation.key
     */
    key?: "brightness";
    /**
     * (Highcharts) The ending value of a color variation. The last sibling will
     * receive this value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.colorVariation.to
     */
    to?: number;
}
/**
 * (Highcharts) Set options on specific levels. Takes precedence over series
 * options, but not point options.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels
 */
export interface PlotTreemapLevelsOptions {
    /**
     * (Highcharts) Can set a `borderColor` on all points which lies on the same
     * level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) Set the dash style of the border of all the point which lies
     * on the level. See (see online documentation for example) for possible
     * options.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.borderDashStyle
     */
    borderDashStyle?: string;
    /**
     * (Highcharts) Can set the borderWidth on all points which lies on the same
     * level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) Can set a color on all points which lies on the same level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) A configuration object to define how the color of a child
     * varies from the parent's color. The variation is distributed among the
     * children of node. For example when setting brightness, the brightness
     * change will range from the parent's original brightness on the first
     * child, to the amount set in the `to` setting on the last node. This
     * allows a gradient-like color scheme that sets children out from each
     * other while highlighting the grouping on treemaps and sectors on sunburst
     * charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.colorVariation
     */
    colorVariation?: PlotTreemapLevelsColorVariationOptions;
    /**
     * (Highcharts) Can set the options of dataLabels on each point which lies
     * on the level. plotOptions.treemap.dataLabels for possible values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.dataLabels
     */
    dataLabels?: object;
    /**
     * (Highcharts) Can set the layoutAlgorithm option on a specific level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.layoutAlgorithm
     */
    layoutAlgorithm?: ("squarified"|"strip"|"stripes"|"sliceAndDice");
    /**
     * (Highcharts) Can set the layoutStartingDirection option on a specific
     * level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.layoutStartingDirection
     */
    layoutStartingDirection?: ("horizontal"|"vertical");
    /**
     * (Highcharts) Decides which level takes effect from the options set in the
     * levels object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels.level
     */
    level?: number;
}
/**
 * (Highcharts) A treemap displays hierarchical data using nested rectangles.
 * The data can be laid out in varying ways depending on options.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `treemap` series are defined in plotOptions.treemap.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap
 */
export interface PlotTreemapOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) When enabled the user can click on a point which is a parent
     * and zoom in on its children.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.allowDrillToNode
     */
    allowDrillToNode?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enabling this option will make the treemap alternate the
     * drawing direction between vertical and horizontal. The next levels
     * starting direction will always be the opposite of the previous.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.alternateStartingDirection
     */
    alternateStartingDirection?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTreemapAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The color of the border surrounding each tree map item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The width of the border surrounding each tree map item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) When using automatic point colors pulled from the
     * `options.colors` collection, this option determines whether the chart
     * should receive one color per series or one color per point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts) A series specific or series type specific color set to apply
     * instead of the global colors when colorByPoint is true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.connectors
     */
    connectors?: PlotTreemapConnectorsOptions;
    /**
     * (Highcharts) When the series contains less points than the crop
     * threshold, all points are drawn, event if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.dataGrouping
     */
    dataGrouping?: PlotTreemapDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dataLabels
     */
    dataLabels?: PlotTreemapDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.dragDrop
     */
    dragDrop?: PlotTreemapDragDropOptions;
    /**
     * (Highcharts) Options for the button appearing when drilling down in a
     * treemap.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.drillUpButton
     */
    drillUpButton?: PlotTreemapDrillUpButtonOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.events
     */
    events?: PlotTreemapEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts) Whether to ignore hidden points when the layout algorithm
     * runs. If `false`, hidden points will leave open spaces.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.ignoreHiddenPoint
     */
    ignoreHiddenPoint?: boolean;
    /**
     * (Highcharts) This option decides if the user can interact with the parent
     * nodes or just the leaf nodes. When this option is undefined, it will be
     * true by default. However when allowDrillToNode is true, then it will be
     * false by default.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.interactByLeaf
     */
    interactByLeaf?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.label
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.label
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.label
     */
    label?: PlotTreemapLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.lastPrice
     */
    lastPrice?: PlotTreemapLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.lastVisiblePrice
     */
    lastVisiblePrice?: PlotTreemapLastVisiblePriceOptions;
    /**
     * (Highcharts) This option decides which algorithm is used for setting
     * position and dimensions of the points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.layoutAlgorithm
     */
    layoutAlgorithm?: ("squarified"|"strip"|"stripes"|"sliceAndDice");
    /**
     * (Highcharts) Defines which direction the layout algorithm will start
     * drawing.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.layoutStartingDirection
     */
    layoutStartingDirection?: ("horizontal"|"vertical");
    /**
     * (Highcharts) Used together with the levels and allowDrillToNode options.
     * When set to false the first level visible when drilling is considered to
     * be level one. Otherwise the level will be the same as the tree structure.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levelIsConstant
     */
    levelIsConstant?: boolean;
    /**
     * (Highcharts) Set options on specific levels. Takes precedence over series
     * options, but not point options.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.levels
     */
    levels?: Array<PlotTreemapLevelsOptions>;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) The width of the line connecting the data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The color for the parts of the graph or points that are
     * below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The opacity of a point in treemap. When a point has
     * children, the visibility of the children is determined by the opacity.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.opacity
     */
    opacity?: number;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point
     */
    point?: PlotTreemapPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this series type or specific series item
     * in the legend.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts) The sort index of the point inside the treemap level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.sortIndex
     */
    sortIndex?: number;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states
     */
    states?: PlotTreemapStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.step
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip
     */
    tooltip?: PlotTreemapTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.zones
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.zones
     */
    zones?: Array<PlotTreemapZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events
 */
export interface PlotTreemapPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point
 */
export interface PlotTreemapPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.point.events
     */
    events?: PlotTreemapPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.animation
 */
export interface PlotTreemapStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.halo
 */
export interface PlotTreemapStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker
 */
export interface PlotTreemapStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states
     */
    states?: PlotTreemapStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover.animation
 */
export interface PlotTreemapStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover
 */
export interface PlotTreemapStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTreemapStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.normal
 */
export interface PlotTreemapStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states
 */
export interface PlotTreemapStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.hover
     */
    hover?: PlotTreemapStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.normal
     */
    normal?: PlotTreemapStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.select
     */
    select?: PlotTreemapStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.select
 */
export interface PlotTreemapStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) Options for the hovered series
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover
 */
export interface PlotTreemapStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTreemapStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color for the hovered state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.hover.borderColor
     */
    borderColor?: string;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) Brightness for the hovered point. Defaults to 0 if the heatmap
     * series is loaded first, otherwise 0.1.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.halo
     */
    halo?: (boolean|PlotTreemapStatesHoverHaloOptions);
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.hover.marker
     */
    marker?: PlotTreemapStatesHoverMarkerOptions;
    /**
     * (Highcharts) The opacity of a point in treemap. When a point has
     * children, the visibility of the children is determined by the opacity.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.opacity
     */
    opacity?: number;
    /**
     * (Highcharts) The shadow option for hovered state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover.shadow
     */
    shadow?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.normal
 */
export interface PlotTreemapStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states
 */
export interface PlotTreemapStatesOptions {
    /**
     * (Highcharts) Options for the hovered series
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.hover
     */
    hover?: PlotTreemapStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.normal
     */
    normal?: PlotTreemapStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.select
     */
    select?: PlotTreemapStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.animation
 */
export interface PlotTreemapStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.halo
 */
export interface PlotTreemapStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker
 */
export interface PlotTreemapStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states
     */
    states?: PlotTreemapStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover.animation
 */
export interface PlotTreemapStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover
 */
export interface PlotTreemapStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTreemapStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.normal
 */
export interface PlotTreemapStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states
 */
export interface PlotTreemapStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.hover
     */
    hover?: PlotTreemapStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.normal
     */
    normal?: PlotTreemapStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.select
     */
    select?: PlotTreemapStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.select
 */
export interface PlotTreemapStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.select
 */
export interface PlotTreemapStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTreemapStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.treemap.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.halo
     */
    halo?: PlotTreemapStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.states.select.marker
     */
    marker?: PlotTreemapStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.treemap.tooltip.dateTimeLabelFormats
 */
export interface PlotTreemapTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip
 */
export interface PlotTreemapTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotTreemapTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.treemap.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.treemap.zones
 * @see https://api.highcharts.com/highstock/plotOptions.treemap.zones
 */
export interface PlotTreemapZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.treemap.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.treemap.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.animation
 */
export interface PlotTrixAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker
 */
export interface PlotTrixConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker
 */
export interface PlotTrixConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors
 */
export interface PlotTrixConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.endMarker
     */
    endMarker?: PlotTrixConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.marker
     */
    marker?: PlotTrixConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker
     */
    startMarker?: PlotTrixConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker
 */
export interface PlotTrixConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.dataGrouping
 */
export interface PlotTrixDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.filter
 */
export interface PlotTrixDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels
 */
export interface PlotTrixDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.trix.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.filter
     */
    filter?: PlotTrixDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragHandle
 */
export interface PlotTrixDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.guideBox.default
 */
export interface PlotTrixDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.guideBox
 */
export interface PlotTrixDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.guideBox.default
     */
    default?: PlotTrixDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop
 */
export interface PlotTrixDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragHandle
     */
    dragHandle?: PlotTrixDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.guideBox
     */
    guideBox?: (PlotTrixDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.events
 */
export interface PlotTrixEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.trix.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.trix.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.label
 * @see https://api.highcharts.com/highstock/plotOptions.trix.label
 * @see https://api.highcharts.com/gantt/plotOptions.trix.label
 */
export interface PlotTrixLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.trix.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.trix.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.trix.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.trix.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.trix.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.trix.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.trix.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.trix.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.trix.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.trix.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.trix.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.trix.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.trix.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.trix.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.trix.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.trix.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.lastPrice
 */
export interface PlotTrixLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotTrixLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.lastVisiblePrice
 */
export interface PlotTrixLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotTrixLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.marker
 */
export interface PlotTrixMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states
     */
    states?: PlotTrixMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover.animation
 */
export interface PlotTrixMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover
 */
export interface PlotTrixMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTrixMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.normal
 */
export interface PlotTrixMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states
 */
export interface PlotTrixMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.hover
     */
    hover?: PlotTrixMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.normal
     */
    normal?: PlotTrixMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.select
     */
    select?: PlotTrixMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.select
 */
export interface PlotTrixMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Normalized average true range indicator (NATR). This series
 * requires `linkedTo` option to be set.
 *
 * Requires https://code.highcharts.com/stock/indicators/ema.js and
 * https://code.highcharts.com/stock/indicators/tema.js.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `trix` series are defined in plotOptions.trix.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix
 */
export interface PlotTrixOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTrixAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.trix.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.trix.connectors
     */
    connectors?: PlotTrixConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.trix.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataGrouping
     */
    dataGrouping?: PlotTrixDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dataLabels
     */
    dataLabels?: PlotTrixDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.dragDrop
     */
    dragDrop?: PlotTrixDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.events
     */
    events?: PlotTrixEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.trix.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.trix.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.label
     * @see https://api.highcharts.com/highstock/plotOptions.trix.label
     * @see https://api.highcharts.com/gantt/plotOptions.trix.label
     */
    label?: PlotTrixLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.lastPrice
     */
    lastPrice?: PlotTrixLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.lastVisiblePrice
     */
    lastVisiblePrice?: PlotTrixLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.trix.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.trix.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.trix.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.trix.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.marker
     */
    marker?: PlotTrixMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.params
     */
    params?: PlotTrixParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point
     */
    point?: PlotTrixPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.trix.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states
     */
    states?: PlotTrixStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.step
     * @see https://api.highcharts.com/highstock/plotOptions.trix.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.trix.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip
     */
    tooltip?: PlotTrixTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.trix.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.trix.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.trix.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.zones
     * @see https://api.highcharts.com/highstock/plotOptions.trix.zones
     */
    zones?: Array<PlotTrixZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.params
 */
export interface PlotTrixParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * By default index value used to be set to 0. Since Highstock 7 by default
     * index is set to 3 which means that the ema indicator will be calculated
     * using Close values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events
 */
export interface PlotTrixPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.point
 */
export interface PlotTrixPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.point.events
     */
    events?: PlotTrixPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.animation
 */
export interface PlotTrixStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.halo
 */
export interface PlotTrixStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker
 */
export interface PlotTrixStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states
     */
    states?: PlotTrixStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover.animation
 */
export interface PlotTrixStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover
 */
export interface PlotTrixStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTrixStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.normal
 */
export interface PlotTrixStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states
 */
export interface PlotTrixStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.hover
     */
    hover?: PlotTrixStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.normal
     */
    normal?: PlotTrixStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.select
     */
    select?: PlotTrixStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.select
 */
export interface PlotTrixStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover
 */
export interface PlotTrixStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTrixStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.halo
     */
    halo?: PlotTrixStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover.marker
     */
    marker?: PlotTrixStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.normal
 */
export interface PlotTrixStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states
 */
export interface PlotTrixStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.hover
     */
    hover?: PlotTrixStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.normal
     */
    normal?: PlotTrixStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.select
     */
    select?: PlotTrixStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.animation
 */
export interface PlotTrixStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.halo
 */
export interface PlotTrixStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker
 */
export interface PlotTrixStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states
     */
    states?: PlotTrixStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover.animation
 */
export interface PlotTrixStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover
 */
export interface PlotTrixStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTrixStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.normal
 */
export interface PlotTrixStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states
 */
export interface PlotTrixStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.hover
     */
    hover?: PlotTrixStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.normal
     */
    normal?: PlotTrixStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.select
     */
    select?: PlotTrixStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.select
 */
export interface PlotTrixStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.select
 */
export interface PlotTrixStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotTrixStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.trix.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.halo
     */
    halo?: PlotTrixStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.trix.states.select.marker
     */
    marker?: PlotTrixStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.trix.tooltip.dateTimeLabelFormats
 */
export interface PlotTrixTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip
 */
export interface PlotTrixTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.trix.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotTrixTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.trix.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.trix.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.trix.zones
 * @see https://api.highcharts.com/highstock/plotOptions.trix.zones
 */
export interface PlotTrixZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.trix.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.trix.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.trix.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.trix.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.trix.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.trix.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.animation
 */
export interface PlotVariablepieAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker
 */
export interface PlotVariablepieConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker
 */
export interface PlotVariablepieConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors
 */
export interface PlotVariablepieConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.endMarker
     */
    endMarker?: PlotVariablepieConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.marker
     */
    marker?: PlotVariablepieConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker
     */
    startMarker?: PlotVariablepieConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker
 */
export interface PlotVariablepieConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataGrouping
 */
export interface PlotVariablepieDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.filter
 */
export interface PlotVariablepieDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels
 */
export interface PlotVariablepieDataLabelsOptions {
    /**
     * (Highcharts) Alignment method for data labels. Possible values are:
     * `'toPlotEdges'` (each label touches the nearest vertical edge of the plot
     * area) or `'connectors'` (connectors have the same x position and the
     * widest label of each half (left & right) touches the nearest vertical
     * edge of the plot area).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.alignTo
     */
    alignTo?: string;
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The color of the line connecting the data label to the pie
     * slice. The default color is the same as the point's color.
     *
     * In styled mode, the connector stroke is given in the
     * `.highcharts-data-label-connector` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.connectorColor
     */
    connectorColor?: ColorString;
    /**
     * (Highcharts) The distance from the data label to the connector. Note that
     * data labels also have a default `padding`, so in order for the connector
     * to touch the text, the `padding` must also be 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.connectorPadding
     */
    connectorPadding?: number;
    /**
     * (Highcharts) Specifies the method that is used to generate the connector
     * path. Highcharts provides 3 built-in connector shapes: `'fixedOffset'`
     * (default), `'straight'` and `'crookedLine'`. Using `'crookedLine'` has
     * the most sense (in most of the cases) when `'alignTo'` is set.
     *
     * Users can provide their own method by passing a function instead of a
     * String. 3 arguments are passed to the callback:
     *
     * (see online documentation for example)
     *
     * The function has to return an SVG path definition in array form (see the
     * example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.connectorShape
     */
    connectorShape?: (() => void|string);
    /**
     * (Highcharts) The width of the line connecting the data label to the pie
     * slice.
     *
     * In styled mode, the connector stroke width is given in the
     * `.highcharts-data-label-connector` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.connectorWidth
     */
    connectorWidth?: number;
    /**
     * (Highcharts) Works only if `connectorShape` is `'crookedLine'`. It
     * defines how far from the vertical plot edge the coonnector path should be
     * crooked.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.crookDistance
     */
    crookDistance?: string;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) The distance of the data label from the pie's edge. Negative
     * numbers put the data label on top of the pie slices. Connectors are only
     * shown for data labels outside the pie.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.distance
     */
    distance?: number;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.filter
     */
    filter?: PlotVariablepieDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Whether to render the connector as a soft arc or a line with
     * sharp break. Works only if `connectorShape` equals to `fixedOffset`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.softConnector
     */
    softConnector?: number;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragHandle
 */
export interface PlotVariablepieDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.guideBox.default
 */
export interface PlotVariablepieDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.guideBox
 */
export interface PlotVariablepieDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.guideBox.default
     */
    default?: PlotVariablepieDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop
 */
export interface PlotVariablepieDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragHandle
     */
    dragHandle?: PlotVariablepieDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.guideBox
     */
    guideBox?: (PlotVariablepieDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.events
 */
export interface PlotVariablepieEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the point name in the legend
     * is clicked. One parameter, event, is passed to the function. The state of
     * the checkbox is found by event.checked. The checked item is found by
     * event.item. Return false to prevent the default action which is to toggle
     * the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.events.checkboxClick
     */
    checkboxClick?: () => void;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.label
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.label
 * @see https://api.highcharts.com/gantt/plotOptions.variablepie.label
 */
export interface PlotVariablepieLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.lastPrice
 */
export interface PlotVariablepieLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotVariablepieLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.lastVisiblePrice
 */
export interface PlotVariablepieLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotVariablepieLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A variable pie series is a two dimensional series type, where
 * each point renders an Y and Z value. Each point is drawn as a pie slice where
 * the size (arc) of the slice relates to the Y value and the radius of pie
 * slice relates to the Z value. Requires `highcharts-more.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `variablepie` series are defined in
 * plotOptions.variablepie.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie
 */
export interface PlotVariablepieOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVariablepieAnimationOptions);
    /**
     * (Highcharts) The color of the border surrounding each slice. When `null`,
     * the border takes the same color as the slice fill. This can be used
     * together with a `borderWidth` to fill drawing gaps created by
     * antialiazing artefacts in borderless pies.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The width of the border surrounding each slice.
     *
     * When setting the border width to 0, there may be small gaps between the
     * slices due to SVG antialiasing artefacts. To work around this, keep the
     * border width at 0.5 or 1, but set the `borderColor` to `null` instead.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) The center of the pie chart relative to the plot area. Can
     * be percentages or pixel values. The default behaviour (as of 3.0) is to
     * center the pie so that all slices and data labels are within the plot
     * area. As a consequence, the pie may actually jump around in a chart with
     * dynamic values, as the data labels move. In that case, the center should
     * be explicitly set, for example to `["50%", "50%"]`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.center
     */
    center?: Array<(number|string|null)>;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts) A series specific or series type specific color set to use
     * instead of the global colors.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.connectors
     */
    connectors?: PlotVariablepieConnectorsOptions;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.dataGrouping
     */
    dataGrouping?: PlotVariablepieDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dataLabels
     */
    dataLabels?: PlotVariablepieDataLabelsOptions;
    /**
     * (Highcharts) The thickness of a 3D pie. Requires `highcharts-3d.js`
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.depth
     */
    depth?: number;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.dragDrop
     */
    dragDrop?: PlotVariablepieDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) The end angle of the pie in degrees where 0 is top and 90 is
     * right. Defaults to `startAngle` plus 360.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.endAngle
     */
    endAngle?: number;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.events
     */
    events?: PlotVariablepieEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts) Equivalent to chart.ignoreHiddenSeries, this option tells
     * whether the series shall be redrawn as if the hidden point were `null`.
     *
     * The default value changed from `false` to `true` with Highcharts 3.0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.ignoreHiddenPoint
     */
    ignoreHiddenPoint?: boolean;
    /**
     * (Highcharts) The size of the inner diameter for the pie. A size greater
     * than 0 renders a donut chart. Can be a percentage or pixel value.
     * Percentages are relative to the pie size. Pixel values are given as
     * integers.
     *
     * Note: in Highcharts < 4.1.2, the percentage was relative to the plot
     * area, not the pie size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.innerSize
     */
    innerSize?: (number|string);
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.label
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.label
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.label
     */
    label?: PlotVariablepieLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.lastPrice
     */
    lastPrice?: PlotVariablepieLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.lastVisiblePrice
     */
    lastVisiblePrice?: PlotVariablepieLastVisiblePriceOptions;
    legendType?: string;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) The maximum size of the points' radius related to chart's
     * `plotArea`. If a number is set, it applies in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.maxPointSize
     */
    maxPointSize?: (number|string);
    /**
     * (Highcharts) The minimum size of the points' radius related to chart's
     * `plotArea`. If a number is set, it applies in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.minPointSize
     */
    minPointSize?: (number|string);
    /**
     * (Highcharts) The minimum size for a pie in response to auto margins. The
     * pie will try to shrink to make room for data labels in side the plot
     * area, but only to this size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.minSize
     */
    minSize?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point
     */
    point?: PlotVariablepiePointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. Since 2.1, pies are not shown in the legend by default.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) The diameter of the pie relative to the plot area. Can be a
     * percentage or pixel value. Pixel values are given as integers. The
     * default behaviour (as of 3.0) is to scale to the plot area and give room
     * for data labels within the plot area. slicedOffset is also included in
     * the default size calculation. As a consequence, the size of the pie may
     * vary when points are updated and data labels more around. In that case it
     * is best to set a fixed value, for example `"75%"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.size
     */
    size?: (number|string|null);
    /**
     * (Highcharts) Whether the pie slice's value should be represented by the
     * area or the radius of the slice. Can be either `area` or `radius`. The
     * default, `area`, corresponds best to the human perception of the size of
     * each pie slice.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.sizeBy
     */
    sizeBy?: ("area"|"radius");
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) If a point is sliced, moved out from the center, how many
     * pixels should it be moved?.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.slicedOffset
     */
    slicedOffset?: number;
    /**
     * (Highcharts) The start angle of the pie slices in degrees where 0 is top
     * and 90 right.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.startAngle
     */
    startAngle?: number;
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states
     */
    states?: PlotVariablepieStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip. When `stickyTracking` is
     * false and `tooltip.shared` is false, the tooltip will be hidden when
     * moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip
     */
    tooltip?: PlotVariablepieTooltipOptions;
    /**
     * (Highstock) The parameter allows setting line series type and use OHLC
     * indicators. Data in OHLC format is required.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.useOhlcData
     */
    useOhlcData?: boolean;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts) The maximum possible z value for the point's radius
     * calculation. If the point's Z value is bigger than zMax, the slice will
     * be drawn according to the zMax value
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.zMax
     */
    zMax?: number;
    /**
     * (Highcharts) The minimum possible z value for the point's radius
     * calculation. If the point's Z value is smaller than zMin, the slice will
     * be drawn according to the zMin value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.zMin
     */
    zMin?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events
 */
export interface PlotVariablepiePointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the legend item belonging to the pie point
     * (slice) is clicked. The `this` keyword refers to the point itself. One
     * parameter, `event`, is passed to the function, containing common event
     * information. The default action is to toggle the visibility of the point.
     * This can be prevented by calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point
 */
export interface PlotVariablepiePointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.point.events
     */
    events?: PlotVariablepiePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover.animation
 */
export interface PlotVariablepieStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.hover.halo
 */
export interface PlotVariablepieStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover
 */
export interface PlotVariablepieStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVariablepieStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) How much to brighten the point on interaction. Requires the
     * main color to be defined in hex or rgb(a) format.
     *
     * In styled mode, the hover brightness is by default replaced by a
     * fill-opacity given in the `.highcharts-point-hover` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.hover.halo
     */
    halo?: PlotVariablepieStatesHoverHaloOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.normal
 */
export interface PlotVariablepieStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states
 */
export interface PlotVariablepieStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.hover
     */
    hover?: PlotVariablepieStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.normal
     */
    normal?: PlotVariablepieStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.select
     */
    select?: PlotVariablepieStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.animation
 */
export interface PlotVariablepieStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.halo
 */
export interface PlotVariablepieStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker
 */
export interface PlotVariablepieStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states
     */
    states?: PlotVariablepieStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover.animation
 */
export interface PlotVariablepieStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover
 */
export interface PlotVariablepieStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVariablepieStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.normal
 */
export interface PlotVariablepieStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states
 */
export interface PlotVariablepieStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.hover
     */
    hover?: PlotVariablepieStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.normal
     */
    normal?: PlotVariablepieStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.select
     */
    select?: PlotVariablepieStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.select
 */
export interface PlotVariablepieStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.select
 */
export interface PlotVariablepieStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVariablepieStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variablepie.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.halo
     */
    halo?: PlotVariablepieStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.states.select.marker
     */
    marker?: PlotVariablepieStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.variablepie.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.variablepie.tooltip.dateTimeLabelFormats
 */
export interface PlotVariablepieTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip
 */
export interface PlotVariablepieTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotVariablepieTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variablepie.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.variablepie.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.variablepie.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.animation
 */
export interface PlotVariwideAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker
 */
export interface PlotVariwideConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker
 */
export interface PlotVariwideConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors
 */
export interface PlotVariwideConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.endMarker
     */
    endMarker?: PlotVariwideConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.marker
     */
    marker?: PlotVariwideConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker
     */
    startMarker?: PlotVariwideConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker
 */
export interface PlotVariwideConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataGrouping
 */
export interface PlotVariwideDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.filter
 */
export interface PlotVariwideDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels
 */
export interface PlotVariwideDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.filter
     */
    filter?: PlotVariwideDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragHandle
 */
export interface PlotVariwideDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.guideBox.default
 */
export interface PlotVariwideDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.guideBox
 */
export interface PlotVariwideDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.guideBox.default
     */
    default?: PlotVariwideDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop
 */
export interface PlotVariwideDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragHandle
     */
    dragHandle?: PlotVariwideDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.guideBox
     */
    guideBox?: (PlotVariwideDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.events
 */
export interface PlotVariwideEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.label
 * @see https://api.highcharts.com/highstock/plotOptions.variwide.label
 * @see https://api.highcharts.com/gantt/plotOptions.variwide.label
 */
export interface PlotVariwideLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.variwide.lastPrice
 */
export interface PlotVariwideLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotVariwideLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.variwide.lastVisiblePrice
 */
export interface PlotVariwideLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotVariwideLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A variwide chart (related to marimekko chart) is a column chart
 * with a variable width expressing a third dimension.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `variwide` series are defined in plotOptions.variwide.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide
 */
export interface PlotVariwideOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variwide.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVariwideAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variwide.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.colors
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.colors
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.connectors
     */
    connectors?: PlotVariwideConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.dataGrouping
     */
    dataGrouping?: PlotVariwideDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dataLabels
     */
    dataLabels?: PlotVariwideDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.dragDrop
     */
    dragDrop?: PlotVariwideDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.events
     */
    events?: PlotVariwideEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) In a variwide chart, the group padding is
     * 0 in order to express the horizontal stacking of items.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variwide.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.label
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.label
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.label
     */
    label?: PlotVariwideLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.lastPrice
     */
    lastPrice?: PlotVariwideLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.lastVisiblePrice
     */
    lastVisiblePrice?: PlotVariwideLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The color for the parts of the graph or points that are
     * below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point
     */
    point?: PlotVariwidePointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) In a variwide chart, the point padding is
     * 0 in order to express the horizontal stacking of items.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states
     */
    states?: PlotVariwideStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.threshold
     */
    threshold?: number;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip
     */
    tooltip?: PlotVariwideTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variwide.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.zones
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.zones
     */
    zones?: Array<PlotVariwideZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events
 */
export interface PlotVariwidePointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point
 */
export interface PlotVariwidePointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.point.events
     */
    events?: PlotVariwidePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.hover.animation
 */
export interface PlotVariwideStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.variwide.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.hover
 */
export interface PlotVariwideStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVariwideStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variwide.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.variwide.states.normal
 */
export interface PlotVariwideStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variwide.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states
 */
export interface PlotVariwideStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.hover
     */
    hover?: PlotVariwideStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variwide.states.normal
     */
    normal?: PlotVariwideStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.select
     */
    select?: PlotVariwideStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.select.animation
 */
export interface PlotVariwideStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.variwide.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.select
 */
export interface PlotVariwideStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVariwideStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.variwide.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.variwide.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.variwide.tooltip.dateTimeLabelFormats
 */
export interface PlotVariwideTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip
 */
export interface PlotVariwideTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotVariwideTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.variwide.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.variwide.zones
 * @see https://api.highcharts.com/highstock/plotOptions.variwide.zones
 */
export interface PlotVariwideZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.variwide.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.variwide.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.animation
 */
export interface PlotVbpAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker
 */
export interface PlotVbpConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker
 */
export interface PlotVbpConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors
 */
export interface PlotVbpConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.endMarker
     */
    endMarker?: PlotVbpConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.marker
     */
    marker?: PlotVbpConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker
     */
    startMarker?: PlotVbpConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker
 */
export interface PlotVbpConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataGrouping
 */
export interface PlotVbpDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.filter
 */
export interface PlotVbpDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels
 */
export interface PlotVbpDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.filter
     */
    filter?: PlotVbpDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.style
     */
    style?: PlotVbpDataLabelsStyleOptions;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Styles for the label. The default `color` setting is
 * `"contrast"`, which is a pseudo color that Highcharts picks up and applies
 * the maximum contrast to the underlying point item, for example the bar in a
 * bar chart.
 *
 * The `textOutline` is a pseudo property that applies an outline of the given
 * width with the given color, which by default is the maximum contrast to the
 * text. So a bright text color will result in a black text outline for maximum
 * readability on a mixed background. In some cases, especially with grayscale
 * text, the text outline doesn't work well, in which cases it can be disabled
 * by setting it to `"none"`. When `useHTML` is true, the `textOutline` will not
 * be picked up. In this, case, the same effect can be acheived through the
 * `text-shadow` CSS property.
 *
 * For some series types, where each point has an extent, like for example tree
 * maps, the data label may overflow the point. There are two strategies for
 * handling overflow. By default, the text will wrap to multiple lines. The
 * other strategy is to set `style.textOverflow` to `ellipsis`, which will keep
 * the text on one line plus it will break inside long words.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels.style
 */
export interface PlotVbpDataLabelsStyleOptions {
    fontSize?: string;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragHandle
 */
export interface PlotVbpDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.guideBox.default
 */
export interface PlotVbpDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.guideBox
 */
export interface PlotVbpDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.guideBox.default
     */
    default?: PlotVbpDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop
 */
export interface PlotVbpDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragHandle
     */
    dragHandle?: PlotVbpDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.guideBox
     */
    guideBox?: (PlotVbpDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.events
 */
export interface PlotVbpEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.label
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.label
 * @see https://api.highcharts.com/gantt/plotOptions.vbp.label
 */
export interface PlotVbpLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.lastPrice
 */
export interface PlotVbpLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotVbpLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.lastVisiblePrice
 */
export interface PlotVbpLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotVbpLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker
 */
export interface PlotVbpMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states
     */
    states?: PlotVbpMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover.animation
 */
export interface PlotVbpMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover
 */
export interface PlotVbpMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVbpMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.normal
 */
export interface PlotVbpMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states
 */
export interface PlotVbpMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.hover
     */
    hover?: PlotVbpMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.normal
     */
    normal?: PlotVbpMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.select
     */
    select?: PlotVbpMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.select
 */
export interface PlotVbpMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Volume By Price indicator.
 *
 * This series requires `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `vbp` series are defined in plotOptions.vbp.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp
 */
export interface PlotVbpOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVbpAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.connectors
     */
    connectors?: PlotVbpConnectorsOptions;
    crisp?: boolean;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataGrouping
     */
    dataGrouping?: PlotVbpDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dataLabels
     */
    dataLabels?: PlotVbpDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.dragDrop
     */
    dragDrop?: PlotVbpDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.events
     */
    events?: PlotVbpEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.label
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.label
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.label
     */
    label?: PlotVbpLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.lastPrice
     */
    lastPrice?: PlotVbpLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.lastVisiblePrice
     */
    lastVisiblePrice?: PlotVbpLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.marker
     */
    marker?: PlotVbpMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.params
     */
    params?: PlotVbpParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point
     */
    point?: PlotVbpPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    pointPadding?: number;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states
     */
    states?: PlotVbpStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.step
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip
     */
    tooltip?: PlotVbpTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.visible
     */
    visible?: boolean;
    /**
     * (Highstock) The styles for bars when volume is divided into
     * positive/negative.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.volumeDivision
     */
    volumeDivision?: PlotVbpVolumeDivisionOptions;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highstock) The styles for lines which determine price zones.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zoneLines
     */
    zoneLines?: PlotVbpZoneLinesOptions;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.zones
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zones
     */
    zones?: Array<PlotVbpZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.params
 */
export interface PlotVbpParamsOptions {
    /**
     * (Highstock) The number of price zones.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.params.ranges
     */
    ranges?: number;
    /**
     * (Highstock) The id of volume series which is mandatory. For example using
     * OHLC data, volumeSeriesID='volume' means the indicator will be calculated
     * using OHLC and volume values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.params.volumeSeriesID
     */
    volumeSeriesID?: string;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events
 */
export interface PlotVbpPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.point
 */
export interface PlotVbpPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.point.events
     */
    events?: PlotVbpPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.animation
 */
export interface PlotVbpStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.halo
 */
export interface PlotVbpStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker
 */
export interface PlotVbpStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states
     */
    states?: PlotVbpStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover.animation
 */
export interface PlotVbpStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover
 */
export interface PlotVbpStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVbpStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.normal
 */
export interface PlotVbpStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states
 */
export interface PlotVbpStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.hover
     */
    hover?: PlotVbpStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.normal
     */
    normal?: PlotVbpStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.select
     */
    select?: PlotVbpStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.select
 */
export interface PlotVbpStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover
 */
export interface PlotVbpStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVbpStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.halo
     */
    halo?: PlotVbpStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover.marker
     */
    marker?: PlotVbpStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.normal
 */
export interface PlotVbpStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states
 */
export interface PlotVbpStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.hover
     */
    hover?: PlotVbpStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.normal
     */
    normal?: PlotVbpStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.select
     */
    select?: PlotVbpStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.animation
 */
export interface PlotVbpStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.halo
 */
export interface PlotVbpStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker
 */
export interface PlotVbpStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states
     */
    states?: PlotVbpStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover.animation
 */
export interface PlotVbpStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover
 */
export interface PlotVbpStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVbpStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.normal
 */
export interface PlotVbpStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states
 */
export interface PlotVbpStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.hover
     */
    hover?: PlotVbpStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.normal
     */
    normal?: PlotVbpStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.select
     */
    select?: PlotVbpStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.select
 */
export interface PlotVbpStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.select
 */
export interface PlotVbpStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVbpStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vbp.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.halo
     */
    halo?: PlotVbpStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.states.select.marker
     */
    marker?: PlotVbpStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.vbp.tooltip.dateTimeLabelFormats
 */
export interface PlotVbpTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip
 */
export interface PlotVbpTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotVbpTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.vbp.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highstock) The styles for bars when volume is divided into
 * positive/negative.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.volumeDivision
 */
export interface PlotVbpVolumeDivisionOptions {
    /**
     * (Highstock) Option to control if volume is divided.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.volumeDivision.enabled
     */
    enabled?: boolean;
    styles?: PlotVbpVolumeDivisionStylesOptions;
}
export interface PlotVbpVolumeDivisionStylesOptions {
    /**
     * (Highstock) Color of negative volume bars.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.volumeDivision.styles.negativeColor
     */
    negativeColor?: ColorString;
    /**
     * (Highstock) Color of positive volume bars.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.volumeDivision.styles.positiveColor
     */
    positiveColor?: ColorString;
}
/**
 * (Highstock) The styles for lines which determine price zones.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.zoneLines
 */
export interface PlotVbpZoneLinesOptions {
    /**
     * (Highstock) Enable/disable zone lines.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zoneLines.enabled
     */
    enabled?: boolean;
    styles?: PlotVbpZoneLinesStylesOptions;
}
export interface PlotVbpZoneLinesStylesOptions {
    /**
     * (Highstock) Color of zone lines.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zoneLines.styles.color
     */
    color?: ColorString;
    /**
     * (Highstock) The dash style of zone lines.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zoneLines.styles.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highstock) Pixel width of zone lines.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zoneLines.styles.lineWidth
     */
    lineWidth?: number;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vbp.zones
 * @see https://api.highcharts.com/highstock/plotOptions.vbp.zones
 */
export interface PlotVbpZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vbp.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.vbp.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.animation
 * @see https://api.highcharts.com/highstock/plotOptions.vector.animation
 */
export interface PlotVectorAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker
 */
export interface PlotVectorConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker
 */
export interface PlotVectorConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors
 */
export interface PlotVectorConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.endMarker
     */
    endMarker?: PlotVectorConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.marker
     */
    marker?: PlotVectorConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker
     */
    startMarker?: PlotVectorConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker
 */
export interface PlotVectorConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.filter
 */
export interface PlotVectorDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels
 */
export interface PlotVectorDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.vector.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.filter
     */
    filter?: PlotVectorDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragHandle
 */
export interface PlotVectorDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.guideBox.default
 */
export interface PlotVectorDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.guideBox
 */
export interface PlotVectorDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.guideBox.default
     */
    default?: PlotVectorDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop
 */
export interface PlotVectorDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragHandle
     */
    dragHandle?: PlotVectorDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.guideBox
     */
    guideBox?: (PlotVectorDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.events
 * @see https://api.highcharts.com/highstock/plotOptions.vector.events
 */
export interface PlotVectorEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.vector.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.vector.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.vector.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.vector.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.vector.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.vector.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.vector.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.vector.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.vector.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.label
 * @see https://api.highcharts.com/highstock/plotOptions.vector.label
 * @see https://api.highcharts.com/gantt/plotOptions.vector.label
 */
export interface PlotVectorLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.vector.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.vector.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.vector.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.vector.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.vector.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.vector.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vector.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.vector.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.vector.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.vector.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.vector.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.vector.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.vector.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.vector.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.vector.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.vector.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vector.lastPrice
 */
export interface PlotVectorLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotVectorLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vector.lastVisiblePrice
 */
export interface PlotVectorLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotVectorLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) A vector plot is a type of cartesian chart where each
 * point has an X and Y position, a length and a direction. Vectors are drawn as
 * arrows.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `vector` series are defined in plotOptions.vector.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector
 * @see https://api.highcharts.com/highstock/plotOptions.vector
 */
export interface PlotVectorOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.vector.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vector.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVectorAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.vector.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.className
     * @see https://api.highcharts.com/highstock/plotOptions.vector.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.clip
     * @see https://api.highcharts.com/highstock/plotOptions.vector.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.color
     * @see https://api.highcharts.com/highstock/plotOptions.vector.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.vector.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vector.connectors
     */
    connectors?: PlotVectorConnectorsOptions;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dataLabels
     */
    dataLabels?: PlotVectorDataLabelsOptions;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.description
     * @see https://api.highcharts.com/highstock/plotOptions.vector.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.vector.dragDrop
     */
    dragDrop?: PlotVectorDragDropOptions;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.vector.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.events
     * @see https://api.highcharts.com/highstock/plotOptions.vector.events
     */
    events?: PlotVectorEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.vector.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.vector.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.vector.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.vector.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.keys
     * @see https://api.highcharts.com/highstock/plotOptions.vector.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.label
     * @see https://api.highcharts.com/highstock/plotOptions.vector.label
     * @see https://api.highcharts.com/gantt/plotOptions.vector.label
     */
    label?: PlotVectorLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.lastPrice
     */
    lastPrice?: PlotVectorLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.lastVisiblePrice
     */
    lastVisiblePrice?: PlotVectorLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The line width for each vector arrow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.vector.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.vector.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point
     */
    point?: PlotVectorPointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.vector.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.vector.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.vector.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.vector.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.vector.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.vector.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.vector.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock) What part of the vector it should be rotated
     * around. Can be one of `start`, `center` and `end`. When `start`, the
     * vectors will start from the given [x, y] position, and when `end` the
     * vectors will end in the [x, y] position.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.rotationOrigin
     * @see https://api.highcharts.com/highstock/plotOptions.vector.rotationOrigin
     */
    rotationOrigin?: ("center"|"end"|"start");
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.selected
     * @see https://api.highcharts.com/highstock/plotOptions.vector.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.vector.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.vector.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.vector.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vector.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states
     */
    states?: PlotVectorStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.vector.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.vector.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip
     */
    tooltip?: PlotVectorTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vector.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.vector.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Maximum length of the arrows in the vector plot.
     * The individual arrow length is computed between 0 and this value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.vectorLength
     * @see https://api.highcharts.com/highstock/plotOptions.vector.vectorLength
     */
    vectorLength?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.visible
     * @see https://api.highcharts.com/highstock/plotOptions.vector.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.vector.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.zones
     * @see https://api.highcharts.com/highstock/plotOptions.vector.zones
     */
    zones?: Array<PlotVectorZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events
 */
export interface PlotVectorPointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.point
 * @see https://api.highcharts.com/highstock/plotOptions.vector.point
 */
export interface PlotVectorPointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.vector.point.events
     */
    events?: PlotVectorPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.animation
 */
export interface PlotVectorStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.halo
 */
export interface PlotVectorStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker
 */
export interface PlotVectorStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states
     */
    states?: PlotVectorStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover.animation
 */
export interface PlotVectorStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover
 */
export interface PlotVectorStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVectorStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.normal
 */
export interface PlotVectorStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states
 */
export interface PlotVectorStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.hover
     */
    hover?: PlotVectorStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.normal
     */
    normal?: PlotVectorStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.select
     */
    select?: PlotVectorStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.select
 */
export interface PlotVectorStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) Options for the hovered series. These settings
 * override the normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover
 */
export interface PlotVectorStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVectorStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Enable separate styles for the hovered series to
     * visualize that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.halo
     */
    halo?: PlotVectorStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Additonal line width for the vector errors when
     * they are hovered.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover.marker
     */
    marker?: PlotVectorStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.normal
 */
export interface PlotVectorStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states
 */
export interface PlotVectorStatesOptions {
    /**
     * (Highcharts, Highstock) Options for the hovered series. These settings
     * override the normal state options when a series is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.hover
     */
    hover?: PlotVectorStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.normal
     */
    normal?: PlotVectorStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.select
     */
    select?: PlotVectorStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.animation
 */
export interface PlotVectorStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.halo
 */
export interface PlotVectorStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker
 */
export interface PlotVectorStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states
     */
    states?: PlotVectorStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover.animation
 */
export interface PlotVectorStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover
 */
export interface PlotVectorStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVectorStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.normal
 */
export interface PlotVectorStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states
 */
export interface PlotVectorStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.hover
     */
    hover?: PlotVectorStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.normal
     */
    normal?: PlotVectorStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.select
     */
    select?: PlotVectorStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.select
 */
export interface PlotVectorStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.select
 */
export interface PlotVectorStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVectorStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vector.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.halo
     */
    halo?: PlotVectorStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.vector.states.select.marker
     */
    marker?: PlotVectorStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.vector.tooltip.dateTimeLabelFormats
 */
export interface PlotVectorTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip
 */
export interface PlotVectorTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.vector.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotVectorTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.vector.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.vector.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vector.zones
 * @see https://api.highcharts.com/highstock/plotOptions.vector.zones
 */
export interface PlotVectorZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.vector.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.vector.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.vector.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vector.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vector.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.vector.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.animation
 */
export interface PlotVennAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker
 */
export interface PlotVennConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker
 */
export interface PlotVennConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors
 */
export interface PlotVennConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.endMarker
     */
    endMarker?: PlotVennConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.marker
     */
    marker?: PlotVennConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker
     */
    startMarker?: PlotVennConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker
 */
export interface PlotVennConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.venn.dataGrouping
 */
export interface PlotVennDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.filter
 */
export interface PlotVennDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels
 */
export interface PlotVennDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.venn.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.venn.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.filter
     */
    filter?: PlotVennDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.y
     */
    y?: number;
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragHandle
 */
export interface PlotVennDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.guideBox.default
 */
export interface PlotVennDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.guideBox
 */
export interface PlotVennDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.guideBox.default
     */
    default?: PlotVennDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop
 */
export interface PlotVennDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragHandle
     */
    dragHandle?: PlotVennDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.guideBox
     */
    guideBox?: (PlotVennDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.events
 */
export interface PlotVennEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.venn.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.venn.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.events.show
     */
    show?: () => void;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.venn.lastPrice
 */
export interface PlotVennLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotVennLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.venn.lastVisiblePrice
 */
export interface PlotVennLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotVennLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A Venn diagram displays all possible logical relations between a
 * collection of different sets. The sets are represented by circles, and the
 * relation between the sets are displayed by the overlap or lack of overlap
 * between them. The venn diagram is a special case of Euler diagrams, which can
 * also be displayed by this series type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `venn` series are defined in plotOptions.venn.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn
 */
export interface PlotVennOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVennAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.borderColor
     */
    borderColor?: string;
    borderDashStyle?: string;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.borderWidth
     */
    borderWidth?: number;
    brighten?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.colorAxis
     */
    colorAxis?: boolean;
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.venn.connectors
     */
    connectors?: PlotVennConnectorsOptions;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.dataGrouping
     */
    dataGrouping?: PlotVennDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dataLabels
     */
    dataLabels?: PlotVennDataLabelsOptions;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.dragDrop
     */
    dragDrop?: PlotVennDragDropOptions;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.events
     */
    events?: PlotVennEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.keys
     */
    keys?: Array<string>;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.lastPrice
     */
    lastPrice?: PlotVennLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.lastVisiblePrice
     */
    lastVisiblePrice?: PlotVennLastVisiblePriceOptions;
    marker?: boolean;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    opacity?: number;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point
     */
    point?: PlotVennPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) The width of each point on the x axis. For example in a
     * column chart with one value each day, the pointRange would be 1 day (= 24
     * * 3600
     *
     * * 1000 milliseconds). This is normally computed automatically, but this
     * option can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.pointRange
     */
    pointRange?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states
     */
    states?: PlotVennStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.step
     * @see https://api.highcharts.com/highstock/plotOptions.venn.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.venn.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip. Overridable
     * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
     * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
     * series.name by default shows in the headerFormat and point.x and point.y
     * in the pointFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip
     */
    tooltip?: PlotVennTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.venn.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.venn.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events
 */
export interface PlotVennPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.point
 */
export interface PlotVennPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.point.events
     */
    events?: PlotVennPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.animation
 */
export interface PlotVennStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.halo
 */
export interface PlotVennStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker
 */
export interface PlotVennStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states
     */
    states?: PlotVennStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover.animation
 */
export interface PlotVennStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover
 */
export interface PlotVennStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVennStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.normal
 */
export interface PlotVennStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states
 */
export interface PlotVennStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.hover
     */
    hover?: PlotVennStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.normal
     */
    normal?: PlotVennStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.select
     */
    select?: PlotVennStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.select
 */
export interface PlotVennStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover
 */
export interface PlotVennStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVennStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.hover.borderColor
     */
    borderColor?: string;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.halo
     */
    halo?: (boolean|PlotVennStatesHoverHaloOptions);
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.hover.marker
     */
    marker?: PlotVennStatesHoverMarkerOptions;
    opacity?: number;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.normal
 */
export interface PlotVennStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states
 */
export interface PlotVennStatesOptions {
    /**
     * (Highcharts) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.hover
     */
    hover?: PlotVennStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.normal
     */
    normal?: PlotVennStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.select
     */
    select?: PlotVennStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.animation
 */
export interface PlotVennStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.halo
 */
export interface PlotVennStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker
 */
export interface PlotVennStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states
     */
    states?: PlotVennStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover.animation
 */
export interface PlotVennStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover
 */
export interface PlotVennStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVennStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.normal
 */
export interface PlotVennStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states
 */
export interface PlotVennStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.hover
     */
    hover?: PlotVennStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.normal
     */
    normal?: PlotVennStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.select
     */
    select?: PlotVennStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.select
 */
export interface PlotVennStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.select
 */
export interface PlotVennStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.animation
     */
    animation?: (boolean|PlotVennStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.select.borderColor
     */
    borderColor?: string;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.select.color
     */
    color?: string;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.venn.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.halo
     */
    halo?: PlotVennStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.venn.states.select.marker
     */
    marker?: PlotVennStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.venn.tooltip.dateTimeLabelFormats
 */
export interface PlotVennTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip. Overridable
 * properties are `headerFormat`, `pointFormat`, `yDecimals`, `xDateFormat`,
 * `yPrefix` and `ySuffix`. Unlike other series, in a scatter plot the
 * series.name by default shows in the headerFormat and point.x and point.y in
 * the pointFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip
 */
export interface PlotVennTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.venn.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotVennTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The HTML of the point's line in the tooltip.
     * Variables are enclosed by curly brackets. Available variables are
     * point.x, point.y, series. name and series.color and other properties on
     * the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.venn.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.venn.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.venn.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.animation
 */
export interface PlotVwapAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker
 */
export interface PlotVwapConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker
 */
export interface PlotVwapConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors
 */
export interface PlotVwapConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.endMarker
     */
    endMarker?: PlotVwapConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.marker
     */
    marker?: PlotVwapConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker
     */
    startMarker?: PlotVwapConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker
 */
export interface PlotVwapConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataGrouping
 */
export interface PlotVwapDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.filter
 */
export interface PlotVwapDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels
 */
export interface PlotVwapDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.filter
     */
    filter?: PlotVwapDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragHandle
 */
export interface PlotVwapDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.guideBox.default
 */
export interface PlotVwapDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.guideBox
 */
export interface PlotVwapDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.guideBox.default
     */
    default?: PlotVwapDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop
 */
export interface PlotVwapDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragHandle
     */
    dragHandle?: PlotVwapDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.guideBox
     */
    guideBox?: (PlotVwapDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.events
 */
export interface PlotVwapEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.label
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.label
 * @see https://api.highcharts.com/gantt/plotOptions.vwap.label
 */
export interface PlotVwapLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.lastPrice
 */
export interface PlotVwapLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotVwapLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.lastVisiblePrice
 */
export interface PlotVwapLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotVwapLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker
 */
export interface PlotVwapMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states
     */
    states?: PlotVwapMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover.animation
 */
export interface PlotVwapMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover
 */
export interface PlotVwapMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVwapMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.normal
 */
export interface PlotVwapMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states
 */
export interface PlotVwapMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.hover
     */
    hover?: PlotVwapMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.normal
     */
    normal?: PlotVwapMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.select
     */
    select?: PlotVwapMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.select
 */
export interface PlotVwapMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Volume Weighted Average Price indicator.
 *
 * This series requires `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `vwap` series are defined in plotOptions.vwap.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap
 */
export interface PlotVwapOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVwapAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.connectors
     */
    connectors?: PlotVwapConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataGrouping
     */
    dataGrouping?: PlotVwapDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dataLabels
     */
    dataLabels?: PlotVwapDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.dragDrop
     */
    dragDrop?: PlotVwapDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.events
     */
    events?: PlotVwapEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.label
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.label
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.label
     */
    label?: PlotVwapLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.lastPrice
     */
    lastPrice?: PlotVwapLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.lastVisiblePrice
     */
    lastVisiblePrice?: PlotVwapLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.marker
     */
    marker?: PlotVwapMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.params
     */
    params?: PlotVwapParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point
     */
    point?: PlotVwapPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states
     */
    states?: PlotVwapStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.step
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip
     */
    tooltip?: PlotVwapTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.zones
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.zones
     */
    zones?: Array<PlotVwapZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.params
 */
export interface PlotVwapParamsOptions {
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.params.period
     */
    period?: number;
    /**
     * (Highstock) The id of volume series which is mandatory. For example using
     * OHLC data, volumeSeriesID='volume' means the indicator will be calculated
     * using OHLC and volume values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.params.volumeSeriesID
     */
    volumeSeriesID?: string;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events
 */
export interface PlotVwapPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.point
 */
export interface PlotVwapPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.point.events
     */
    events?: PlotVwapPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.animation
 */
export interface PlotVwapStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.halo
 */
export interface PlotVwapStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker
 */
export interface PlotVwapStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states
     */
    states?: PlotVwapStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover.animation
 */
export interface PlotVwapStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover
 */
export interface PlotVwapStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVwapStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.normal
 */
export interface PlotVwapStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states
 */
export interface PlotVwapStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.hover
     */
    hover?: PlotVwapStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.normal
     */
    normal?: PlotVwapStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.select
     */
    select?: PlotVwapStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.select
 */
export interface PlotVwapStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover
 */
export interface PlotVwapStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVwapStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.halo
     */
    halo?: PlotVwapStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover.marker
     */
    marker?: PlotVwapStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.normal
 */
export interface PlotVwapStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states
 */
export interface PlotVwapStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.hover
     */
    hover?: PlotVwapStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.normal
     */
    normal?: PlotVwapStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.select
     */
    select?: PlotVwapStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.animation
 */
export interface PlotVwapStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.halo
 */
export interface PlotVwapStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker
 */
export interface PlotVwapStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states
     */
    states?: PlotVwapStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover.animation
 */
export interface PlotVwapStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover
 */
export interface PlotVwapStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVwapStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.normal
 */
export interface PlotVwapStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states
 */
export interface PlotVwapStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.hover
     */
    hover?: PlotVwapStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.normal
     */
    normal?: PlotVwapStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.select
     */
    select?: PlotVwapStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.select
 */
export interface PlotVwapStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.select
 */
export interface PlotVwapStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotVwapStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.vwap.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.halo
     */
    halo?: PlotVwapStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.states.select.marker
     */
    marker?: PlotVwapStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.vwap.tooltip.dateTimeLabelFormats
 */
export interface PlotVwapTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip
 */
export interface PlotVwapTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotVwapTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.vwap.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.vwap.zones
 * @see https://api.highcharts.com/highstock/plotOptions.vwap.zones
 */
export interface PlotVwapZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.vwap.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.vwap.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.animation
 */
export interface PlotWaterfallAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker
 */
export interface PlotWaterfallConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker
 */
export interface PlotWaterfallConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors
 */
export interface PlotWaterfallConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.endMarker
     */
    endMarker?: PlotWaterfallConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.marker
     */
    marker?: PlotWaterfallConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker
     */
    startMarker?: PlotWaterfallConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker
 */
export interface PlotWaterfallConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataGrouping
 */
export interface PlotWaterfallDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.filter
 */
export interface PlotWaterfallDataLabelsFilterOptions {
    /**
     * (Highcharts) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels
 */
export interface PlotWaterfallDataLabelsOptions {
    /**
     * (Highcharts) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) A class name for the data label. Particularly in styled
     * mode, this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.filter
     */
    filter?: PlotWaterfallDataLabelsFilterOptions;
    /**
     * (Highcharts) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts) For points with an extent, like columns or map areas,
     * whether to align the data label inside the box or to the actual value
     * point. Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragHandle
 */
export interface PlotWaterfallDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.guideBox.default
 */
export interface PlotWaterfallDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.guideBox
 */
export interface PlotWaterfallDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.guideBox.default
     */
    default?: PlotWaterfallDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop
 */
export interface PlotWaterfallDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragHandle
     */
    dragHandle?: PlotWaterfallDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.guideBox
     */
    guideBox?: (PlotWaterfallDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.events
 */
export interface PlotWaterfallEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.label
 * @see https://api.highcharts.com/highstock/plotOptions.waterfall.label
 * @see https://api.highcharts.com/gantt/plotOptions.waterfall.label
 */
export interface PlotWaterfallLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.waterfall.lastPrice
 */
export interface PlotWaterfallLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotWaterfallLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.waterfall.lastVisiblePrice
 */
export interface PlotWaterfallLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotWaterfallLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A waterfall chart displays sequentially introduced positive or
 * negative values in cumulative columns.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `waterfall` series are defined in plotOptions.waterfall.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall
 */
export interface PlotWaterfallOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.waterfall.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWaterfallAnimationOptions);
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highcharts) The color of the border of each waterfall column.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.className
     */
    className?: string;
    /**
     * (Highcharts) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.clip
     */
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.waterfall.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.colors
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.colors
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.connectors
     */
    connectors?: PlotWaterfallConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) A name for the dash style to use for the line connecting the
     * columns of the waterfall series. Possible values: Dash, DashDot, Dot,
     * LongDash, LongDashDot, LongDashDotDot, ShortDash, ShortDashDot,
     * ShortDashDotDot, ShortDot, Solid
     *
     * In styled mode, the stroke dash-array can be set with the
     * `.highcharts-graph` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.dataGrouping
     */
    dataGrouping?: PlotWaterfallDataGroupingOptions;
    /**
     * (Highcharts) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dataLabels
     */
    dataLabels?: PlotWaterfallDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.depth
     */
    depth?: number;
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.dragDrop
     */
    dragDrop?: PlotWaterfallDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.events
     */
    events?: PlotWaterfallEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.waterfall.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.label
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.label
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.label
     */
    label?: PlotWaterfallLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.lastPrice
     */
    lastPrice?: PlotWaterfallLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.lastVisiblePrice
     */
    lastVisiblePrice?: PlotWaterfallLastVisiblePriceOptions;
    /**
     * (Highcharts) The color of the line that connects columns in a waterfall
     * series.
     *
     * In styled mode, the stroke can be set with the `.highcharts-graph` class.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The width of the line connecting waterfall columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts) The color for the parts of the graph or points that are
     * below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point
     */
    point?: PlotWaterfallPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) Whether to stack the values of each series on top
     * of each other. Possible values are `undefined` to disable, `"normal"` to
     * stack by value or `"percent"`. When stacking is enabled, data must be
     * sorted in ascending X order. A special stacking option is with the
     * streamgraph series type, where the stacking option is set to `"stream"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.stacking
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.stacking
     */
    stacking?: ("normal"|"percent");
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states
     */
    states?: PlotWaterfallStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.threshold
     */
    threshold?: number;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip
     */
    tooltip?: PlotWaterfallTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) The color used specifically for positive point columns. When
     * not specified, the general series color is used.
     *
     * In styled mode, the waterfall colors can be set with the
     * `.highcharts-point-negative`, `.highcharts-sum` and
     * `.highcharts-intermediate-sum` classes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.upColor
     */
    upColor?: (ColorString|GradientColorObject);
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.waterfall.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.zones
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.zones
     */
    zones?: Array<PlotWaterfallZonesOptions>;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events
 */
export interface PlotWaterfallPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point
 */
export interface PlotWaterfallPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.point.events
     */
    events?: PlotWaterfallPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.hover.animation
 */
export interface PlotWaterfallStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.waterfall.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.hover
 */
export interface PlotWaterfallStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWaterfallStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.waterfall.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.hover.enabled
     */
    enabled?: boolean;
    lineWidthPlus?: number;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.waterfall.states.normal
 */
export interface PlotWaterfallStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.waterfall.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states
 */
export interface PlotWaterfallStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.hover
     */
    hover?: PlotWaterfallStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.waterfall.states.normal
     */
    normal?: PlotWaterfallStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.select
     */
    select?: PlotWaterfallStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.select.animation
 */
export interface PlotWaterfallStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.waterfall.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.select
 */
export interface PlotWaterfallStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWaterfallStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.waterfall.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.waterfall.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.waterfall.tooltip.dateTimeLabelFormats
 */
export interface PlotWaterfallTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip
 */
export interface PlotWaterfallTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotWaterfallTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.waterfall.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.zones
 * @see https://api.highcharts.com/highstock/plotOptions.waterfall.zones
 */
export interface PlotWaterfallZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.waterfall.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.waterfall.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.animation
 */
export interface PlotWilliamsrAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker
 */
export interface PlotWilliamsrConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker
 */
export interface PlotWilliamsrConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors
 */
export interface PlotWilliamsrConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.endMarker
     */
    endMarker?: PlotWilliamsrConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.marker
     */
    marker?: PlotWilliamsrConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker
     */
    startMarker?: PlotWilliamsrConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker
 */
export interface PlotWilliamsrConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataGrouping
 */
export interface PlotWilliamsrDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.filter
 */
export interface PlotWilliamsrDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels
 */
export interface PlotWilliamsrDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.filter
     */
    filter?: PlotWilliamsrDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragHandle
 */
export interface PlotWilliamsrDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.guideBox.default
 */
export interface PlotWilliamsrDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.guideBox
 */
export interface PlotWilliamsrDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.guideBox.default
     */
    default?: PlotWilliamsrDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop
 */
export interface PlotWilliamsrDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragHandle
     */
    dragHandle?: PlotWilliamsrDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.guideBox
     */
    guideBox?: (PlotWilliamsrDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.events
 */
export interface PlotWilliamsrEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.label
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.label
 * @see https://api.highcharts.com/gantt/plotOptions.williamsr.label
 */
export interface PlotWilliamsrLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.lastPrice
 */
export interface PlotWilliamsrLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotWilliamsrLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.lastVisiblePrice
 */
export interface PlotWilliamsrLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotWilliamsrLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker
 */
export interface PlotWilliamsrMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states
     */
    states?: PlotWilliamsrMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover.animation
 */
export interface PlotWilliamsrMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover
 */
export interface PlotWilliamsrMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWilliamsrMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.normal
 */
export interface PlotWilliamsrMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states
 */
export interface PlotWilliamsrMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.hover
     */
    hover?: PlotWilliamsrMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.normal
     */
    normal?: PlotWilliamsrMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.select
     */
    select?: PlotWilliamsrMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.select
 */
export interface PlotWilliamsrMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Williams %R. This series requires the `linkedTo` option to be set
 * and should be loaded after the `stock/indicators/indicators.js`.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `williamsr` series are defined in plotOptions.williamsr.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr
 */
export interface PlotWilliamsrOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWilliamsrAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.connectors
     */
    connectors?: PlotWilliamsrConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataGrouping
     */
    dataGrouping?: PlotWilliamsrDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dataLabels
     */
    dataLabels?: PlotWilliamsrDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.dragDrop
     */
    dragDrop?: PlotWilliamsrDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.events
     */
    events?: PlotWilliamsrEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.label
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.label
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.label
     */
    label?: PlotWilliamsrLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.lastPrice
     */
    lastPrice?: PlotWilliamsrLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.lastVisiblePrice
     */
    lastVisiblePrice?: PlotWilliamsrLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.marker
     */
    marker?: PlotWilliamsrMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of Williams %R series points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.params
     */
    params?: PlotWilliamsrParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point
     */
    point?: PlotWilliamsrPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states
     */
    states?: PlotWilliamsrStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.step
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip
     */
    tooltip?: PlotWilliamsrTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.zones
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.zones
     */
    zones?: Array<PlotWilliamsrZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of Williams %R series points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.params
 */
export interface PlotWilliamsrParamsOptions {
    /**
     * (Highstock) Period for Williams %R oscillator
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events
 */
export interface PlotWilliamsrPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point
 */
export interface PlotWilliamsrPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.point.events
     */
    events?: PlotWilliamsrPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.animation
 */
export interface PlotWilliamsrStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.halo
 */
export interface PlotWilliamsrStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker
 */
export interface PlotWilliamsrStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states
     */
    states?: PlotWilliamsrStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover.animation
 */
export interface PlotWilliamsrStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover
 */
export interface PlotWilliamsrStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWilliamsrStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.normal
 */
export interface PlotWilliamsrStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states
 */
export interface PlotWilliamsrStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.hover
     */
    hover?: PlotWilliamsrStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.normal
     */
    normal?: PlotWilliamsrStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.select
     */
    select?: PlotWilliamsrStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.select
 */
export interface PlotWilliamsrStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover
 */
export interface PlotWilliamsrStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWilliamsrStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.halo
     */
    halo?: PlotWilliamsrStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover.marker
     */
    marker?: PlotWilliamsrStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.normal
 */
export interface PlotWilliamsrStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states
 */
export interface PlotWilliamsrStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.hover
     */
    hover?: PlotWilliamsrStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.normal
     */
    normal?: PlotWilliamsrStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.select
     */
    select?: PlotWilliamsrStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.animation
 */
export interface PlotWilliamsrStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.halo
 */
export interface PlotWilliamsrStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker
 */
export interface PlotWilliamsrStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states
     */
    states?: PlotWilliamsrStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover.animation
 */
export interface PlotWilliamsrStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover
 */
export interface PlotWilliamsrStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWilliamsrStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.normal
 */
export interface PlotWilliamsrStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states
 */
export interface PlotWilliamsrStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.hover
     */
    hover?: PlotWilliamsrStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.normal
     */
    normal?: PlotWilliamsrStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.select
     */
    select?: PlotWilliamsrStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.select
 */
export interface PlotWilliamsrStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.select
 */
export interface PlotWilliamsrStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWilliamsrStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.williamsr.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.halo
     */
    halo?: PlotWilliamsrStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.states.select.marker
     */
    marker?: PlotWilliamsrStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.williamsr.tooltip.dateTimeLabelFormats
 */
export interface PlotWilliamsrTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip
 */
export interface PlotWilliamsrTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotWilliamsrTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.williamsr.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.zones
 * @see https://api.highcharts.com/highstock/plotOptions.williamsr.zones
 */
export interface PlotWilliamsrZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.williamsr.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.williamsr.zones.value
     */
    value?: number;
}
/**
 * (Highcharts, Highstock) Enable or disable the initial animation when a series
 * is displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.animation
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.animation
 */
export interface PlotWindbarbAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker
 */
export interface PlotWindbarbConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker
 */
export interface PlotWindbarbConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors
 */
export interface PlotWindbarbConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.endMarker
     */
    endMarker?: PlotWindbarbConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.marker
     */
    marker?: PlotWindbarbConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker
     */
    startMarker?: PlotWindbarbConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker
 */
export interface PlotWindbarbConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.filter
 */
export interface PlotWindbarbDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock) The operator to compare by. Can be one of `>`,
     * `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock) The point property to filter by. Point options
     * are passed directly to properties, additionally there are `y` value,
     * `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock) Options for the series data labels, appearing next to
 * each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels
 */
export interface PlotWindbarbDataLabelsOptions {
    /**
     * (Highcharts, Highstock) The alignment of the data label compared to the
     * point. If `right`, the right side of the label should be touching the
     * point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to allow data labels to overlap. To make
     * the labels less sensitive for overlapping, the dataLabels.padding can be
     * set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock) The background color or gradient for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The border color for the data label. Defaults to
     * `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) A class name for the data label. Particularly in
     * styled mode, this can be used to give each series' or point's data label
     * unique styling. In addition to this option, a default color class name is
     * added so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The text color for the data labels. Defaults to
     * `undefined`. For certain series types, like column or map, the data
     * labels can be drawn inside the points. In this case the data label will
     * be drawn with maximum contrast by default. Additionally, it will be given
     * a `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Whether to hide data labels that are outside the
     * plot area. By default, the data label is moved inside the plot area
     * according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A declarative filter for which data labels to
     * display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.filter
     */
    filter?: PlotWindbarbDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock) Callback JavaScript function to format the data
     * label. Note that if a `format` is defined, the format takes precedence
     * and the formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock) For points with an extent, like columns or map
     * areas, whether to align the data label inside the box or to the actual
     * value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock) How to handle data labels that flow outside the
     * plot area. The default is `"justify"`, which aligns them inside the plot
     * area. For columns and bars, this means it will be moved inside the bar.
     * To display data labels outside the plot area, set `crop` to `false` and
     * `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) Text rotation in degrees. Note that due to a more
     * complex structure, backgrounds, borders and padding will be lost on a
     * rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the label. Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock) Styles for the label. The default `color` setting
     * is `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock) The vertical alignment of a data label. Can be
     * one of `top`, `middle` or `bottom`. The default value depends on the
     * data, for instance in a column chart, the label is above positive values
     * and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock) The x position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y position offset of the label relative to
     * the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts, Highstock) The Z index of the data labels. The default Z
     * index puts it above the series. Use a Z index of 2 to display it behind
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragHandle
 */
export interface PlotWindbarbDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) The mouse cursor to use for the drag handles. By
     * default this is intelligently switching between `ew-resize` and
     * `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Function to define the SVG path to use for the
     * drag handles. Takes the point as argument. Should return an SVG path in
     * array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.guideBox.default
 */
export interface PlotWindbarbDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock) CSS class name of the guide box in this state.
     * Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock) Style options for the guide box. The guide box has
 * one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.guideBox
 */
export interface PlotWindbarbDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.guideBox.default
     */
    default?: PlotWindbarbDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock) The draggable-points module allows points to be moved
 * around or modified in the chart. In addition to the options mentioned under
 * the `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop
 */
export interface PlotWindbarbDragDropOptions {
    /**
     * (Highcharts, Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock) Enable dragging in the Y dimension. Note that
     * this is not supported for TreeGrid axes (the default axis type in Gantt
     * charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragHandle
     */
    dragHandle?: PlotWindbarbDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock) Set the maximum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock) Set the maximum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock) Set the minimum X value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock) Set the minimum Y value the points can be moved
     * to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock) The X precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock) The Y precision value to drag to for this series.
     * Set to 0 to disable. By default this is disabled, except for category
     * axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock) The amount of pixels to drag the pointer before
     * it counts as a drag operation. This prevents drag/drop to fire when just
     * clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock) Group the points by a property. Points with the
     * same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock) Style options for the guide box. The guide box
     * has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.guideBox
     */
    guideBox?: (PlotWindbarbDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock) Update points as they are dragged. If false, a
     * guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) General event handlers for the series items. These
 * event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.events
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.events
 */
export interface PlotWindbarbEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the checkbox next to the series' name
     * in the legend is clicked. One parameter, `event`, is passed to the
     * function. The state of the checkbox is found by `event.checked`. The
     * checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the series is hidden after chart
     * generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the legend item belonging to the
     * series is clicked. One parameter, `event`, is passed to the function. The
     * default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.label
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.label
 * @see https://api.highcharts.com/gantt/plotOptions.windbarb.label
 */
export interface PlotWindbarbLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.lastPrice
 */
export interface PlotWindbarbLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotWindbarbLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.lastVisiblePrice
 */
export interface PlotWindbarbLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotWindbarbLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock) Wind barbs are a convenient way to represent wind
 * speed and direction in one graphical form. Wind direction is given by the
 * stem direction, and wind speed by the number and shape of barbs.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `windbarb` series are defined in plotOptions.windbarb.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb
 */
export interface PlotWindbarbOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.windbarb.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock) Allow this series' points to be selected by
     * clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock) Enable or disable the initial animation when a
     * series is displayed. The animation can also be set as a configuration
     * object. Please note that this option only applies to the initial
     * animation of the series itself. For other animations, see chart.animation
     * and the animation parameter under the API methods. The following
     * properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.animation
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWindbarbAnimationOptions);
    /**
     * (Highcharts, Highstock) For some series, there is a limit that shuts down
     * initial animation by default when the total number of points in the chart
     * is too high. For example, for a column chart and its derivatives,
     * animation doesn't run if there is more than 250 points totally. To
     * disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock) An additional class name to apply to the series'
     * graphical elements. This option does not replace default class names of
     * the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.className
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Disable this option to allow series rendering in
     * the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.clip
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock) The main color of the series. In line type series
     * it applies to the line and the point markers unless otherwise specified.
     * In bar type series it applies to the bars unless a color is specified per
     * point. The default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.color
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.windbarb.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts, Highstock) Styled mode only. A specific color index to use
     * for the series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.colors
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.colors
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.connectors
     */
    connectors?: PlotWindbarbConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When true, each column edge is rounded to
     * its nearest pixel in order to render sharp on screen. In some cases, when
     * there are a lot of densely packed columns, this leads to visible
     * difference in column widths or distance between columns. In these cases,
     * setting `crisp` to `false` may look better, even though each column is
     * rendered blurry.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.crisp
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.crisp
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.crisp
     */
    crisp?: boolean;
    /**
     * (Highcharts, Highstock) You can set the cursor to "pointer" if you have
     * click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts, Highstock) Options for the series data labels, appearing
     * next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dataLabels
     */
    dataLabels?: PlotWindbarbDataLabelsOptions;
    /**
     * (Highcharts) Depth of the columns in a 3D column chart. Requires
     * `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.depth
     */
    depth?: number;
    /**
     * (Highcharts, Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.description
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The draggable-points module allows points to be
     * moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.dragDrop
     */
    dragDrop?: PlotWindbarbDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The color of the edges. Similar to
     * `borderColor`, except it defaults to the same color as the column.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.edgeColor
     */
    edgeColor?: ColorString;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts, Highstock) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock) General event handlers for the series items.
     * These event hooks can also be attached to the series at run time using
     * the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.events
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.events
     */
    events?: PlotWindbarbEventsOptions;
    /**
     * (Highcharts, Highstock) By default, series are exposed to screen readers
     * as regions. By enabling this option, the series element itself will be
     * exposed in the same way as the data points. This is useful if the series
     * is not used as a grouping entity in the chart, but you still want to
     * attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock) Determines whether the series should look for the
     * nearest point in both dimensions or just the x-dimension when hovering
     * the series. Defaults to `'xy'` for scatter series and `'x'` for most
     * other series. If the data has duplicate x-values, it is recommended to
     * set this to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.findNearestPointBy
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.windbarb.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock) An array specifying which option maps to which
     * key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.keys
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.label
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.label
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.label
     */
    label?: PlotWindbarbLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.lastPrice
     */
    lastPrice?: PlotWindbarbLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.lastVisiblePrice
     */
    lastVisiblePrice?: PlotWindbarbLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The line width of the wind barb symbols.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock) The color for the parts of the graph or points
     * that are below the threshold.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.negativeColor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The id of another series in the chart that the
     * wind barbs are projected on. When `null`, the wind symbols are drawn on
     * the X axis, but offset up or down by the `yOffset` setting.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.onSeries
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.onSeries
     */
    onSeries?: (string|null);
    /**
     * (Highcharts, Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point
     */
    point?: PlotWindbarbPointOptions;
    /**
     * (Highcharts, Highstock) Same as accessibility.pointDescriptionFormatter,
     * but for an individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, `pointInterval` defines the interval of the x values. For
     * example, if a series contains one value every decade starting from year
     * 0, set `pointInterval` to `10`. In true `datetime` axes, the
     * `pointInterval` is set in milliseconds.
     *
     * It can be also be combined with `pointIntervalUnit` to draw irregular
     * time intervals.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.pointInterval
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.pointInterval
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.pointInterval
     */
    pointInterval?: number;
    /**
     * (Highcharts, Highstock, Gantt) On datetime series, this allows for
     * setting the pointInterval to irregular time units, `day`, `month` and
     * `year`. A day is usually the same as 24 hours, but `pointIntervalUnit`
     * also takes the DST crossover into consideration when dealing with local
     * time. Combine this option with `pointInterval` to draw weeks, quarters, 6
     * months, 10 years etc.
     *
     * Please note that this options applies to the _series data_, not the
     * interval of the axis ticks, which is independent.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.pointIntervalUnit
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.pointIntervalUnit
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.pointIntervalUnit
     */
    pointIntervalUnit?: ("day"|"month"|"year");
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Possible values: `"on"`, `"between"`,
     * `number`.
     *
     * In a column chart, when pointPlacement is `"on"`, the point will not
     * create any padding of the X axis. In a polar column chart this means that
     * the first column points directly north. If the pointPlacement is
     * `"between"`, the columns will be laid out between ticks. This is useful
     * for example for visualising an amount between two points in time or in a
     * certain sector of a polar chart.
     *
     * Since Highcharts 3.0.2, the point placement can also be numeric, where 0
     * is on the axis value, -0.5 is between this value and the previous, and
     * 0.5 is between this value and the next. Unlike the textual options,
     * numeric point placement options won't affect axis padding.
     *
     * Note that pointPlacement needs a pointRange to work. For column series
     * this is computed, but for line-type series it needs to be set.
     *
     * For the `xrange` series type and gantt charts, if the Y axis is a
     * category axis, the `pointPlacement` applies to the Y axis rather than the
     * (typically datetime) X axis.
     *
     * Defaults to `undefined` in cartesian charts, `"between"` in polar charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.pointPlacement
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.pointPlacement
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.pointPlacement
     */
    pointPlacement?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The X axis range that each point is valid
     * for. This determines the width of the column. On a categorized axis, the
     * range will be 1 by default (one category unit). On linear and datetime
     * axes, the range will be computed as the distance between the two closest
     * data points.
     *
     * The default `null` means it is computed automatically, but this option
     * can be used to override the automatic value.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.pointRange
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.pointRange
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.pointRange
     */
    pointRange?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) If no x values are given for the points in
     * a series, pointStart defines on what value to start. For example, if a
     * series contains one yearly value starting from 1945, set pointStart to
     * 1945.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.pointStart
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.pointStart
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.pointStart
     */
    pointStart?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.selected
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) If true, a checkbox is displayed next to the
     * legend item to allow selecting the series. The state of the checkbox is
     * determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock) Whether to display this particular series or
     * series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock) If set to `true`, the accessibility module will
     * skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highcharts, Highstock) A wrapper object for all the series options in
     * specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states
     */
    states?: PlotWindbarbStatesOptions;
    /**
     * (Highcharts, Highstock) Sticky tracking of mouse events. When true, the
     * `mouseOut` event on a series isn't triggered until the mouse moves over
     * another series, or out of the plot area. When false, the `mouseOut` event
     * on a series is triggered when the mouse leaves the area around the
     * series' graph or markers. This also implies the tooltip when not shared.
     * When `stickyTracking` is false and `tooltip.shared` is false, the tooltip
     * will be hidden when moving the mouse between series. Defaults to true for
     * line and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) The Y axis value to serve as the base for the columns, for
     * distinguishing between values above and below a threshold. If `null`, the
     * columns extend from the padding Y axis minimum.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.threshold
     */
    threshold?: number;
    /**
     * (Highcharts, Highstock) A configuration object for the tooltip rendering
     * of each single series. Properties are inherited from tooltip, but only
     * the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip
     */
    tooltip?: PlotWindbarbTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock) Pixel length of the stems.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.vectorLength
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.vectorLength
     */
    vectorLength?: number;
    /**
     * (Highcharts, Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.visible
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.visible
     */
    visible?: boolean;
    /**
     * (Highcharts, Highstock) Horizontal offset from the cartesian position, in
     * pixels. When the chart is inverted, this option allows translation like
     * yOffset in non inverted charts.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.xOffset
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.xOffset
     */
    xOffset?: number;
    /**
     * (Highcharts, Highstock) Vertical offset from the cartesian position, in
     * pixels. The default value makes sure the symbols don't overlap the X axis
     * when `onSeries` is `null`, and that they don't overlap the linked series
     * when `onSeries` is given.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.yOffset
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.yOffset
     */
    yOffset?: number;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.windbarb.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.zones
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.zones
     */
    zones?: Array<PlotWindbarbZonesOptions>;
}
/**
 * (Highcharts, Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events
 */
export interface PlotWindbarbPointEventsOptions {
    /**
     * (Highcharts, Highstock) Fires when a point is clicked. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires while dragging a point. The
     * mouse event is passed in as parameter. The original data can be accessed
     * from `e.origin`, and the new point values can be accessed from
     * `e.newPoints`. If there is only a single point being updated, it can be
     * accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when starting to drag a
     * point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock) Callback that fires when the point is dropped.
     * The parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock) Fires when the mouse leaves the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the mouse enters the area close to the
     * point. One parameter, `event`, is passed to the function, containing
     * common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock) Fires when the point is updated programmatically
     * through the `.update()` method. One parameter, `event`, is passed to the
     * function. The new point options can be accessed through `event.options`.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point
 */
export interface PlotWindbarbPointOptions {
    /**
     * (Highcharts, Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.point.events
     */
    events?: PlotWindbarbPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.hover.animation
 */
export interface PlotWindbarbStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.hover
 */
export interface PlotWindbarbStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWindbarbStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.windbarb.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.hover.enabled
     */
    enabled?: boolean;
    lineWidthPlus?: number;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.windbarb.states.normal
 */
export interface PlotWindbarbStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.windbarb.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states
 */
export interface PlotWindbarbStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.hover
     */
    hover?: PlotWindbarbStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.windbarb.states.normal
     */
    normal?: PlotWindbarbStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.select
     */
    select?: PlotWindbarbStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.select.animation
 */
export interface PlotWindbarbStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.select
 */
export interface PlotWindbarbStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWindbarbStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.windbarb.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.windbarb.tooltip.dateTimeLabelFormats
 */
export interface PlotWindbarbTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock) A configuration object for the tooltip rendering of
 * each single series. Properties are inherited from tooltip, but only the
 * following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip
 */
export interface PlotWindbarbTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotWindbarbTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts, Highstock) Whether the tooltip should follow the mouse as it
     * moves across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock) Whether the tooltip should update as the finger
     * moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock) The HTML of the tooltip header line. Variables
     * are enclosed by curly brackets. Available variables are `point.key`,
     * `series.name`, `series.color` and other members from the `point` and
     * `series` objects. The `point.key` variable contains the category name, x
     * value or datetime string depending on the type of axis. For datetime
     * axes, the `point.key` date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock) The name of a symbol to use for the border around
     * the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) The number of milliseconds to wait until the
     * tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock) Whether to allow the tooltip to render outside
     * the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock) The default point format for the wind barb
     * tooltip. Note the `point.beaufort` property that refers to the Beaufort
     * wind scale. The names can be internationalized by modifying
     * `Highcharts.seriesTypes.windbarb.prototype.beaufortNames`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock) A callback function for formatting the HTML
     * output for a single point in the tooltip. Like the `pointFormat` string,
     * but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock) How many decimals to show in each series' y
     * value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock) A string to prepend to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock) A string to append to each series' y value.
     * Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.windbarb.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.zones
 * @see https://api.highcharts.com/highstock/plotOptions.windbarb.zones
 */
export interface PlotWindbarbZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.windbarb.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.windbarb.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.animation
 */
export interface PlotWmaAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker
 */
export interface PlotWmaConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker
 */
export interface PlotWmaConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors
 */
export interface PlotWmaConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.endMarker
     */
    endMarker?: PlotWmaConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.marker
     */
    marker?: PlotWmaConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker
     */
    startMarker?: PlotWmaConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker
 */
export interface PlotWmaConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.dataGrouping
 */
export interface PlotWmaDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.filter
 */
export interface PlotWmaDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels
 */
export interface PlotWmaDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.wma.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.filter
     */
    filter?: PlotWmaDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragHandle
 */
export interface PlotWmaDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.guideBox.default
 */
export interface PlotWmaDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.guideBox
 */
export interface PlotWmaDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.guideBox.default
     */
    default?: PlotWmaDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop
 */
export interface PlotWmaDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragHandle
     */
    dragHandle?: PlotWmaDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.guideBox
     */
    guideBox?: (PlotWmaDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.events
 */
export interface PlotWmaEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.wma.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.wma.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.label
 * @see https://api.highcharts.com/highstock/plotOptions.wma.label
 * @see https://api.highcharts.com/gantt/plotOptions.wma.label
 */
export interface PlotWmaLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.wma.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.wma.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.wma.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.wma.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.wma.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.wma.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.wma.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.wma.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.wma.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.wma.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.wma.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.wma.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.wma.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.wma.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.wma.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.wma.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.lastPrice
 */
export interface PlotWmaLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotWmaLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.lastVisiblePrice
 */
export interface PlotWmaLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotWmaLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.marker
 */
export interface PlotWmaMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states
     */
    states?: PlotWmaMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover.animation
 */
export interface PlotWmaMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover
 */
export interface PlotWmaMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWmaMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.normal
 */
export interface PlotWmaMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states
 */
export interface PlotWmaMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.hover
     */
    hover?: PlotWmaMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.normal
     */
    normal?: PlotWmaMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.select
     */
    select?: PlotWmaMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.select
 */
export interface PlotWmaMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Weighted moving average indicator (WMA). This series requires
 * `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `wma` series are defined in plotOptions.wma.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma
 */
export interface PlotWmaOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWmaAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.wma.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wma.connectors
     */
    connectors?: PlotWmaConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.wma.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataGrouping
     */
    dataGrouping?: PlotWmaDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dataLabels
     */
    dataLabels?: PlotWmaDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.dragDrop
     */
    dragDrop?: PlotWmaDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.events
     */
    events?: PlotWmaEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.wma.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.wma.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.label
     * @see https://api.highcharts.com/highstock/plotOptions.wma.label
     * @see https://api.highcharts.com/gantt/plotOptions.wma.label
     */
    label?: PlotWmaLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.lastPrice
     */
    lastPrice?: PlotWmaLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.lastVisiblePrice
     */
    lastVisiblePrice?: PlotWmaLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.wma.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.wma.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.wma.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.wma.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.marker
     */
    marker?: PlotWmaMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.params
     */
    params?: PlotWmaParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point
     */
    point?: PlotWmaPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.wma.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states
     */
    states?: PlotWmaStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.step
     * @see https://api.highcharts.com/highstock/plotOptions.wma.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.wma.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip
     */
    tooltip?: PlotWmaTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.wma.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.wma.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.wma.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.zones
     * @see https://api.highcharts.com/highstock/plotOptions.wma.zones
     */
    zones?: Array<PlotWmaZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.params
 */
export interface PlotWmaParamsOptions {
    /**
     * (Highstock) The point index which indicator calculations will base. For
     * example using OHLC data, index=2 means the indicator will be calculated
     * using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.params.index
     */
    index?: number;
    /**
     * (Highstock) The base period for indicator calculations. This is the
     * number of data points which are taken into account for the indicator
     * calculations.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.params.period
     */
    period?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events
 */
export interface PlotWmaPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.point
 */
export interface PlotWmaPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.point.events
     */
    events?: PlotWmaPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.animation
 */
export interface PlotWmaStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.halo
 */
export interface PlotWmaStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker
 */
export interface PlotWmaStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states
     */
    states?: PlotWmaStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover.animation
 */
export interface PlotWmaStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover
 */
export interface PlotWmaStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWmaStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.normal
 */
export interface PlotWmaStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states
 */
export interface PlotWmaStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.hover
     */
    hover?: PlotWmaStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.normal
     */
    normal?: PlotWmaStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.select
     */
    select?: PlotWmaStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.select
 */
export interface PlotWmaStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover
 */
export interface PlotWmaStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWmaStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.halo
     */
    halo?: PlotWmaStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover.marker
     */
    marker?: PlotWmaStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.normal
 */
export interface PlotWmaStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states
 */
export interface PlotWmaStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.hover
     */
    hover?: PlotWmaStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.normal
     */
    normal?: PlotWmaStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.select
     */
    select?: PlotWmaStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.animation
 */
export interface PlotWmaStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.halo
 */
export interface PlotWmaStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker
 */
export interface PlotWmaStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states
     */
    states?: PlotWmaStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover.animation
 */
export interface PlotWmaStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover
 */
export interface PlotWmaStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWmaStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.normal
 */
export interface PlotWmaStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states
 */
export interface PlotWmaStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.hover
     */
    hover?: PlotWmaStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.normal
     */
    normal?: PlotWmaStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.select
     */
    select?: PlotWmaStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.select
 */
export interface PlotWmaStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.select
 */
export interface PlotWmaStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWmaStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wma.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.halo
     */
    halo?: PlotWmaStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.wma.states.select.marker
     */
    marker?: PlotWmaStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.wma.tooltip.dateTimeLabelFormats
 */
export interface PlotWmaTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip
 */
export interface PlotWmaTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.wma.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotWmaTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.wma.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.wma.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wma.zones
 * @see https://api.highcharts.com/highstock/plotOptions.wma.zones
 */
export interface PlotWmaZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.wma.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.wma.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.wma.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.wma.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wma.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.wma.zones.value
     */
    value?: number;
}
/**
 * (Highcharts) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.animation
 */
export interface PlotWordcloudAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker
 */
export interface PlotWordcloudConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker
 */
export interface PlotWordcloudConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors
 */
export interface PlotWordcloudConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.endMarker
     */
    endMarker?: PlotWordcloudConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.marker
     */
    marker?: PlotWordcloudConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker
     */
    startMarker?: PlotWordcloudConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker
 */
export interface PlotWordcloudConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highcharts) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragHandle
 */
export interface PlotWordcloudDragDropDragHandleOptions {
    /**
     * (Highcharts) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts) The mouse cursor to use for the drag handles. By default
     * this is intelligently switching between `ew-resize` and `ns-resize`
     * depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.guideBox.default
 */
export interface PlotWordcloudDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.guideBox
 */
export interface PlotWordcloudDragDropGuideBoxOptions {
    /**
     * (Highcharts) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.guideBox.default
     */
    default?: PlotWordcloudDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop
 */
export interface PlotWordcloudDragDropOptions {
    /**
     * (Highcharts) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragHandle
     */
    dragHandle?: PlotWordcloudDragDropDragHandleOptions;
    /**
     * (Highcharts) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts) The X precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts) The Y precision value to drag to for this series. Set to 0
     * to disable. By default this is disabled, except for category axes, where
     * the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts) Group the points by a property. Points with the same
     * property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.guideBox
     */
    guideBox?: (PlotWordcloudDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.events
 */
export interface PlotWordcloudEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.label
 * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.label
 * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.label
 */
export interface PlotWordcloudLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.lastPrice
 */
export interface PlotWordcloudLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotWordcloudLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.lastVisiblePrice
 */
export interface PlotWordcloudLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotWordcloudLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts) A word cloud is a visualization of a set of words, where the
 * size and placement of a word is determined by how it is weighted.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `wordcloud` series are defined in plotOptions.wordcloud.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud
 */
export interface PlotWordcloudOptions {
    /**
     * (Highcharts) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.animation
     */
    animation?: PlotWordcloudAnimationOptions;
    /**
     * (Highcharts) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.className
     */
    className?: string;
    clip?: boolean;
    /**
     * (Highcharts) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) When using automatic point colors pulled
     * from the global colors or series-specific plotOptions.column.colors
     * collections, this option determines whether the chart should receive one
     * color per series or one color per point.
     *
     * In styled mode, the `colors` or `series.colors` arrays are not supported,
     * and instead this option gives the points individual color class names on
     * the form `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.colors
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.colors
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.connectors
     */
    connectors?: PlotWordcloudConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) When the series contains less points than
     * the crop threshold, all points are drawn, event if the points fall
     * outside the visible plot area at the current zoom. The advantage of
     * drawing all points (including markers and columns), is that animation is
     * performed on updates. On the other hand, when the series contains more
     * points than the crop threshold, the series data is cropped to only
     * contain points that fall within the plot area. The advantage of cropping
     * away invisible points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.cropThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highcharts) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highcharts) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.description
     */
    description?: string;
    /**
     * (Highcharts) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.dragDrop
     */
    dragDrop?: PlotWordcloudDragDropOptions;
    /**
     * (Highcharts) 3D columns only. The width of the colored edges.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.edgeWidth
     */
    edgeWidth?: number;
    /**
     * (Highcharts) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.events
     */
    events?: PlotWordcloudEventsOptions;
    /**
     * (Highcharts) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts) An array specifying which option maps to which key in the
     * data point array. This makes it convenient to work with unstructured data
     * arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.label
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.label
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.label
     */
    label?: PlotWordcloudLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.lastPrice
     */
    lastPrice?: PlotWordcloudLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.lastVisiblePrice
     */
    lastVisiblePrice?: PlotWordcloudLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts) The word with the largest weight will have a font size equal
     * to this value. The font size of a word is the ratio between its weight
     * and the largest occuring weight, multiplied with the value of
     * maxFontSize.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.maxFontSize
     */
    maxFontSize?: number;
    /**
     * (Highcharts) A threshold determining the minimum font size that can be
     * applied to a word.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.minFontSize
     */
    minFontSize?: number;
    /**
     * (Highcharts) This option decides which algorithm is used for placement,
     * and rotation of a word. The choice of algorith is therefore a crucial
     * part of the resulting layout of the wordcloud. It is possible for users
     * to add their own custom placement strategies for use in word cloud. Read
     * more about it in our documentation
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.placementStrategy
     */
    placementStrategy?: string;
    /**
     * (Highcharts) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point
     */
    point?: PlotWordcloudPointOptions;
    /**
     * (Highcharts) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts) Rotation options for the words in the wordcloud.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.rotation
     */
    rotation?: PlotWordcloudRotationOptions;
    /**
     * (Highcharts) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highcharts) If set to `true`, the accessibility module will skip past
     * the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts) Spiral used for placing a word after the initial position
     * experienced a collision with either another word or the borders. It is
     * possible for users to add their own custom spiralling algorithms for use
     * in word cloud. Read more about it in our documentation
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.spiral
     */
    spiral?: string;
    /**
     * (Highcharts) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states
     */
    states?: PlotWordcloudStatesOptions;
    /**
     * (Highcharts) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts) CSS styles for the words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip
     */
    tooltip?: PlotWordcloudTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wordcloud.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events
 */
export interface PlotWordcloudPointEventsOptions {
    /**
     * (Highcharts) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts) Callback that fires when the point is dropped. The
     * parameters passed are the same as for drag. To stop the default drop
     * action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts) Fires when the point is removed using the `.remove()`
     * method. One parameter, `event`, is passed to the function. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts) Fires when the point is unselected either programmatically
     * or following a click on the point. One parameter, `event`, is passed to
     * the function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point
 */
export interface PlotWordcloudPointOptions {
    /**
     * (Highcharts) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.point.events
     */
    events?: PlotWordcloudPointEventsOptions;
}
/**
 * (Highcharts) Rotation options for the words in the wordcloud.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.rotation
 */
export interface PlotWordcloudRotationOptions {
    /**
     * (Highcharts) The smallest degree of rotation for a word.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.rotation.from
     */
    from?: number;
    /**
     * (Highcharts) The number of possible orientations for a word, within the
     * range of `rotation.from` and `rotation.to`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.rotation.orientations
     */
    orientations?: number;
    /**
     * (Highcharts) The largest degree of rotation for a word.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.rotation.to
     */
    to?: number;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.hover.animation
 */
export interface PlotWordcloudStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.hover
 */
export interface PlotWordcloudStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWordcloudStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wordcloud.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.wordcloud.states.normal
 */
export interface PlotWordcloudStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wordcloud.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states
 */
export interface PlotWordcloudStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.hover
     */
    hover?: PlotWordcloudStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wordcloud.states.normal
     */
    normal?: PlotWordcloudStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.select
     */
    select?: PlotWordcloudStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.select.animation
 */
export interface PlotWordcloudStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.select
 */
export interface PlotWordcloudStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotWordcloudStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.wordcloud.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.tooltip.dateTimeLabelFormats
 */
export interface PlotWordcloudTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip
 */
export interface PlotWordcloudTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotWordcloudTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts) The name of a symbol to use for the border around the
     * tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts) How many decimals to show in each series' y value. This is
     * overridable in each series' tooltip options object. The default is to
     * preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.wordcloud.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.wordcloud.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.wordcloud.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock, Gantt) Enable or disable the initial animation when a
 * series is displayed. The animation can also be set as a configuration object.
 * Please note that this option only applies to the initial animation of the
 * series itself. For other animations, see chart.animation and the animation
 * parameter under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.animation
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.animation
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.animation
 */
export interface PlotXrangeAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker
 */
export interface PlotXrangeConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker
 */
export interface PlotXrangeConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors
 */
export interface PlotXrangeConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.endMarker
     */
    endMarker?: PlotXrangeConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.marker
     */
    marker?: PlotXrangeConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker
     */
    startMarker?: PlotXrangeConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker
 */
export interface PlotXrangeConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataGrouping
 */
export interface PlotXrangeDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. Defaults to `10`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highcharts, Highstock, Gantt) A declarative filter for which data labels to
 * display. The declarative filter is designed for use when callback functions
 * are not available, like when the chart options require a pure JSON structure
 * or for use with graphical editors. For programmatic control, use the
 * `formatter` instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.filter
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.filter
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.filter
 */
export interface PlotXrangeDataLabelsFilterOptions {
    /**
     * (Highcharts, Highstock, Gantt) The operator to compare by. Can be one of
     * `>`, `<`, `>=`, `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.filter.operator
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.filter.operator
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highcharts, Highstock, Gantt) The point property to filter by. Point
     * options are passed directly to properties, additionally there are `y`
     * value, `percentage` and others listed under Point members.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.filter.property
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.filter.property
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highcharts, Highstock, Gantt) The value to compare against.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.filter.value
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.filter.value
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the series data labels, appearing
 * next to each data point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels
 */
export interface PlotXrangeDataLabelsOptions {
    /**
     * (Highcharts, Highstock, Gantt) The alignment of the data label compared
     * to the point. If `right`, the right side of the label should be touching
     * the point. For points with an extent, like columns, the alignments also
     * dictates how to align it inside the box, as given with the inside option.
     * Can be one of `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.align
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.align
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Whether to allow data labels to overlap.
     * To make the labels less sensitive for overlapping, the dataLabels.padding
     * can be set to 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.allowOverlap
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.allowOverlap
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) The background color or gradient for the
     * data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.backgroundColor
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.backgroundColor
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) The border color for the data label.
     * Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The border radius in pixels for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The border width in pixels for the data
     * label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A class name for the data label.
     * Particularly in styled mode, this can be used to give each series' or
     * point's data label unique styling. In addition to this option, a default
     * color class name is added so that we can give the labels a contrast text
     * shadow.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.className
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.className
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text color for the data labels.
     * Defaults to `undefined`. For certain series types, like column or map,
     * the data labels can be drawn inside the points. In this case the data
     * label will be drawn with maximum contrast by default. Additionally, it
     * will be given a `text-outline` style with the opposite color, to further
     * increase the contrast. This can be overridden by setting the
     * `text-outline` style to `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.color
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.color
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) Whether to hide data labels that are
     * outside the plot area. By default, the data label is moved inside the
     * plot area according to the overflow option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.crop
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.crop
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A declarative filter for which data labels
     * to display. The declarative filter is designed for use when callback
     * functions are not available, like when the chart options require a pure
     * JSON structure or for use with graphical editors. For programmatic
     * control, use the `formatter` instead, and return `undefined` to disable a
     * single data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.filter
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.filter
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.filter
     */
    filter?: PlotXrangeDataLabelsFilterOptions;
    /**
     * (Highcharts, Highstock, Gantt) A format string for the data label.
     * Available variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.format
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.format
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock, Gantt) The default formatter for X-range data
     * labels displays the percentage of the partial fill amount.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.formatter
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.formatter
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highcharts, Highstock, Gantt) For points with an extent, like columns or
     * map areas, whether to align the data label inside the box or to the
     * actual value point. Defaults to `false` in most cases, `true` in stacked
     * columns.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.inside
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.inside
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) How to handle data labels that flow
     * outside the plot area. The default is `"justify"`, which aligns them
     * inside the plot area. For columns and bars, this means it will be moved
     * inside the bar. To display data labels outside the plot area, set `crop`
     * to `false` and `overflow` to `"allow"`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.overflow
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.overflow
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Highstock, Gantt) When either the `borderWidth` or the
     * `backgroundColor` is set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.padding
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.padding
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Text rotation in degrees. Note that due to
     * a more complex structure, backgrounds, borders and padding will be lost
     * on a rotated data label.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.rotation
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.rotation
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) The shadow of the box. Works best with
     * `borderWidth` or `backgroundColor`. Since 2.3 the shadow can be an object
     * configuration containing `color`, `offsetX`, `offsetY`, `opacity` and
     * `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.shadow
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock, Gantt) The name of a symbol to use for the border
     * around the label. Symbols are predefined functions on the Renderer
     * object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.shape
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.shape
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highcharts, Highstock, Gantt) Styles for the label. The default `color`
     * setting is `"contrast"`, which is a pseudo color that Highcharts picks up
     * and applies the maximum contrast to the underlying point item, for
     * example the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.style
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.style
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.useHTML
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.useHTML
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) The vertical alignment of a data label.
     * Can be one of `top`, `middle` or `bottom`. The default value depends on
     * the data, for instance in a column chart, the label is above positive
     * values and below negative values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.verticalAlign
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.verticalAlign
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) The x position offset of the label
     * relative to the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.x
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.x
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) The y position offset of the label
     * relative to the point in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.y
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.y
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.y
     */
    y?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) The Z index of the data labels. The
     * default Z index puts it above the series. Use a Z index of 2 to display
     * it behind the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels.zIndex
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragHandle
 */
export interface PlotXrangeDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Gantt) The class name of the drag handles.
     * Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The mouse cursor to use for the drag
     * handles. By default this is intelligently switching between `ew-resize`
     * and `ns-resize` depending on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Gantt) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Function to define the SVG path to use for
     * the drag handles. Takes the point as argument. Should return an SVG path
     * in array format. The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.guideBox.default
 */
export interface PlotXrangeDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Gantt) CSS class name of the guide box in this
     * state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Gantt) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Style options for the guide box. The guide box
 * has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.guideBox
 */
export interface PlotXrangeDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Gantt) Style options for the guide box default
     * state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.guideBox.default
     */
    default?: PlotXrangeDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Gantt) The draggable-points module allows points to
 * be moved around or modified in the chart. In addition to the options
 * mentioned under the `dragDrop` API structure, the module fires three events,
 * point.dragStart, point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop
 */
export interface PlotXrangeDragDropOptions {
    /**
     * (Highcharts, Highstock, Gantt) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Allow x value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.draggableX1
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.draggableX1
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.draggableX1
     */
    draggableX1?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Allow x2 value to be dragged individually.
     * Requires `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.draggableX2
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.draggableX2
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.draggableX2
     */
    draggableX2?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Enable dragging in the Y dimension. Note
     * that this is not supported for TreeGrid axes (the default axis type in
     * Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragHandle
     */
    dragHandle?: PlotXrangeDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Gantt) Set the maximum X value the points can be
     * moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Gantt) Set the maximum Y value the points can be
     * moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Gantt) Set the minimum X value the points can be
     * moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Gantt) Set the minimum Y value the points can be
     * moved to.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Gantt) The X precision value to drag to for this
     * series. Set to 0 to disable. By default this is disabled, except for
     * category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Gantt) The Y precision value to drag to for this
     * series. Set to 0 to disable. By default this is disabled, except for
     * category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Gantt) The amount of pixels to drag the pointer
     * before it counts as a drag operation. This prevents drag/drop to fire
     * when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Gantt) Group the points by a property. Points
     * with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Gantt) Style options for the guide box. The guide
     * box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.guideBox
     */
    guideBox?: (PlotXrangeDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Gantt) Update points as they are dragged. If
     * false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) General event handlers for the series items.
 * These event hooks can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.events
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.events
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.events
 */
export interface PlotXrangeEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the checkbox next to the
     * series' name in the legend is clicked. One parameter, `event`, is passed
     * to the function. The state of the checkbox is found by `event.checked`.
     * The checked item is found by `event.item`. Return `false` to prevent the
     * default action which is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.events.checkboxClick
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.events.checkboxClick
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the series is clicked. One
     * parameter, `event`, is passed to the function, containing common event
     * information. Additionally, `event.point` holds a pointer to the nearest
     * point on the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.events.click
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the series is hidden after
     * chart generation time, either by clicking the legend item or by calling
     * `.hide()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.events.hide
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.events.hide
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.events.hide
     */
    hide?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the legend item belonging to
     * the series is clicked. One parameter, `event`, is passed to the function.
     * The default action is to toggle the visibility of the series. This can be
     * prevented by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.events.legendItemClick
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.events.legendItemClick
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the mouse leaves the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information. If the stickyTracking option is true, `mouseOut` doesn't
     * happen before the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.events.mouseOut
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the mouse enters the graph. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.events.mouseOver
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the series is shown after chart
     * generation time, either by clicking the legend item or by calling
     * `.show()`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.events.show
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.events.show
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.label
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.label
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.label
 */
export interface PlotXrangeLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.lastPrice
 */
export interface PlotXrangeLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotXrangeLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.lastVisiblePrice
 */
export interface PlotXrangeLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotXrangeLastVisiblePriceLabelOptions;
}
/**
 * (Highcharts, Highstock, Gantt) The X-range series displays ranges on the X
 * axis, typically time intervals with a start and end date.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `xrange` series are defined in plotOptions.xrange.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange
 * @see https://api.highcharts.com/highstock/plotOptions.xrange
 * @see https://api.highcharts.com/gantt/plotOptions.xrange
 */
export interface PlotXrangeOptions {
    /**
     * (Highmaps) Whether all areas of the map defined in `mapData` should be
     * rendered. If `true`, areas which don't correspond to a data point, are
     * rendered as `null` points. If `false`, those areas are skipped.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.xrange.allAreas
     */
    allAreas?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Allow this series' points to be selected
     * by clicking on the graphic (columns, point markers, pie slices, map areas
     * etc).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.allowPointSelect
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.allowPointSelect
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Enable or disable the initial animation
     * when a series is displayed. The animation can also be set as a
     * configuration object. Please note that this option only applies to the
     * initial animation of the series itself. For other animations, see
     * chart.animation and the animation parameter under the API methods. The
     * following properties are supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.animation
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.animation
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotXrangeAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) For some series, there is a limit that
     * shuts down initial animation by default when the total number of points
     * in the chart is too high. For example, for a column chart and its
     * derivatives, animation doesn't run if there is more than 250 points
     * totally. To disable this cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.animationLimit
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.animationLimit
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highcharts, Highstock, Gantt) The color of the border surrounding each
     * column or bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The corner radius of the border
     * surrounding each column or bar.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.borderRadius
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.borderRadius
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width of the border surrounding each
     * column or bar. Defaults to `1` when there is room for a border, but to
     * `0` when the columns are so dense that a border would cover the next
     * column.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.borderWidth
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.borderWidth
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) An additional class name to apply to the
     * series' graphical elements. This option does not replace default class
     * names of the graphical element.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.className
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.className
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Disable this option to allow series
     * rendering in the whole plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.clip
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.clip
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.clip
     */
    clip?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) The main color of the series. In line type
     * series it applies to the line and the point markers unless otherwise
     * specified. In bar type series it applies to the bars unless a color is
     * specified per point. The default value is pulled from the
     * `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.color
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.color
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highmaps) Set this option to `false` to prevent a series from connecting
     * to the global color axis. This will cause the series to have its own
     * legend item.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.xrange.colorAxis
     */
    colorAxis?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) In an X-range series, this option makes
     * all points of the same Y-axis category the same color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.colorByPoint
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.colorByPoint
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.colorByPoint
     */
    colorByPoint?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Styled mode only. A specific color index
     * to use for the series, so its graphic representations are given the class
     * name `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.colorIndex
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.colorIndex
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) A series specific or series type specific
     * color set to apply instead of the global colors when colorByPoint is
     * true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.colors
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.colors
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.colors
     */
    colors?: Array<ColorString>;
    /**
     * (Highstock) Compare the values of the series against the first non-null,
     * non- zero value in the visible range. The y axis will show percentage or
     * absolute change depending on whether `compare` is set to `"percent"` or
     * `"value"`. When this is applied to multiple series, it allows comparing
     * the development of the series against each other. Adds a `change` field
     * to every point object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.compare
     */
    compare?: string;
    /**
     * (Highstock) When compare is `percent`, this option dictates whether to
     * use 0 or 100 as the base of comparison.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.compareBase
     */
    compareBase?: (0|100);
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.compareStart
     */
    compareStart?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.connectors
     */
    connectors?: PlotXrangeConnectorsOptions;
    /**
     * (Highcharts, Highstock, Gantt) You can set the cursor to "pointer" if you
     * have click events attached to the series, to signal to the user that the
     * points and lines can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.cursor
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.cursor
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataGrouping
     */
    dataGrouping?: PlotXrangeDataGroupingOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the series data labels,
     * appearing next to each data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dataLabels
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dataLabels
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dataLabels
     */
    dataLabels?: PlotXrangeDataLabelsOptions;
    /**
     * (Highcharts, Highstock, Gantt) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.description
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.description
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Gantt) The draggable-points module allows points
     * to be moved around or modified in the chart. In addition to the options
     * mentioned under the `dragDrop` API structure, the module fires three
     * events, point.dragStart, point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.dragDrop
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.dragDrop
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.dragDrop
     */
    dragDrop?: PlotXrangeDragDropOptions;
    /**
     * (Highcharts, Highstock, Gantt) Enable or disable the mouse tracking for a
     * specific series. This includes point tooltips and click events on graphs
     * and points. For large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.enableMouseTracking
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.enableMouseTracking
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) General event handlers for the series
     * items. These event hooks can also be attached to the series at run time
     * using the `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.events
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.events
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.events
     */
    events?: PlotXrangeEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) By default, series are exposed to screen
     * readers as regions. By enabling this option, the series element itself
     * will be exposed in the same way as the data points. This is useful if the
     * series is not used as a grouping entity in the chart, but you still want
     * to attach a description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.exposeElementToA11y
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.exposeElementToA11y
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to group non-stacked columns or to
     * let them render independent of each other. Non-grouped columns will be
     * laid out individually and overlap each other.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.grouping
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.grouping
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.grouping
     */
    grouping?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each value groups, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.groupPadding
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.groupPadding
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.groupPadding
     */
    groupPadding?: number;
    /**
     * (Highcharts) The spacing between columns on the Z Axis in a 3D chart.
     * Requires `highcharts-3d.js`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.groupZPadding
     */
    groupZPadding?: number;
    /**
     * (Highmaps) What property to join the `mapData` to the value data. For
     * example, if joinBy is "code", the mapData items with a specific code is
     * merged into the data with the same code. For maps loaded from GeoJSON,
     * the keys may be held in each point's `properties` object.
     *
     * The joinBy option can also be an array of two values, where the first
     * points to a key in the `mapData`, and the second points to another key in
     * the `data`.
     *
     * When joinBy is `null`, the map items are joined by their position in the
     * array, which performs much better in maps with many data points. This is
     * the recommended option if you are printing more than a thousand data
     * points and have a backend that can preprocess the data into a parallel
     * array of the mapData.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.xrange.joinBy
     */
    joinBy?: (string|Array<string>);
    /**
     * (Highcharts, Highstock, Gantt) An array specifying which option maps to
     * which key in the data point array. This makes it convenient to work with
     * unstructured data arrays from different sources.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.keys
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.keys
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.keys
     */
    keys?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.label
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.label
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.label
     */
    label?: PlotXrangeLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.lastPrice
     */
    lastPrice?: PlotXrangeLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.lastVisiblePrice
     */
    lastVisiblePrice?: PlotXrangeLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock, Gantt) The id of another series to link to.
     * Additionally, the value can be ":previous" to link to the previous
     * series. When two series are linked, only the first one appears in the
     * legend. Toggling the visibility of this also toggles the linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highcharts, Highstock, Gantt) The maximum allowed pixel width for a
     * column, translated to the height of a bar in a bar chart. This prevents
     * the columns from becoming too wide when there is a small number of points
     * in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.maxPointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.maxPointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.maxPointWidth
     */
    maxPointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The minimal height for a column or width
     * for a bar. By default, 0 values are not shown. To visualize a 0 (or close
     * to zero) point, set the minimal point length to a pixel value like 3\. In
     * stacked column charts, minPointLength might not be respected for tightly
     * packed values.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.minPointLength
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.minPointLength
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.minPointLength
     */
    minPointLength?: number;
    /**
     * (Highstock) Options for the corresponding navigator series if
     * `showInNavigator` is `true` for this series. Available options are the
     * same as any series, documented at plotOptions and series.
     *
     * These options are merged with options in navigator.series, and will take
     * precedence if the same option is defined both places.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.navigatorOptions
     */
    navigatorOptions?: PlotSeriesOptions;
    /**
     * (Highcharts, Highstock, Gantt) A partial fill for each point, typically
     * used to visualize how much of a task is performed. The partial fill
     * object can be set either on series or point level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.partialFill
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.partialFill
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.partialFill
     */
    partialFill?: PlotXrangePartialFillOptions;
    /**
     * (Highcharts, Highstock, Gantt) Properties for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point
     */
    point?: PlotXrangePointOptions;
    /**
     * (Highcharts, Highstock, Gantt) Same as
     * accessibility.pointDescriptionFormatter, but for an individual series.
     * Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.pointDescriptionFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.pointDescriptionFormatter
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Padding between each column or bar, in x
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.pointPadding
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.pointPadding
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.pointPadding
     */
    pointPadding?: number;
    pointRange?: number;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * each column or bar. When `null`, the width is calculated from the
     * `pointPadding` and `groupPadding`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.pointWidth
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.pointWidth
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether to select the series initially. If
     * `showCheckbox` is true, the checkbox next to the series name in the
     * legend will be checked for a selected series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.selected
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.selected
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to apply a drop shadow to the
     * graph line. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.shadow
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.shadow
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highcharts, Highstock, Gantt) If true, a checkbox is displayed next to
     * the legend item to allow selecting the series. The state of the checkbox
     * is determined by the `selected` option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.showCheckbox
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.showCheckbox
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to display this particular series
     * or series type in the legend. The default value is `true` for standalone
     * series, `false` for linked series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.showInLegend
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.showInLegend
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) Whether or not to show the series in the navigator. Takes
     * precedence over navigator.baseSeries if defined.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.showInNavigator
     */
    showInNavigator?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If set to `true`, the accessibility module
     * will skip past the points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.skipKeyboardNavigation
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.skipKeyboardNavigation
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A wrapper object for all the series
     * options in specific states.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.states
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.states
     */
    states?: PlotXrangeStatesOptions;
    /**
     * (Highcharts, Highstock, Gantt) Sticky tracking of mouse events. When
     * true, the `mouseOut` event on a series isn't triggered until the mouse
     * moves over another series, or out of the plot area. When false, the
     * `mouseOut` event on a series is triggered when the mouse leaves the area
     * around the series' graph or markers. This also implies the tooltip when
     * not shared. When `stickyTracking` is false and `tooltip.shared` is false,
     * the tooltip will be hidden when moving the mouse between series. Defaults
     * to true for line and area type series, but to false for columns, pies
     * etc.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.stickyTracking
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.stickyTracking
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A configuration object for the tooltip
     * rendering of each single series. Properties are inherited from tooltip,
     * but only the following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip
     */
    tooltip?: PlotXrangeTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highcharts, Highstock, Gantt) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.visible
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.visible
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.xrange.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.zones
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.zones
     */
    zones?: Array<PlotXrangeZonesOptions>;
}
/**
 * (Highcharts, Highstock, Gantt) A partial fill for each point, typically used
 * to visualize how much of a task is performed. The partial fill object can be
 * set either on series or point level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.partialFill
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.partialFill
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.partialFill
 */
export interface PlotXrangePartialFillOptions {
    /**
     * (Highcharts, Highstock, Gantt) The fill color to be used for partial
     * fills. Defaults to a darker shade of the point color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.partialFill.fill
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.partialFill.fill
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.partialFill.fill
     */
    fill?: (ColorString|GradientColorObject|PatternObject);
}
/**
 * (Highcharts, Highstock, Gantt) Events for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events
 */
export interface PlotXrangePointEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires when a point is clicked. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events.click
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events.click
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) Callback that fires while dragging a
     * point. The mouse event is passed in as parameter. The original data can
     * be accessed from `e.origin`, and the new point values can be accessed
     * from `e.newPoints`. If there is only a single point being updated, it can
     * be accessed from `e.newPoint` for simplicity, and its ID can be accessed
     * from `e.newPointId`. The `this` context is the point being dragged. To
     * stop the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events.drag
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events.drag
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) Callback that fires when starting to drag
     * a point. The mouse event object is passed in as an argument. If a drag
     * handle is used, `e.updateProp` is set to the data property being dragged.
     * The `this` context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events.dragStart
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events.dragStart
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) Callback that fires when the point is
     * dropped. The parameters passed are the same as for drag. To stop the
     * default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events.drop
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events.drop
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the mouse leaves the area close
     * to the point. One parameter, `event`, is passed to the function,
     * containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events.mouseOut
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events.mouseOut
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the mouse enters the area close
     * to the point. One parameter, `event`, is passed to the function,
     * containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events.mouseOver
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events.mouseOver
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the point is removed using the
     * `.remove()` method. One parameter, `event`, is passed to the function.
     * Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events.remove
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events.remove
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the point is selected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events.select
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events.select
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the point is unselected either
     * programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events.unselect
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events.unselect
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events.update
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events.update
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Properties for each single point.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.point
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.point
 */
export interface PlotXrangePointOptions {
    /**
     * (Highcharts, Highstock, Gantt) Events for each single point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.point.events
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.point.events
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.point.events
     */
    events?: PlotXrangePointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.hover.animation
 */
export interface PlotXrangeStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the hovered point. These settings
 * override the normal state options when a point is moused over or touched.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.states.hover
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.hover
 */
export interface PlotXrangeStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotXrangeStatesHoverAnimationOptions);
    /**
     * (Highcharts, Gantt) A specific border color for the hovered point.
     * Defaults to inherit the normal state border color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.hover.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.xrange.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) How much to brighten the point on
     * interaction. Requires the main color to be defined in hex or rgb(a)
     * format.
     *
     * In styled mode, the hover brightening is by default replaced with a
     * fill-opacity set in the `.highcharts-point:hover` rule.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.hover.brightness
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.states.hover.brightness
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highcharts, Gantt) A specific color for the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.hover.color
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.hover.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.states.hover.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.hover.enabled
     */
    enabled?: boolean;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.xrange.states.normal
 */
export interface PlotXrangeStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.xrange.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Gantt) A wrapper object for all the series options in
 * specific states.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.states
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.states
 */
export interface PlotXrangeStatesOptions {
    /**
     * (Highcharts, Highstock, Gantt) Options for the hovered point. These
     * settings override the normal state options when a point is moused over or
     * touched.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.states.hover
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.hover
     */
    hover?: PlotXrangeStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.xrange.states.normal
     */
    normal?: PlotXrangeStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Gantt) Options for the selected point. These
     * settings override the normal state options when a point is selected.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.states.select
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.select
     */
    select?: PlotXrangeStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.select.animation
 */
export interface PlotXrangeStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Options for the selected point. These settings
 * override the normal state options when a point is selected.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.states.select
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.select
 */
export interface PlotXrangeStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotXrangeStatesSelectAnimationOptions);
    /**
     * (Highcharts, Highstock, Gantt) A specific border color for the selected
     * point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.select.borderColor
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.states.select.borderColor
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.xrange.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A specific color for the selected point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.select.color
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.states.select.color
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.select.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) Enable separate styles for the hovered
     * series to visualize that the user hovers either the series itself or the
     * legend. .
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.states.select.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.states.select.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.dateTimeLabelFormats
 */
export interface PlotXrangeTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highcharts, Highstock, Gantt) A configuration object for the tooltip
 * rendering of each single series. Properties are inherited from tooltip, but
 * only the following properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip
 * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip
 */
export interface PlotXrangeTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotXrangeTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    distance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the tooltip should follow the
     * mouse as it moves across columns, pie slices and other point types with
     * an extent. By default it behaves this way for scatter, bubble and pie
     * series by override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.followPointer
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.followPointer
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether the tooltip should update as the
     * finger moves on a touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.followTouchMove
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.footerFormat
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock, Gantt) The HTML of the tooltip header line.
     * Variables are enclosed by curly brackets. Available variables are
     * `point.key`, `series.name`, `series.color` and other members from the
     * `point` and `series` objects. The `point.key` variable contains the
     * category name, x value or datetime string depending on the type of axis.
     * For datetime axes, the `point.key` date format can be set using
     * `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.headerFormat
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock, Gantt) The name of a symbol to use for the border
     * around the tooltip header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.headerShape
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.headerShape
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock, Gantt) The number of milliseconds to wait until
     * the tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.hideDelay
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether to allow the tooltip to render
     * outside the chart's SVG element box. By default (`false`), the tooltip is
     * rendered within the chart's SVG element, which results in the tooltip
     * being aligned inside the chart area. For small charts, this may result in
     * clipping or overlapping. When `true`, a separate SVG element is created
     * and overlaid on the page, allowing the tooltip to be aligned inside the
     * page itself.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.outside
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.outside
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.padding
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.padding
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock, Gantt) The HTML of the point's line in the
     * tooltip. Variables are enclosed by curly brackets. Available variables
     * are point.x, point.y, series. name and series.color and other properties
     * on the same form. Furthermore, `point.y` can be extended by the
     * `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can also
     * be overridden for each series, which makes it a good hook for displaying
     * units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.pointFormat
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock, Gantt) A callback function for formatting the
     * HTML output for a single point in the tooltip. Like the `pointFormat`
     * string, but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.pointFormatter
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) How many decimals to show in each series'
     * y value. This is overridable in each series' tooltip options object. The
     * default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.valueDecimals
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) A string to prepend to each series' y
     * value. Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.valuePrefix
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock, Gantt) A string to append to each series' y
     * value. Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.valueSuffix
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.xrange.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.xrange.zones
 * @see https://api.highcharts.com/highstock/plotOptions.xrange.zones
 */
export interface PlotXrangeZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.xrange.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.xrange.zones.value
     */
    value?: number;
}
/**
 * (Highstock) Enable or disable the initial animation when a series is
 * displayed. The animation can also be set as a configuration object. Please
 * note that this option only applies to the initial animation of the series
 * itself. For other animations, see chart.animation and the animation parameter
 * under the API methods. The following properties are supported:
 *
 * (see online documentation for example)
 *
 * Due to poor performance, animation is disabled in old IE browsers for several
 * chart types.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.animation
 */
export interface PlotZigzagAnimationOptions {
    duration?: number;
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker
 */
export interface PlotZigzagConnectorsEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker
 */
export interface PlotZigzagConnectorsMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Override Pathfinder connector options for a series. Requires
 * Highcharts Gantt to be loaded.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors
 */
export interface PlotZigzagConnectorsOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.endMarker
     */
    endMarker?: PlotZigzagConnectorsEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.marker
     */
    marker?: PlotZigzagConnectorsMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker
     */
    startMarker?: PlotZigzagConnectorsStartMarkerOptions;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker
 */
export interface PlotZigzagConnectorsStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors.startMarker.width
     */
    width?: number;
}
/**
 * (Highstock) Data grouping is the concept of sampling the data values into
 * larger blocks in order to ease readability and increase performance of the
 * JavaScript charts. Highstock by default applies data grouping when the points
 * become closer than a certain pixel value, determined by the `groupPixelWidth`
 * option.
 *
 * If data grouping is applied, the grouping information of grouped points can
 * be read from the Point.dataGroup. If point options other than the data itself
 * are set, for example `name` or `color` or custom properties, the grouping
 * logic doesn't know how to group it. In this case the options of the first
 * point instance are copied over to the group point. This can be altered
 * through a custom `approximation` callback function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataGrouping
 */
export interface PlotZigzagDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
/**
 * (Highstock) A declarative filter for which data labels to display. The
 * declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the `formatter`
 * instead, and return `undefined` to disable a single data label.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.filter
 */
export interface PlotZigzagDataLabelsFilterOptions {
    /**
     * (Highstock) The operator to compare by. Can be one of `>`, `<`, `>=`,
     * `<=`, `==`, and `===`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.filter.operator
     */
    operator?: ("=="|"==="|">"|">="|"<"|"<=");
    /**
     * (Highstock) The point property to filter by. Point options are passed
     * directly to properties, additionally there are `y` value, `percentage`
     * and others listed under Point members.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.filter.property
     */
    property?: string;
    /**
     * (Highstock) The value to compare against.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.filter.value
     */
    value?: any;
}
/**
 * (Highstock) Options for the series data labels, appearing next to each data
 * point.
 *
 * Since v6.2.0, multiple data labels can be applied to each single point by
 * defining them as an array of configs.
 *
 * In styled mode, the data labels can be styled with the
 * `.highcharts-data-label-box` and `.highcharts-data-label` class names (see
 * example).
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels
 */
export interface PlotZigzagDataLabelsOptions {
    /**
     * (Highstock) The alignment of the data label compared to the point. If
     * `right`, the right side of the label should be touching the point. For
     * points with an extent, like columns, the alignments also dictates how to
     * align it inside the box, as given with the inside option. Can be one of
     * `left`, `center` or `right`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) Whether to allow data labels to overlap. To make the labels
     * less sensitive for overlapping, the dataLabels.padding can be set to 0.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highstock) The background color or gradient for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the data label. Defaults to `undefined`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border radius in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width in pixels for the data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A class name for the data label. Particularly in styled mode,
     * this can be used to give each series' or point's data label unique
     * styling. In addition to this option, a default color class name is added
     * so that we can give the labels a contrast text shadow.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.className
     */
    className?: string;
    /**
     * (Highstock) The text color for the data labels. Defaults to `undefined`.
     * For certain series types, like column or map, the data labels can be
     * drawn inside the points. In this case the data label will be drawn with
     * maximum contrast by default. Additionally, it will be given a
     * `text-outline` style with the opposite color, to further increase the
     * contrast. This can be overridden by setting the `text-outline` style to
     * `none` in the `dataLabels.style` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.color
     */
    color?: ColorString;
    /**
     * (Highstock) Whether to hide data labels that are outside the plot area.
     * By default, the data label is moved inside the plot area according to the
     * overflow option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.crop
     */
    crop?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to defer displaying the data
     * labels until the initial series animation has finished.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.dataLabels.defer
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.defer
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.dataLabels.defer
     */
    defer?: boolean;
    /**
     * (Highstock) Enable or disable the data labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) A declarative filter for which data labels to display. The
     * declarative filter is designed for use when callback functions are not
     * available, like when the chart options require a pure JSON structure or
     * for use with graphical editors. For programmatic control, use the
     * `formatter` instead, and return `undefined` to disable a single data
     * label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.filter
     */
    filter?: PlotZigzagDataLabelsFilterOptions;
    /**
     * (Highstock) A format string for the data label. Available variables are
     * the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.format
     */
    format?: string;
    /**
     * (Highstock) Callback JavaScript function to format the data label. Note
     * that if a `format` is defined, the format takes precedence and the
     * formatter is ignored. Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.formatter
     */
    formatter?: FormatterCallbackFunction<SeriesDataLabelsFormatterContextObject>;
    /**
     * (Highstock) For points with an extent, like columns or map areas, whether
     * to align the data label inside the box or to the actual value point.
     * Defaults to `false` in most cases, `true` in stacked columns.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.inside
     */
    inside?: boolean;
    /**
     * (Highstock) How to handle data labels that flow outside the plot area.
     * The default is `"justify"`, which aligns them inside the plot area. For
     * columns and bars, this means it will be moved inside the bar. To display
     * data labels outside the plot area, set `crop` to `false` and `overflow`
     * to `"allow"`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highstock) When either the `borderWidth` or the `backgroundColor` is
     * set, this is the padding within the box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.padding
     */
    padding?: number;
    /**
     * (Highstock) Text rotation in degrees. Note that due to a more complex
     * structure, backgrounds, borders and padding will be lost on a rotated
     * data label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.rotation
     */
    rotation?: number;
    /**
     * (Highstock) The shadow of the box. Works best with `borderWidth` or
     * `backgroundColor`. Since 2.3 the shadow can be an object configuration
     * containing `color`, `offsetX`, `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) The name of a symbol to use for the border around the label.
     * Symbols are predefined functions on the Renderer object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.shape
     */
    shape?: string;
    /**
     * (Highstock) Styles for the label. The default `color` setting is
     * `"contrast"`, which is a pseudo color that Highcharts picks up and
     * applies the maximum contrast to the underlying point item, for example
     * the bar in a bar chart.
     *
     * The `textOutline` is a pseudo property that applies an outline of the
     * given width with the given color, which by default is the maximum
     * contrast to the text. So a bright text color will result in a black text
     * outline for maximum readability on a mixed background. In some cases,
     * especially with grayscale text, the text outline doesn't work well, in
     * which cases it can be disabled by setting it to `"none"`. When `useHTML`
     * is true, the `textOutline` will not be picked up. In this, case, the same
     * effect can be acheived through the `text-shadow` CSS property.
     *
     * For some series types, where each point has an extent, like for example
     * tree maps, the data label may overflow the point. There are two
     * strategies for handling overflow. By default, the text will wrap to
     * multiple lines. The other strategy is to set `style.textOverflow` to
     * `ellipsis`, which will keep the text on one line plus it will break
     * inside long words.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.style
     */
    style?: CSSObject;
    /**
     * (Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highstock) The vertical alignment of a data label. Can be one of `top`,
     * `middle` or `bottom`. The default value depends on the data, for instance
     * in a column chart, the label is above positive values and below negative
     * values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.x
     */
    x?: number;
    /**
     * (Highstock) The y position offset of the label relative to the point in
     * pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.y
     */
    y?: number;
    /**
     * (Highstock) The Z index of the data labels. The default Z index puts it
     * above the series. Use a Z index of 2 to display it behind the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragHandle
 */
export interface PlotZigzagDragDropDragHandleOptions {
    /**
     * (Highstock) The class name of the drag handles. Defaults to
     * `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highstock) The fill color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highstock) The mouse cursor to use for the drag handles. By default this
     * is intelligently switching between `ew-resize` and `ns-resize` depending
     * on the direction the point is being dragged.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highstock) The line color of the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The line width for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Function to define the SVG path to use for the drag handles.
     * Takes the point as argument. Should return an SVG path in array format.
     * The SVG path is automatically positioned on the point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highstock) The z index for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box default state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.guideBox.default
 */
export interface PlotZigzagDragDropGuideBoxDefaultOptions {
    /**
     * (Highstock) CSS class name of the guide box in this state. Defaults to
     * `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highstock) Guide box fill color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highstock) Guide box cursor.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Color of the border around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Width of the line around the guide box.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Style options for the guide box. The guide box has one state by
 * default, the `default` state.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.guideBox
 */
export interface PlotZigzagDragDropGuideBoxOptions {
    /**
     * (Highstock) Style options for the guide box default state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.guideBox.default
     */
    default?: PlotZigzagDragDropGuideBoxDefaultOptions;
}
/**
 * (Highstock) The draggable-points module allows points to be moved around or
 * modified in the chart. In addition to the options mentioned under the
 * `dragDrop` API structure, the module fires three events, point.dragStart,
 * point.drag and point.drop.
 *
 * It requires the `modules/draggable-points.js` file to be loaded.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop
 */
export interface PlotZigzagDragDropOptions {
    /**
     * (Highstock) Enable dragging in the X dimension.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highstock) Enable dragging in the Y dimension. Note that this is not
     * supported for TreeGrid axes (the default axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highstock) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragHandle
     */
    dragHandle?: PlotZigzagDragDropDragHandleOptions;
    /**
     * (Highstock) Set the maximum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highstock) Set the maximum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highstock) Set the minimum X value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highstock) Set the minimum Y value the points can be moved to.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highstock) The X precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highstock) The Y precision value to drag to for this series. Set to 0 to
     * disable. By default this is disabled, except for category axes, where the
     * default is 1.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highstock) The amount of pixels to drag the pointer before it counts as
     * a drag operation. This prevents drag/drop to fire when just clicking or
     * selecting points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highstock) Group the points by a property. Points with the same property
     * value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highstock) Style options for the guide box. The guide box has one state
     * by default, the `default` state.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.guideBox
     */
    guideBox?: (PlotZigzagDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highstock) Update points as they are dragged. If false, a guide box is
     * drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highstock) General event handlers for the series items. These event hooks
 * can also be attached to the series at run time using the
 * `Highcharts.addEvent` function.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.events
 */
export interface PlotZigzagEventsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Fires after the series has finished its
     * initial animation, or in case animation is disabled, immediately as the
     * series is displayed.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.events.afterAnimate
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.events.afterAnimate
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.events.afterAnimate
     */
    afterAnimate?: SeriesAfterAnimateCallbackFunction;
    /**
     * (Highstock) Fires when the checkbox next to the series' name in the
     * legend is clicked. One parameter, `event`, is passed to the function. The
     * state of the checkbox is found by `event.checked`. The checked item is
     * found by `event.item`. Return `false` to prevent the default action which
     * is to toggle the select state of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.events.checkboxClick
     */
    checkboxClick?: SeriesCheckboxClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     * Additionally, `event.point` holds a pointer to the nearest point on the
     * graph.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.events.click
     */
    click?: SeriesClickCallbackFunction;
    /**
     * (Highstock) Fires when the series is hidden after chart generation time,
     * either by clicking the legend item or by calling `.hide()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.events.hide
     */
    hide?: () => void;
    /**
     * (Highstock) Fires when the legend item belonging to the series is
     * clicked. One parameter, `event`, is passed to the function. The default
     * action is to toggle the visibility of the series. This can be prevented
     * by returning `false` or calling `event.preventDefault()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.events.legendItemClick
     */
    legendItemClick?: () => void;
    /**
     * (Highstock) Fires when the mouse leaves the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     * If the stickyTracking option is true, `mouseOut` doesn't happen before
     * the mouse enters another graph or leaves the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the graph. One parameter,
     * `event`, is passed to the function, containing common event information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the series is shown after chart generation time,
     * either by clicking the legend item or by calling `.show()`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.events.show
     */
    show?: () => void;
}
/**
 * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
 * series as possible in a natural way, seeking to avoid other series. The goal
 * of this feature is to make the chart more easily readable, like if a human
 * designer placed the labels in the optimal position.
 *
 * The series labels currently work with series types having a `graph` or an
 * `area`.
 *
 * Requires the `series-label.js` module.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.label
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.label
 * @see https://api.highcharts.com/gantt/plotOptions.zigzag.label
 */
export interface PlotZigzagLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of boxes to avoid when laying out
     * the labels. Each item has a `left`, `right`, `top` and `bottom` property.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.label.boxesToAvoid
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.label.boxesToAvoid
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.label.boxesToAvoid
     */
    boxesToAvoid?: Array<LabelIntersectBoxObject>;
    /**
     * (Highcharts, Highstock, Gantt) Allow labels to be placed distant to the
     * graph if necessary, and draw a connector line to the graph. Setting this
     * option to true may decrease the performance significantly, since the
     * algorithm with systematically search for open spaces in the while plot
     * area. Visually, it may also result in a more cluttered chart, though more
     * of the series will be labeled.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.label.connectorAllowed
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.label.connectorAllowed
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.label.connectorAllowed
     */
    connectorAllowed?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) If the label is closer than this to a
     * neighbour graph, draw a connector.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.label.connectorNeighbourDistance
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.label.connectorNeighbourDistance
     */
    connectorNeighbourDistance?: number;
    /**
     * (Highcharts, Highstock, Gantt) Enable the series label per series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.label.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.label.enabled
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.label.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.label.maxFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.label.maxFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.label.maxFontSize
     */
    maxFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) For area-like series, allow the font size
     * to vary so that small areas get a smaller font size. The default applies
     * this effect to area-like series but not line-like series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.label.minFontSize
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.label.minFontSize
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.label.minFontSize
     */
    minFontSize?: (number|null);
    /**
     * (Highcharts, Highstock, Gantt) Draw the label on the area of an area
     * series. By default it is drawn on the area. Set it to `false` to draw it
     * next to the graph instead.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.label.onArea
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.label.onArea
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.label.onArea
     */
    onArea?: (boolean|null);
    /**
     * (Highcharts, Highstock, Gantt) Styles for the series label. The color
     * defaults to the series color, or a contrast color if `onArea`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.label.style
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.label.style
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.label.style
     */
    style?: CSSObject;
}
/**
 * (Highstock) The line marks the last price from all points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.lastPrice
 */
export interface PlotZigzagLastPriceOptions {
    /**
     * (Highstock) The color of the line of last price.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.lastPrice.color
     */
    color?: string;
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.lastPrice.enabled
     */
    enabled?: boolean;
}
export interface PlotZigzagLastVisiblePriceLabelOptions {
    /**
     * (Highstock) Enable or disable the label.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.lastVisiblePrice.label.enabled
     */
    enabled?: boolean;
}
/**
 * (Highstock) The line marks the last price from visible range of points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.lastVisiblePrice
 */
export interface PlotZigzagLastVisiblePriceOptions {
    /**
     * (Highstock) Enable or disable the indicator.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.lastVisiblePrice.enabled
     */
    enabled?: boolean;
    label?: PlotZigzagLastVisiblePriceLabelOptions;
}
/**
 * (Highstock) Options for the point markers of line-like series. Properties
 * like `fillColor`, `lineColor` and `lineWidth` define the visual appearance of
 * the markers. Other series types, like column series, don't have markers, but
 * have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker
 */
export interface PlotZigzagMarkerOptions {
    /**
     * (Highstock) Enable or disable the point marker. If `undefined`, the
     * markers are hidden when the data is dense, and shown for more widespread
     * data points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The threshold for how dense the point markers should be
     * before they are hidden, given that `enabled` is not defined. The number
     * indicates the horizontal distance between the two closest points in the
     * series, as multiples of the `marker.radius`. In other words, the default
     * value of 2 means points are hidden if overlapping horizontally.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highstock) The fill color of the point marker. When `undefined`, the
     * series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.height
     */
    height?: number;
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.radius
     */
    radius?: number;
    /**
     * (Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states
     */
    states?: PlotZigzagMarkerStatesOptions;
    /**
     * (Highstock) A predefined shape or symbol for the marker. When undefined,
     * the symbol is pulled from options.symbols. Other possible values are
     * "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.symbol
     */
    symbol?: string;
    /**
     * (Highstock) Image markers only. Set the image width explicitly. When
     * using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.width
     */
    width?: number;
}
/**
 * (Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover.animation
 */
export interface PlotZigzagMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover
 */
export interface PlotZigzagMarkerStatesHoverOptions {
    /**
     * (Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotZigzagMarkerStatesHoverAnimationOptions);
    /**
     * (Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline. When `undefined`,
     * the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2 as per the radiusPlus option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highstock) The number of pixels to increase the radius of the hovered
     * point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highstock) The normal state of a single point marker. Currently only used
 * for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.normal
 */
export interface PlotZigzagMarkerStatesNormalOptions {
    /**
     * (Highstock) Animation when returning to normal state after hovering.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states
 */
export interface PlotZigzagMarkerStatesOptions {
    /**
     * (Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.hover
     */
    hover?: PlotZigzagMarkerStatesHoverOptions;
    /**
     * (Highstock) The normal state of a single point marker. Currently only
     * used for setting animation when returning to normal state from hover.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.normal
     */
    normal?: PlotZigzagMarkerStatesNormalOptions;
    /**
     * (Highstock) The appearance of the point marker when selected. In order to
     * allow a point to be selected, set the `series.allowPointSelect` option to
     * true.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.select
     */
    select?: PlotZigzagMarkerStatesSelectOptions;
}
/**
 * (Highstock) The appearance of the point marker when selected. In order to
 * allow a point to be selected, set the `series.allowPointSelect` option to
 * true.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.select
 */
export interface PlotZigzagMarkerStatesSelectOptions {
    /**
     * (Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The color of the point marker's outline. When `undefined`,
     * the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) The radius of the point marker. In hover state, it defaults
     * to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Zig Zag indicator.
 *
 * This series requires `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `zigzag` series are defined in plotOptions.zigzag.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag
 */
export interface PlotZigzagOptions {
    /**
     * (Highstock) Allow this series' points to be selected by clicking on the
     * graphic (columns, point markers, pie slices, map areas etc).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.allowPointSelect
     */
    allowPointSelect?: boolean;
    /**
     * (Highstock) Enable or disable the initial animation when a series is
     * displayed. The animation can also be set as a configuration object.
     * Please note that this option only applies to the initial animation of the
     * series itself. For other animations, see chart.animation and the
     * animation parameter under the API methods. The following properties are
     * supported:
     *
     * (see online documentation for example)
     *
     * Due to poor performance, animation is disabled in old IE browsers for
     * several chart types.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotZigzagAnimationOptions);
    /**
     * (Highstock) For some series, there is a limit that shuts down initial
     * animation by default when the total number of points in the chart is too
     * high. For example, for a column chart and its derivatives, animation
     * doesn't run if there is more than 250 points totally. To disable this
     * cap, set `animationLimit` to `Infinity`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.animationLimit
     */
    animationLimit?: number;
    /**
     * (Highstock) Set the point threshold for when a series should enter boost
     * mode.
     *
     * Setting it to e.g. 2000 will cause the series to enter boost mode when
     * there are 2000 or more points in the series.
     *
     * To disable boosting on the series, set the `boostThreshold` to 0. Setting
     * it to 1 will force boosting.
     *
     * Note that the cropThreshold also affects this setting. When zooming in on
     * a series that has fewer points than the `cropThreshold`, all points are
     * rendered although outside the visible plot area, and the `boostThreshold`
     * won't take effect.
     *
     * Requires `modules/boost.js`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.boostThreshold
     */
    boostThreshold?: number;
    /**
     * (Highmaps) The border color of the map areas.
     *
     * In styled mode, the border stroke is given in the `.highcharts-point`
     * class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of each map area.
     *
     * In styled mode, the border stroke width is given in the
     * `.highcharts-point` class.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) An additional class name to apply to the series' graphical
     * elements. This option does not replace default class names of the
     * graphical element.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.className
     */
    className?: string;
    /**
     * (Highstock) Disable this option to allow series rendering in the whole
     * plotting area.
     *
     * **Note:** Clipping should be always enabled when chart.zoomType is set
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.clip
     */
    clip?: boolean;
    /**
     * (Highstock) The main color of the series. In line type series it applies
     * to the line and the point markers unless otherwise specified. In bar type
     * series it applies to the bars unless a color is specified per point. The
     * default value is pulled from the `options.colors` array.
     *
     * In styled mode, the color can be defined by the colorIndex option. Also,
     * the series color can be set with the `.highcharts-series`,
     * `.highcharts-color-{n}`, `.highcharts-{type}-series` or
     * `.highcharts-series-{n}` class, or individual classes given by the
     * `className` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Styled mode only. A specific color index to use for the
     * series, so its graphic representations are given the class name
     * `highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) Defines if comparison should start from the first point
     * within the visible range or should start from the first point (see online
     * documentation for example) the range. In other words, this flag
     * determines if first point within the visible range will have 0%
     * (`compareStart=true`) or should have been already calculated according to
     * the previous point (`compareStart=false`).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.compareStart
     */
    compareStart?: boolean;
    /**
     * (Highcharts) Polar charts only. Whether to connect the ends of a line
     * series plot across the extremes.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.connectEnds
     */
    connectEnds?: boolean;
    /**
     * (Highcharts, Highstock) Whether to connect a graph line across null
     * points, or render a gap between the two points on either side of the
     * null.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.connectNulls
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.connectNulls
     */
    connectNulls?: boolean;
    /**
     * (Gantt) Override Pathfinder connector options for a series. Requires
     * Highcharts Gantt to be loaded.
     *
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.connectors
     */
    connectors?: PlotZigzagConnectorsOptions;
    /**
     * (Highcharts, Highstock) When the series contains less points than the
     * crop threshold, all points are drawn, even if the points fall outside the
     * visible plot area at the current zoom. The advantage of drawing all
     * points (including markers and columns), is that animation is performed on
     * updates. On the other hand, when the series contains more points than the
     * crop threshold, the series data is cropped to only contain points that
     * fall within the plot area. The advantage of cropping away invisible
     * points is to increase performance on large series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.cropThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.cropThreshold
     */
    cropThreshold?: number;
    /**
     * (Highstock) You can set the cursor to "pointer" if you have click events
     * attached to the series, to signal to the user that the points and lines
     * can be clicked.
     *
     * In styled mode, the series cursor can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.cursor
     */
    cursor?: (string|CursorType);
    /**
     * (Highstock) A name for the dash style to use for the graph, or for some
     * series types the outline of each shape.
     *
     * In styled mode, the stroke dash-array can be set with the same classes as
     * listed under series.color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) Data grouping is the concept of sampling the data values into
     * larger blocks in order to ease readability and increase performance of
     * the JavaScript charts. Highstock by default applies data grouping when
     * the points become closer than a certain pixel value, determined by the
     * `groupPixelWidth` option.
     *
     * If data grouping is applied, the grouping information of grouped points
     * can be read from the Point.dataGroup. If point options other than the
     * data itself are set, for example `name` or `color` or custom properties,
     * the grouping logic doesn't know how to group it. In this case the options
     * of the first point instance are copied over to the group point. This can
     * be altered through a custom `approximation` callback function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataGrouping
     */
    dataGrouping?: PlotZigzagDataGroupingOptions;
    /**
     * (Highstock) Options for the series data labels, appearing next to each
     * data point.
     *
     * Since v6.2.0, multiple data labels can be applied to each single point by
     * defining them as an array of configs.
     *
     * In styled mode, the data labels can be styled with the
     * `.highcharts-data-label-box` and `.highcharts-data-label` class names
     * (see example).
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dataLabels
     */
    dataLabels?: PlotZigzagDataLabelsOptions;
    /**
     * (Highstock) Requires the Accessibility module.
     *
     * A description of the series to add to the screen reader information about
     * the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.description
     */
    description?: string;
    /**
     * (Highstock) The draggable-points module allows points to be moved around
     * or modified in the chart. In addition to the options mentioned under the
     * `dragDrop` API structure, the module fires three events, point.dragStart,
     * point.drag and point.drop.
     *
     * It requires the `modules/draggable-points.js` file to be loaded.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.dragDrop
     */
    dragDrop?: PlotZigzagDragDropOptions;
    /**
     * (Highstock) Enable or disable the mouse tracking for a specific series.
     * This includes point tooltips and click events on graphs and points. For
     * large datasets it improves performance.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.enableMouseTracking
     */
    enableMouseTracking?: boolean;
    /**
     * (Highstock) General event handlers for the series items. These event
     * hooks can also be attached to the series at run time using the
     * `Highcharts.addEvent` function.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.events
     */
    events?: PlotZigzagEventsOptions;
    /**
     * (Highstock) By default, series are exposed to screen readers as regions.
     * By enabling this option, the series element itself will be exposed in the
     * same way as the data points. This is useful if the series is not used as
     * a grouping entity in the chart, but you still want to attach a
     * description to the series.
     *
     * Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.exposeElementToA11y
     */
    exposeElementToA11y?: boolean;
    /**
     * (Highstock) Determines whether the series should look for the nearest
     * point in both dimensions or just the x-dimension when hovering the
     * series. Defaults to `'xy'` for scatter series and `'x'` for most other
     * series. If the data has duplicate x-values, it is recommended to set this
     * to `'xy'` to allow hovering over all points.
     *
     * Applies only to series types using nearest neighbor search (not direct
     * hover) for tooltip.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.findNearestPointBy
     */
    findNearestPointBy?: ("x"|"xy");
    /**
     * (Highstock) Defines when to display a gap in the graph, together with the
     * gapUnit option.
     *
     * In case when `dataGrouping` is enabled, points can be grouped into a
     * larger time span. This can make the grouped points to have a greater
     * distance than the absolute value of `gapSize` property, which will result
     * in disappearing graph completely. To prevent this situation the mentioned
     * distance between grouped points is used instead of previously defined
     * `gapSize`.
     *
     * In practice, this option is most often used to visualize gaps in time
     * series. In a stock chart, intraday data is available for daytime hours,
     * while gaps will appear in nights and weekends.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.gapSize
     */
    gapSize?: number;
    /**
     * (Highstock) Together with gapSize, this option defines where to draw gaps
     * in the graph.
     *
     * When the `gapUnit` is `relative` (default), a gap size of 5 means that if
     * the distance between two points is greater than five times that of the
     * two closest points, the graph will be broken.
     *
     * When the `gapUnit` is `value`, the gap is based on absolute axis values,
     * which on a datetime axis is milliseconds. This also applies to the
     * navigator series that inherits gap options from the base series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.gapUnit
     */
    gapUnit?: ("relative"|"value");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use the Y extremes of the total
     * chart width or only the zoomed area when zooming in on parts of the X
     * axis. By default, the Y axis adjusts to the min and max of the visible
     * data. Cartesian series only.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.getExtremesFromAll
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.getExtremesFromAll
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.getExtremesFromAll
     */
    getExtremesFromAll?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Series labels are placed as close to the
     * series as possible in a natural way, seeking to avoid other series. The
     * goal of this feature is to make the chart more easily readable, like if a
     * human designer placed the labels in the optimal position.
     *
     * The series labels currently work with series types having a `graph` or an
     * `area`.
     *
     * Requires the `series-label.js` module.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.label
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.label
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.label
     */
    label?: PlotZigzagLabelOptions;
    /**
     * (Highstock) The line marks the last price from all points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.lastPrice
     */
    lastPrice?: PlotZigzagLastPriceOptions;
    /**
     * (Highstock) The line marks the last price from visible range of points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.lastVisiblePrice
     */
    lastVisiblePrice?: PlotZigzagLastVisiblePriceOptions;
    /**
     * (Highcharts, Highstock) The SVG value used for the `stroke-linecap` and
     * `stroke-linejoin` of a line graph. Round means that lines are rounded in
     * the ends and bends.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.linecap
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.linecap
     */
    linecap?: ("butt"|"round"|"square");
    /**
     * (Highcharts, Highstock) Pixel width of the graph line.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The main series ID that indicator will be
     * based on. Required for this indicator.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.linkedTo
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.linkedTo
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.linkedTo
     */
    linkedTo?: string;
    /**
     * (Highstock) Options for the point markers of line-like series. Properties
     * like `fillColor`, `lineColor` and `lineWidth` define the visual
     * appearance of the markers. Other series types, like column series, don't
     * have markers, but have visual options on the series level instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.marker
     */
    marker?: PlotZigzagMarkerOptions;
    /**
     * (Highstock) The name of the series as shown in the legend, tooltip etc.
     * If not set, it will be based on a technical indicator type and default
     * params.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.name
     */
    name?: string;
    /**
     * (Highstock) The color for the parts of the graph or points that are below
     * the threshold.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.negativeColor
     */
    negativeColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) Paramters used in calculation of regression series' points.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.params
     */
    params?: PlotZigzagParamsOptions;
    /**
     * (Highstock) Properties for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point
     */
    point?: PlotZigzagPointOptions;
    /**
     * (Highstock) Same as accessibility.pointDescriptionFormatter, but for an
     * individual series. Overrides the chart wide configuration.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.pointDescriptionFormatter
     */
    pointDescriptionFormatter?: () => void;
    /**
     * (Highstock) Whether to select the series initially. If `showCheckbox` is
     * true, the checkbox next to the series name in the legend will be checked
     * for a selected series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.selected
     */
    selected?: boolean;
    /**
     * (Highstock) Whether to apply a drop shadow to the graph line. Since 2.3
     * the shadow can be an object configuration containing `color`, `offsetX`,
     * `offsetY`, `opacity` and `width`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.shadow
     */
    shadow?: (boolean|ShadowOptionsObject);
    /**
     * (Highstock) If true, a checkbox is displayed next to the legend item to
     * allow selecting the series. The state of the checkbox is determined by
     * the `selected` option.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.showCheckbox
     */
    showCheckbox?: boolean;
    /**
     * (Highstock) Whether to display this particular series or series type in
     * the legend. The default value is `true` for standalone series, `false`
     * for linked series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.showInLegend
     */
    showInLegend?: boolean;
    /**
     * (Highstock) If set to `true`, the accessibility module will skip past the
     * points in this series for keyboard navigation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.skipKeyboardNavigation
     */
    skipKeyboardNavigation?: boolean;
    /**
     * (Highcharts, Highstock) When this is true, the series will not cause the
     * Y axis to cross the zero plane (or threshold option) unless the data
     * actually crosses the plane.
     *
     * For example, if `softThreshold` is `false`, a series of 0, 1, 2, 3 will
     * make the Y axis show negative values according to the `minPadding`
     * option. If `softThreshold` is `true`, the Y axis starts at 0.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.softThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.softThreshold
     */
    softThreshold?: boolean;
    /**
     * (Highstock) A wrapper object for all the series options in specific
     * states.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states
     */
    states?: PlotZigzagStatesOptions;
    /**
     * (Highcharts, Highstock) Whether to apply steps to the line. Possible
     * values are `left`, `center` and `right`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.step
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.step
     */
    step?: ("center"|"left"|"right");
    /**
     * (Highstock) Sticky tracking of mouse events. When true, the `mouseOut`
     * event on a series isn't triggered until the mouse moves over another
     * series, or out of the plot area. When false, the `mouseOut` event on a
     * series is triggered when the mouse leaves the area around the series'
     * graph or markers. This also implies the tooltip when not shared. When
     * `stickyTracking` is false and `tooltip.shared` is false, the tooltip will
     * be hidden when moving the mouse between series. Defaults to true for line
     * and area type series, but to false for columns, pies etc.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.stickyTracking
     */
    stickyTracking?: boolean;
    /**
     * (Highcharts, Highstock) The threshold, also called zero level or base
     * level. For line type series this is only used in conjunction with
     * negativeColor.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.threshold
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.threshold
     */
    threshold?: number;
    /**
     * (Highstock) A configuration object for the tooltip rendering of each
     * single series. Properties are inherited from tooltip, but only the
     * following properties can be defined on a series level.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip
     */
    tooltip?: PlotZigzagTooltipOptions;
    /**
     * (Highcharts, Highstock, Gantt) When a series contains a data array that
     * is longer than this, only one dimensional arrays of numbers, or two
     * dimensional arrays with x and y values are allowed. Also, only the first
     * point is tested, and the rest are assumed to be the same format. This
     * saves expensive data checking and indexing in long series. Set it to `0`
     * disable.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.turboThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.turboThreshold
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.turboThreshold
     */
    turboThreshold?: number;
    /**
     * (Highstock) Set the initial visibility of the series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.visible
     */
    visible?: boolean;
    /**
     * (Highmaps) Define the z index of the series.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.zIndex
     */
    zIndex?: number;
    /**
     * (Highcharts, Highstock) Defines the Axis on which the zones are applied.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.zoneAxis
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.zoneAxis
     */
    zoneAxis?: string;
    /**
     * (Highcharts, Highstock) An array defining zones within a series. Zones
     * can be applied to the X axis, Y axis or Z axis for bubbles, according to
     * the `zoneAxis` option. The zone definitions have to be in ascending order
     * regarding to the value.
     *
     * In styled mode, the color zones are styled with the
     * `.highcharts-zone-{n}` class, or custom classed from the `className`
     * option (view live demo).
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.zones
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.zones
     */
    zones?: Array<PlotZigzagZonesOptions>;
}
/**
 * (Highstock) Paramters used in calculation of regression series' points.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.params
 */
export interface PlotZigzagParamsOptions {
    /**
     * (Highstock) The threshold for the value change.
     *
     * For example deviation=1 means the indicator will ignore all price
     * movements less than 1%.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.params.deviation
     */
    deviation?: number;
    /**
     * (Highstock) The point index which indicator calculations will base - high
     * value.
     *
     * For example using OHLC data, index=1 means the indicator will be
     * calculated using High values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.params.highIndex
     */
    highIndex?: number;
    /**
     * (Highstock) The point index which indicator calculations will base - low
     * value.
     *
     * For example using OHLC data, index=2 means the indicator will be
     * calculated using Low values.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.params.lowIndex
     */
    lowIndex?: number;
}
/**
 * (Highstock) Events for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events
 */
export interface PlotZigzagPointEventsOptions {
    /**
     * (Highstock) Fires when a point is clicked. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highstock) Callback that fires while dragging a point. The mouse event
     * is passed in as parameter. The original data can be accessed from
     * `e.origin`, and the new point values can be accessed from `e.newPoints`.
     * If there is only a single point being updated, it can be accessed from
     * `e.newPoint` for simplicity, and its ID can be accessed from
     * `e.newPointId`. The `this` context is the point being dragged. To stop
     * the default drag action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highstock) Callback that fires when starting to drag a point. The mouse
     * event object is passed in as an argument. If a drag handle is used,
     * `e.updateProp` is set to the data property being dragged. The `this`
     * context is the point. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highstock) Callback that fires when the point is dropped. The parameters
     * passed are the same as for drag. To stop the default drop action, return
     * false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highstock) Fires when the mouse leaves the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highstock) Fires when the mouse enters the area close to the point. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highstock) Fires when the point is removed using the `.remove()` method.
     * One parameter, `event`, is passed to the function. Returning `false`
     * cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events.remove
     */
    remove?: () => void;
    /**
     * (Highstock) Fires when the point is selected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events.select
     */
    select?: () => void;
    /**
     * (Highstock) Fires when the point is unselected either programmatically or
     * following a click on the point. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highstock) Fires when the point is updated programmatically through the
     * `.update()` method. One parameter, `event`, is passed to the function.
     * The new point options can be accessed through `event.options`. Returning
     * `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) Properties for each single point.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point
 */
export interface PlotZigzagPointOptions {
    /**
     * (Highstock) Events for each single point.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.point.events
     */
    events?: PlotZigzagPointEventsOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.animation
 */
export interface PlotZigzagStatesHoverAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.halo
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.halo
 */
export interface PlotZigzagStatesHoverHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker
 */
export interface PlotZigzagStatesHoverMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states
     */
    states?: PlotZigzagStatesHoverMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover.animation
 */
export interface PlotZigzagStatesHoverMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover
 */
export interface PlotZigzagStatesHoverMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotZigzagStatesHoverMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.normal
 */
export interface PlotZigzagStatesHoverMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states
 */
export interface PlotZigzagStatesHoverMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.hover
     */
    hover?: PlotZigzagStatesHoverMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.normal
     */
    normal?: PlotZigzagStatesHoverMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.select
     */
    select?: PlotZigzagStatesHoverMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.select
 */
export interface PlotZigzagStatesHoverMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highstock) Options for the hovered series. These settings override the
 * normal state options when a series is moused over or touched.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover
 */
export interface PlotZigzagStatesHoverOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotZigzagStatesHoverAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.hover.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.hover.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The relative brightness of the point when hovered, relative to
     * the normal point color.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.hover.brightness
     */
    brightness?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.hover.color
     */
    color?: ColorString;
    /**
     * (Highstock) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.halo
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.halo
     */
    halo?: PlotZigzagStatesHoverHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.hover.marker
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover.marker
     */
    marker?: PlotZigzagStatesHoverMarkerOptions;
}
/**
 * (Highmaps) Overrides for the normal state.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.normal
 */
export interface PlotZigzagStatesNormalOptions {
    /**
     * (Highmaps) Animation options for the fill color when returning from hover
     * state to normal state. The animation adds some latency in order to reduce
     * the effect of flickering when hovering in and out of for example an
     * uneven coastline.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highstock) A wrapper object for all the series options in specific states.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states
 */
export interface PlotZigzagStatesOptions {
    /**
     * (Highstock) Options for the hovered series. These settings override the
     * normal state options when a series is moused over or touched.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.hover
     */
    hover?: PlotZigzagStatesHoverOptions;
    /**
     * (Highmaps) Overrides for the normal state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.normal
     */
    normal?: PlotZigzagStatesNormalOptions;
    /**
     * (Highmaps) Specific options for point in selected states, after being
     * selected by allowPointSelect or programmatically.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.select
     */
    select?: PlotZigzagStatesSelectOptions;
}
/**
 * (Highcharts) Animation setting for hovering the graph in line-type series.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.animation
 */
export interface PlotZigzagStatesSelectAnimationOptions {
    /**
     * (Highcharts) The duration of the hover animation in milliseconds. By
     * default the hover state animates quickly in, and slowly back to normal.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.animation.duration
     */
    duration?: number;
}
/**
 * (Highcharts, Highstock) Options for the halo appearing around the hovered
 * point in line- type series as well as outside the hovered slice in pie
 * charts. By default the halo is filled by the current point or series color
 * with an opacity of 0.25\. The halo can be disabled by setting the `halo`
 * option to `false`.
 *
 * In styled mode, the halo is styled with the `.highcharts-halo` class, with
 * colors inherited from `.highcharts-color-{n}`.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.halo
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.halo
 */
export interface PlotZigzagStatesSelectHaloOptions {
    /**
     * (Highcharts, Highstock) A collection of SVG attributes to override the
     * appearance of the halo, for example `fill`, `stroke` and `stroke-width`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.halo.attributes
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.halo.attributes
     */
    attributes?: SVGAttributes;
    /**
     * (Highcharts, Highstock) Opacity for the halo unless a specific fill is
     * overridden using the `attributes` setting. Note that Highcharts is only
     * able to apply opacity to colors of hex or rgb(a) formats.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.halo.opacity
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.halo.opacity
     */
    opacity?: number;
    /**
     * (Highcharts, Highstock) The pixel size of the halo. For point markers
     * this is the radius of the halo. For pie slices it is the width of the
     * halo outside the slice. For bubbles it defaults to 5 and is the width of
     * the halo outside the bubble.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.halo.size
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.halo.size
     */
    size?: number;
}
/**
 * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
 * belonging to the hovered series. For settings on the hover state of the
 * individual point, see marker.states.hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker
 */
export interface PlotZigzagStatesSelectMarkerOptions {
    /**
     * (Highcharts, Highstock) Enable or disable the point marker. If
     * `undefined`, the markers are hidden when the data is dense, and shown for
     * more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The threshold for how dense the point markers
     * should be before they are hidden, given that `enabled` is not defined.
     * The number indicates the horizontal distance between the two closest
     * points in the series, as multiples of the `marker.radius`. In other
     * words, the default value of 2 means points are hidden if overlapping
     * horizontally.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock) The fill color of the point marker. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `width` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.height
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.radius
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) States for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states
     */
    states?: PlotZigzagStatesSelectMarkerStatesOptions;
    /**
     * (Highcharts, Highstock) A predefined shape or symbol for the marker. When
     * undefined, the symbol is pulled from options.symbols. Other possible
     * values are "circle", "square", "diamond", "triangle" and "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.symbol
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock) Image markers only. Set the image width
     * explicitly. When using this option, a `height` must also be set.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.width
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock) Animation when hovering over the marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover.animation
 */
export interface PlotZigzagStatesSelectMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock) The hover state for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover
 */
export interface PlotZigzagStatesSelectMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock) Animation when hovering over the marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotZigzagStatesSelectMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock) Enable or disable the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the marker in hover state. When
     * `undefined`, the series' or point's fillColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's lineColor for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline. When
     * `undefined`, the series' or point's lineWidth for normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for a hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2 as per the radiusPlus
     * option.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock) The number of pixels to increase the radius of
     * the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock) The normal state of a single point marker. Currently
 * only used for setting animation when returning to normal state from hover.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.normal
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.normal
 */
export interface PlotZigzagStatesSelectMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock) Animation when returning to normal state after
     * hovering.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states
 */
export interface PlotZigzagStatesSelectMarkerStatesOptions {
    /**
     * (Highcharts, Highstock) The hover state for a single point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.hover
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.hover
     */
    hover?: PlotZigzagStatesSelectMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock) The normal state of a single point marker.
     * Currently only used for setting animation when returning to normal state
     * from hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.normal
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.normal
     */
    normal?: PlotZigzagStatesSelectMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock) The appearance of the point marker when selected.
     * In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.select
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.select
     */
    select?: PlotZigzagStatesSelectMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock) The appearance of the point marker when selected. In
 * order to allow a point to be selected, set the `series.allowPointSelect`
 * option to true.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.select
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.select
 */
export interface PlotZigzagStatesSelectMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock) Enable or disable visible feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) The fill color of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The color of the point marker's outline. When
     * `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the point marker's outline.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The radius of the point marker. In hover state,
     * it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highmaps) Specific options for point in selected states, after being
 * selected by allowPointSelect or programmatically.
 *
 * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.select
 */
export interface PlotZigzagStatesSelectOptions {
    /**
     * (Highcharts) Animation setting for hovering the graph in line-type
     * series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.animation
     */
    animation?: (boolean|AnimationOptionsObject|PlotZigzagStatesSelectAnimationOptions);
    /**
     * (Highmaps) The border color of the point in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.select.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highmaps) The border width of the point in this state
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.select.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highmaps) The color of the shape in this state.
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.select.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Enable separate styles for the hovered series to visualize
     * that the user hovers either the series itself or the legend. .
     *
     * @see https://api.highcharts.com/highmaps/plotOptions.zigzag.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) Options for the halo appearing around the hovered
     * point in line- type series as well as outside the hovered slice in pie
     * charts. By default the halo is filled by the current point or series
     * color with an opacity of 0.25\. The halo can be disabled by setting the
     * `halo` option to `false`.
     *
     * In styled mode, the halo is styled with the `.highcharts-halo` class,
     * with colors inherited from `.highcharts-color-{n}`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.halo
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.halo
     */
    halo?: PlotZigzagStatesSelectHaloOptions;
    /**
     * (Highcharts, Highstock) Pixel width of the graph line. By default this
     * property is undefined, and the `lineWidthPlus` property dictates how much
     * to increase the linewidth from normal state.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock) The additional line width for the graph of a
     * hovered series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.lineWidthPlus
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock) In Highcharts 1.0, the appearance of all markers
     * belonging to the hovered series. For settings on the hover state of the
     * individual point, see marker.states.hover.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.states.select.marker
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.states.select.marker
     */
    marker?: PlotZigzagStatesSelectMarkerOptions;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/plotOptions.zigzag.tooltip.dateTimeLabelFormats
 */
export interface PlotZigzagTooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
/**
 * (Highstock) A configuration object for the tooltip rendering of each single
 * series. Properties are inherited from tooltip, but only the following
 * properties can be defined on a series level.
 *
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip
 */
export interface PlotZigzagTooltipOptions {
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (PlotZigzagTooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highstock) Whether the tooltip should follow the mouse as it moves
     * across columns, pie slices and other point types with an extent. By
     * default it behaves this way for scatter, bubble and pie series by
     * override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highstock) Whether the tooltip should update as the finger moves on a
     * touch device. If this is `true` and chart.panning is
     * set,`followTouchMove` will take over one-finger touches, so the user
     * needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highstock) A string to append to the tooltip format.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highstock) The HTML of the tooltip header line. Variables are enclosed
     * by curly brackets. Available variables are `point.key`, `series.name`,
     * `series.color` and other members from the `point` and `series` objects.
     * The `point.key` variable contains the category name, x value or datetime
     * string depending on the type of axis. For datetime axes, the `point.key`
     * date format can be set using `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highstock) The name of a symbol to use for the border around the tooltip
     * header. Applies only when tooltip.split is enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highstock) The number of milliseconds to wait until the tooltip is
     * hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highstock) Whether to allow the tooltip to render outside the chart's
     * SVG element box. By default (`false`), the tooltip is rendered within the
     * chart's SVG element, which results in the tooltip being aligned inside
     * the chart area. For small charts, this may result in clipping or
     * overlapping. When `true`, a separate SVG element is created and overlaid
     * on the page, allowing the tooltip to be aligned inside the page itself.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highstock) Padding inside the tooltip, in pixels.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.padding
     */
    padding?: number;
    /**
     * (Highstock) The HTML of the point's line in the tooltip. Variables are
     * enclosed by curly brackets. Available variables are point.x, point.y,
     * series. name and series.color and other properties on the same form.
     * Furthermore, `point.y` can be extended by the `tooltip.valuePrefix` and
     * `tooltip.valueSuffix` variables. This can also be overridden for each
     * series, which makes it a good hook for displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highstock) A callback function for formatting the HTML output for a
     * single point in the tooltip. Like the `pointFormat` string, but with more
     * flexibility.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.tooltip.split
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.split
     */
    split?: boolean;
    /**
     * (Highstock) Number of decimals in indicator series.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highstock) A string to prepend to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highstock) A string to append to each series' y value. Overridable in
     * each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/plotOptions.zigzag.tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock) An array defining zones within a series. Zones can be
 * applied to the X axis, Y axis or Z axis for bubbles, according to the
 * `zoneAxis` option. The zone definitions have to be in ascending order
 * regarding to the value.
 *
 * In styled mode, the color zones are styled with the `.highcharts-zone-{n}`
 * class, or custom classed from the `className` option (view live demo).
 *
 * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.zones
 * @see https://api.highcharts.com/highstock/plotOptions.zigzag.zones
 */
export interface PlotZigzagZonesOptions {
    /**
     * (Highcharts, Highstock) Styled mode only. A custom class name for the
     * zone.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.zones.className
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.zones.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock) Defines the color of the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.zones.color
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.zones.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock) A name for the dash style to use for the graph.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.zones.dashStyle
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.zones.dashStyle
     */
    dashStyle?: string;
    /**
     * (Highcharts, Highstock) Defines the fill color for the series (in area
     * type series)
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.zones.fillColor
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.zones.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock) The value up to where the zone extends, if
     * undefined the zones stretches to the last value in the series.
     *
     * @see https://api.highcharts.com/highcharts/plotOptions.zigzag.zones.value
     * @see https://api.highcharts.com/highstock/plotOptions.zigzag.zones.value
     */
    value?: number;
}
/**
 * One position in relation to an axis.
 */
export interface PointerAxisCoordinateObject {
    /**
     * Related axis.
     */
    axis: Axis;
    /**
     * Axis value.
     */
    value: number;
}
/**
 * Positions in terms of axis values.
 */
export interface PointerAxisCoordinatesObject {
    /**
     * Positions on the x-axis.
     */
    xAxis: Array<PointerAxisCoordinateObject>;
    /**
     * Positions on the y-axis.
     */
    yAxis: Array<PointerAxisCoordinateObject>;
}
/**
 * Pointer coordinates.
 */
export interface PointerCoordinatesObject {
    chartX: number;
    chartY: number;
}
/**
 * A native browser mouse or touch event, extended with position information
 * relative to the Chart.container.
 */
export interface PointerEventObject extends PointerEvent {
    /**
     * The X coordinate of the pointer interaction relative to the chart.
     */
    chartX: number;
    /**
     * The Y coordinate of the pointer interaction relative to the chart.
     */
    chartY: number;
}
/**
 * Configuration hash for the data label and tooltip formatters.
 */
export interface PointLabelObject {
    /**
     * The point's current color.
     */
    color: (ColorString|GradientColorObject|PatternObject);
    /**
     * The point's current color index, used in styled mode instead of `color`.
     * The color index is inserted in class names used for styling.
     */
    colorIndex: number;
    /**
     * The name of the related point.
     */
    key: (number|string);
    /**
     * The percentage for related points in a stacked series or pies.
     */
    percentage: number;
    /**
     * The related point.
     */
    point: Point;
    /**
     * The related series.
     */
    series: Series;
    /**
     * The total of values in either a stack for stacked series, or a pie in a
     * pie series.
     */
    total: number;
    /**
     * For categorized axes this property holds the category name for the point.
     * For other axes it holds the X value.
     */
    x: (number|string);
    /**
     * The y value of the point.
     */
    y?: number;
}
/**
 * An object containing `x` and `y` properties for the position of an element.
 */
export interface PositionObject {
    /**
     * X position of the element.
     */
    x: number;
    /**
     * Y position of the element.
     */
    y: number;
}
/**
 * Defines the center position and the radius for a gradient.
 */
export interface RadialGradientColorObject {
    /**
     * Center horizontal position relative to the shape. Float ranges 0-1.
     */
    cx: number;
    /**
     * Center vertical position relative to the shape. Float ranges 0-1.
     */
    cy: number;
    /**
     * Radius relative to the shape. Float ranges 0-1.
     */
    r: number;
}
/**
 * (Highstock) Positioning for the button row.
 *
 * @see https://api.highcharts.com/highstock/rangeSelector.buttonPosition
 */
export interface RangeSelectorButtonPositionOptions {
    /**
     * (Highstock) The alignment of the input box. Allowed properties are
     * `left`, `center`, `right`.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttonPosition.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) X offset of the button row.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttonPosition.x
     */
    x?: number;
    /**
     * (Highstock) Y offset of the button row.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttonPosition.y
     */
    y?: number;
}
/**
 * (Highstock) A custom data grouping object for each button.
 *
 * @see https://api.highcharts.com/highstock/rangeSelector.buttons.dataGrouping
 */
export interface RangeSelectorButtonsDataGroupingOptions {
    /**
     * (Highstock) The method of approximation inside a group. When for example
     * 30 days are grouped into one month, this determines what value should
     * represent the group. Possible values are "average", "averages", "open",
     * "high", "low", "close" and "sum". For OHLC and candlestick series the
     * approximation is "ohlc" by default, which finds the open, high, low and
     * close values within all the grouped data. For ranges, the approximation
     * is "range", which finds the low and high values. For multi-dimensional
     * data, like ranges and OHLC, "averages" will compute the average for each
     * dimension.
     *
     * Custom aggregate methods can be added by assigning a callback function as
     * the approximation. This function takes a numeric array as the argument
     * and should return a single numeric value or `null`. Note that the numeric
     * array will never contain null values, only true numbers. Instead, if null
     * values are present in the raw data, the numeric array will have an
     * `.hasNulls` property set to `true`. For single-value data sets the data
     * is available in the first argument of the callback function. For OHLC
     * data sets, all the open values are in the first argument, all high values
     * in the second etc.
     *
     * Since v4.2.7, grouping meta data is available in the approximation
     * callback from `this.dataGroupInfo`. It can be used to extract information
     * from the raw data.
     *
     * Defaults to `average` for line-type series, `sum` for columns, `range`
     * for range series and `ohlc` for OHLC and candlestick.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.dataGrouping.approximation
     */
    approximation?: ("average"|"averages"|"close"|"high"|"low"|"open"|"sum");
    /**
     * (Highstock) Datetime formats for the header of the tooltip in a stock
     * chart. The format can vary within a chart depending on the currently
     * selected time range and the current data grouping.
     *
     * The default formats are:
     *
     * (see online documentation for example)
     *
     * For each of these array definitions, the first item is the format used
     * when the active time span is one unit. For instance, if the current data
     * applies to one week, the first item of the week array is used. The second
     * and third items are used when the active time span is more than two
     * units. For instance, if the current data applies to two weeks, the second
     * and third item of the week array are used, and applied to the start and
     * end date of the time span.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.dataGrouping.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: object;
    /**
     * (Highstock) Enable or disable data grouping.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.dataGrouping.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When data grouping is forced, it runs no matter how small the
     * intervals are. This can be handy for example when the sum should be
     * calculated for values appearing at random times within each hour.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.dataGrouping.forced
     */
    forced?: boolean;
    /**
     * (Highstock) By default only points within the visible range are grouped.
     * Enabling this option will force data grouping to calculate all grouped
     * points for a given dataset. That option prevents for example a column
     * series from calculating a grouped point partially. The effect is similar
     * to Series.getExtremesFromAll but does not affect yAxis extremes.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.dataGrouping.groupAll
     */
    groupAll?: boolean;
    /**
     * (Highstock) The approximate pixel width of each group. If for example a
     * series with 30 points is displayed over a 600 pixel wide plot area, no
     * grouping is performed. If however the series contains so many points that
     * the spacing is less than the groupPixelWidth, Highcharts will try to
     * group it into appropriate groups so that each is more or less two pixels
     * wide. If multiple series with different group pixel widths are drawn on
     * the same x axis, all series will take the greatest width. For example,
     * line series have 2px default group width, while column series have 10px.
     * If combined, both the line and the column will have 10px by default.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.dataGrouping.groupPixelWidth
     */
    groupPixelWidth?: number;
    /**
     * (Highstock) Normally, a group is indexed by the start of that group, so
     * for example when 30 daily values are grouped into one month, that month's
     * x value will be the 1st of the month. This apparently shifts the data to
     * the left. When the smoothed option is true, this is compensated for. The
     * data is shifted to the middle of the group, and min and max values are
     * preserved. Internally, this is used in the Navigator series.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.dataGrouping.smoothed
     */
    smoothed?: boolean;
    /**
     * (Highstock) An array determining what time intervals the data is allowed
     * to be grouped to. Each array item is an array where the first value is
     * the time unit and the second value another array of allowed multiples.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.dataGrouping.units
     */
    units?: Array<[string, (Array<number>|null)]>;
}
export interface RangeSelectorButtonsEventsOptions {
    /**
     * (Highstock) Fires when clicking on the rangeSelector button. One
     * parameter, event, is passed to the function, containing common event
     * information.
     *
     * (see online documentation for example)
     *
     * Return false to stop default button's click action.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.events.click
     */
    click?: RangeSelectorClickCallbackFunction;
}
/**
 * (Highstock) An array of configuration objects for the buttons.
 *
 * Defaults to
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/rangeSelector.buttons
 */
export interface RangeSelectorButtonsOptions {
    /**
     * (Highstock) How many units of the defined type the button should span. If
     * `type` is "month" and `count` is 3, the button spans three months.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.count
     */
    count?: number;
    /**
     * (Highstock) A custom data grouping object for each button.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.dataGrouping
     */
    dataGrouping?: RangeSelectorButtonsDataGroupingOptions;
    events?: RangeSelectorButtonsEventsOptions;
    /**
     * (Highstock) Additional range (in milliseconds) added to the end of the
     * calculated time span.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.offsetMax
     */
    offsetMax?: number;
    /**
     * (Highstock) Additional range (in milliseconds) added to the start of the
     * calculated time span.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.offsetMin
     */
    offsetMin?: number;
    /**
     * (Highstock) When buttons apply dataGrouping on a series, by default
     * zooming in/out will deselect buttons and unset dataGrouping. Enable this
     * option to keep buttons selected when extremes change.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.preserveDataGrouping
     */
    preserveDataGrouping?: boolean;
    /**
     * (Highstock) The text for the button itself.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.text
     */
    text?: string;
    /**
     * (Highstock) Defined the time span for the button. Can be one of
     * `millisecond`, `second`, `minute`, `hour`, `day`, `week`, `month`, `ytd`,
     * `all`.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons.type
     */
    type?: ("all"|"day"|"millisecond"|"minute"|"month"|"second"|"week"|"ytd");
}
/**
 * (Highstock) Positioning for the input boxes. Allowed properties are `align`,
 * `x` and `y`.
 *
 * @see https://api.highcharts.com/highstock/rangeSelector.inputPosition
 */
export interface RangeSelectorInputPositionOptions {
    /**
     * (Highstock) The alignment of the input box. Allowed properties are
     * `left`, `center`, `right`.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputPosition.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highstock) X offset of the input row.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputPosition.x
     */
    x?: number;
    /**
     * (Highstock) Y offset of the input row.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputPosition.y
     */
    y?: number;
}
/**
 * (Highstock) The range selector is a tool for selecting ranges to display
 * within the chart. It provides buttons to select preconfigured ranges in the
 * chart, like 1 day, 1 week, 1 month etc. It also provides input boxes where
 * min and max dates can be manually input.
 *
 * @see https://api.highcharts.com/highstock/rangeSelector
 */
export interface RangeSelectorOptions {
    /**
     * (Highstock) Whether to enable all buttons from the start. By default
     * buttons are only enabled if the corresponding time range exists on the X
     * axis, but enabling all buttons allows for dynamically loading different
     * time ranges.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.allButtonsEnabled
     */
    allButtonsEnabled?: boolean;
    /**
     * (Highstock) Positioning for the button row.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttonPosition
     */
    buttonPosition?: RangeSelectorButtonPositionOptions;
    /**
     * (Highstock) An array of configuration objects for the buttons.
     *
     * Defaults to
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttons
     */
    buttons?: Array<RangeSelectorButtonsOptions>;
    /**
     * (Highstock) The space in pixels between the buttons in the range
     * selector.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttonSpacing
     */
    buttonSpacing?: number;
    /**
     * (Highstock) A collection of attributes for the buttons. The object takes
     * SVG attributes like `fill`, `stroke`, `stroke-width`, as well as `style`,
     * a collection of CSS properties for the text.
     *
     * The object can also be extended with states, so you can set
     * presentational options for `hover`, `select` or `disabled` button states.
     *
     * CSS styles for the text label.
     *
     * In styled mode, the buttons are styled by the
     * `.highcharts-range-selector-buttons .highcharts-button` rule with its
     * different states.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.buttonTheme
     */
    buttonTheme?: CSSObject;
    /**
     * (Highstock) Enable or disable the range selector.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) When the rangeselector is floating, the plot area does not
     * reserve space for it. This opens for positioning anywhere on the chart.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.floating
     */
    floating?: boolean;
    /**
     * (Highstock) Deprecated. The height of the range selector. Currently it is
     * calculated dynamically.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.height
     */
    height?: (number|undefined);
    /**
     * (Highstock) The border color of the date input boxes.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputBoxBorderColor
     */
    inputBoxBorderColor?: ColorString;
    /**
     * (Highstock) The pixel height of the date input boxes.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputBoxHeight
     */
    inputBoxHeight?: number;
    /**
     * (Highstock) CSS for the container DIV holding the input boxes. Deprecated
     * as of 1.2.5\. Use inputPosition instead.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputBoxStyle
     */
    inputBoxStyle?: CSSObject;
    /**
     * (Highstock) The pixel width of the date input boxes.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputBoxWidth
     */
    inputBoxWidth?: number;
    /**
     * (Highstock) The date format in the input boxes when not selected for
     * editing. Defaults to `%b %e, %Y`.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputDateFormat
     */
    inputDateFormat?: string;
    /**
     * (Highstock) A custom callback function to parse values entered in the
     * input boxes and return a valid JavaScript time as milliseconds since
     * 1970.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputDateParser
     */
    inputDateParser?: RangeSelectorParseCallbackFunction;
    /**
     * (Highstock) The date format in the input boxes when they are selected for
     * editing. This must be a format that is recognized by JavaScript
     * Date.parse.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputEditDateFormat
     */
    inputEditDateFormat?: string;
    /**
     * (Highstock) Enable or disable the date input boxes. Defaults to enabled
     * when there is enough space, disabled if not (typically mobile).
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputEnabled
     */
    inputEnabled?: boolean;
    /**
     * (Highstock) Positioning for the input boxes. Allowed properties are
     * `align`, `x` and `y`.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputPosition
     */
    inputPosition?: RangeSelectorInputPositionOptions;
    /**
     * (Highstock) CSS for the HTML inputs in the range selector.
     *
     * In styled mode, the inputs are styled by the `.highcharts-range-input
     * text` rule in SVG mode, and `input.highcharts-range-selector` when
     * active.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.inputStyle
     */
    inputStyle?: CSSObject;
    /**
     * (Highstock) CSS styles for the labels - the Zoom, From and To texts.
     *
     * In styled mode, the labels are styled by the `.highcharts-range-label`
     * class.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.labelStyle
     */
    labelStyle?: CSSObject;
    /**
     * (Highstock) The index of the button to appear pre-selected.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.selected
     */
    selected?: number;
    /**
     * (Highstock) The vertical alignment of the rangeselector box. Allowed
     * properties are `top`, `middle`, `bottom`.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highstock) The x offset of the range selector relative to its horizontal
     * alignment within `chart.spacingLeft` and `chart.spacingRight`.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.x
     */
    x?: number;
    /**
     * (Highstock) The y offset of the range selector relative to its horizontal
     * alignment within `chart.spacingLeft` and `chart.spacingRight`.
     *
     * @see https://api.highcharts.com/highstock/rangeSelector.y
     */
    y?: number;
}
/**
 * A rectangle.
 */
export interface RectangleObject {
    /**
     * Height of the rectangle.
     */
    height: number;
    /**
     * Width of the rectangle.
     */
    width: number;
    /**
     * Horizontal position of the rectangle.
     */
    x: number;
    /**
     * Vertical position of the rectangle.
     */
    y: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Allows setting a set of rules to
 * apply for different screen or chart sizes. Each rule specifies additional
 * chart options.
 *
 * @see https://api.highcharts.com/highcharts/responsive
 * @see https://api.highcharts.com/highstock/responsive
 * @see https://api.highcharts.com/highmaps/responsive
 * @see https://api.highcharts.com/gantt/responsive
 */
export interface ResponsiveOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A set of rules for responsive
     * settings. The rules are executed from the top down.
     *
     * @see https://api.highcharts.com/highcharts/responsive.rules
     * @see https://api.highcharts.com/highstock/responsive.rules
     * @see https://api.highcharts.com/highmaps/responsive.rules
     * @see https://api.highcharts.com/gantt/responsive.rules
     */
    rules?: Array<ResponsiveRulesOptions>;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Under which conditions the rule
 * applies.
 *
 * @see https://api.highcharts.com/highcharts/responsive.rules.condition
 * @see https://api.highcharts.com/highstock/responsive.rules.condition
 * @see https://api.highcharts.com/highmaps/responsive.rules.condition
 * @see https://api.highcharts.com/gantt/responsive.rules.condition
 */
export interface ResponsiveRulesConditionOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A callback function to gain
     * complete control on when the responsive rule applies. Return `true` if it
     * applies. This opens for checking against other metrics than the chart
     * size, or example the document size or other elements.
     *
     * @see https://api.highcharts.com/highcharts/responsive.rules.condition.callback
     * @see https://api.highcharts.com/highstock/responsive.rules.condition.callback
     * @see https://api.highcharts.com/highmaps/responsive.rules.condition.callback
     * @see https://api.highcharts.com/gantt/responsive.rules.condition.callback
     */
    callback?: ResponsiveCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The responsive rule applies if
     * the chart height is less than this.
     *
     * @see https://api.highcharts.com/highcharts/responsive.rules.condition.maxHeight
     * @see https://api.highcharts.com/highstock/responsive.rules.condition.maxHeight
     * @see https://api.highcharts.com/highmaps/responsive.rules.condition.maxHeight
     * @see https://api.highcharts.com/gantt/responsive.rules.condition.maxHeight
     */
    maxHeight?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The responsive rule applies if
     * the chart width is less than this.
     *
     * @see https://api.highcharts.com/highcharts/responsive.rules.condition.maxWidth
     * @see https://api.highcharts.com/highstock/responsive.rules.condition.maxWidth
     * @see https://api.highcharts.com/highmaps/responsive.rules.condition.maxWidth
     * @see https://api.highcharts.com/gantt/responsive.rules.condition.maxWidth
     */
    maxWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The responsive rule applies if
     * the chart height is greater than this.
     *
     * @see https://api.highcharts.com/highcharts/responsive.rules.condition.minHeight
     * @see https://api.highcharts.com/highstock/responsive.rules.condition.minHeight
     * @see https://api.highcharts.com/highmaps/responsive.rules.condition.minHeight
     * @see https://api.highcharts.com/gantt/responsive.rules.condition.minHeight
     */
    minHeight?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The responsive rule applies if
     * the chart width is greater than this.
     *
     * @see https://api.highcharts.com/highcharts/responsive.rules.condition.minWidth
     * @see https://api.highcharts.com/highstock/responsive.rules.condition.minWidth
     * @see https://api.highcharts.com/highmaps/responsive.rules.condition.minWidth
     * @see https://api.highcharts.com/gantt/responsive.rules.condition.minWidth
     */
    minWidth?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) A set of rules for responsive
 * settings. The rules are executed from the top down.
 *
 * @see https://api.highcharts.com/highcharts/responsive.rules
 * @see https://api.highcharts.com/highstock/responsive.rules
 * @see https://api.highcharts.com/highmaps/responsive.rules
 * @see https://api.highcharts.com/gantt/responsive.rules
 */
export interface ResponsiveRulesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A full set of chart options to
     * apply as overrides to the general chart options. The chart options are
     * applied when the given rule is active.
     *
     * A special case is configuration objects that take arrays, for example
     * xAxis, yAxis or series. For these collections, an `id` option is used to
     * map the new option set to an existing object. If an existing object of
     * the same id is not found, the item of the same indexupdated. So for
     * example, setting `chartOptions` with two series items without an `id`,
     * will cause the existing chart's two series to be updated with respective
     * options.
     *
     * @see https://api.highcharts.com/highcharts/responsive.rules.chartOptions
     * @see https://api.highcharts.com/highstock/responsive.rules.chartOptions
     * @see https://api.highcharts.com/highmaps/responsive.rules.chartOptions
     * @see https://api.highcharts.com/gantt/responsive.rules.chartOptions
     */
    chartOptions?: Options;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Under which conditions the rule
     * applies.
     *
     * @see https://api.highcharts.com/highcharts/responsive.rules.condition
     * @see https://api.highcharts.com/highstock/responsive.rules.condition
     * @see https://api.highcharts.com/highmaps/responsive.rules.condition
     * @see https://api.highcharts.com/gantt/responsive.rules.condition
     */
    condition?: ResponsiveRulesConditionOptions;
}
/**
 * (Highstock) The scrollbar is a means of panning over the X axis of a stock
 * chart. Scrollbars can also be applied to other types of axes.
 *
 * Another approach to scrollable charts is the chart.scrollablePlotArea option
 * that is especially suitable for simpler cartesian charts on mobile.
 *
 * In styled mode, all the presentational options for the scrollbar are replaced
 * by the classes `.highcharts-scrollbar-thumb`, `.highcharts-scrollbar-arrow`,
 * `.highcharts-scrollbar-button`, `.highcharts-scrollbar-rifles` and
 * `.highcharts-scrollbar-track`.
 *
 * @see https://api.highcharts.com/highstock/scrollbar
 */
export interface ScrollbarOptions {
    /**
     * (Highstock) The background color of the scrollbar itself.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.barBackgroundColor
     */
    barBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the scrollbar's border.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.barBorderColor
     */
    barBorderColor?: ColorString;
    /**
     * (Highstock) The border rounding radius of the bar.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.barBorderRadius
     */
    barBorderRadius?: number;
    /**
     * (Highstock) The width of the bar's border.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.barBorderWidth
     */
    barBorderWidth?: number;
    /**
     * (Highstock) The color of the small arrow inside the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.buttonArrowColor
     */
    buttonArrowColor?: ColorString;
    /**
     * (Highstock) The color of scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.buttonBackgroundColor
     */
    buttonBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the border of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.buttonBorderColor
     */
    buttonBorderColor?: ColorString;
    /**
     * (Highstock) The corner radius of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.buttonBorderRadius
     */
    buttonBorderRadius?: number;
    /**
     * (Highstock) The border width of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.buttonBorderWidth
     */
    buttonBorderWidth?: number;
    /**
     * (Highstock) Enable or disable the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The height of the scrollbar. The height also applies to the
     * width of the scroll arrows so that they are always squares. Defaults to
     * 20 for touch devices and 14 for mouse devices.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.height
     */
    height?: number;
    /**
     * (Highstock) Whether to redraw the main chart as the scrollbar or the
     * navigator zoomed window is moved. Defaults to `true` for modern browsers
     * and `false` for legacy IE browsers as well as mobile devices.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.liveRedraw
     */
    liveRedraw?: boolean;
    /**
     * (Highstock) The margin between the scrollbar and its axis when the
     * scrollbar is applied directly to an axis.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.margin
     */
    margin?: number;
    /**
     * (Highstock) The minimum width of the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.minWidth
     */
    minWidth?: number;
    /**
     * (Highstock) The color of the small rifles in the middle of the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.rifleColor
     */
    rifleColor?: ColorString;
    /**
     * (Highstock) Whether to show or hide the scrollbar when the scrolled
     * content is zoomed out to it full extent.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.showFull
     */
    showFull?: boolean;
    step?: number;
    /**
     * (Highstock) The color of the track background.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.trackBackgroundColor
     */
    trackBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.trackBorderColor
     */
    trackBorderColor?: ColorString;
    /**
     * (Highstock) The corner radius of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.trackBorderRadius
     */
    trackBorderRadius?: number;
    /**
     * (Highstock) The width of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.trackBorderWidth
     */
    trackBorderWidth?: number;
    /**
     * (Highstock) The z index of the scrollbar group.
     *
     * @see https://api.highcharts.com/highstock/scrollbar.zIndex
     */
    zIndex?: number;
}
/**
 * Axis-specific data of a selection.
 */
export interface SelectDataObject {
    axis: Axis;
    max: number;
    min: number;
}
/**
 * Object for select events.
 */
export interface SelectEventObject {
    originalEvent: Event;
    xAxis: Array<SelectDataObject>;
    yAxis: Array<SelectDataObject>;
}
/**
 * (Highstock) An Acceleration bands indicator. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `abands` series are defined in plotOptions.abands.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.abands
 */
export interface SeriesAbandsOptions extends PlotAbandsOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "abands";
}
/**
 * (Highstock) A `AD` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ad` series are defined in plotOptions.ad.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.ad
 */
export interface SeriesAdOptions extends PlotAdOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "ad";
}
/**
 * Event information regarding completed animation of a series.
 */
export interface SeriesAfterAnimateEventObject {
    /**
     * Animated series.
     */
    target: Series;
    /**
     * Event type.
     */
    type: "afterAnimate";
}
/**
 * (Highstock) An `AO` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ao` series are defined in plotOptions.ao.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.ao
 */
export interface SeriesAoOptions extends PlotAoOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "ao";
}
/**
 * (Highstock) An `Absolute Price Oscillator` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `apo` series are defined in plotOptions.apo.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.apo
 */
export interface SeriesApoOptions extends PlotApoOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "apo";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragHandle
 */
export interface SeriesAreaDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.guideBox.default
 */
export interface SeriesAreaDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.guideBox
 */
export interface SeriesAreaDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.guideBox.default
     */
    default?: SeriesAreaDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.area.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.area.data.dragDrop
 */
export interface SeriesAreaDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesAreaDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.guideBox
     */
    guideBox?: (SeriesAreaDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.events
 * @see https://api.highcharts.com/highstock/series.area.data.events
 * @see https://api.highcharts.com/gantt/series.area.data.events
 */
export interface SeriesAreaDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events.click
     * @see https://api.highcharts.com/highstock/series.area.data.events.click
     * @see https://api.highcharts.com/highmaps/series.area.data.events.click
     * @see https://api.highcharts.com/gantt/series.area.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events.drag
     * @see https://api.highcharts.com/highstock/series.area.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.area.data.events.drag
     * @see https://api.highcharts.com/gantt/series.area.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.area.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.area.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.area.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events.drop
     * @see https://api.highcharts.com/highstock/series.area.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.area.data.events.drop
     * @see https://api.highcharts.com/gantt/series.area.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.area.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.area.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.area.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.area.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.area.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.area.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events.remove
     * @see https://api.highcharts.com/highstock/series.area.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.area.data.events.remove
     * @see https://api.highcharts.com/gantt/series.area.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events.select
     * @see https://api.highcharts.com/highstock/series.area.data.events.select
     * @see https://api.highcharts.com/highmaps/series.area.data.events.select
     * @see https://api.highcharts.com/gantt/series.area.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.area.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.area.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.area.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events.update
     * @see https://api.highcharts.com/highstock/series.area.data.events.update
     * @see https://api.highcharts.com/highmaps/series.area.data.events.update
     * @see https://api.highcharts.com/gantt/series.area.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.marker
 * @see https://api.highcharts.com/highstock/series.area.data.marker
 */
export interface SeriesAreaDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.area.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.area.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.area.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.area.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.area.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.area.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.height
     * @see https://api.highcharts.com/highstock/series.area.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.height
     * @see https://api.highcharts.com/gantt/series.area.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.area.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.area.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.area.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.area.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.area.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.area.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states
     */
    states?: SeriesAreaDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.area.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.area.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.width
     * @see https://api.highcharts.com/highstock/series.area.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.width
     * @see https://api.highcharts.com/gantt/series.area.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover.animation
 */
export interface SeriesAreaDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover
 */
export interface SeriesAreaDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesAreaDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.area.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.area.data.marker.states.normal
 */
export interface SeriesAreaDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.marker.states
 * @see https://api.highcharts.com/highstock/series.area.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.area.data.marker.states
 * @see https://api.highcharts.com/gantt/series.area.data.marker.states
 */
export interface SeriesAreaDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.hover
     */
    hover?: SeriesAreaDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.normal
     */
    normal?: SeriesAreaDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.select
     */
    select?: SeriesAreaDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.area.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.area.data.marker.states.select
 */
export interface SeriesAreaDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.area.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.area.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.area.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `area` series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` * and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.area.data
 * @see https://api.highcharts.com/highstock/series.area.data
 */
export interface SeriesAreaDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.className
     * @see https://api.highcharts.com/gantt/series.area.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.color
     * @see https://api.highcharts.com/highstock/series.area.data.color
     * @see https://api.highcharts.com/gantt/series.area.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.area.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.area.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.area.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.description
     * @see https://api.highcharts.com/highstock/series.area.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.area.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.area.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.area.data.dragDrop
     */
    dragDrop?: SeriesAreaDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.events
     * @see https://api.highcharts.com/highstock/series.area.data.events
     * @see https://api.highcharts.com/gantt/series.area.data.events
     */
    events?: SeriesAreaDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.id
     * @see https://api.highcharts.com/highstock/series.area.data.id
     * @see https://api.highcharts.com/gantt/series.area.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.labelrank
     * @see https://api.highcharts.com/highstock/series.area.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.marker
     * @see https://api.highcharts.com/highstock/series.area.data.marker
     */
    marker?: SeriesAreaDataMarkerOptions;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.name
     * @see https://api.highcharts.com/highstock/series.area.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.selected
     * @see https://api.highcharts.com/highstock/series.area.data.selected
     * @see https://api.highcharts.com/gantt/series.area.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.x
     * @see https://api.highcharts.com/highstock/series.area.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.area.data.y
     * @see https://api.highcharts.com/highstock/series.area.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `area` series. If the type option is not specified,
 * it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `area` series are defined in plotOptions.area.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.area
 * @see https://api.highcharts.com/highstock/series.area
 */
export interface SeriesAreaOptions extends PlotAreaOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `area` series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` * and `pointInterval` given in the series options. If the
     * axis has categories, these will be used. Example:(see online
     * documentation for example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.area.data
     * @see https://api.highcharts.com/highstock/series.area.data
     */
    data?: Array<(number|[(number|string), number]|SeriesAreaDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "area";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragHandle
 */
export interface SeriesArearangeDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.guideBox.default
 */
export interface SeriesArearangeDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.guideBox
 */
export interface SeriesArearangeDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.guideBox.default
     */
    default?: SeriesArearangeDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop
 */
export interface SeriesArearangeDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesArearangeDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.guideBox
     */
    guideBox?: (SeriesArearangeDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.arearange.data.events
 * @see https://api.highcharts.com/highstock/series.arearange.data.events
 * @see https://api.highcharts.com/gantt/series.arearange.data.events
 */
export interface SeriesArearangeDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events.click
     * @see https://api.highcharts.com/highstock/series.arearange.data.events.click
     * @see https://api.highcharts.com/highmaps/series.arearange.data.events.click
     * @see https://api.highcharts.com/gantt/series.arearange.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events.drag
     * @see https://api.highcharts.com/highstock/series.arearange.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.arearange.data.events.drag
     * @see https://api.highcharts.com/gantt/series.arearange.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.arearange.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.arearange.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.arearange.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events.drop
     * @see https://api.highcharts.com/highstock/series.arearange.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.arearange.data.events.drop
     * @see https://api.highcharts.com/gantt/series.arearange.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.arearange.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.arearange.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.arearange.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.arearange.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.arearange.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.arearange.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events.remove
     * @see https://api.highcharts.com/highstock/series.arearange.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.arearange.data.events.remove
     * @see https://api.highcharts.com/gantt/series.arearange.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events.select
     * @see https://api.highcharts.com/highstock/series.arearange.data.events.select
     * @see https://api.highcharts.com/highmaps/series.arearange.data.events.select
     * @see https://api.highcharts.com/gantt/series.arearange.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.arearange.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.arearange.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.arearange.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events.update
     * @see https://api.highcharts.com/highstock/series.arearange.data.events.update
     * @see https://api.highcharts.com/highmaps/series.arearange.data.events.update
     * @see https://api.highcharts.com/gantt/series.arearange.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `arearange` series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 or 2 values. In this case, the values correspond
 * to `x,low,high`. If the first value is a string, it is applied as the name of
 * the point, and the `x` value is inferred. The `x` value can also be omitted,
 * in which case the inner arrays should be of length 2\. Then the `x` value is
 * automatically calculated, either starting at 0 and incremented by 1, or from
 * `pointStart` and `pointInterval` given in the series options.(see online
 * documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.arearange.data
 * @see https://api.highcharts.com/highstock/series.arearange.data
 */
export interface SeriesArearangeDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.className
     * @see https://api.highcharts.com/gantt/series.arearange.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.color
     * @see https://api.highcharts.com/highstock/series.arearange.data.color
     * @see https://api.highcharts.com/gantt/series.arearange.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.arearange.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.arearange.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.arearange.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.description
     * @see https://api.highcharts.com/highstock/series.arearange.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.arearange.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.arearange.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.arearange.data.dragDrop
     */
    dragDrop?: SeriesArearangeDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.events
     * @see https://api.highcharts.com/highstock/series.arearange.data.events
     * @see https://api.highcharts.com/gantt/series.arearange.data.events
     */
    events?: SeriesArearangeDataEventsOptions;
    /**
     * (Highcharts, Highstock) The high or maximum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.high
     * @see https://api.highcharts.com/highstock/series.arearange.data.high
     */
    high?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.id
     * @see https://api.highcharts.com/highstock/series.arearange.data.id
     * @see https://api.highcharts.com/gantt/series.arearange.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.labelrank
     * @see https://api.highcharts.com/highstock/series.arearange.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) The low or minimum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.low
     * @see https://api.highcharts.com/highstock/series.arearange.data.low
     */
    low?: number;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.name
     * @see https://api.highcharts.com/highstock/series.arearange.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.selected
     * @see https://api.highcharts.com/highstock/series.arearange.data.selected
     * @see https://api.highcharts.com/gantt/series.arearange.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data.x
     * @see https://api.highcharts.com/highstock/series.arearange.data.x
     */
    x?: number;
}
/**
 * (Highcharts, Highstock) A `arearange` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `arearange` series are defined in plotOptions.arearange.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.arearange
 * @see https://api.highcharts.com/highstock/series.arearange
 */
export interface SeriesArearangeOptions extends PlotArearangeOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `arearange` series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 or 2 values. In this case, the values
     * correspond to `x,low,high`. If the first value is a string, it is applied
     * as the name of the point, and the `x` value is inferred. The `x` value
     * can also be omitted, in which case the inner arrays should be of length
     * 2\. Then the `x` value is automatically calculated, either starting at 0
     * and incremented by 1, or from `pointStart` and `pointInterval` given in
     * the series options.(see online documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.arearange.data
     * @see https://api.highcharts.com/highstock/series.arearange.data
     */
    data?: Array<([(number|string), number]|[(number|string), number, number]|SeriesArearangeDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "arearange";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragHandle
 */
export interface SeriesAreasplineDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.guideBox.default
 */
export interface SeriesAreasplineDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.guideBox
 */
export interface SeriesAreasplineDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.guideBox.default
     */
    default?: SeriesAreasplineDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop
 */
export interface SeriesAreasplineDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesAreasplineDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.guideBox
     */
    guideBox?: (SeriesAreasplineDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.events
 * @see https://api.highcharts.com/highstock/series.areaspline.data.events
 * @see https://api.highcharts.com/gantt/series.areaspline.data.events
 */
export interface SeriesAreasplineDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events.click
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events.click
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.events.click
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events.drag
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.events.drag
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events.drop
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.events.drop
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events.remove
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.events.remove
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events.select
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events.select
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.events.select
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events.update
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events.update
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.events.update
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker
 * @see https://api.highcharts.com/highstock/series.areaspline.data.marker
 */
export interface SeriesAreasplineDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.height
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.height
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states
     */
    states?: SeriesAreasplineDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.width
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.width
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover.animation
 */
export interface SeriesAreasplineDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover
 */
export interface SeriesAreasplineDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesAreasplineDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.normal
 */
export interface SeriesAreasplineDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states
 * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states
 * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states
 */
export interface SeriesAreasplineDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.hover
     */
    hover?: SeriesAreasplineDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.normal
     */
    normal?: SeriesAreasplineDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.select
     */
    select?: SeriesAreasplineDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.select
 */
export interface SeriesAreasplineDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.areaspline.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `areaspline` series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline.data
 * @see https://api.highcharts.com/highstock/series.areaspline.data
 */
export interface SeriesAreasplineDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.className
     * @see https://api.highcharts.com/gantt/series.areaspline.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.color
     * @see https://api.highcharts.com/highstock/series.areaspline.data.color
     * @see https://api.highcharts.com/gantt/series.areaspline.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.areaspline.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.description
     * @see https://api.highcharts.com/highstock/series.areaspline.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.areaspline.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.areaspline.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.areaspline.data.dragDrop
     */
    dragDrop?: SeriesAreasplineDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.events
     * @see https://api.highcharts.com/highstock/series.areaspline.data.events
     * @see https://api.highcharts.com/gantt/series.areaspline.data.events
     */
    events?: SeriesAreasplineDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.id
     * @see https://api.highcharts.com/highstock/series.areaspline.data.id
     * @see https://api.highcharts.com/gantt/series.areaspline.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.labelrank
     * @see https://api.highcharts.com/highstock/series.areaspline.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.marker
     * @see https://api.highcharts.com/highstock/series.areaspline.data.marker
     */
    marker?: SeriesAreasplineDataMarkerOptions;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.name
     * @see https://api.highcharts.com/highstock/series.areaspline.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.selected
     * @see https://api.highcharts.com/highstock/series.areaspline.data.selected
     * @see https://api.highcharts.com/gantt/series.areaspline.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.x
     * @see https://api.highcharts.com/highstock/series.areaspline.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data.y
     * @see https://api.highcharts.com/highstock/series.areaspline.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `areaspline` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `areaspline` series are defined in plotOptions.areaspline.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.areaspline
 * @see https://api.highcharts.com/highstock/series.areaspline
 */
export interface SeriesAreasplineOptions extends PlotAreasplineOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `areaspline` series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.areaspline.data
     * @see https://api.highcharts.com/highstock/series.areaspline.data
     */
    data?: Array<(number|[(number|string), number]|SeriesAreasplineDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "areaspline";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragHandle
 */
export interface SeriesAreasplinerangeDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.guideBox.default
 */
export interface SeriesAreasplinerangeDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.guideBox
 */
export interface SeriesAreasplinerangeDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.guideBox.default
     */
    default?: SeriesAreasplinerangeDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop
 */
export interface SeriesAreasplinerangeDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesAreasplinerangeDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.guideBox
     */
    guideBox?: (SeriesAreasplinerangeDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events
 * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events
 * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events
 */
export interface SeriesAreasplinerangeDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events.click
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events.click
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.events.click
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events.drag
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.events.drag
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events.drop
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.events.drop
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events.remove
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.events.remove
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events.select
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events.select
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.events.select
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events.update
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events.update
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.events.update
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `areasplinerange` series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 or 2 values. In this case, the values correspond
 * to `x,low,high`. If the first value is a string, it is applied as the name of
 * the point, and the `x` value is inferred. The `x` value can also be omitted,
 * in which case the inner arrays should be of length 2\. Then the `x` value is
 * automatically calculated, either starting at 0 and incremented by 1, or from
 * `pointStart` and `pointInterval` given in the series options.(see online
 * documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.areasplinerange.data
 * @see https://api.highcharts.com/highstock/series.areasplinerange.data
 */
export interface SeriesAreasplinerangeDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.className
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.color
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.color
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.description
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.areasplinerange.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.dragDrop
     */
    dragDrop?: SeriesAreasplinerangeDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.events
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.events
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.events
     */
    events?: SeriesAreasplinerangeDataEventsOptions;
    /**
     * (Highcharts, Highstock) The high or maximum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.high
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.high
     */
    high?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.id
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.id
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.labelrank
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) The low or minimum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.low
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.low
     */
    low?: number;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.name
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.selected
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.selected
     * @see https://api.highcharts.com/gantt/series.areasplinerange.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data.x
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data.x
     */
    x?: number;
}
/**
 * (Highcharts, Highstock) A `areasplinerange` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `areasplinerange` series are defined in
 * plotOptions.areasplinerange.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.areasplinerange
 * @see https://api.highcharts.com/highstock/series.areasplinerange
 */
export interface SeriesAreasplinerangeOptions extends PlotAreasplinerangeOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `areasplinerange` series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 or 2 values. In this case, the values
     * correspond to `x,low,high`. If the first value is a string, it is applied
     * as the name of the point, and the `x` value is inferred. The `x` value
     * can also be omitted, in which case the inner arrays should be of length
     * 2\. Then the `x` value is automatically calculated, either starting at 0
     * and incremented by 1, or from `pointStart` and `pointInterval` given in
     * the series options.(see online documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.areasplinerange.data
     * @see https://api.highcharts.com/highstock/series.areasplinerange.data
     */
    data?: Array<([(number|string), number]|[(number|string), number, number]|SeriesAreasplinerangeDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "areasplinerange";
}
/**
 * (Highstock) A Aroon indicator. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `aroon` series are defined in plotOptions.aroon.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.aroon
 */
export interface SeriesAroonOptions extends PlotAroonOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "aroon";
}
/**
 * (Highstock) An `Aroon Oscillator` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `aroonoscillator` series are defined in
 * plotOptions.aroonoscillator.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.aroonoscillator
 */
export interface SeriesAroonoscillatorOptions extends PlotAroonoscillatorOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "aroonoscillator";
}
/**
 * (Highstock) A `ATR` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `atr` series are defined in plotOptions.atr.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.atr
 */
export interface SeriesAtrOptions extends PlotAtrOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "atr";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragHandle
 */
export interface SeriesBarDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.guideBox.default
 */
export interface SeriesBarDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.guideBox
 */
export interface SeriesBarDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.guideBox.default
     */
    default?: SeriesBarDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop
 */
export interface SeriesBarDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesBarDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.guideBox
     */
    guideBox?: (SeriesBarDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.bar.data.events
 * @see https://api.highcharts.com/highstock/series.bar.data.events
 * @see https://api.highcharts.com/gantt/series.bar.data.events
 */
export interface SeriesBarDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events.click
     * @see https://api.highcharts.com/highstock/series.bar.data.events.click
     * @see https://api.highcharts.com/highmaps/series.bar.data.events.click
     * @see https://api.highcharts.com/gantt/series.bar.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events.drag
     * @see https://api.highcharts.com/highstock/series.bar.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.bar.data.events.drag
     * @see https://api.highcharts.com/gantt/series.bar.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.bar.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.bar.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.bar.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events.drop
     * @see https://api.highcharts.com/highstock/series.bar.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.bar.data.events.drop
     * @see https://api.highcharts.com/gantt/series.bar.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.bar.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.bar.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.bar.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.bar.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.bar.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.bar.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events.remove
     * @see https://api.highcharts.com/highstock/series.bar.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.bar.data.events.remove
     * @see https://api.highcharts.com/gantt/series.bar.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events.select
     * @see https://api.highcharts.com/highstock/series.bar.data.events.select
     * @see https://api.highcharts.com/highmaps/series.bar.data.events.select
     * @see https://api.highcharts.com/gantt/series.bar.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.bar.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.bar.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.bar.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events.update
     * @see https://api.highcharts.com/highstock/series.bar.data.events.update
     * @see https://api.highcharts.com/highmaps/series.bar.data.events.update
     * @see https://api.highcharts.com/gantt/series.bar.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `bar` series
 * type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.bar.data
 */
export interface SeriesBarDataOptions {
    /**
     * (Highcharts, Highstock) The color of the border surrounding the column or
     * bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.borderColor
     * @see https://api.highcharts.com/highstock/series.bar.data.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the border surrounding the column or
     * bar.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.borderWidth
     * @see https://api.highcharts.com/highstock/series.bar.data.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.className
     * @see https://api.highcharts.com/gantt/series.bar.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.color
     * @see https://api.highcharts.com/highstock/series.bar.data.color
     * @see https://api.highcharts.com/gantt/series.bar.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.bar.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.bar.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.bar.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.bar.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.bar.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.bar.data.dragDrop
     */
    dragDrop?: SeriesBarDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.events
     * @see https://api.highcharts.com/highstock/series.bar.data.events
     * @see https://api.highcharts.com/gantt/series.bar.data.events
     */
    events?: SeriesBarDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.id
     * @see https://api.highcharts.com/highstock/series.bar.data.id
     * @see https://api.highcharts.com/gantt/series.bar.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * the column or bar. Overrides pointWidth on the series.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.pointWidth
     * @see https://api.highcharts.com/highstock/series.bar.data.pointWidth
     * @see https://api.highcharts.com/gantt/series.bar.data.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.selected
     * @see https://api.highcharts.com/highstock/series.bar.data.selected
     * @see https://api.highcharts.com/gantt/series.bar.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.x
     * @see https://api.highcharts.com/highstock/series.bar.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data.y
     * @see https://api.highcharts.com/highstock/series.bar.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `bar` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `bar` series are defined in plotOptions.bar.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.bar
 */
export interface SeriesBarOptions extends PlotBarOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `bar` series
     * type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.bar.data
     */
    data?: Array<(number|[(number|string), number]|SeriesBarDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "bar";
}
/**
 * (Highstock) A bollinger bands indicator. If the type option is not specified,
 * it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `bb` series are defined in plotOptions.bb.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.bb
 */
export interface SeriesBbOptions extends PlotBbOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "bb";
}
/**
 * (Highcharts) A `bellcurve` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * For options that apply to multiple series, it is recommended to add them to
 * the plotOptions.series options structure. To apply to all series of this
 * specific type, apply it to plotOptions.bellcurve.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `bellcurve` series are defined in plotOptions.bellcurve.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.bellcurve
 */
export interface SeriesBellcurveOptions extends PlotBellcurveOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "bellcurve";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragHandle
 */
export interface SeriesBoxplotDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.guideBox.default
 */
export interface SeriesBoxplotDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.guideBox
 */
export interface SeriesBoxplotDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.guideBox.default
     */
    default?: SeriesBoxplotDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop
 */
export interface SeriesBoxplotDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesBoxplotDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.guideBox
     */
    guideBox?: (SeriesBoxplotDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.boxplot.data.events
 * @see https://api.highcharts.com/highstock/series.boxplot.data.events
 * @see https://api.highcharts.com/gantt/series.boxplot.data.events
 */
export interface SeriesBoxplotDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events.click
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events.click
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.events.click
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events.drag
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.events.drag
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events.drop
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.events.drop
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events.remove
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.events.remove
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events.select
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events.select
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.events.select
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events.update
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events.update
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.events.update
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `boxplot` series
 * type, points can be given in the following ways:
 *
 * 1. An array of arrays with 6 or 5 values. In this case, the values correspond
 * to `x,low,q1,median,q3,high`. If the first value is a string, it is applied
 * as the name of the point, and the `x` value is inferred. The `x` value can
 * also be omitted, in which case the inner arrays should be of length 5. Then
 * the `x` value is automatically calculated, either starting at 0 and
 * incremented by 1, or from `pointStart` and `pointInterval` given in the
 * series options.(see online documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.boxplot.data
 */
export interface SeriesBoxplotDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.className
     * @see https://api.highcharts.com/gantt/series.boxplot.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.color
     * @see https://api.highcharts.com/highstock/series.boxplot.data.color
     * @see https://api.highcharts.com/gantt/series.boxplot.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.boxplot.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.boxplot.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.boxplot.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.boxplot.data.dragDrop
     */
    dragDrop?: SeriesBoxplotDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.events
     * @see https://api.highcharts.com/highstock/series.boxplot.data.events
     * @see https://api.highcharts.com/gantt/series.boxplot.data.events
     */
    events?: SeriesBoxplotDataEventsOptions;
    /**
     * (Highcharts) The `high` value for each data point, signifying the highest
     * value in the sample set. The top whisker is drawn here.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.high
     */
    high?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.id
     * @see https://api.highcharts.com/highstock/series.boxplot.data.id
     * @see https://api.highcharts.com/gantt/series.boxplot.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The `low` value for each data point, signifying the lowest
     * value in the sample set. The bottom whisker is drawn here.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.low
     */
    low?: number;
    /**
     * (Highcharts) The median for each data point. This is drawn as a line
     * through the middle area of the box.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.median
     */
    median?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.name
     */
    name?: string;
    /**
     * (Highcharts) The lower quartile for each data point. This is the bottom
     * of the box.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.q1
     */
    q1?: number;
    /**
     * (Highcharts) The higher quartile for each data point. This is the top of
     * the box.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.q3
     */
    q3?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.selected
     * @see https://api.highcharts.com/highstock/series.boxplot.data.selected
     * @see https://api.highcharts.com/gantt/series.boxplot.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.x
     * @see https://api.highcharts.com/highstock/series.boxplot.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data.y
     * @see https://api.highcharts.com/highstock/series.boxplot.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `boxplot` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `boxplot` series are defined in plotOptions.boxplot.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.boxplot
 */
export interface SeriesBoxplotOptions extends PlotBoxplotOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `boxplot`
     * series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 6 or 5 values. In this case, the values
     * correspond to `x,low,q1,median,q3,high`. If the first value is a string,
     * it is applied as the name of the point, and the `x` value is inferred.
     * The `x` value can also be omitted, in which case the inner arrays should
     * be of length 5. Then the `x` value is automatically calculated, either
     * starting at 0 and incremented by 1, or from `pointStart` and
     * `pointInterval` given in the series options.(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.boxplot.data
     */
    data?: Array<([(number|string), number, number, number, number]|[(number|string), number, number, number, number, number]|SeriesBoxplotDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "boxplot";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragHandle
 */
export interface SeriesBubbleDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.guideBox.default
 */
export interface SeriesBubbleDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.guideBox
 */
export interface SeriesBubbleDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.guideBox.default
     */
    default?: SeriesBubbleDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop
 */
export interface SeriesBubbleDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesBubbleDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.guideBox
     */
    guideBox?: (SeriesBubbleDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.bubble.data.events
 * @see https://api.highcharts.com/highstock/series.bubble.data.events
 * @see https://api.highcharts.com/gantt/series.bubble.data.events
 */
export interface SeriesBubbleDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events.click
     * @see https://api.highcharts.com/highstock/series.bubble.data.events.click
     * @see https://api.highcharts.com/highmaps/series.bubble.data.events.click
     * @see https://api.highcharts.com/gantt/series.bubble.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events.drag
     * @see https://api.highcharts.com/highstock/series.bubble.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.bubble.data.events.drag
     * @see https://api.highcharts.com/gantt/series.bubble.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.bubble.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.bubble.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.bubble.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events.drop
     * @see https://api.highcharts.com/highstock/series.bubble.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.bubble.data.events.drop
     * @see https://api.highcharts.com/gantt/series.bubble.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.bubble.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.bubble.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.bubble.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.bubble.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.bubble.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.bubble.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events.remove
     * @see https://api.highcharts.com/highstock/series.bubble.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.bubble.data.events.remove
     * @see https://api.highcharts.com/gantt/series.bubble.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events.select
     * @see https://api.highcharts.com/highstock/series.bubble.data.events.select
     * @see https://api.highcharts.com/highmaps/series.bubble.data.events.select
     * @see https://api.highcharts.com/gantt/series.bubble.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.bubble.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.bubble.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.bubble.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events.update
     * @see https://api.highcharts.com/highstock/series.bubble.data.events.update
     * @see https://api.highcharts.com/highmaps/series.bubble.data.events.update
     * @see https://api.highcharts.com/gantt/series.bubble.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `bubble` series
 * type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 or 2 values. In this case, the values correspond
 * to `x,y,z`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred. The `x` value can also be omitted, in
 * which case the inner arrays should be of length 2\. Then the `x` value is
 * automatically calculated, either starting at 0 and incremented by 1, or from
 * `pointStart` and `pointInterval` given in the series options.(see online
 * documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.bubble.data
 */
export interface SeriesBubbleDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.className
     * @see https://api.highcharts.com/gantt/series.bubble.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.color
     * @see https://api.highcharts.com/highstock/series.bubble.data.color
     * @see https://api.highcharts.com/gantt/series.bubble.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.bubble.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.bubble.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.bubble.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.bubble.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.bubble.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.bubble.data.dragDrop
     */
    dragDrop?: SeriesBubbleDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.events
     * @see https://api.highcharts.com/highstock/series.bubble.data.events
     * @see https://api.highcharts.com/gantt/series.bubble.data.events
     */
    events?: SeriesBubbleDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.id
     * @see https://api.highcharts.com/highstock/series.bubble.data.id
     * @see https://api.highcharts.com/gantt/series.bubble.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.selected
     * @see https://api.highcharts.com/highstock/series.bubble.data.selected
     * @see https://api.highcharts.com/gantt/series.bubble.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.x
     * @see https://api.highcharts.com/highstock/series.bubble.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.y
     * @see https://api.highcharts.com/highstock/series.bubble.data.y
     */
    y?: number;
    /**
     * (Highcharts) The size value for each bubble. The bubbles' diameters are
     * computed based on the `z`, and controlled by series options like
     * `minSize`, `maxSize`, `sizeBy`, `zMin` and `zMax`.
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data.z
     */
    z?: number;
}
/**
 * (Highcharts, Highstock) A `bubble` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `bubble` series are defined in plotOptions.bubble.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.bubble
 * @see https://api.highcharts.com/highstock/series.bubble
 */
export interface SeriesBubbleOptions extends PlotBubbleOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `bubble`
     * series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 or 2 values. In this case, the values
     * correspond to `x,y,z`. If the first value is a string, it is applied as
     * the name of the point, and the `x` value is inferred. The `x` value can
     * also be omitted, in which case the inner arrays should be of length 2\.
     * Then the `x` value is automatically calculated, either starting at 0 and
     * incremented by 1, or from `pointStart` and `pointInterval` given in the
     * series options.(see online documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.bubble.data
     */
    data?: Array<([(number|string), number]|[(number|string), number, number]|SeriesBubbleDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "bubble";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragHandle
 */
export interface SeriesBulletDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.guideBox.default
 */
export interface SeriesBulletDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.guideBox
 */
export interface SeriesBulletDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.guideBox.default
     */
    default?: SeriesBulletDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop
 */
export interface SeriesBulletDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesBulletDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.guideBox
     */
    guideBox?: (SeriesBulletDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.bullet.data.events
 * @see https://api.highcharts.com/highstock/series.bullet.data.events
 * @see https://api.highcharts.com/gantt/series.bullet.data.events
 */
export interface SeriesBulletDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events.click
     * @see https://api.highcharts.com/highstock/series.bullet.data.events.click
     * @see https://api.highcharts.com/highmaps/series.bullet.data.events.click
     * @see https://api.highcharts.com/gantt/series.bullet.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events.drag
     * @see https://api.highcharts.com/highstock/series.bullet.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.bullet.data.events.drag
     * @see https://api.highcharts.com/gantt/series.bullet.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.bullet.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.bullet.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.bullet.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events.drop
     * @see https://api.highcharts.com/highstock/series.bullet.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.bullet.data.events.drop
     * @see https://api.highcharts.com/gantt/series.bullet.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.bullet.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.bullet.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.bullet.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.bullet.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.bullet.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.bullet.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events.remove
     * @see https://api.highcharts.com/highstock/series.bullet.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.bullet.data.events.remove
     * @see https://api.highcharts.com/gantt/series.bullet.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events.select
     * @see https://api.highcharts.com/highstock/series.bullet.data.events.select
     * @see https://api.highcharts.com/highmaps/series.bullet.data.events.select
     * @see https://api.highcharts.com/gantt/series.bullet.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.bullet.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.bullet.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.bullet.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events.update
     * @see https://api.highcharts.com/highstock/series.bullet.data.events.update
     * @see https://api.highcharts.com/highmaps/series.bullet.data.events.update
     * @see https://api.highcharts.com/gantt/series.bullet.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `bullet` series
 * type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 or 2 values. In this case, the values correspond
 * to `x,y,target`. If the first value is a string, it is applied as the name of
 * the point, and the `x` value is inferred. The `x` value can also be omitted,
 * in which case the inner arrays should be of length 2\. Then the `x` value is
 * automatically calculated, either starting at 0 and incremented by 1, or from
 * `pointStart` and `pointInterval` given in the series options.(see online
 * documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.bullet.data
 */
export interface SeriesBulletDataOptions {
    /**
     * (Highcharts, Highstock) The color of the border surrounding the column or
     * bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.borderColor
     * @see https://api.highcharts.com/highstock/series.bullet.data.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the border surrounding the column or
     * bar.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.borderWidth
     * @see https://api.highcharts.com/highstock/series.bullet.data.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.className
     * @see https://api.highcharts.com/gantt/series.bullet.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.color
     * @see https://api.highcharts.com/highstock/series.bullet.data.color
     * @see https://api.highcharts.com/gantt/series.bullet.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.bullet.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.bullet.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.bullet.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.bullet.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.bullet.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.bullet.data.dragDrop
     */
    dragDrop?: SeriesBulletDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.events
     * @see https://api.highcharts.com/highstock/series.bullet.data.events
     * @see https://api.highcharts.com/gantt/series.bullet.data.events
     */
    events?: SeriesBulletDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.id
     * @see https://api.highcharts.com/highstock/series.bullet.data.id
     * @see https://api.highcharts.com/gantt/series.bullet.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * the column or bar. Overrides pointWidth on the series.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.pointWidth
     * @see https://api.highcharts.com/highstock/series.bullet.data.pointWidth
     * @see https://api.highcharts.com/gantt/series.bullet.data.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.selected
     * @see https://api.highcharts.com/highstock/series.bullet.data.selected
     * @see https://api.highcharts.com/gantt/series.bullet.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) The target value of a point.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.target
     */
    target?: number;
    /**
     * (Highcharts) Individual target options for each point.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.targetOptions
     */
    targetOptions?: SeriesBulletDataTargetOptions;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.x
     * @see https://api.highcharts.com/highstock/series.bullet.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.y
     * @see https://api.highcharts.com/highstock/series.bullet.data.y
     */
    y?: number;
}
/**
 * (Highcharts) Individual target options for each point.
 *
 * @see https://api.highcharts.com/highcharts/series.bullet.data.targetOptions
 */
export interface SeriesBulletDataTargetOptions {
    /**
     * (Highcharts) The border color of the rectangle representing the target.
     * When not set, the point's border color is used.
     *
     * In styled mode, use class `highcharts-bullet-target` instead.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.targetOptions.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts) The border width of the rectangle representing the target.
     *
     * In styled mode, use class `highcharts-bullet-target` instead.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.targetOptions.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts) The color of the rectangle representing the target. When not
     * set, point's color (if set in point's options - `color`) or zone of the
     * target value (if `zones` or `negativeColor` are set) or the same color as
     * the point has is used.
     *
     * In styled mode, use class `highcharts-bullet-target` instead.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.targetOptions.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Highcharts) The height of the rectangle representing the target.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.targetOptions.height
     */
    height?: number;
    /**
     * (Highcharts) The width of the rectangle representing the target. Could be
     * set as a pixel value or as a percentage of a column width.
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data.targetOptions.width
     */
    width?: (number|string);
}
/**
 * (Highcharts) A `bullet` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `bullet` series are defined in plotOptions.bullet.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.bullet
 */
export interface SeriesBulletOptions extends PlotBulletOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `bullet`
     * series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 or 2 values. In this case, the values
     * correspond to `x,y,target`. If the first value is a string, it is applied
     * as the name of the point, and the `x` value is inferred. The `x` value
     * can also be omitted, in which case the inner arrays should be of length
     * 2\. Then the `x` value is automatically calculated, either starting at 0
     * and incremented by 1, or from `pointStart` and `pointInterval` given in
     * the series options.(see online documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.bullet.data
     */
    data?: Array<([(number|string), number]|[(number|string), number, number]|SeriesBulletDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "bullet";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragHandle
 */
export interface SeriesCandlestickDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.guideBox.default
 */
export interface SeriesCandlestickDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.guideBox
 */
export interface SeriesCandlestickDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.guideBox.default
     */
    default?: SeriesCandlestickDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop
 */
export interface SeriesCandlestickDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesCandlestickDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.guideBox
     */
    guideBox?: (SeriesCandlestickDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.candlestick.data.events
 * @see https://api.highcharts.com/highstock/series.candlestick.data.events
 * @see https://api.highcharts.com/gantt/series.candlestick.data.events
 */
export interface SeriesCandlestickDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events.click
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events.click
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.events.click
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events.drag
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.events.drag
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events.drop
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.events.drop
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events.remove
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.events.remove
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events.select
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events.select
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.events.select
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events.update
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events.update
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.events.update
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) An array of data points for the series. For the `candlestick`
 * series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 5 or 4 values. In this case, the values correspond
 * to `x,open,high,low,close`. If the first value is a string, it is applied as
 * the name of the point, and the `x` value is inferred. The `x` value can also
 * be omitted, in which case the inner arrays should be of length 4. Then the
 * `x` value is automatically calculated, either starting at 0 and incremented
 * by 1, or from `pointStart` and `pointInterval` given in the series
 * options.(see online documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.candlestick.data
 */
export interface SeriesCandlestickDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.className
     * @see https://api.highcharts.com/gantt/series.candlestick.data.className
     */
    className?: string;
    /**
     * (Highstock) The closing value of each data point.
     *
     * @see https://api.highcharts.com/highstock/series.candlestick.data.close
     */
    close?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.color
     * @see https://api.highcharts.com/highstock/series.candlestick.data.color
     * @see https://api.highcharts.com/gantt/series.candlestick.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.candlestick.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highstock) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/series.candlestick.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.candlestick.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.candlestick.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.candlestick.data.dragDrop
     */
    dragDrop?: SeriesCandlestickDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.events
     * @see https://api.highcharts.com/highstock/series.candlestick.data.events
     * @see https://api.highcharts.com/gantt/series.candlestick.data.events
     */
    events?: SeriesCandlestickDataEventsOptions;
    /**
     * (Highcharts, Highstock) The high or maximum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.high
     * @see https://api.highcharts.com/highstock/series.candlestick.data.high
     */
    high?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.id
     * @see https://api.highcharts.com/highstock/series.candlestick.data.id
     * @see https://api.highcharts.com/gantt/series.candlestick.data.id
     */
    id?: string;
    /**
     * (Highstock) The rank for this point's data label in case of collision. If
     * two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highstock/series.candlestick.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) The low or minimum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.low
     * @see https://api.highcharts.com/highstock/series.candlestick.data.low
     */
    low?: number;
    /**
     * (Highstock) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highstock/series.candlestick.data.name
     */
    name?: string;
    /**
     * (Highstock) The opening value of each data point.
     *
     * @see https://api.highcharts.com/highstock/series.candlestick.data.open
     */
    open?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.selected
     * @see https://api.highcharts.com/highstock/series.candlestick.data.selected
     * @see https://api.highcharts.com/gantt/series.candlestick.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.candlestick.data.x
     * @see https://api.highcharts.com/highstock/series.candlestick.data.x
     */
    x?: number;
}
/**
 * (Highstock) A `candlestick` series. If the type option is not specified, it
 * is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `candlestick` series are defined in
 * plotOptions.candlestick.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.candlestick
 */
export interface SeriesCandlestickOptions extends PlotCandlestickOptions, SeriesOptions {
    /**
     * (Highstock) An array of data points for the series. For the `candlestick`
     * series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 5 or 4 values. In this case, the values
     * correspond to `x,open,high,low,close`. If the first value is a string, it
     * is applied as the name of the point, and the `x` value is inferred. The
     * `x` value can also be omitted, in which case the inner arrays should be
     * of length 4. Then the `x` value is automatically calculated, either
     * starting at 0 and incremented by 1, or from `pointStart` and
     * `pointInterval` given in the series options.(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/series.candlestick.data
     */
    data?: Array<([(number|string), number, number, number]|[(number|string), number, number, number, number]|SeriesCandlestickDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "candlestick";
}
/**
 * (Highstock) A `CCI` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `cci` series are defined in plotOptions.cci.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.cci
 */
export interface SeriesCciOptions extends PlotCciOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "cci";
}
/**
 * (Highstock) A `Chaikin Oscillator` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `chaikin` series are defined in plotOptions.chaikin.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.chaikin
 */
export interface SeriesChaikinOptions extends PlotChaikinOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "chaikin";
}
/**
 * Event information regarding check of a series box.
 */
export interface SeriesCheckboxClickEventObject {
    /**
     * Whether the box has been checked.
     */
    checked: boolean;
    /**
     * Related series.
     */
    item: Series;
    /**
     * Related series.
     */
    target: Series;
    /**
     * Event type.
     */
    type: "checkboxClick";
}
/**
 * Common information for a click event on a series.
 */
export interface SeriesClickEventObject {
    /**
     * Nearest point on the graph.
     */
    point: Point;
}
/**
 * (Highstock) A `CMF` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `cmf` series are defined in plotOptions.cmf.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.cmf
 */
export interface SeriesCmfOptions extends PlotCmfOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "cmf";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragHandle
 */
export interface SeriesColumnDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.guideBox.default
 */
export interface SeriesColumnDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.guideBox
 */
export interface SeriesColumnDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.guideBox.default
     */
    default?: SeriesColumnDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.column.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.column.data.dragDrop
 */
export interface SeriesColumnDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesColumnDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.guideBox
     */
    guideBox?: (SeriesColumnDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.column.data.events
 * @see https://api.highcharts.com/highstock/series.column.data.events
 * @see https://api.highcharts.com/gantt/series.column.data.events
 */
export interface SeriesColumnDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events.click
     * @see https://api.highcharts.com/highstock/series.column.data.events.click
     * @see https://api.highcharts.com/highmaps/series.column.data.events.click
     * @see https://api.highcharts.com/gantt/series.column.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events.drag
     * @see https://api.highcharts.com/highstock/series.column.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.column.data.events.drag
     * @see https://api.highcharts.com/gantt/series.column.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.column.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.column.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.column.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events.drop
     * @see https://api.highcharts.com/highstock/series.column.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.column.data.events.drop
     * @see https://api.highcharts.com/gantt/series.column.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.column.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.column.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.column.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.column.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.column.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.column.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events.remove
     * @see https://api.highcharts.com/highstock/series.column.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.column.data.events.remove
     * @see https://api.highcharts.com/gantt/series.column.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events.select
     * @see https://api.highcharts.com/highstock/series.column.data.events.select
     * @see https://api.highcharts.com/highmaps/series.column.data.events.select
     * @see https://api.highcharts.com/gantt/series.column.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.column.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.column.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.column.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events.update
     * @see https://api.highcharts.com/highstock/series.column.data.events.update
     * @see https://api.highcharts.com/highmaps/series.column.data.events.update
     * @see https://api.highcharts.com/gantt/series.column.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `column` series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.column.data
 * @see https://api.highcharts.com/highstock/series.column.data
 */
export interface SeriesColumnDataOptions {
    /**
     * (Highcharts, Highstock) The color of the border surrounding the column or
     * bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.borderColor
     * @see https://api.highcharts.com/highstock/series.column.data.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the border surrounding the column or
     * bar.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.borderWidth
     * @see https://api.highcharts.com/highstock/series.column.data.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.className
     * @see https://api.highcharts.com/gantt/series.column.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.color
     * @see https://api.highcharts.com/highstock/series.column.data.color
     * @see https://api.highcharts.com/gantt/series.column.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.column.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.column.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.column.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.description
     * @see https://api.highcharts.com/highstock/series.column.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.column.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.column.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.column.data.dragDrop
     */
    dragDrop?: SeriesColumnDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.events
     * @see https://api.highcharts.com/highstock/series.column.data.events
     * @see https://api.highcharts.com/gantt/series.column.data.events
     */
    events?: SeriesColumnDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.id
     * @see https://api.highcharts.com/highstock/series.column.data.id
     * @see https://api.highcharts.com/gantt/series.column.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.labelrank
     * @see https://api.highcharts.com/highstock/series.column.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.name
     * @see https://api.highcharts.com/highstock/series.column.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * the column or bar. Overrides pointWidth on the series.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.pointWidth
     * @see https://api.highcharts.com/highstock/series.column.data.pointWidth
     * @see https://api.highcharts.com/gantt/series.column.data.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.selected
     * @see https://api.highcharts.com/highstock/series.column.data.selected
     * @see https://api.highcharts.com/gantt/series.column.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.x
     * @see https://api.highcharts.com/highstock/series.column.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.column.data.y
     * @see https://api.highcharts.com/highstock/series.column.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `column` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `column` series are defined in plotOptions.column.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.column
 * @see https://api.highcharts.com/highstock/series.column
 */
export interface SeriesColumnOptions extends PlotColumnOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `column` series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.column.data
     * @see https://api.highcharts.com/highstock/series.column.data
     */
    data?: Array<(number|[(number|string), number]|SeriesColumnDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "column";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragHandle
 */
export interface SeriesColumnpyramidDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.guideBox.default
 */
export interface SeriesColumnpyramidDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.guideBox
 */
export interface SeriesColumnpyramidDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.guideBox.default
     */
    default?: SeriesColumnpyramidDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop
 */
export interface SeriesColumnpyramidDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesColumnpyramidDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.guideBox
     */
    guideBox?: (SeriesColumnpyramidDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events
 * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events
 * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events
 */
export interface SeriesColumnpyramidDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events.click
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events.click
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.events.click
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events.drag
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.events.drag
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events.drop
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.events.drop
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events.remove
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.events.remove
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events.select
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events.select
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.events.select
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events.update
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events.update
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.events.update
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `columnpyramid` series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The objects are point configuration
 * objects as seen below. If the total number of data points exceeds the series'
 * turboThreshold, this option is not available.(see online documentation for
 * example)
 *
 * @see https://api.highcharts.com/highcharts/series.columnpyramid.data
 * @see https://api.highcharts.com/highstock/series.columnpyramid.data
 */
export interface SeriesColumnpyramidDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.className
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.color
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.color
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.description
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.columnpyramid.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.dragDrop
     */
    dragDrop?: SeriesColumnpyramidDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.events
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.events
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.events
     */
    events?: SeriesColumnpyramidDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.id
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.id
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.labelrank
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.name
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.selected
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.selected
     * @see https://api.highcharts.com/gantt/series.columnpyramid.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.x
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data.y
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `columnpyramid` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `columnpyramid` series are defined in
 * plotOptions.columnpyramid.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.columnpyramid
 * @see https://api.highcharts.com/highstock/series.columnpyramid
 */
export interface SeriesColumnpyramidOptions extends PlotColumnpyramidOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `columnpyramid` series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The objects are point
     * configuration objects as seen below. If the total number of data points
     * exceeds the series' turboThreshold, this option is not available.(see
     * online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.columnpyramid.data
     * @see https://api.highcharts.com/highstock/series.columnpyramid.data
     */
    data?: Array<(number|[(number|string), number]|SeriesColumnpyramidDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "columnpyramid";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragHandle
 */
export interface SeriesColumnrangeDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.guideBox.default
 */
export interface SeriesColumnrangeDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.guideBox
 */
export interface SeriesColumnrangeDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.guideBox.default
     */
    default?: SeriesColumnrangeDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop
 */
export interface SeriesColumnrangeDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesColumnrangeDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.guideBox
     */
    guideBox?: (SeriesColumnrangeDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.columnrange.data.events
 * @see https://api.highcharts.com/highstock/series.columnrange.data.events
 * @see https://api.highcharts.com/gantt/series.columnrange.data.events
 */
export interface SeriesColumnrangeDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events.click
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events.click
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.events.click
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events.drag
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.events.drag
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events.drop
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.events.drop
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events.remove
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.events.remove
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events.select
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events.select
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.events.select
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events.update
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events.update
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.events.update
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `columnrange` series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 or 2 values. In this case, the values correspond
 * to `x,low,high`. If the first value is a string, it is applied as the name of
 * the point, and the `x` value is inferred. The `x` value can also be omitted,
 * in which case the inner arrays should be of length 2\. Then the `x` value is
 * automatically calculated, either starting at 0 and incremented by 1, or from
 * `pointStart` and `pointInterval` given in the series options.(see online
 * documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.columnrange.data
 * @see https://api.highcharts.com/highstock/series.columnrange.data
 */
export interface SeriesColumnrangeDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.className
     * @see https://api.highcharts.com/gantt/series.columnrange.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.color
     * @see https://api.highcharts.com/highstock/series.columnrange.data.color
     * @see https://api.highcharts.com/gantt/series.columnrange.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.columnrange.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.description
     * @see https://api.highcharts.com/highstock/series.columnrange.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.columnrange.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.columnrange.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.columnrange.data.dragDrop
     */
    dragDrop?: SeriesColumnrangeDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.events
     * @see https://api.highcharts.com/highstock/series.columnrange.data.events
     * @see https://api.highcharts.com/gantt/series.columnrange.data.events
     */
    events?: SeriesColumnrangeDataEventsOptions;
    /**
     * (Highcharts, Highstock) The high or maximum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.high
     * @see https://api.highcharts.com/highstock/series.columnrange.data.high
     */
    high?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.id
     * @see https://api.highcharts.com/highstock/series.columnrange.data.id
     * @see https://api.highcharts.com/gantt/series.columnrange.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.labelrank
     * @see https://api.highcharts.com/highstock/series.columnrange.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) The low or minimum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.low
     * @see https://api.highcharts.com/highstock/series.columnrange.data.low
     */
    low?: number;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.name
     * @see https://api.highcharts.com/highstock/series.columnrange.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.selected
     * @see https://api.highcharts.com/highstock/series.columnrange.data.selected
     * @see https://api.highcharts.com/gantt/series.columnrange.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data.x
     * @see https://api.highcharts.com/highstock/series.columnrange.data.x
     */
    x?: number;
}
/**
 * (Highcharts, Highstock) A `columnrange` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `columnrange` series are defined in
 * plotOptions.columnrange.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.columnrange
 * @see https://api.highcharts.com/highstock/series.columnrange
 */
export interface SeriesColumnrangeOptions extends PlotColumnrangeOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `columnrange` series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 or 2 values. In this case, the values
     * correspond to `x,low,high`. If the first value is a string, it is applied
     * as the name of the point, and the `x` value is inferred. The `x` value
     * can also be omitted, in which case the inner arrays should be of length
     * 2\. Then the `x` value is automatically calculated, either starting at 0
     * and incremented by 1, or from `pointStart` and `pointInterval` given in
     * the series options.(see online documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.columnrange.data
     * @see https://api.highcharts.com/highstock/series.columnrange.data
     */
    data?: Array<([(number|string), number]|[(number|string), number, number]|SeriesColumnrangeDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "columnrange";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragHandle
 */
export interface SeriesCylinderDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.guideBox.default
 */
export interface SeriesCylinderDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.guideBox
 */
export interface SeriesCylinderDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.guideBox.default
     */
    default?: SeriesCylinderDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop
 */
export interface SeriesCylinderDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesCylinderDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.guideBox
     */
    guideBox?: (SeriesCylinderDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.cylinder.data.events
 * @see https://api.highcharts.com/highstock/series.cylinder.data.events
 * @see https://api.highcharts.com/gantt/series.cylinder.data.events
 */
export interface SeriesCylinderDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events.click
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events.click
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.events.click
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events.drag
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.events.drag
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events.drop
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.events.drop
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events.remove
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.events.remove
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events.select
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events.select
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.events.select
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events.update
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events.update
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.events.update
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `cylinder` series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.cylinder.data
 * @see https://api.highcharts.com/highstock/series.cylinder.data
 */
export interface SeriesCylinderDataOptions {
    /**
     * (Highcharts, Highstock) The color of the border surrounding the column or
     * bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.borderColor
     * @see https://api.highcharts.com/highstock/series.cylinder.data.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the border surrounding the column or
     * bar.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.borderWidth
     * @see https://api.highcharts.com/highstock/series.cylinder.data.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.className
     * @see https://api.highcharts.com/gantt/series.cylinder.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.color
     * @see https://api.highcharts.com/highstock/series.cylinder.data.color
     * @see https://api.highcharts.com/gantt/series.cylinder.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.cylinder.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.description
     * @see https://api.highcharts.com/highstock/series.cylinder.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.cylinder.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.cylinder.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.cylinder.data.dragDrop
     */
    dragDrop?: SeriesCylinderDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.events
     * @see https://api.highcharts.com/highstock/series.cylinder.data.events
     * @see https://api.highcharts.com/gantt/series.cylinder.data.events
     */
    events?: SeriesCylinderDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.id
     * @see https://api.highcharts.com/highstock/series.cylinder.data.id
     * @see https://api.highcharts.com/gantt/series.cylinder.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.labelrank
     * @see https://api.highcharts.com/highstock/series.cylinder.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.name
     * @see https://api.highcharts.com/highstock/series.cylinder.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * the column or bar. Overrides pointWidth on the series.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.pointWidth
     * @see https://api.highcharts.com/highstock/series.cylinder.data.pointWidth
     * @see https://api.highcharts.com/gantt/series.cylinder.data.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.selected
     * @see https://api.highcharts.com/highstock/series.cylinder.data.selected
     * @see https://api.highcharts.com/gantt/series.cylinder.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.x
     * @see https://api.highcharts.com/highstock/series.cylinder.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data.y
     * @see https://api.highcharts.com/highstock/series.cylinder.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `cylinder` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `cylinder` series are defined in plotOptions.cylinder.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.cylinder
 */
export interface SeriesCylinderOptions extends PlotCylinderOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `cylinder` series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.cylinder.data
     * @see https://api.highcharts.com/highstock/series.cylinder.data
     */
    data?: Array<(number|[(number|string), number]|SeriesCylinderDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "cylinder";
}
export interface SeriesDataLabelsFormatterContextObject {
    point: Point;
}
/**
 * (Highstock) A `DEMA` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `dema` series are defined in plotOptions.dema.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.dema
 */
export interface SeriesDemaOptions extends PlotDemaOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "dema";
}
/**
 * (Highstock) A Detrended Price Oscillator. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `dpo` series are defined in plotOptions.dpo.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.dpo
 */
export interface SeriesDpoOptions extends PlotDpoOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "dpo";
}
/**
 * (Highstock) A `EMA` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ema` series are defined in plotOptions.ema.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.ema
 */
export interface SeriesEmaOptions extends PlotEmaOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "ema";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragHandle
 */
export interface SeriesErrorbarDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.guideBox.default
 */
export interface SeriesErrorbarDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.guideBox
 */
export interface SeriesErrorbarDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.guideBox.default
     */
    default?: SeriesErrorbarDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop
 */
export interface SeriesErrorbarDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesErrorbarDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.guideBox
     */
    guideBox?: (SeriesErrorbarDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.errorbar.data.events
 * @see https://api.highcharts.com/highstock/series.errorbar.data.events
 * @see https://api.highcharts.com/gantt/series.errorbar.data.events
 */
export interface SeriesErrorbarDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events.click
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events.click
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.events.click
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events.drag
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.events.drag
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events.drop
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.events.drop
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events.remove
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.events.remove
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events.select
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events.select
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.events.select
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events.update
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events.update
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.events.update
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `errorbar`
 * series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 or 2 values. In this case, the values correspond
 * to `x,low,high`. If the first value is a string, it is applied as the name of
 * the point, and the `x` value is inferred. The `x` value can also be omitted,
 * in which case the inner arrays should be of length 2\. Then the `x` value is
 * automatically calculated, either starting at 0 and incremented by 1, or from
 * `pointStart` and `pointInterval` given in the series options.(see online
 * documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.errorbar.data
 */
export interface SeriesErrorbarDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.className
     * @see https://api.highcharts.com/gantt/series.errorbar.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.color
     * @see https://api.highcharts.com/highstock/series.errorbar.data.color
     * @see https://api.highcharts.com/gantt/series.errorbar.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.errorbar.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.errorbar.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.errorbar.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.errorbar.data.dragDrop
     */
    dragDrop?: SeriesErrorbarDataDragDropOptions;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.events
     * @see https://api.highcharts.com/highstock/series.errorbar.data.events
     * @see https://api.highcharts.com/gantt/series.errorbar.data.events
     */
    events?: SeriesErrorbarDataEventsOptions;
    /**
     * (Highcharts, Highstock) The high or maximum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.high
     * @see https://api.highcharts.com/highstock/series.errorbar.data.high
     */
    high?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.id
     * @see https://api.highcharts.com/highstock/series.errorbar.data.id
     * @see https://api.highcharts.com/gantt/series.errorbar.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) The low or minimum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.low
     * @see https://api.highcharts.com/highstock/series.errorbar.data.low
     */
    low?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.selected
     * @see https://api.highcharts.com/highstock/series.errorbar.data.selected
     * @see https://api.highcharts.com/gantt/series.errorbar.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data.x
     * @see https://api.highcharts.com/highstock/series.errorbar.data.x
     */
    x?: number;
}
/**
 * (Highcharts) A `errorbar` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `errorbar` series are defined in plotOptions.errorbar.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.errorbar
 */
export interface SeriesErrorbarOptions extends PlotErrorbarOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `errorbar`
     * series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 or 2 values. In this case, the values
     * correspond to `x,low,high`. If the first value is a string, it is applied
     * as the name of the point, and the `x` value is inferred. The `x` value
     * can also be omitted, in which case the inner arrays should be of length
     * 2\. Then the `x` value is automatically calculated, either starting at 0
     * and incremented by 1, or from `pointStart` and `pointInterval` given in
     * the series options.(see online documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.errorbar.data
     */
    data?: Array<([(number|string), number]|[(number|string), number, number]|SeriesErrorbarDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "errorbar";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragHandle
 */
export interface SeriesFlagsDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.guideBox.default
 */
export interface SeriesFlagsDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.guideBox
 */
export interface SeriesFlagsDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.guideBox.default
     */
    default?: SeriesFlagsDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop
 */
export interface SeriesFlagsDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesFlagsDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.guideBox
     */
    guideBox?: (SeriesFlagsDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.flags.data.events
 * @see https://api.highcharts.com/highstock/series.flags.data.events
 * @see https://api.highcharts.com/gantt/series.flags.data.events
 */
export interface SeriesFlagsDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events.click
     * @see https://api.highcharts.com/highstock/series.flags.data.events.click
     * @see https://api.highcharts.com/highmaps/series.flags.data.events.click
     * @see https://api.highcharts.com/gantt/series.flags.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events.drag
     * @see https://api.highcharts.com/highstock/series.flags.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.flags.data.events.drag
     * @see https://api.highcharts.com/gantt/series.flags.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.flags.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.flags.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.flags.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events.drop
     * @see https://api.highcharts.com/highstock/series.flags.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.flags.data.events.drop
     * @see https://api.highcharts.com/gantt/series.flags.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.flags.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.flags.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.flags.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.flags.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.flags.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.flags.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events.remove
     * @see https://api.highcharts.com/highstock/series.flags.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.flags.data.events.remove
     * @see https://api.highcharts.com/gantt/series.flags.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events.select
     * @see https://api.highcharts.com/highstock/series.flags.data.events.select
     * @see https://api.highcharts.com/highmaps/series.flags.data.events.select
     * @see https://api.highcharts.com/gantt/series.flags.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.flags.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.flags.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.flags.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events.update
     * @see https://api.highcharts.com/highstock/series.flags.data.events.update
     * @see https://api.highcharts.com/highmaps/series.flags.data.events.update
     * @see https://api.highcharts.com/gantt/series.flags.data.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) An array of data points for the series. For the `flags` series
 * type, points can be given in the following ways:
 *
 * 1. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.flags.data
 */
export interface SeriesFlagsDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.className
     * @see https://api.highcharts.com/gantt/series.flags.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.color
     * @see https://api.highcharts.com/highstock/series.flags.data.color
     * @see https://api.highcharts.com/gantt/series.flags.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.flags.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highstock) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/series.flags.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.flags.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.flags.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.flags.data.dragDrop
     */
    dragDrop?: SeriesFlagsDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.events
     * @see https://api.highcharts.com/highstock/series.flags.data.events
     * @see https://api.highcharts.com/gantt/series.flags.data.events
     */
    events?: SeriesFlagsDataEventsOptions;
    /**
     * (Highstock) The fill color of an individual flag. By default it inherits
     * from the series color.
     *
     * @see https://api.highcharts.com/highstock/series.flags.data.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.id
     * @see https://api.highcharts.com/highstock/series.flags.data.id
     * @see https://api.highcharts.com/gantt/series.flags.data.id
     */
    id?: string;
    /**
     * (Highstock) The rank for this point's data label in case of collision. If
     * two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highstock/series.flags.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.selected
     * @see https://api.highcharts.com/highstock/series.flags.data.selected
     * @see https://api.highcharts.com/gantt/series.flags.data.selected
     */
    selected?: boolean;
    /**
     * (Highstock) The longer text to be shown in the flag's tooltip.
     *
     * @see https://api.highcharts.com/highstock/series.flags.data.text
     */
    text?: string;
    /**
     * (Highstock) The short text to be shown on the flag.
     *
     * @see https://api.highcharts.com/highstock/series.flags.data.title
     */
    title?: string;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.flags.data.x
     * @see https://api.highcharts.com/highstock/series.flags.data.x
     */
    x?: number;
}
/**
 * (Highstock) A `flags` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `flags` series are defined in plotOptions.flags.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.flags
 */
export interface SeriesFlagsOptions extends PlotFlagsOptions, SeriesOptions {
    /**
     * (Highstock) An array of data points for the series. For the `flags`
     * series type, points can be given in the following ways:
     *
     * 1. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/series.flags.data
     */
    data?: Array<SeriesFlagsDataOptions>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "flags";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragHandle
 */
export interface SeriesFunnelDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.guideBox.default
 */
export interface SeriesFunnelDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.guideBox
 */
export interface SeriesFunnelDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.guideBox.default
     */
    default?: SeriesFunnelDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop
 */
export interface SeriesFunnelDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesFunnelDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.guideBox
     */
    guideBox?: (SeriesFunnelDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.funnel.data.events
 * @see https://api.highcharts.com/highstock/series.funnel.data.events
 * @see https://api.highcharts.com/gantt/series.funnel.data.events
 */
export interface SeriesFunnelDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events.click
     * @see https://api.highcharts.com/highstock/series.funnel.data.events.click
     * @see https://api.highcharts.com/highmaps/series.funnel.data.events.click
     * @see https://api.highcharts.com/gantt/series.funnel.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events.drag
     * @see https://api.highcharts.com/highstock/series.funnel.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.funnel.data.events.drag
     * @see https://api.highcharts.com/gantt/series.funnel.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.funnel.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.funnel.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.funnel.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events.drop
     * @see https://api.highcharts.com/highstock/series.funnel.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.funnel.data.events.drop
     * @see https://api.highcharts.com/gantt/series.funnel.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.funnel.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.funnel.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.funnel.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.funnel.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.funnel.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.funnel.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events.remove
     * @see https://api.highcharts.com/highstock/series.funnel.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.funnel.data.events.remove
     * @see https://api.highcharts.com/gantt/series.funnel.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events.select
     * @see https://api.highcharts.com/highstock/series.funnel.data.events.select
     * @see https://api.highcharts.com/highmaps/series.funnel.data.events.select
     * @see https://api.highcharts.com/gantt/series.funnel.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.funnel.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.funnel.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.funnel.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events.update
     * @see https://api.highcharts.com/highstock/series.funnel.data.events.update
     * @see https://api.highcharts.com/highmaps/series.funnel.data.events.update
     * @see https://api.highcharts.com/gantt/series.funnel.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `funnel` series
 * type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. Example:(see online documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.funnel.data
 */
export interface SeriesFunnelDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.className
     * @see https://api.highcharts.com/gantt/series.funnel.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.color
     * @see https://api.highcharts.com/highstock/series.funnel.data.color
     * @see https://api.highcharts.com/gantt/series.funnel.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.funnel.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.funnel.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.funnel.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.funnel.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.funnel.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.funnel.data.dragDrop
     */
    dragDrop?: SeriesFunnelDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.events
     * @see https://api.highcharts.com/highstock/series.funnel.data.events
     * @see https://api.highcharts.com/gantt/series.funnel.data.events
     */
    events?: SeriesFunnelDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.id
     * @see https://api.highcharts.com/highstock/series.funnel.data.id
     * @see https://api.highcharts.com/gantt/series.funnel.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The sequential index of the data point in the legend.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.legendIndex
     */
    legendIndex?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.selected
     * @see https://api.highcharts.com/highstock/series.funnel.data.selected
     * @see https://api.highcharts.com/gantt/series.funnel.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data.y
     * @see https://api.highcharts.com/highstock/series.funnel.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `funnel` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `funnel` series are defined in plotOptions.funnel.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.funnel
 */
export interface SeriesFunnelOptions extends PlotFunnelOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `funnel`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. Example:(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.funnel.data
     */
    data?: Array<(number|SeriesFunnelDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "funnel";
}
/**
 * (Gantt) Progress indicator, how much of the task completed. If it is a
 * number, the `fill` will be applied automatically.
 *
 * @see https://api.highcharts.com/gantt/series.gantt.data.completed
 */
export interface SeriesGanttDataCompletedOptions {
    /**
     * (Highcharts, Highstock, Gantt) The amount of the progress indicator,
     * ranging from 0 (not started) to 1 (finished).
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.completed.amount
     * @see https://api.highcharts.com/highstock/series.gantt.data.completed.amount
     * @see https://api.highcharts.com/gantt/series.gantt.data.completed.amount
     */
    amount?: number;
    /**
     * (Highcharts, Highstock, Gantt) The fill of the progress indicator.
     * Defaults to a darkened variety of the main color.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.completed.fill
     * @see https://api.highcharts.com/highstock/series.gantt.data.completed.fill
     * @see https://api.highcharts.com/gantt/series.gantt.data.completed.fill
     */
    fill?: (ColorString|GradientColorObject|PatternObject);
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker
 */
export interface SeriesGanttDataDependencyEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker
 */
export interface SeriesGanttDataDependencyMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker.width
     */
    width?: number;
}
/**
 * (Gantt) The ID of the point (task) that this point depends on in Gantt
 * charts. Aliases connect. Can also be an object, specifying further connecting
 * options between the points. Multiple connections can be specified by
 * providing an array.
 *
 * @see https://api.highcharts.com/gantt/series.gantt.data.dependency
 */
export interface SeriesGanttDataDependencyOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.endMarker
     */
    endMarker?: SeriesGanttDataDependencyEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.marker
     */
    marker?: SeriesGanttDataDependencyMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker
     */
    startMarker?: SeriesGanttDataDependencyStartMarkerOptions;
    /**
     * (Gantt) The ID of the point to connect to.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.to
     */
    to?: string;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker
 */
export interface SeriesGanttDataDependencyStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency.startMarker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragHandle
 */
export interface SeriesGanttDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.guideBox.default
 */
export interface SeriesGanttDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.guideBox
 */
export interface SeriesGanttDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.guideBox.default
     */
    default?: SeriesGanttDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop
 */
export interface SeriesGanttDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesGanttDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.guideBox
     */
    guideBox?: (SeriesGanttDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.gantt.data.marker
 * @see https://api.highcharts.com/highstock/series.gantt.data.marker
 */
export interface SeriesGanttDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.height
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.height
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states
     */
    states?: SeriesGanttDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.width
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.width
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover.animation
 */
export interface SeriesGanttDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover
 */
export interface SeriesGanttDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesGanttDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.normal
 */
export interface SeriesGanttDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states
 * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states
 * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states
 */
export interface SeriesGanttDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.hover
     */
    hover?: SeriesGanttDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.normal
     */
    normal?: SeriesGanttDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.select
     */
    select?: SeriesGanttDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.select
 */
export interface SeriesGanttDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.gantt.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.gantt.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Gantt) Data for a Gantt series.
 *
 * @see https://api.highcharts.com/gantt/series.gantt.data
 */
export interface SeriesGanttDataOptions {
    /**
     * (Gantt) Whether the grid node belonging to this point should start as
     * collapsed. Used in axes of type treegrid.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.collapsed
     */
    collapsed?: boolean;
    /**
     * (Gantt) Progress indicator, how much of the task completed. If it is a
     * number, the `fill` will be applied automatically.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.completed
     */
    completed?: (number|SeriesGanttDataCompletedOptions);
    /**
     * (Gantt) The ID of the point (task) that this point depends on in Gantt
     * charts. Aliases connect. Can also be an object, specifying further
     * connecting options between the points. Multiple connections can be
     * specified by providing an array.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.dependency
     */
    dependency?: (string|SeriesGanttDataDependencyOptions|Array<(string|SeriesGanttDataDependencyOptions)>);
    /**
     * (Gantt) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.gantt.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.gantt.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.gantt.data.dragDrop
     */
    dragDrop?: SeriesGanttDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.drilldown
     */
    drilldown?: string;
    /**
     * (Gantt) The end time of a task.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.end
     */
    end?: number;
    /**
     * (Gantt) The rank for this point's data label in case of collision. If two
     * data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.gantt.data.marker
     * @see https://api.highcharts.com/highstock/series.gantt.data.marker
     */
    marker?: SeriesGanttDataMarkerOptions;
    /**
     * (Gantt) Whether this point is a milestone. If so, only the `start` option
     * is handled, while `end` is ignored.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.milestone
     */
    milestone?: boolean;
    /**
     * (Gantt) The name of a task. If a `treegrid` y-axis is used (default in
     * Gantt charts), this will be picked up automatically, and used to
     * calculate the y-value.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.name
     */
    name?: string;
    /**
     * (Gantt) The ID of the parent point (task) of this point in Gantt charts.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.parent
     */
    parent?: string;
    /**
     * (Gantt) The start time of a task.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.start
     */
    start?: number;
    /**
     * (Gantt) The Y value of a task.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data.y
     */
    y?: number;
}
/**
 * (Gantt) A `gantt` series.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `gantt` series are defined in plotOptions.gantt.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/gantt/series.gantt
 */
export interface SeriesGanttOptions extends PlotGanttOptions, SeriesOptions {
    /**
     * (Gantt) Data for a Gantt series.
     *
     * @see https://api.highcharts.com/gantt/series.gantt.data
     */
    data?: Array<SeriesGanttDataOptions>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "gantt";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragHandle
 */
export interface SeriesGaugeDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.guideBox.default
 */
export interface SeriesGaugeDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.guideBox
 */
export interface SeriesGaugeDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.guideBox.default
     */
    default?: SeriesGaugeDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop
 */
export interface SeriesGaugeDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesGaugeDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.guideBox
     */
    guideBox?: (SeriesGaugeDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.gauge.data.events
 * @see https://api.highcharts.com/highstock/series.gauge.data.events
 * @see https://api.highcharts.com/gantt/series.gauge.data.events
 */
export interface SeriesGaugeDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events.click
     * @see https://api.highcharts.com/highstock/series.gauge.data.events.click
     * @see https://api.highcharts.com/highmaps/series.gauge.data.events.click
     * @see https://api.highcharts.com/gantt/series.gauge.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events.drag
     * @see https://api.highcharts.com/highstock/series.gauge.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.gauge.data.events.drag
     * @see https://api.highcharts.com/gantt/series.gauge.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.gauge.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.gauge.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.gauge.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events.drop
     * @see https://api.highcharts.com/highstock/series.gauge.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.gauge.data.events.drop
     * @see https://api.highcharts.com/gantt/series.gauge.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.gauge.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.gauge.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.gauge.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.gauge.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.gauge.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.gauge.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events.remove
     * @see https://api.highcharts.com/highstock/series.gauge.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.gauge.data.events.remove
     * @see https://api.highcharts.com/gantt/series.gauge.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events.select
     * @see https://api.highcharts.com/highstock/series.gauge.data.events.select
     * @see https://api.highcharts.com/highmaps/series.gauge.data.events.select
     * @see https://api.highcharts.com/gantt/series.gauge.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.gauge.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.gauge.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.gauge.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events.update
     * @see https://api.highcharts.com/highstock/series.gauge.data.events.update
     * @see https://api.highcharts.com/highmaps/series.gauge.data.events.update
     * @see https://api.highcharts.com/gantt/series.gauge.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `gauge` series
 * type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. Example:(see online documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * The typical gauge only contains a single data value.
 *
 * @see https://api.highcharts.com/highcharts/series.gauge.data
 */
export interface SeriesGaugeDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.className
     * @see https://api.highcharts.com/gantt/series.gauge.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.color
     * @see https://api.highcharts.com/highstock/series.gauge.data.color
     * @see https://api.highcharts.com/gantt/series.gauge.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.gauge.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.gauge.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.gauge.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.gauge.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.gauge.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.gauge.data.dragDrop
     */
    dragDrop?: SeriesGaugeDataDragDropOptions;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.events
     * @see https://api.highcharts.com/highstock/series.gauge.data.events
     * @see https://api.highcharts.com/gantt/series.gauge.data.events
     */
    events?: SeriesGaugeDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.id
     * @see https://api.highcharts.com/highstock/series.gauge.data.id
     * @see https://api.highcharts.com/gantt/series.gauge.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.selected
     * @see https://api.highcharts.com/highstock/series.gauge.data.selected
     * @see https://api.highcharts.com/gantt/series.gauge.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data.y
     * @see https://api.highcharts.com/highstock/series.gauge.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `gauge` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `gauge` series are defined in plotOptions.gauge.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.gauge
 */
export interface SeriesGaugeOptions extends PlotGaugeOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `gauge`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. Example:(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * The typical gauge only contains a single data value.
     *
     * @see https://api.highcharts.com/highcharts/series.gauge.data
     */
    data?: Array<(number|SeriesGaugeDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "gauge";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragHandle
 */
export interface SeriesHeatmapDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.guideBox.default
 */
export interface SeriesHeatmapDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.guideBox
 */
export interface SeriesHeatmapDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.guideBox.default
     */
    default?: SeriesHeatmapDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop
 */
export interface SeriesHeatmapDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesHeatmapDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.guideBox
     */
    guideBox?: (SeriesHeatmapDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.heatmap.data.events
 * @see https://api.highcharts.com/highstock/series.heatmap.data.events
 * @see https://api.highcharts.com/gantt/series.heatmap.data.events
 */
export interface SeriesHeatmapDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events.click
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events.click
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.events.click
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events.drag
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.events.drag
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events.drop
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.events.drop
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events.remove
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.events.remove
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events.select
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events.select
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.events.select
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events.update
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events.update
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.events.update
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highmaps) An array of data points for the series. For the
 * `heatmap` series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 or 2 values. In this case, the values correspond
 * to `x,y,value`. If the first value is a string, it is applied as the name of
 * the point, and the `x` value is inferred. The `x` value can also be omitted,
 * in which case the inner arrays should be of length 2\. Then the `x` value is
 * automatically calculated, either starting at 0 and incremented by 1, or from
 * `pointStart` and `pointInterval` given in the series options.(see online
 * documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.heatmap.data
 * @see https://api.highcharts.com/highmaps/series.heatmap.data
 */
export interface SeriesHeatmapDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.className
     * @see https://api.highcharts.com/gantt/series.heatmap.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) The color of the point. In heat maps the point
     * color is rarely set explicitly, as we use the color to denote the
     * `value`. Options for this are set in the colorAxis configuration.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.color
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.heatmap.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highmaps) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.description
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.heatmap.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.heatmap.data.dragDrop
     */
    dragDrop?: SeriesHeatmapDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.events
     * @see https://api.highcharts.com/highstock/series.heatmap.data.events
     * @see https://api.highcharts.com/gantt/series.heatmap.data.events
     */
    events?: SeriesHeatmapDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.id
     * @see https://api.highcharts.com/highstock/series.heatmap.data.id
     * @see https://api.highcharts.com/gantt/series.heatmap.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highmaps) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.labelrank
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highmaps) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.name
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highmaps) Point padding for a single point.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.pointPadding
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.selected
     * @see https://api.highcharts.com/highstock/series.heatmap.data.selected
     * @see https://api.highcharts.com/gantt/series.heatmap.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highmaps) The value of the point, resulting in a color
     * controled by options as set in the colorAxis configuration.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.value
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.value
     */
    value?: number;
    /**
     * (Highcharts, Highmaps) The x value of the point. For datetime axes, the X
     * value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.x
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highmaps) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data.y
     * @see https://api.highcharts.com/highmaps/series.heatmap.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highmaps) A `heatmap` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `heatmap` series are defined in plotOptions.heatmap.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.heatmap
 * @see https://api.highcharts.com/highmaps/series.heatmap
 */
export interface SeriesHeatmapOptions extends PlotHeatmapOptions, SeriesOptions {
    /**
     * (Highcharts, Highmaps) An array of data points for the series. For the
     * `heatmap` series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 or 2 values. In this case, the values
     * correspond to `x,y,value`. If the first value is a string, it is applied
     * as the name of the point, and the `x` value is inferred. The `x` value
     * can also be omitted, in which case the inner arrays should be of length
     * 2\. Then the `x` value is automatically calculated, either starting at 0
     * and incremented by 1, or from `pointStart` and `pointInterval` given in
     * the series options.(see online documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.heatmap.data
     * @see https://api.highcharts.com/highmaps/series.heatmap.data
     */
    data?: Array<(Array<number>|SeriesHeatmapDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "heatmap";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragHandle
 */
export interface SeriesHistogramDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.guideBox.default
 */
export interface SeriesHistogramDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.guideBox
 */
export interface SeriesHistogramDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.guideBox.default
     */
    default?: SeriesHistogramDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop
 */
export interface SeriesHistogramDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesHistogramDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.guideBox
     */
    guideBox?: (SeriesHistogramDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.histogram.data.events
 * @see https://api.highcharts.com/highstock/series.histogram.data.events
 * @see https://api.highcharts.com/gantt/series.histogram.data.events
 */
export interface SeriesHistogramDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events.click
     * @see https://api.highcharts.com/highstock/series.histogram.data.events.click
     * @see https://api.highcharts.com/highmaps/series.histogram.data.events.click
     * @see https://api.highcharts.com/gantt/series.histogram.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events.drag
     * @see https://api.highcharts.com/highstock/series.histogram.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.histogram.data.events.drag
     * @see https://api.highcharts.com/gantt/series.histogram.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.histogram.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.histogram.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.histogram.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events.drop
     * @see https://api.highcharts.com/highstock/series.histogram.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.histogram.data.events.drop
     * @see https://api.highcharts.com/gantt/series.histogram.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.histogram.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.histogram.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.histogram.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.histogram.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.histogram.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.histogram.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events.remove
     * @see https://api.highcharts.com/highstock/series.histogram.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.histogram.data.events.remove
     * @see https://api.highcharts.com/gantt/series.histogram.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events.select
     * @see https://api.highcharts.com/highstock/series.histogram.data.events.select
     * @see https://api.highcharts.com/highmaps/series.histogram.data.events.select
     * @see https://api.highcharts.com/gantt/series.histogram.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.histogram.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.histogram.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.histogram.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events.update
     * @see https://api.highcharts.com/highstock/series.histogram.data.events.update
     * @see https://api.highcharts.com/highmaps/series.histogram.data.events.update
     * @see https://api.highcharts.com/gantt/series.histogram.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `histogram`
 * series type, points are calculated dynamically. See histogram.baseSeries.
 *
 * @see https://api.highcharts.com/highcharts/series.histogram.data
 */
export interface SeriesHistogramDataOptions {
    /**
     * (Highcharts, Highstock) The color of the border surrounding the column or
     * bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.borderColor
     * @see https://api.highcharts.com/highstock/series.histogram.data.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the border surrounding the column or
     * bar.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.borderWidth
     * @see https://api.highcharts.com/highstock/series.histogram.data.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.className
     * @see https://api.highcharts.com/gantt/series.histogram.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.color
     * @see https://api.highcharts.com/highstock/series.histogram.data.color
     * @see https://api.highcharts.com/gantt/series.histogram.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.histogram.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.histogram.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.histogram.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.histogram.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.histogram.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.histogram.data.dragDrop
     */
    dragDrop?: SeriesHistogramDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.events
     * @see https://api.highcharts.com/highstock/series.histogram.data.events
     * @see https://api.highcharts.com/gantt/series.histogram.data.events
     */
    events?: SeriesHistogramDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.id
     * @see https://api.highcharts.com/highstock/series.histogram.data.id
     * @see https://api.highcharts.com/gantt/series.histogram.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * the column or bar. Overrides pointWidth on the series.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.pointWidth
     * @see https://api.highcharts.com/highstock/series.histogram.data.pointWidth
     * @see https://api.highcharts.com/gantt/series.histogram.data.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.selected
     * @see https://api.highcharts.com/highstock/series.histogram.data.selected
     * @see https://api.highcharts.com/gantt/series.histogram.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.x
     * @see https://api.highcharts.com/highstock/series.histogram.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data.y
     * @see https://api.highcharts.com/highstock/series.histogram.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `histogram` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `histogram` series are defined in plotOptions.histogram.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.histogram
 */
export interface SeriesHistogramOptions extends PlotHistogramOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `histogram`
     * series type, points are calculated dynamically. See histogram.baseSeries.
     *
     * @see https://api.highcharts.com/highcharts/series.histogram.data
     */
    data?: (SeriesHistogramDataOptions|Array<(object|any[])>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "histogram";
}
/**
 * (Highstock) A `IKH` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ikh` series are defined in plotOptions.ikh.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.ikh
 */
export interface SeriesIkhOptions extends PlotIkhOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "ikh";
}
/**
 * (Highstock) A Keltner Channels indicator. If the type option is not
 * specified, it is inherited fromchart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `keltnerchannels` series are defined in
 * plotOptions.keltnerchannels.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.keltnerchannels
 */
export interface SeriesKeltnerchannelsOptions extends PlotKeltnerchannelsOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "keltnerchannels";
}
/**
 * (Highstock) A linear regression intercept series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `linearregressionangle` series are defined in
 * plotOptions.linearregressionangle.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.linearregressionangle
 */
export interface SeriesLinearregressionangleOptions extends PlotLinearregressionangleOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "linearregressionangle";
}
/**
 * (Highstock) A linear regression intercept series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `linearregressionintercept` series are defined in
 * plotOptions.linearregressionintercept.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.linearregressionintercept
 */
export interface SeriesLinearregressioninterceptOptions extends PlotLinearregressioninterceptOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "linearregressionintercept";
}
/**
 * (Highstock) A linear regression series. If the type option is not specified,
 * it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `linearregression` series are defined in
 * plotOptions.linearregression.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.linearregression
 */
export interface SeriesLinearregressionOptions extends PlotLinearregressionOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "linearregression";
}
/**
 * (Highstock) A linear regression slope series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `linearregressionslope` series are defined in
 * plotOptions.linearregressionslope.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.linearregressionslope
 */
export interface SeriesLinearregressionslopeOptions extends PlotLinearregressionslopeOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "linearregressionslope";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragHandle
 */
export interface SeriesLineDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.guideBox.default
 */
export interface SeriesLineDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.guideBox
 */
export interface SeriesLineDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.guideBox.default
     */
    default?: SeriesLineDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.line.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.line.data.dragDrop
 */
export interface SeriesLineDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesLineDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.guideBox
     */
    guideBox?: (SeriesLineDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.events
 * @see https://api.highcharts.com/highstock/series.line.data.events
 * @see https://api.highcharts.com/gantt/series.line.data.events
 */
export interface SeriesLineDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events.click
     * @see https://api.highcharts.com/highstock/series.line.data.events.click
     * @see https://api.highcharts.com/highmaps/series.line.data.events.click
     * @see https://api.highcharts.com/gantt/series.line.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events.drag
     * @see https://api.highcharts.com/highstock/series.line.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.line.data.events.drag
     * @see https://api.highcharts.com/gantt/series.line.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.line.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.line.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.line.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events.drop
     * @see https://api.highcharts.com/highstock/series.line.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.line.data.events.drop
     * @see https://api.highcharts.com/gantt/series.line.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.line.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.line.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.line.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.line.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.line.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.line.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events.remove
     * @see https://api.highcharts.com/highstock/series.line.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.line.data.events.remove
     * @see https://api.highcharts.com/gantt/series.line.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events.select
     * @see https://api.highcharts.com/highstock/series.line.data.events.select
     * @see https://api.highcharts.com/highmaps/series.line.data.events.select
     * @see https://api.highcharts.com/gantt/series.line.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.line.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.line.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.line.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events.update
     * @see https://api.highcharts.com/highstock/series.line.data.events.update
     * @see https://api.highcharts.com/highmaps/series.line.data.events.update
     * @see https://api.highcharts.com/gantt/series.line.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.marker
 * @see https://api.highcharts.com/highstock/series.line.data.marker
 */
export interface SeriesLineDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.line.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.line.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.line.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.line.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.line.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.line.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.height
     * @see https://api.highcharts.com/highstock/series.line.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.height
     * @see https://api.highcharts.com/gantt/series.line.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.line.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.line.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.line.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.line.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.line.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.line.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states
     */
    states?: SeriesLineDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.line.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.line.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.width
     * @see https://api.highcharts.com/highstock/series.line.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.width
     * @see https://api.highcharts.com/gantt/series.line.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover.animation
 */
export interface SeriesLineDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover
 */
export interface SeriesLineDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesLineDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.line.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.line.data.marker.states.normal
 */
export interface SeriesLineDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.marker.states
 * @see https://api.highcharts.com/highstock/series.line.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.line.data.marker.states
 * @see https://api.highcharts.com/gantt/series.line.data.marker.states
 */
export interface SeriesLineDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.hover
     */
    hover?: SeriesLineDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.normal
     */
    normal?: SeriesLineDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.select
     */
    select?: SeriesLineDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.line.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.line.data.marker.states.select
 */
export interface SeriesLineDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.line.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.line.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.line.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `line` series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.line.data
 * @see https://api.highcharts.com/highstock/series.line.data
 */
export interface SeriesLineDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.className
     * @see https://api.highcharts.com/gantt/series.line.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.color
     * @see https://api.highcharts.com/highstock/series.line.data.color
     * @see https://api.highcharts.com/gantt/series.line.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.line.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.line.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.line.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.description
     * @see https://api.highcharts.com/highstock/series.line.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.line.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.line.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.line.data.dragDrop
     */
    dragDrop?: SeriesLineDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.events
     * @see https://api.highcharts.com/highstock/series.line.data.events
     * @see https://api.highcharts.com/gantt/series.line.data.events
     */
    events?: SeriesLineDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.id
     * @see https://api.highcharts.com/highstock/series.line.data.id
     * @see https://api.highcharts.com/gantt/series.line.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.labelrank
     * @see https://api.highcharts.com/highstock/series.line.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.marker
     * @see https://api.highcharts.com/highstock/series.line.data.marker
     */
    marker?: SeriesLineDataMarkerOptions;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.name
     * @see https://api.highcharts.com/highstock/series.line.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.selected
     * @see https://api.highcharts.com/highstock/series.line.data.selected
     * @see https://api.highcharts.com/gantt/series.line.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.x
     * @see https://api.highcharts.com/highstock/series.line.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.line.data.y
     * @see https://api.highcharts.com/highstock/series.line.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `line` series. If the type option is not specified,
 * it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `line` series are defined in plotOptions.line.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.line
 * @see https://api.highcharts.com/highstock/series.line
 */
export interface SeriesLineOptions extends PlotLineOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `line` series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.line.data
     * @see https://api.highcharts.com/highstock/series.line.data
     */
    data?: Array<(number|[(number|string), number]|SeriesLineDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "line";
}
/**
 * (Highstock) A `MACD` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `macd` series are defined in plotOptions.macd.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.macd
 */
export interface SeriesMacdOptions extends PlotMacdOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "macd";
}
/**
 * (Highmaps) Individual point events
 *
 * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events
 */
export interface SeriesMapbubbleDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.mapbubble.data.events.click
     * @see https://api.highcharts.com/highstock/series.mapbubble.data.events.click
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events.click
     * @see https://api.highcharts.com/gantt/series.mapbubble.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.mapbubble.data.events.drag
     * @see https://api.highcharts.com/highstock/series.mapbubble.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events.drag
     * @see https://api.highcharts.com/gantt/series.mapbubble.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.mapbubble.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.mapbubble.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.mapbubble.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.mapbubble.data.events.drop
     * @see https://api.highcharts.com/highstock/series.mapbubble.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events.drop
     * @see https://api.highcharts.com/gantt/series.mapbubble.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.mapbubble.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.mapbubble.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.mapbubble.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.mapbubble.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.mapbubble.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.mapbubble.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.mapbubble.data.events.remove
     * @see https://api.highcharts.com/highstock/series.mapbubble.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events.remove
     * @see https://api.highcharts.com/gantt/series.mapbubble.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.mapbubble.data.events.select
     * @see https://api.highcharts.com/highstock/series.mapbubble.data.events.select
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events.select
     * @see https://api.highcharts.com/gantt/series.mapbubble.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.mapbubble.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.mapbubble.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.mapbubble.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.mapbubble.data.events.update
     * @see https://api.highcharts.com/highstock/series.mapbubble.data.events.update
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events.update
     * @see https://api.highcharts.com/gantt/series.mapbubble.data.events.update
     */
    update?: () => void;
}
/**
 * (Highmaps) An array of data points for the series. For the `mapbubble` series
 * type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `z` options. Example:(see online documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/series.mapbubble.data
 */
export interface SeriesMapbubbleDataOptions {
    /**
     * (Highmaps) Individual color for the point. By default the color is either
     * used to denote the value, or pulled from the global `colors` array.
     *
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Individual data label for each point. The options are the same
     * as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.dataLabels
     */
    dataLabels?: object;
    /**
     * (Highmaps) The `id` of a series in the drilldown.series array to use for
     * a drilldown for this point.
     *
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highmaps) Individual point events
     *
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.events
     */
    events?: SeriesMapbubbleDataEventsOptions;
    /**
     * (Highmaps) An id for the point. This can be used after render time to get
     * a pointer to the point object through `chart.get()`.
     *
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.id
     */
    id?: string;
    /**
     * (Highmaps) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.name
     */
    name?: string;
    /**
     * (Highmaps) While the `x` and `y` values of the bubble are determined by
     * the underlying map, the `z` indicates the actual value that gives the
     * size of the bubble.
     *
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data.z
     */
    z?: number;
}
/**
 * (Highmaps) A `mapbubble` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `mapbubble` series are defined in plotOptions.mapbubble.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/series.mapbubble
 */
export interface SeriesMapbubbleOptions extends PlotMapbubbleOptions, SeriesOptions {
    /**
     * (Highmaps) An array of data points for the series. For the `mapbubble`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `z` options. Example:(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/series.mapbubble.data
     */
    data?: Array<(number|SeriesMapbubbleDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "mapbubble";
}
/**
 * (Highmaps) Individual point events
 *
 * @see https://api.highcharts.com/highmaps/series.map.data.events
 */
export interface SeriesMapDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.map.data.events.click
     * @see https://api.highcharts.com/highstock/series.map.data.events.click
     * @see https://api.highcharts.com/highmaps/series.map.data.events.click
     * @see https://api.highcharts.com/gantt/series.map.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.map.data.events.drag
     * @see https://api.highcharts.com/highstock/series.map.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.map.data.events.drag
     * @see https://api.highcharts.com/gantt/series.map.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.map.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.map.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.map.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.map.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.map.data.events.drop
     * @see https://api.highcharts.com/highstock/series.map.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.map.data.events.drop
     * @see https://api.highcharts.com/gantt/series.map.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.map.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.map.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.map.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.map.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.map.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.map.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.map.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.map.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.map.data.events.remove
     * @see https://api.highcharts.com/highstock/series.map.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.map.data.events.remove
     * @see https://api.highcharts.com/gantt/series.map.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.map.data.events.select
     * @see https://api.highcharts.com/highstock/series.map.data.events.select
     * @see https://api.highcharts.com/highmaps/series.map.data.events.select
     * @see https://api.highcharts.com/gantt/series.map.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.map.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.map.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.map.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.map.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.map.data.events.update
     * @see https://api.highcharts.com/highstock/series.map.data.events.update
     * @see https://api.highcharts.com/highmaps/series.map.data.events.update
     * @see https://api.highcharts.com/gantt/series.map.data.events.update
     */
    update?: () => void;
}
/**
 * (Highmaps) An array of data points for the series. For the `map` series type,
 * points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `value` options. Example:(see online documentation for
 * example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `[hc-key, value]`. Example:(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/series.map.data
 */
export interface SeriesMapDataOptions {
    /**
     * (Highmaps) Individual color for the point. By default the color is either
     * used to denote the value, or pulled from the global `colors` array.
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Individual data label for each point. The options are the same
     * as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.dataLabels
     */
    dataLabels?: object;
    /**
     * (Highmaps) The `id` of a series in the drilldown.series array to use for
     * a drilldown for this point.
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highmaps) Individual point events
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.events
     */
    events?: SeriesMapDataEventsOptions;
    /**
     * (Highmaps) An id for the point. This can be used after render time to get
     * a pointer to the point object through `chart.get()`.
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.id
     */
    id?: string;
    /**
     * (Highmaps) When data labels are laid out on a map, Highmaps runs a
     * simplified algorithm to detect collision. When two labels collide, the
     * one with the lowest rank is hidden. By default the rank is computed from
     * the area.
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highmaps) The relative mid point of an area, used to place the data
     * label. Ranges from 0 to 1\. When `mapData` is used, middleX can be
     * defined there.
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.middleX
     */
    middleX?: number;
    /**
     * (Highmaps) The relative mid point of an area, used to place the data
     * label. Ranges from 0 to 1\. When `mapData` is used, middleY can be
     * defined there.
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.middleY
     */
    middleY?: number;
    /**
     * (Highmaps) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.name
     */
    name?: string;
    /**
     * (Highmaps) For map and mapline series types, the SVG path for the shape.
     * For compatibily with old IE, not all SVG path definitions are supported,
     * but M, L and C operators are safe.
     *
     * To achieve a better separation between the structure and the data, it is
     * recommended to use `mapData` to define that paths instead of defining
     * them on the data points themselves.
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.path
     */
    path?: string;
    /**
     * (Highmaps) The numeric value of the data point.
     *
     * @see https://api.highcharts.com/highmaps/series.map.data.value
     */
    value?: number;
}
/**
 * (Highmaps) A `mapline` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `mapline` series are defined in plotOptions.mapline.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/series.mapline
 */
export interface SeriesMaplineOptions extends PlotMaplineOptions, SeriesOptions {
    /**
     * (Highmaps) An array of data points for the series. For the `mapline`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `value` options. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `[hc-key, value]`. Example:(see online documentation for example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/series.mapline.data
     */
    data?: Array<(number|[string, number]|object)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "mapline";
}
/**
 * (Highmaps) A `map` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `map` series are defined in plotOptions.map.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/series.map
 */
export interface SeriesMapOptions extends PlotMapOptions, SeriesOptions {
    /**
     * (Highmaps) An array of data points for the series. For the `map` series
     * type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `value` options. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `[hc-key, value]`. Example:(see online documentation for example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/series.map.data
     */
    data?: Array<(number|[string, number]|SeriesMapDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "map";
}
/**
 * (Highmaps) Individual point events
 *
 * @see https://api.highcharts.com/highmaps/series.mappoint.data.events
 */
export interface SeriesMappointDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.mappoint.data.events.click
     * @see https://api.highcharts.com/highstock/series.mappoint.data.events.click
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events.click
     * @see https://api.highcharts.com/gantt/series.mappoint.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.mappoint.data.events.drag
     * @see https://api.highcharts.com/highstock/series.mappoint.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events.drag
     * @see https://api.highcharts.com/gantt/series.mappoint.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.mappoint.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.mappoint.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.mappoint.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.mappoint.data.events.drop
     * @see https://api.highcharts.com/highstock/series.mappoint.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events.drop
     * @see https://api.highcharts.com/gantt/series.mappoint.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.mappoint.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.mappoint.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.mappoint.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.mappoint.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.mappoint.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.mappoint.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.mappoint.data.events.remove
     * @see https://api.highcharts.com/highstock/series.mappoint.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events.remove
     * @see https://api.highcharts.com/gantt/series.mappoint.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.mappoint.data.events.select
     * @see https://api.highcharts.com/highstock/series.mappoint.data.events.select
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events.select
     * @see https://api.highcharts.com/gantt/series.mappoint.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.mappoint.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.mappoint.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.mappoint.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.mappoint.data.events.update
     * @see https://api.highcharts.com/highstock/series.mappoint.data.events.update
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events.update
     * @see https://api.highcharts.com/gantt/series.mappoint.data.events.update
     */
    update?: () => void;
}
/**
 * (Highmaps) An array of data points for the series. For the `mappoint` series
 * type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/series.mappoint.data
 */
export interface SeriesMappointDataOptions {
    /**
     * (Highmaps) Individual color for the point. By default the color is either
     * used to denote the value, or pulled from the global `colors` array.
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.color
     */
    color?: ColorString;
    /**
     * (Highmaps) Individual data label for each point. The options are the same
     * as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.dataLabels
     */
    dataLabels?: object;
    /**
     * (Highmaps) The `id` of a series in the drilldown.series array to use for
     * a drilldown for this point.
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highmaps) Individual point events
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.events
     */
    events?: SeriesMappointDataEventsOptions;
    /**
     * (Highmaps) An id for the point. This can be used after render time to get
     * a pointer to the point object through `chart.get()`.
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.id
     */
    id?: string;
    /**
     * (Highmaps) The latitude of the point. Must be combined with the `lon`
     * option to work. Overrides `x` and `y` values.
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.lat
     */
    lat?: number;
    /**
     * (Highmaps) The longitude of the point. Must be combined with the `lon`
     * option to work. Overrides `x` and `y` values.
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.lon
     */
    lon?: number;
    /**
     * (Highmaps) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.name
     */
    name?: string;
    /**
     * (Highmaps) The x coordinate of the point in terms of the map path
     * coordinates.
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.x
     */
    x?: number;
    /**
     * (Highmaps) The x coordinate of the point in terms of the map path
     * coordinates.
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data.y
     */
    y?: number;
}
/**
 * (Highmaps) A `mappoint` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `mappoint` series are defined in plotOptions.mappoint.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highmaps/series.mappoint
 */
export interface SeriesMappointOptions extends PlotMappointOptions, SeriesOptions {
    /**
     * (Highmaps) An array of data points for the series. For the `mappoint`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highmaps/series.mappoint.data
     */
    data?: Array<(number|[number, number]|SeriesMappointDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "mappoint";
}
/**
 * (Highstock) A `MFI` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `mfi` series are defined in plotOptions.mfi.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.mfi
 */
export interface SeriesMfiOptions extends PlotMfiOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "mfi";
}
/**
 * (Highstock) A `Momentum` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `momentum` series are defined in plotOptions.momentum.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.momentum
 */
export interface SeriesMomentumOptions extends PlotMomentumOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "momentum";
}
/**
 * (Highstock) A `NATR` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `natr` series are defined in plotOptions.natr.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.natr
 */
export interface SeriesNatrOptions extends PlotNatrOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "natr";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragHandle
 */
export interface SeriesNetworkgraphDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.guideBox.default
 */
export interface SeriesNetworkgraphDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.guideBox
 */
export interface SeriesNetworkgraphDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.guideBox.default
     */
    default?: SeriesNetworkgraphDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop
 */
export interface SeriesNetworkgraphDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesNetworkgraphDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.guideBox
     */
    guideBox?: (SeriesNetworkgraphDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events
 * @see https://api.highcharts.com/highstock/series.networkgraph.data.events
 * @see https://api.highcharts.com/gantt/series.networkgraph.data.events
 */
export interface SeriesNetworkgraphDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events.click
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events.click
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.events.click
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events.drag
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.events.drag
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events.drop
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.events.drop
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events.remove
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.events.remove
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events.select
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events.select
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.events.select
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events.update
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events.update
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.events.update
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `networkgraph`
 * series type, points can be given in the following way:
 *
 * An array of objects with named values. The following snippet shows only a few
 * settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.networkgraph.data
 */
export interface SeriesNetworkgraphDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.className
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.color
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.color
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.networkgraph.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.dragDrop
     */
    dragDrop?: SeriesNetworkgraphDataDragDropOptions;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.events
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.events
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.events
     */
    events?: SeriesNetworkgraphDataEventsOptions;
    /**
     * (Highcharts) The node that the link runs from.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.from
     */
    from?: string;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.id
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.id
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.selected
     * @see https://api.highcharts.com/highstock/series.networkgraph.data.selected
     * @see https://api.highcharts.com/gantt/series.networkgraph.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) The node that the link runs to.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.to
     */
    to?: string;
    /**
     * (Highcharts) The weight of the link.
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data.weight
     */
    weight?: number;
}
/**
 * (Highcharts) A `networkgraph` series. If the type option is not specified, it
 * is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `networkgraph` series are defined in
 * plotOptions.networkgraph.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.networkgraph
 */
export interface SeriesNetworkgraphOptions extends PlotNetworkgraphOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the
     * `networkgraph` series type, points can be given in the following way:
     *
     * An array of objects with named values. The following snippet shows only a
     * few settings, see the complete options set below. If the total number of
     * data points exceeds the series' turboThreshold, this option is not
     * available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.networkgraph.data
     */
    data?: (SeriesNetworkgraphDataOptions|Array<(object|any[]|number)>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "networkgraph";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragHandle
 */
export interface SeriesOhlcDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.guideBox.default
 */
export interface SeriesOhlcDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.guideBox
 */
export interface SeriesOhlcDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.guideBox.default
     */
    default?: SeriesOhlcDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop
 */
export interface SeriesOhlcDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesOhlcDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.guideBox
     */
    guideBox?: (SeriesOhlcDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.ohlc.data.events
 * @see https://api.highcharts.com/highstock/series.ohlc.data.events
 * @see https://api.highcharts.com/gantt/series.ohlc.data.events
 */
export interface SeriesOhlcDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events.click
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events.click
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.events.click
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events.drag
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.events.drag
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events.drop
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.events.drop
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events.remove
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.events.remove
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events.select
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events.select
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.events.select
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events.update
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events.update
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.events.update
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events.update
     */
    update?: () => void;
}
/**
 * (Highstock) An array of data points for the series. For the `ohlc` series
 * type, points can be given in the following ways:
 *
 * 1. An array of arrays with 5 or 4 values. In this case, the values correspond
 * to `x,open,high,low,close`. If the first value is a string, it is applied as
 * the name of the point, and the `x` value is inferred. The `x` value can also
 * be omitted, in which case the inner arrays should be of length 4\. Then the
 * `x` value is automatically calculated, either starting at 0 and incremented
 * by 1, or from `pointStart` and `pointInterval` given in the series
 * options.(see online documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.ohlc.data
 */
export interface SeriesOhlcDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.className
     * @see https://api.highcharts.com/gantt/series.ohlc.data.className
     */
    className?: string;
    /**
     * (Highstock) The closing value of each data point.
     *
     * @see https://api.highcharts.com/highstock/series.ohlc.data.close
     */
    close?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.color
     * @see https://api.highcharts.com/highstock/series.ohlc.data.color
     * @see https://api.highcharts.com/gantt/series.ohlc.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.ohlc.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highstock) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highstock/series.ohlc.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.ohlc.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.ohlc.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.ohlc.data.dragDrop
     */
    dragDrop?: SeriesOhlcDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.events
     * @see https://api.highcharts.com/highstock/series.ohlc.data.events
     * @see https://api.highcharts.com/gantt/series.ohlc.data.events
     */
    events?: SeriesOhlcDataEventsOptions;
    /**
     * (Highcharts, Highstock) The high or maximum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.high
     * @see https://api.highcharts.com/highstock/series.ohlc.data.high
     */
    high?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.id
     * @see https://api.highcharts.com/highstock/series.ohlc.data.id
     * @see https://api.highcharts.com/gantt/series.ohlc.data.id
     */
    id?: string;
    /**
     * (Highstock) The rank for this point's data label in case of collision. If
     * two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highstock/series.ohlc.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) The low or minimum value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.low
     * @see https://api.highcharts.com/highstock/series.ohlc.data.low
     */
    low?: number;
    /**
     * (Highstock) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highstock/series.ohlc.data.name
     */
    name?: string;
    /**
     * (Highstock) The opening value of each data point.
     *
     * @see https://api.highcharts.com/highstock/series.ohlc.data.open
     */
    open?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.selected
     * @see https://api.highcharts.com/highstock/series.ohlc.data.selected
     * @see https://api.highcharts.com/gantt/series.ohlc.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.ohlc.data.x
     * @see https://api.highcharts.com/highstock/series.ohlc.data.x
     */
    x?: number;
}
/**
 * (Highstock) A `ohlc` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ohlc` series are defined in plotOptions.ohlc.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.ohlc
 */
export interface SeriesOhlcOptions extends PlotOhlcOptions, SeriesOptions {
    /**
     * (Highstock) An array of data points for the series. For the `ohlc` series
     * type, points can be given in the following ways:
     *
     * 1. An array of arrays with 5 or 4 values. In this case, the values
     * correspond to `x,open,high,low,close`. If the first value is a string, it
     * is applied as the name of the point, and the `x` value is inferred. The
     * `x` value can also be omitted, in which case the inner arrays should be
     * of length 4\. Then the `x` value is automatically calculated, either
     * starting at 0 and incremented by 1, or from `pointStart` and
     * `pointInterval` given in the series options.(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highstock/series.ohlc.data
     */
    data?: Array<([(number|string), number, number, number]|[(number|string), number, number, number, number]|SeriesOhlcDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "ohlc";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Series options for specific data and
 * the data itself. In TypeScript you have to cast the series options to
 * specific series types, to get all possible options for a series.
 *
 * @see https://api.highcharts.com/highcharts/series
 * @see https://api.highcharts.com/highstock/series
 * @see https://api.highcharts.com/highmaps/series
 * @see https://api.highcharts.com/gantt/series
 */
export interface SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An id for the series. This can
     * be used after render time to get a pointer to the series object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.id
     * @see https://api.highcharts.com/highstock/series.id
     * @see https://api.highcharts.com/highmaps/series.id
     * @see https://api.highcharts.com/gantt/series.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The index of the series in the
     * chart, affecting the internal index in the `chart.series` array, the
     * visible Z index as well as the order in the legend.
     *
     * @see https://api.highcharts.com/highcharts/series.index
     * @see https://api.highcharts.com/highstock/series.index
     * @see https://api.highcharts.com/highmaps/series.index
     * @see https://api.highcharts.com/gantt/series.index
     */
    index?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The sequential index of the
     * series in the legend.
     *
     * @see https://api.highcharts.com/highcharts/series.legendIndex
     * @see https://api.highcharts.com/highstock/series.legendIndex
     * @see https://api.highcharts.com/highmaps/series.legendIndex
     * @see https://api.highcharts.com/gantt/series.legendIndex
     */
    legendIndex?: number;
    /**
     * (Highmaps) A map data object containing a `path` definition and
     * optionally additional properties to join in the data as per the `joinBy`
     * option.
     *
     * @see https://api.highcharts.com/highmaps/series.mapData
     */
    mapData?: (MapDataObject|Array<MapDataObject>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The name of the series as shown
     * in the legend, tooltip etc.
     *
     * @see https://api.highcharts.com/highcharts/series.name
     * @see https://api.highcharts.com/highstock/series.name
     * @see https://api.highcharts.com/highmaps/series.name
     * @see https://api.highcharts.com/gantt/series.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock) This option allows grouping series in a stacked
     * chart. The stack option can be a string or anything else, as long as the
     * grouped series' stack options match each other after conversion into a
     * string.
     *
     * @see https://api.highcharts.com/highcharts/series.stack
     * @see https://api.highcharts.com/highstock/series.stack
     */
    stack?: (object|string);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The type of series, for example
     * `line` or `column`. By default, the series type is inherited from
     * chart.type, so unless the chart is a combination of series types, there
     * is no need to set it on the series level.
     *
     * @see https://api.highcharts.com/highcharts/series.type
     * @see https://api.highcharts.com/highstock/series.type
     * @see https://api.highcharts.com/highmaps/series.type
     * @see https://api.highcharts.com/gantt/series.type
     */
    type: string;
    /**
     * (Highcharts, Highstock) When using dual or multiple x axes, this number
     * defines which xAxis the particular series is connected to. It refers to
     * either the axis id or the index of the axis in the xAxis array, with 0
     * being the first.
     *
     * @see https://api.highcharts.com/highcharts/series.xAxis
     * @see https://api.highcharts.com/highstock/series.xAxis
     */
    xAxis?: (number|string);
    /**
     * (Highcharts, Highstock) When using dual or multiple y axes, this number
     * defines which yAxis the particular series is connected to. It refers to
     * either the axis id or the index of the axis in the yAxis array, with 0
     * being the first.
     *
     * @see https://api.highcharts.com/highcharts/series.yAxis
     * @see https://api.highcharts.com/highstock/series.yAxis
     */
    yAxis?: (number|string);
    /**
     * (Highcharts, Highstock) Define the visual z index of the series.
     *
     * @see https://api.highcharts.com/highcharts/series.zIndex
     * @see https://api.highcharts.com/highstock/series.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragHandle
 */
export interface SeriesPackedbubbleDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.guideBox.default
 */
export interface SeriesPackedbubbleDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.guideBox
 */
export interface SeriesPackedbubbleDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.guideBox.default
     */
    default?: SeriesPackedbubbleDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop
 */
export interface SeriesPackedbubbleDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesPackedbubbleDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.guideBox
     */
    guideBox?: (SeriesPackedbubbleDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events
 * @see https://api.highcharts.com/highstock/series.packedbubble.data.events
 * @see https://api.highcharts.com/gantt/series.packedbubble.data.events
 */
export interface SeriesPackedbubbleDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events.click
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events.click
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.events.click
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events.drag
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.events.drag
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events.drop
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.events.drop
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events.remove
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.events.remove
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events.select
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events.select
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.events.select
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events.update
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events.update
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.events.update
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `packedbubble`
 * series type, points can be given in the following ways:
 *
 * 1. An array of `value` values.(see online documentation for example)
 *
 * 2. An array of objects with named values. The objects are point configuration
 * objects as seen below. If the total number of data points exceeds the series'
 * turboThreshold, this option is not available.(see online documentation for
 * example)
 *
 * @see https://api.highcharts.com/highcharts/series.packedbubble.data
 */
export interface SeriesPackedbubbleDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.className
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.color
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.color
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.packedbubble.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.dragDrop
     */
    dragDrop?: SeriesPackedbubbleDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.events
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.events
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.events
     */
    events?: SeriesPackedbubbleDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.id
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.id
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.selected
     * @see https://api.highcharts.com/highstock/series.packedbubble.data.selected
     * @see https://api.highcharts.com/gantt/series.packedbubble.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) The value of a bubble. The bubble's size proportional to its
     * `value`.
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data.weight
     */
    weight?: number;
}
/**
 * (Highcharts, Highstock) A `packedbubble` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `packedbubble` series are defined in
 * plotOptions.packedbubble.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.packedbubble
 * @see https://api.highcharts.com/highstock/series.packedbubble
 */
export interface SeriesPackedbubbleOptions extends PlotPackedbubbleOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the
     * `packedbubble` series type, points can be given in the following ways:
     *
     * 1. An array of `value` values.(see online documentation for example)
     *
     * 2. An array of objects with named values. The objects are point
     * configuration objects as seen below. If the total number of data points
     * exceeds the series' turboThreshold, this option is not available.(see
     * online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.packedbubble.data
     */
    data?: Array<(number|SeriesPackedbubbleDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "packedbubble";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragHandle
 */
export interface SeriesParetoDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.guideBox.default
 */
export interface SeriesParetoDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.guideBox
 */
export interface SeriesParetoDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.guideBox.default
     */
    default?: SeriesParetoDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop
 */
export interface SeriesParetoDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesParetoDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.guideBox
     */
    guideBox?: (SeriesParetoDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.pareto.data.events
 * @see https://api.highcharts.com/highstock/series.pareto.data.events
 * @see https://api.highcharts.com/gantt/series.pareto.data.events
 */
export interface SeriesParetoDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events.click
     * @see https://api.highcharts.com/highstock/series.pareto.data.events.click
     * @see https://api.highcharts.com/highmaps/series.pareto.data.events.click
     * @see https://api.highcharts.com/gantt/series.pareto.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events.drag
     * @see https://api.highcharts.com/highstock/series.pareto.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.pareto.data.events.drag
     * @see https://api.highcharts.com/gantt/series.pareto.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.pareto.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.pareto.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.pareto.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events.drop
     * @see https://api.highcharts.com/highstock/series.pareto.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.pareto.data.events.drop
     * @see https://api.highcharts.com/gantt/series.pareto.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.pareto.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.pareto.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.pareto.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.pareto.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.pareto.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.pareto.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events.remove
     * @see https://api.highcharts.com/highstock/series.pareto.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.pareto.data.events.remove
     * @see https://api.highcharts.com/gantt/series.pareto.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events.select
     * @see https://api.highcharts.com/highstock/series.pareto.data.events.select
     * @see https://api.highcharts.com/highmaps/series.pareto.data.events.select
     * @see https://api.highcharts.com/gantt/series.pareto.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.pareto.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.pareto.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.pareto.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events.update
     * @see https://api.highcharts.com/highstock/series.pareto.data.events.update
     * @see https://api.highcharts.com/highmaps/series.pareto.data.events.update
     * @see https://api.highcharts.com/gantt/series.pareto.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `pareto` series
 * type, points are calculated dynamically.
 *
 * @see https://api.highcharts.com/highcharts/series.pareto.data
 */
export interface SeriesParetoDataOptions {
    /**
     * (Highcharts, Highstock) The color of the border surrounding the column or
     * bar.
     *
     * In styled mode, the border stroke can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.borderColor
     * @see https://api.highcharts.com/highstock/series.pareto.data.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock) The width of the border surrounding the column or
     * bar.
     *
     * In styled mode, the stroke width can be set with the `.highcharts-point`
     * rule.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.borderWidth
     * @see https://api.highcharts.com/highstock/series.pareto.data.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.className
     * @see https://api.highcharts.com/gantt/series.pareto.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.color
     * @see https://api.highcharts.com/highstock/series.pareto.data.color
     * @see https://api.highcharts.com/gantt/series.pareto.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.pareto.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.pareto.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.pareto.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.pareto.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.pareto.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.pareto.data.dragDrop
     */
    dragDrop?: SeriesParetoDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.events
     * @see https://api.highcharts.com/highstock/series.pareto.data.events
     * @see https://api.highcharts.com/gantt/series.pareto.data.events
     */
    events?: SeriesParetoDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.id
     * @see https://api.highcharts.com/highstock/series.pareto.data.id
     * @see https://api.highcharts.com/gantt/series.pareto.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) A pixel value specifying a fixed width for
     * the column or bar. Overrides pointWidth on the series.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.pointWidth
     * @see https://api.highcharts.com/highstock/series.pareto.data.pointWidth
     * @see https://api.highcharts.com/gantt/series.pareto.data.pointWidth
     */
    pointWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.selected
     * @see https://api.highcharts.com/highstock/series.pareto.data.selected
     * @see https://api.highcharts.com/gantt/series.pareto.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.x
     * @see https://api.highcharts.com/highstock/series.pareto.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data.y
     * @see https://api.highcharts.com/highstock/series.pareto.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `pareto` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `pareto` series are defined in plotOptions.pareto.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.pareto
 */
export interface SeriesParetoOptions extends PlotParetoOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `pareto`
     * series type, points are calculated dynamically.
     *
     * @see https://api.highcharts.com/highcharts/series.pareto.data
     */
    data?: Array<(Array<(number|string)>|SeriesParetoDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "pareto";
}
/**
 * (Highstock) A Price channel indicator. If the type option is not specified,
 * it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `pc` series are defined in plotOptions.pc.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.pc
 */
export interface SeriesPcOptions extends PlotPcOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "pc";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragHandle
 */
export interface SeriesPieDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.guideBox.default
 */
export interface SeriesPieDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.guideBox
 */
export interface SeriesPieDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.guideBox.default
     */
    default?: SeriesPieDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop
 */
export interface SeriesPieDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesPieDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.guideBox
     */
    guideBox?: (SeriesPieDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.pie.data.events
 * @see https://api.highcharts.com/highstock/series.pie.data.events
 * @see https://api.highcharts.com/gantt/series.pie.data.events
 */
export interface SeriesPieDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events.click
     * @see https://api.highcharts.com/highstock/series.pie.data.events.click
     * @see https://api.highcharts.com/highmaps/series.pie.data.events.click
     * @see https://api.highcharts.com/gantt/series.pie.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events.drag
     * @see https://api.highcharts.com/highstock/series.pie.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.pie.data.events.drag
     * @see https://api.highcharts.com/gantt/series.pie.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.pie.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.pie.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.pie.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events.drop
     * @see https://api.highcharts.com/highstock/series.pie.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.pie.data.events.drop
     * @see https://api.highcharts.com/gantt/series.pie.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.pie.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.pie.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.pie.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.pie.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.pie.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.pie.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events.remove
     * @see https://api.highcharts.com/highstock/series.pie.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.pie.data.events.remove
     * @see https://api.highcharts.com/gantt/series.pie.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events.select
     * @see https://api.highcharts.com/highstock/series.pie.data.events.select
     * @see https://api.highcharts.com/highmaps/series.pie.data.events.select
     * @see https://api.highcharts.com/gantt/series.pie.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.pie.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.pie.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.pie.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events.update
     * @see https://api.highcharts.com/highstock/series.pie.data.events.update
     * @see https://api.highcharts.com/highmaps/series.pie.data.events.update
     * @see https://api.highcharts.com/gantt/series.pie.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `pie` series
 * type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. Example:(see online documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.
 *
 *  ```js data: [{ y: 1, name: "Point2", color: "#00FF00" }, { y: 7, name:
 * "Point1", color: "#FF00FF" }]</pre>
 *
 * @see https://api.highcharts.com/highcharts/series.pie.data
 */
export interface SeriesPieDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.className
     * @see https://api.highcharts.com/gantt/series.pie.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.color
     * @see https://api.highcharts.com/highstock/series.pie.data.color
     * @see https://api.highcharts.com/gantt/series.pie.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.pie.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.pie.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.pie.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.pie.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.pie.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.pie.data.dragDrop
     */
    dragDrop?: SeriesPieDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.events
     * @see https://api.highcharts.com/highstock/series.pie.data.events
     * @see https://api.highcharts.com/gantt/series.pie.data.events
     */
    events?: SeriesPieDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.id
     * @see https://api.highcharts.com/highstock/series.pie.data.id
     * @see https://api.highcharts.com/gantt/series.pie.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The sequential index of the data point in the legend.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.legendIndex
     */
    legendIndex?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.selected
     * @see https://api.highcharts.com/highstock/series.pie.data.selected
     * @see https://api.highcharts.com/gantt/series.pie.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to display a slice offset from the center.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.sliced
     */
    sliced?: boolean;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data.y
     * @see https://api.highcharts.com/highstock/series.pie.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `pie` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `pie` series are defined in plotOptions.pie.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.pie
 */
export interface SeriesPieOptions extends PlotPieOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `pie` series
     * type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. Example:(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.
     *
     *  ```js data: [{ y: 1, name: "Point2", color: "#00FF00" }, { y: 7, name:
     * "Point1", color: "#FF00FF" }]</pre>
     *
     * @see https://api.highcharts.com/highcharts/series.pie.data
     */
    data?: Array<(number|[string, number]|SeriesPieDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "pie";
}
/**
 * (Highstock) A pivot points indicator. If the type option is not specified, it
 * is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `pivotpoints` series are defined in
 * plotOptions.pivotpoints.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.pivotpoints
 */
export interface SeriesPivotpointsOptions extends PlotPivotpointsOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "pivotpoints";
}
/**
 * Translation and scale for the plot area of a series.
 */
export interface SeriesPlotBoxObject {
    scaleX: number;
    scaleY: number;
    translateX: number;
    translateY: number;
}
/**
 * Common information for a click event on a series point.
 */
export interface SeriesPointClickEventObject {
    /**
     * Clicked point.
     */
    point: Point;
}
/**
 * Contains common information for a drag event on series points.
 */
export interface SeriesPointDragEventObject {
    /**
     * New points during drag.
     */
    newPoints: Dictionary<SeriesPointDragPointObject>;
    /**
     * Original data.
     */
    origin: object;
    /**
     * Prevent default drag action.
     */
    preventDefault: () => void;
    /**
     * Target point that caused the event.
     */
    target: Point;
    /**
     * Event type.
     */
    type: "drag";
}
/**
 * Contains information about a dragged points new values.
 */
export interface SeriesPointDragPointObject {
    /**
     * New values.
     */
    newValues: Dictionary<number>;
    /**
     * Dragged point.
     */
    point: Point;
}
/**
 * Contains common information for a drag event on series point.
 */
export interface SeriesPointDragStartEventObject {
    /**
     * Data property being dragged.
     */
    updateProp: Dictionary<number>;
}
/**
 * Contains common information for a drop event on series points.
 */
export interface SeriesPointDropEventObject {
    /**
     * New points after drop.
     */
    newPoints: Dictionary<SeriesPointDropPointObject>;
    /**
     * Number of new points.
     */
    numNewPoints: number;
    /**
     * Original data.
     */
    origin: object;
    /**
     * Prevent default drop action.
     */
    preventDefault: () => void;
    /**
     * Target point that caused the event.
     */
    target: Point;
    /**
     * Event type.
     */
    type: "drop";
}
/**
 * Contains information about a dropped points new values.
 */
export interface SeriesPointDropPointObject {
    /**
     * New values.
     */
    newValues: Dictionary<number>;
    /**
     * Dragged point.
     */
    point: Point;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragHandle
 */
export interface SeriesPolygonDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.guideBox.default
 */
export interface SeriesPolygonDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.guideBox
 */
export interface SeriesPolygonDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.guideBox.default
     */
    default?: SeriesPolygonDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop
 */
export interface SeriesPolygonDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesPolygonDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.guideBox
     */
    guideBox?: (SeriesPolygonDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.events
 * @see https://api.highcharts.com/highstock/series.polygon.data.events
 * @see https://api.highcharts.com/gantt/series.polygon.data.events
 */
export interface SeriesPolygonDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events.click
     * @see https://api.highcharts.com/highstock/series.polygon.data.events.click
     * @see https://api.highcharts.com/highmaps/series.polygon.data.events.click
     * @see https://api.highcharts.com/gantt/series.polygon.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events.drag
     * @see https://api.highcharts.com/highstock/series.polygon.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.polygon.data.events.drag
     * @see https://api.highcharts.com/gantt/series.polygon.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.polygon.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.polygon.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.polygon.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events.drop
     * @see https://api.highcharts.com/highstock/series.polygon.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.polygon.data.events.drop
     * @see https://api.highcharts.com/gantt/series.polygon.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.polygon.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.polygon.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.polygon.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.polygon.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.polygon.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.polygon.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events.remove
     * @see https://api.highcharts.com/highstock/series.polygon.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.polygon.data.events.remove
     * @see https://api.highcharts.com/gantt/series.polygon.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events.select
     * @see https://api.highcharts.com/highstock/series.polygon.data.events.select
     * @see https://api.highcharts.com/highmaps/series.polygon.data.events.select
     * @see https://api.highcharts.com/gantt/series.polygon.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.polygon.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.polygon.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.polygon.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events.update
     * @see https://api.highcharts.com/highstock/series.polygon.data.events.update
     * @see https://api.highcharts.com/highmaps/series.polygon.data.events.update
     * @see https://api.highcharts.com/gantt/series.polygon.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.marker
 * @see https://api.highcharts.com/highstock/series.polygon.data.marker
 */
export interface SeriesPolygonDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.height
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.height
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states
     */
    states?: SeriesPolygonDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.width
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.width
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover.animation
 */
export interface SeriesPolygonDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover
 */
export interface SeriesPolygonDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesPolygonDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.normal
 */
export interface SeriesPolygonDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states
 * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states
 * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states
 */
export interface SeriesPolygonDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.hover
     */
    hover?: SeriesPolygonDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.normal
     */
    normal?: SeriesPolygonDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.select
     */
    select?: SeriesPolygonDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.select
 */
export interface SeriesPolygonDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.polygon.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.polygon.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `polygon` series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.polygon.data
 * @see https://api.highcharts.com/highstock/series.polygon.data
 */
export interface SeriesPolygonDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.className
     * @see https://api.highcharts.com/gantt/series.polygon.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.color
     * @see https://api.highcharts.com/highstock/series.polygon.data.color
     * @see https://api.highcharts.com/gantt/series.polygon.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.polygon.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.polygon.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.polygon.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.description
     * @see https://api.highcharts.com/highstock/series.polygon.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.polygon.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.polygon.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.polygon.data.dragDrop
     */
    dragDrop?: SeriesPolygonDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.events
     * @see https://api.highcharts.com/highstock/series.polygon.data.events
     * @see https://api.highcharts.com/gantt/series.polygon.data.events
     */
    events?: SeriesPolygonDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.id
     * @see https://api.highcharts.com/highstock/series.polygon.data.id
     * @see https://api.highcharts.com/gantt/series.polygon.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.labelrank
     * @see https://api.highcharts.com/highstock/series.polygon.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.marker
     * @see https://api.highcharts.com/highstock/series.polygon.data.marker
     */
    marker?: SeriesPolygonDataMarkerOptions;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.name
     * @see https://api.highcharts.com/highstock/series.polygon.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.selected
     * @see https://api.highcharts.com/highstock/series.polygon.data.selected
     * @see https://api.highcharts.com/gantt/series.polygon.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.x
     * @see https://api.highcharts.com/highstock/series.polygon.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data.y
     * @see https://api.highcharts.com/highstock/series.polygon.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `polygon` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `polygon` series are defined in plotOptions.polygon.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.polygon
 * @see https://api.highcharts.com/highstock/series.polygon
 */
export interface SeriesPolygonOptions extends PlotPolygonOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `polygon` series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.polygon.data
     * @see https://api.highcharts.com/highstock/series.polygon.data
     */
    data?: Array<(number|[(number|string), number]|SeriesPolygonDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "polygon";
}
/**
 * (Highstock) A `Percentage Price Oscillator` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `ppo` series are defined in plotOptions.ppo.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.ppo
 */
export interface SeriesPpoOptions extends PlotPpoOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "ppo";
}
/**
 * (Highstock) A price envelopes indicator. If the type option is not specified,
 * it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `priceenvelopes` series are defined in
 * plotOptions.priceenvelopes.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.priceenvelopes
 */
export interface SeriesPriceenvelopesOptions extends PlotPriceenvelopesOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "priceenvelopes";
}
/**
 * (Highstock) A `PSAR` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `psar` series are defined in plotOptions.psar.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.psar
 */
export interface SeriesPsarOptions extends PlotPsarOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "psar";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragHandle
 */
export interface SeriesPyramidDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.guideBox.default
 */
export interface SeriesPyramidDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.guideBox
 */
export interface SeriesPyramidDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.guideBox.default
     */
    default?: SeriesPyramidDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop
 */
export interface SeriesPyramidDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesPyramidDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.guideBox
     */
    guideBox?: (SeriesPyramidDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.pyramid.data.events
 * @see https://api.highcharts.com/highstock/series.pyramid.data.events
 * @see https://api.highcharts.com/gantt/series.pyramid.data.events
 */
export interface SeriesPyramidDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events.click
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events.click
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.events.click
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events.drag
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.events.drag
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events.drop
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.events.drop
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events.remove
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.events.remove
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events.select
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events.select
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.events.select
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events.update
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events.update
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.events.update
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `pyramid` series
 * type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. Example:(see online documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.pyramid.data
 */
export interface SeriesPyramidDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.className
     * @see https://api.highcharts.com/gantt/series.pyramid.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.color
     * @see https://api.highcharts.com/highstock/series.pyramid.data.color
     * @see https://api.highcharts.com/gantt/series.pyramid.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.pyramid.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.pyramid.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.pyramid.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.pyramid.data.dragDrop
     */
    dragDrop?: SeriesPyramidDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.events
     * @see https://api.highcharts.com/highstock/series.pyramid.data.events
     * @see https://api.highcharts.com/gantt/series.pyramid.data.events
     */
    events?: SeriesPyramidDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.id
     * @see https://api.highcharts.com/highstock/series.pyramid.data.id
     * @see https://api.highcharts.com/gantt/series.pyramid.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The sequential index of the data point in the legend.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.legendIndex
     */
    legendIndex?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.selected
     * @see https://api.highcharts.com/highstock/series.pyramid.data.selected
     * @see https://api.highcharts.com/gantt/series.pyramid.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data.y
     * @see https://api.highcharts.com/highstock/series.pyramid.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `pyramid` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `pyramid` series are defined in plotOptions.pyramid.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.pyramid
 */
export interface SeriesPyramidOptions extends PlotPyramidOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `pyramid`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. Example:(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.pyramid.data
     */
    data?: Array<(number|SeriesPyramidDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "pyramid";
}
/**
 * (Highstock) A `ROC` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Rate of change indicator (ROC). The indicator value for each point is defined
 * as:
 *
 * `(C - Cn) / Cn * 100`
 *
 * where: `C` is the close value of the point of the same x in the linked series
 * and `Cn` is the close value of the point `n` periods ago. `n` is set through
 * period.
 *
 * This series requires `linkedTo` option to be set.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `roc` series are defined in plotOptions.roc.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.roc
 */
export interface SeriesRocOptions extends PlotRocOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "roc";
}
/**
 * (Highstock) A `RSI` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `rsi` series are defined in plotOptions.rsi.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.rsi
 */
export interface SeriesRsiOptions extends PlotRsiOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "rsi";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragHandle
 */
export interface SeriesSankeyDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.guideBox.default
 */
export interface SeriesSankeyDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.guideBox
 */
export interface SeriesSankeyDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.guideBox.default
     */
    default?: SeriesSankeyDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop
 */
export interface SeriesSankeyDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesSankeyDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.guideBox
     */
    guideBox?: (SeriesSankeyDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.sankey.data.events
 * @see https://api.highcharts.com/highstock/series.sankey.data.events
 * @see https://api.highcharts.com/gantt/series.sankey.data.events
 */
export interface SeriesSankeyDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events.click
     * @see https://api.highcharts.com/highstock/series.sankey.data.events.click
     * @see https://api.highcharts.com/highmaps/series.sankey.data.events.click
     * @see https://api.highcharts.com/gantt/series.sankey.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events.drag
     * @see https://api.highcharts.com/highstock/series.sankey.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.sankey.data.events.drag
     * @see https://api.highcharts.com/gantt/series.sankey.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.sankey.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.sankey.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.sankey.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events.drop
     * @see https://api.highcharts.com/highstock/series.sankey.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.sankey.data.events.drop
     * @see https://api.highcharts.com/gantt/series.sankey.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.sankey.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.sankey.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.sankey.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.sankey.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.sankey.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.sankey.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events.remove
     * @see https://api.highcharts.com/highstock/series.sankey.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.sankey.data.events.remove
     * @see https://api.highcharts.com/gantt/series.sankey.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events.select
     * @see https://api.highcharts.com/highstock/series.sankey.data.events.select
     * @see https://api.highcharts.com/highmaps/series.sankey.data.events.select
     * @see https://api.highcharts.com/gantt/series.sankey.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.sankey.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.sankey.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.sankey.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events.update
     * @see https://api.highcharts.com/highstock/series.sankey.data.events.update
     * @see https://api.highcharts.com/highmaps/series.sankey.data.events.update
     * @see https://api.highcharts.com/gantt/series.sankey.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `sankey` series
 * type, points can be given in the following way:
 *
 * An array of objects with named values. The following snippet shows only a few
 * settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.sankey.data
 */
export interface SeriesSankeyDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.className
     * @see https://api.highcharts.com/gantt/series.sankey.data.className
     */
    className?: string;
    /**
     * (Highcharts) The color for the individual _link_. By default, the link
     * color is the same as the node it extends from. The `series.fillOpacity`
     * option also applies to the points, so when setting a specific link color,
     * consider setting the `fillOpacity` to 1.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.sankey.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.sankey.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.sankey.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.sankey.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.sankey.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.sankey.data.dragDrop
     */
    dragDrop?: SeriesSankeyDataDragDropOptions;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.events
     * @see https://api.highcharts.com/highstock/series.sankey.data.events
     * @see https://api.highcharts.com/gantt/series.sankey.data.events
     */
    events?: SeriesSankeyDataEventsOptions;
    /**
     * (Highcharts) The node that the link runs from.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.from
     */
    from?: string;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.id
     * @see https://api.highcharts.com/highstock/series.sankey.data.id
     * @see https://api.highcharts.com/gantt/series.sankey.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.name
     */
    name?: string;
    /**
     * (Highcharts) Whether the link goes out of the system.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.outgoing
     */
    outgoing?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.selected
     * @see https://api.highcharts.com/highstock/series.sankey.data.selected
     * @see https://api.highcharts.com/gantt/series.sankey.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) The node that the link runs to.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.to
     */
    to?: string;
    /**
     * (Highcharts) The weight of the link.
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data.weight
     */
    weight?: number;
}
/**
 * (Highcharts) A `sankey` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `sankey` series are defined in plotOptions.sankey.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.sankey
 */
export interface SeriesSankeyOptions extends PlotSankeyOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `sankey`
     * series type, points can be given in the following way:
     *
     * An array of objects with named values. The following snippet shows only a
     * few settings, see the complete options set below. If the total number of
     * data points exceeds the series' turboThreshold, this option is not
     * available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.sankey.data
     */
    data?: Array<SeriesSankeyDataOptions>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "sankey";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragHandle
 */
export interface SeriesScatter3dDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.guideBox.default
 */
export interface SeriesScatter3dDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.guideBox
 */
export interface SeriesScatter3dDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.guideBox.default
     */
    default?: SeriesScatter3dDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop
 */
export interface SeriesScatter3dDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesScatter3dDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.guideBox
     */
    guideBox?: (SeriesScatter3dDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.events
 * @see https://api.highcharts.com/gantt/series.scatter3d.data.events
 */
export interface SeriesScatter3dDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events.click
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events.click
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.events.click
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events.drag
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.events.drag
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events.drop
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.events.drop
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events.remove
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.events.remove
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events.select
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events.select
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.events.select
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events.update
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events.update
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.events.update
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker
 */
export interface SeriesScatter3dDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.height
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.height
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states
     */
    states?: SeriesScatter3dDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.width
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.width
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover.animation
 */
export interface SeriesScatter3dDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover
 */
export interface SeriesScatter3dDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesScatter3dDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.normal
 */
export interface SeriesScatter3dDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states
 * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states
 */
export interface SeriesScatter3dDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.hover
     */
    hover?: SeriesScatter3dDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.normal
     */
    normal?: SeriesScatter3dDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.select
     */
    select?: SeriesScatter3dDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.select
 */
export interface SeriesScatter3dDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts) An array of data points for the series. For the `scatter3d`
 * series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 values. In this case, the values correspond to
 * `x,y,z`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d.data
 */
export interface SeriesScatter3dDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.className
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.color
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.color
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.scatter3d.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.dragDrop
     */
    dragDrop?: SeriesScatter3dDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.events
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.events
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.events
     */
    events?: SeriesScatter3dDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.id
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.id
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.marker
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.marker
     */
    marker?: SeriesScatter3dDataMarkerOptions;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.selected
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.selected
     * @see https://api.highcharts.com/gantt/series.scatter3d.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.x
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.y
     * @see https://api.highcharts.com/highstock/series.scatter3d.data.y
     */
    y?: number;
    /**
     * (Highcharts) The z value for each data point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data.z
     */
    z?: number;
}
/**
 * (Highcharts) A `scatter3d` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * scatter3d](#plotOptions.scatter3d).
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `scatter3d` series are defined in plotOptions.scatter3d.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.scatter3d
 */
export interface SeriesScatter3dOptions extends PlotScatter3dOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `scatter3d`
     * series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 values. In this case, the values correspond
     * to `x,y,z`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.scatter3d.data
     */
    data?: Array<(Array<number>|SeriesScatter3dDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "scatter3d";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragHandle
 */
export interface SeriesScatterDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.guideBox.default
 */
export interface SeriesScatterDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.guideBox
 */
export interface SeriesScatterDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.guideBox.default
     */
    default?: SeriesScatterDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop
 */
export interface SeriesScatterDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesScatterDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.guideBox
     */
    guideBox?: (SeriesScatterDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.events
 * @see https://api.highcharts.com/highstock/series.scatter.data.events
 * @see https://api.highcharts.com/gantt/series.scatter.data.events
 */
export interface SeriesScatterDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events.click
     * @see https://api.highcharts.com/highstock/series.scatter.data.events.click
     * @see https://api.highcharts.com/highmaps/series.scatter.data.events.click
     * @see https://api.highcharts.com/gantt/series.scatter.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events.drag
     * @see https://api.highcharts.com/highstock/series.scatter.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.scatter.data.events.drag
     * @see https://api.highcharts.com/gantt/series.scatter.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.scatter.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.scatter.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.scatter.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events.drop
     * @see https://api.highcharts.com/highstock/series.scatter.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.scatter.data.events.drop
     * @see https://api.highcharts.com/gantt/series.scatter.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.scatter.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.scatter.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.scatter.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.scatter.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.scatter.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.scatter.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events.remove
     * @see https://api.highcharts.com/highstock/series.scatter.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.scatter.data.events.remove
     * @see https://api.highcharts.com/gantt/series.scatter.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events.select
     * @see https://api.highcharts.com/highstock/series.scatter.data.events.select
     * @see https://api.highcharts.com/highmaps/series.scatter.data.events.select
     * @see https://api.highcharts.com/gantt/series.scatter.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.scatter.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.scatter.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.scatter.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events.update
     * @see https://api.highcharts.com/highstock/series.scatter.data.events.update
     * @see https://api.highcharts.com/highmaps/series.scatter.data.events.update
     * @see https://api.highcharts.com/gantt/series.scatter.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.marker
 * @see https://api.highcharts.com/highstock/series.scatter.data.marker
 */
export interface SeriesScatterDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.height
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.height
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states
     */
    states?: SeriesScatterDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.width
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.width
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover.animation
 */
export interface SeriesScatterDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover
 */
export interface SeriesScatterDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesScatterDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.normal
 */
export interface SeriesScatterDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states
 * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states
 * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states
 */
export interface SeriesScatterDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.hover
     */
    hover?: SeriesScatterDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.normal
     */
    normal?: SeriesScatterDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.select
     */
    select?: SeriesScatterDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.select
 */
export interface SeriesScatterDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.scatter.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.scatter.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `scatter` series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.scatter.data
 * @see https://api.highcharts.com/highstock/series.scatter.data
 */
export interface SeriesScatterDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.className
     * @see https://api.highcharts.com/gantt/series.scatter.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.color
     * @see https://api.highcharts.com/highstock/series.scatter.data.color
     * @see https://api.highcharts.com/gantt/series.scatter.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.scatter.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.scatter.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.scatter.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.description
     * @see https://api.highcharts.com/highstock/series.scatter.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.scatter.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.scatter.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.scatter.data.dragDrop
     */
    dragDrop?: SeriesScatterDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.events
     * @see https://api.highcharts.com/highstock/series.scatter.data.events
     * @see https://api.highcharts.com/gantt/series.scatter.data.events
     */
    events?: SeriesScatterDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.id
     * @see https://api.highcharts.com/highstock/series.scatter.data.id
     * @see https://api.highcharts.com/gantt/series.scatter.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.labelrank
     * @see https://api.highcharts.com/highstock/series.scatter.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.marker
     * @see https://api.highcharts.com/highstock/series.scatter.data.marker
     */
    marker?: SeriesScatterDataMarkerOptions;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.name
     * @see https://api.highcharts.com/highstock/series.scatter.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.selected
     * @see https://api.highcharts.com/highstock/series.scatter.data.selected
     * @see https://api.highcharts.com/gantt/series.scatter.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.x
     * @see https://api.highcharts.com/highstock/series.scatter.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data.y
     * @see https://api.highcharts.com/highstock/series.scatter.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `scatter` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `scatter` series are defined in plotOptions.scatter.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.scatter
 * @see https://api.highcharts.com/highstock/series.scatter
 */
export interface SeriesScatterOptions extends PlotScatterOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `scatter` series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.scatter.data
     * @see https://api.highcharts.com/highstock/series.scatter.data
     */
    data?: Array<(number|[(number|string), number]|SeriesScatterDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "scatter";
}
/**
 * (Highstock) A `SMA` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `sma` series are defined in plotOptions.sma.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.sma
 */
export interface SeriesSmaOptions extends PlotSmaOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "sma";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragHandle
 */
export interface SeriesSolidgaugeDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.guideBox.default
 */
export interface SeriesSolidgaugeDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.guideBox
 */
export interface SeriesSolidgaugeDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.guideBox.default
     */
    default?: SeriesSolidgaugeDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop
 */
export interface SeriesSolidgaugeDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesSolidgaugeDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.guideBox
     */
    guideBox?: (SeriesSolidgaugeDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events
 * @see https://api.highcharts.com/highstock/series.solidgauge.data.events
 * @see https://api.highcharts.com/gantt/series.solidgauge.data.events
 */
export interface SeriesSolidgaugeDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events.click
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events.click
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.events.click
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events.drag
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.events.drag
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events.drop
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.events.drop
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events.remove
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.events.remove
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events.select
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events.select
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.events.select
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events.update
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events.update
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.events.update
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `solidgauge`
 * series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. Example:(see online documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * The typical gauge only contains a single data value.
 *
 * @see https://api.highcharts.com/highcharts/series.solidgauge.data
 */
export interface SeriesSolidgaugeDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.className
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.color
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.color
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.solidgauge.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.dragDrop
     */
    dragDrop?: SeriesSolidgaugeDataDragDropOptions;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.events
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.events
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.events
     */
    events?: SeriesSolidgaugeDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.id
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.id
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.id
     */
    id?: string;
    /**
     * (Highcharts) The inner radius of an individual point in a solid gauge.
     * Can be given as a number (pixels) or percentage string.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.innerRadius
     */
    innerRadius?: (number|string);
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.name
     */
    name?: string;
    /**
     * (Highcharts) The outer radius of an individual point in a solid gauge.
     * Can be given as a number (pixels) or percentage string.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.radius
     */
    radius?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.selected
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.selected
     * @see https://api.highcharts.com/gantt/series.solidgauge.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data.y
     * @see https://api.highcharts.com/highstock/series.solidgauge.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `solidgauge` series. If the type option is not specified, it
 * is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `solidgauge` series are defined in plotOptions.solidgauge.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.solidgauge
 */
export interface SeriesSolidgaugeOptions extends PlotSolidgaugeOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `solidgauge`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. Example:(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * The typical gauge only contains a single data value.
     *
     * @see https://api.highcharts.com/highcharts/series.solidgauge.data
     */
    data?: Array<(number|SeriesSolidgaugeDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "solidgauge";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragHandle
 */
export interface SeriesSplineDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.guideBox.default
 */
export interface SeriesSplineDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.guideBox
 */
export interface SeriesSplineDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.guideBox.default
     */
    default?: SeriesSplineDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop
 */
export interface SeriesSplineDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesSplineDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.guideBox
     */
    guideBox?: (SeriesSplineDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.events
 * @see https://api.highcharts.com/highstock/series.spline.data.events
 * @see https://api.highcharts.com/gantt/series.spline.data.events
 */
export interface SeriesSplineDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events.click
     * @see https://api.highcharts.com/highstock/series.spline.data.events.click
     * @see https://api.highcharts.com/highmaps/series.spline.data.events.click
     * @see https://api.highcharts.com/gantt/series.spline.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events.drag
     * @see https://api.highcharts.com/highstock/series.spline.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.spline.data.events.drag
     * @see https://api.highcharts.com/gantt/series.spline.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.spline.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.spline.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.spline.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events.drop
     * @see https://api.highcharts.com/highstock/series.spline.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.spline.data.events.drop
     * @see https://api.highcharts.com/gantt/series.spline.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.spline.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.spline.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.spline.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.spline.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.spline.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.spline.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events.remove
     * @see https://api.highcharts.com/highstock/series.spline.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.spline.data.events.remove
     * @see https://api.highcharts.com/gantt/series.spline.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events.select
     * @see https://api.highcharts.com/highstock/series.spline.data.events.select
     * @see https://api.highcharts.com/highmaps/series.spline.data.events.select
     * @see https://api.highcharts.com/gantt/series.spline.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.spline.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.spline.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.spline.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events.update
     * @see https://api.highcharts.com/highstock/series.spline.data.events.update
     * @see https://api.highcharts.com/highmaps/series.spline.data.events.update
     * @see https://api.highcharts.com/gantt/series.spline.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.marker
 * @see https://api.highcharts.com/highstock/series.spline.data.marker
 */
export interface SeriesSplineDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.height
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.height
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states
     */
    states?: SeriesSplineDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.width
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.width
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover.animation
 */
export interface SeriesSplineDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover
 */
export interface SeriesSplineDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesSplineDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.normal
 */
export interface SeriesSplineDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states
 * @see https://api.highcharts.com/highstock/series.spline.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states
 * @see https://api.highcharts.com/gantt/series.spline.data.marker.states
 */
export interface SeriesSplineDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.hover
     */
    hover?: SeriesSplineDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.normal
     */
    normal?: SeriesSplineDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.select
     */
    select?: SeriesSplineDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.select
 */
export interface SeriesSplineDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.spline.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.spline.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.spline.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `spline` series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.spline.data
 * @see https://api.highcharts.com/highstock/series.spline.data
 */
export interface SeriesSplineDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.className
     * @see https://api.highcharts.com/gantt/series.spline.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.color
     * @see https://api.highcharts.com/highstock/series.spline.data.color
     * @see https://api.highcharts.com/gantt/series.spline.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.spline.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.spline.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.spline.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.description
     * @see https://api.highcharts.com/highstock/series.spline.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.spline.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.spline.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.spline.data.dragDrop
     */
    dragDrop?: SeriesSplineDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.events
     * @see https://api.highcharts.com/highstock/series.spline.data.events
     * @see https://api.highcharts.com/gantt/series.spline.data.events
     */
    events?: SeriesSplineDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.id
     * @see https://api.highcharts.com/highstock/series.spline.data.id
     * @see https://api.highcharts.com/gantt/series.spline.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.labelrank
     * @see https://api.highcharts.com/highstock/series.spline.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.marker
     * @see https://api.highcharts.com/highstock/series.spline.data.marker
     */
    marker?: SeriesSplineDataMarkerOptions;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.name
     * @see https://api.highcharts.com/highstock/series.spline.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.selected
     * @see https://api.highcharts.com/highstock/series.spline.data.selected
     * @see https://api.highcharts.com/gantt/series.spline.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.x
     * @see https://api.highcharts.com/highstock/series.spline.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data.y
     * @see https://api.highcharts.com/highstock/series.spline.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `spline` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `spline` series are defined in plotOptions.spline.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.spline
 * @see https://api.highcharts.com/highstock/series.spline
 */
export interface SeriesSplineOptions extends PlotSplineOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `spline` series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.spline.data
     * @see https://api.highcharts.com/highstock/series.spline.data
     */
    data?: Array<(number|[(number|string), number]|SeriesSplineDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "spline";
}
/**
 * (Highstock) A Stochastic indicator. If the type option is not specified, it
 * is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `stochastic` series are defined in plotOptions.stochastic.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.stochastic
 */
export interface SeriesStochasticOptions extends PlotStochasticOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "stochastic";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragHandle
 */
export interface SeriesStreamgraphDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.guideBox.default
 */
export interface SeriesStreamgraphDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.guideBox
 */
export interface SeriesStreamgraphDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.guideBox.default
     */
    default?: SeriesStreamgraphDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop
 */
export interface SeriesStreamgraphDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesStreamgraphDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.guideBox
     */
    guideBox?: (SeriesStreamgraphDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.events
 * @see https://api.highcharts.com/gantt/series.streamgraph.data.events
 */
export interface SeriesStreamgraphDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events.click
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events.click
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.events.click
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events.drag
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.events.drag
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events.drop
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.events.drop
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events.remove
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.events.remove
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events.select
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events.select
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.events.select
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events.update
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events.update
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.events.update
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker
 */
export interface SeriesStreamgraphDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.height
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.height
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states
     */
    states?: SeriesStreamgraphDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.width
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.width
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover.animation
 */
export interface SeriesStreamgraphDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover
 */
export interface SeriesStreamgraphDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesStreamgraphDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.normal
 */
export interface SeriesStreamgraphDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states
 * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states
 */
export interface SeriesStreamgraphDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.hover
     */
    hover?: SeriesStreamgraphDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.normal
     */
    normal?: SeriesStreamgraphDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.select
     */
    select?: SeriesStreamgraphDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.select
 */
export interface SeriesStreamgraphDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `streamgraph` series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph.data
 * @see https://api.highcharts.com/highstock/series.streamgraph.data
 */
export interface SeriesStreamgraphDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.className
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.color
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.color
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.description
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.streamgraph.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.dragDrop
     */
    dragDrop?: SeriesStreamgraphDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.events
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.events
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.events
     */
    events?: SeriesStreamgraphDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.id
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.id
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.labelrank
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.marker
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.marker
     */
    marker?: SeriesStreamgraphDataMarkerOptions;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.name
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.selected
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.selected
     * @see https://api.highcharts.com/gantt/series.streamgraph.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.x
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data.y
     * @see https://api.highcharts.com/highstock/series.streamgraph.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `streamgraph` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `streamgraph` series are defined in
 * plotOptions.streamgraph.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.streamgraph
 * @see https://api.highcharts.com/highstock/series.streamgraph
 */
export interface SeriesStreamgraphOptions extends PlotStreamgraphOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `streamgraph` series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.streamgraph.data
     * @see https://api.highcharts.com/highstock/series.streamgraph.data
     */
    data?: Array<(number|[(number|string), number]|SeriesStreamgraphDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "streamgraph";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragHandle
 */
export interface SeriesSunburstDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.guideBox.default
 */
export interface SeriesSunburstDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.guideBox
 */
export interface SeriesSunburstDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.guideBox.default
     */
    default?: SeriesSunburstDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop
 */
export interface SeriesSunburstDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesSunburstDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.guideBox
     */
    guideBox?: (SeriesSunburstDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.sunburst.data.events
 * @see https://api.highcharts.com/highstock/series.sunburst.data.events
 * @see https://api.highcharts.com/gantt/series.sunburst.data.events
 */
export interface SeriesSunburstDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events.click
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events.click
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.events.click
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events.drag
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.events.drag
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events.drop
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.events.drop
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events.remove
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.events.remove
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events.select
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events.select
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.events.select
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events.update
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events.update
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.events.update
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `treemap` series
 * type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `value` options. Example:(see online documentation for
 * example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.sunburst.data
 */
export interface SeriesSunburstDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.className
     * @see https://api.highcharts.com/gantt/series.sunburst.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) The color of the point. In heat maps the point
     * color is rarely set explicitly, as we use the color to denote the
     * `value`. Options for this are set in the colorAxis configuration.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.color
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.sunburst.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts) Serves a purpose only if a `colorAxis` object is defined in
     * the chart options. This value will decide which color the point gets from
     * the scale of the colorAxis.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.colorValue
     */
    colorValue?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.sunburst.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.sunburst.data.dragDrop
     */
    dragDrop?: SeriesSunburstDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.events
     * @see https://api.highcharts.com/highstock/series.sunburst.data.events
     * @see https://api.highcharts.com/gantt/series.sunburst.data.events
     */
    events?: SeriesSunburstDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.id
     * @see https://api.highcharts.com/highstock/series.sunburst.data.id
     * @see https://api.highcharts.com/gantt/series.sunburst.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name decides the text for a word.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.name
     */
    name?: string;
    /**
     * (Highcharts) Only for treemap. Use this option to build a tree structure.
     * The value should be the id of the point which is the parent. If no points
     * has a matching id, or this option is undefined, then the parent will be
     * set to the root.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.parent
     */
    parent?: string;
    /**
     * (Highcharts, Highmaps) Point padding for a single point.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.pointPadding
     * @see https://api.highcharts.com/highmaps/series.sunburst.data.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.selected
     * @see https://api.highcharts.com/highstock/series.sunburst.data.selected
     * @see https://api.highcharts.com/gantt/series.sunburst.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to display a slice offset from the center. When a
     * sunburst point is sliced, its children are also offset.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.sliced
     */
    sliced?: boolean;
    /**
     * (Highcharts) The value of the point, resulting in a relative area of the
     * point in the sunburst.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.value
     */
    value?: number;
    /**
     * (Highcharts) The weighting of a word. The weight decides the relative
     * size of a word compared to the rest of the collection.
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data.weight
     */
    weight?: number;
}
/**
 * (Highcharts) A `sunburst` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `sunburst` series are defined in plotOptions.sunburst.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.sunburst
 */
export interface SeriesSunburstOptions extends PlotSunburstOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `treemap`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `value` options. Example:(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.sunburst.data
     */
    data?: Array<(number|SeriesSunburstDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "sunburst";
}
/**
 * (Highstock) A `Supertrend indicator` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `supertrend` series are defined in plotOptions.supertrend.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.supertrend
 */
export interface SeriesSupertrendOptions extends PlotSupertrendOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "supertrend";
}
/**
 * (Highstock) A `TEMA` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `tema` series are defined in plotOptions.tema.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.tema
 */
export interface SeriesTemaOptions extends PlotTemaOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "tema";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragHandle
 */
export interface SeriesTilemapDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.guideBox.default
 */
export interface SeriesTilemapDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.guideBox
 */
export interface SeriesTilemapDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.guideBox.default
     */
    default?: SeriesTilemapDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop
 */
export interface SeriesTilemapDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesTilemapDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.guideBox
     */
    guideBox?: (SeriesTilemapDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.tilemap.data.events
 * @see https://api.highcharts.com/highstock/series.tilemap.data.events
 * @see https://api.highcharts.com/gantt/series.tilemap.data.events
 */
export interface SeriesTilemapDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events.click
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events.click
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.events.click
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events.drag
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.events.drag
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events.drop
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.events.drop
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events.remove
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.events.remove
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events.select
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events.select
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.events.select
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events.update
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events.update
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.events.update
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highmaps) An array of data points for the series. For the
 * `tilemap` series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 or 2 values. In this case, the values correspond
 * to `x,y,value`. If the first value is a string, it is applied as the name of
 * the point, and the `x` value is inferred. The `x` value can also be omitted,
 * in which case the inner arrays should be of length 2\. Then the `x` value is
 * automatically calculated, either starting at 0 and incremented by 1, or from
 * `pointStart` and `pointInterval` given in the series options.(see online
 * documentation for example)
 *
 * 2. An array of objects with named values. The objects are point configuration
 * objects as seen below. If the total number of data points exceeds the series'
 * turboThreshold, this option is not available.(see online documentation for
 * example)
 *
 * Note that for some tileShapes the grid coordinates are offset.
 *
 * @see https://api.highcharts.com/highcharts/series.tilemap.data
 * @see https://api.highcharts.com/highmaps/series.tilemap.data
 */
export interface SeriesTilemapDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.className
     * @see https://api.highcharts.com/gantt/series.tilemap.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) The color of the point. In tilemaps the point
     * color is rarely set explicitly, as we use the color to denote the
     * `value`. Options for this are set in the colorAxis configuration.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.color
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.tilemap.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highmaps) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.description
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.tilemap.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.tilemap.data.dragDrop
     */
    dragDrop?: SeriesTilemapDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.events
     * @see https://api.highcharts.com/highstock/series.tilemap.data.events
     * @see https://api.highcharts.com/gantt/series.tilemap.data.events
     */
    events?: SeriesTilemapDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.id
     * @see https://api.highcharts.com/highstock/series.tilemap.data.id
     * @see https://api.highcharts.com/gantt/series.tilemap.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highmaps) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.labelrank
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highmaps) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.name
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highmaps) Point padding for a single point.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.pointPadding
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.selected
     * @see https://api.highcharts.com/highstock/series.tilemap.data.selected
     * @see https://api.highcharts.com/gantt/series.tilemap.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highmaps) The value of the point, resulting in a color
     * controled by options as set in the colorAxis configuration.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.value
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.value
     */
    value?: number;
    /**
     * (Highcharts, Highmaps) The x coordinate of the point.
     *
     * Note that for some tileShapes the grid coordinates are offset.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.x
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highmaps) The y coordinate of the point.
     *
     * Note that for some tileShapes the grid coordinates are offset.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data.y
     * @see https://api.highcharts.com/highmaps/series.tilemap.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highmaps) A `tilemap` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `tilemap` series are defined in plotOptions.tilemap.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.tilemap
 * @see https://api.highcharts.com/highmaps/series.tilemap
 */
export interface SeriesTilemapOptions extends PlotTilemapOptions, SeriesOptions {
    /**
     * (Highcharts, Highmaps) An array of data points for the series. For the
     * `tilemap` series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 or 2 values. In this case, the values
     * correspond to `x,y,value`. If the first value is a string, it is applied
     * as the name of the point, and the `x` value is inferred. The `x` value
     * can also be omitted, in which case the inner arrays should be of length
     * 2\. Then the `x` value is automatically calculated, either starting at 0
     * and incremented by 1, or from `pointStart` and `pointInterval` given in
     * the series options.(see online documentation for example)
     *
     * 2. An array of objects with named values. The objects are point
     * configuration objects as seen below. If the total number of data points
     * exceeds the series' turboThreshold, this option is not available.(see
     * online documentation for example)
     *
     * Note that for some tileShapes the grid coordinates are offset.
     *
     * @see https://api.highcharts.com/highcharts/series.tilemap.data
     * @see https://api.highcharts.com/highmaps/series.tilemap.data
     */
    data?: Array<([(number|string), number]|[(number|string), number, number]|SeriesTilemapDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "tilemap";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragHandle
 */
export interface SeriesTreemapDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.guideBox.default
 */
export interface SeriesTreemapDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.guideBox
 */
export interface SeriesTreemapDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.guideBox.default
     */
    default?: SeriesTreemapDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop
 */
export interface SeriesTreemapDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesTreemapDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.guideBox
     */
    guideBox?: (SeriesTreemapDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.treemap.data.events
 * @see https://api.highcharts.com/highstock/series.treemap.data.events
 * @see https://api.highcharts.com/gantt/series.treemap.data.events
 */
export interface SeriesTreemapDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events.click
     * @see https://api.highcharts.com/highstock/series.treemap.data.events.click
     * @see https://api.highcharts.com/highmaps/series.treemap.data.events.click
     * @see https://api.highcharts.com/gantt/series.treemap.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events.drag
     * @see https://api.highcharts.com/highstock/series.treemap.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.treemap.data.events.drag
     * @see https://api.highcharts.com/gantt/series.treemap.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.treemap.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.treemap.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.treemap.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events.drop
     * @see https://api.highcharts.com/highstock/series.treemap.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.treemap.data.events.drop
     * @see https://api.highcharts.com/gantt/series.treemap.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.treemap.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.treemap.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.treemap.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.treemap.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.treemap.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.treemap.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events.remove
     * @see https://api.highcharts.com/highstock/series.treemap.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.treemap.data.events.remove
     * @see https://api.highcharts.com/gantt/series.treemap.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events.select
     * @see https://api.highcharts.com/highstock/series.treemap.data.events.select
     * @see https://api.highcharts.com/highmaps/series.treemap.data.events.select
     * @see https://api.highcharts.com/gantt/series.treemap.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.treemap.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.treemap.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.treemap.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events.update
     * @see https://api.highcharts.com/highstock/series.treemap.data.events.update
     * @see https://api.highcharts.com/highmaps/series.treemap.data.events.update
     * @see https://api.highcharts.com/gantt/series.treemap.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `treemap` series
 * type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `value` options. Example:(see online documentation for
 * example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.treemap.data
 */
export interface SeriesTreemapDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.className
     * @see https://api.highcharts.com/gantt/series.treemap.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highmaps) The color of the point. In heat maps the point
     * color is rarely set explicitly, as we use the color to denote the
     * `value`. Options for this are set in the colorAxis configuration.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.color
     * @see https://api.highcharts.com/highmaps/series.treemap.data.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.treemap.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts) Serves a purpose only if a `colorAxis` object is defined in
     * the chart options. This value will decide which color the point gets from
     * the scale of the colorAxis.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.colorValue
     */
    colorValue?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.treemap.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.treemap.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.treemap.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.treemap.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.treemap.data.dragDrop
     */
    dragDrop?: SeriesTreemapDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.events
     * @see https://api.highcharts.com/highstock/series.treemap.data.events
     * @see https://api.highcharts.com/gantt/series.treemap.data.events
     */
    events?: SeriesTreemapDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.id
     * @see https://api.highcharts.com/highstock/series.treemap.data.id
     * @see https://api.highcharts.com/gantt/series.treemap.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.name
     */
    name?: string;
    /**
     * (Highcharts) Only for treemap. Use this option to build a tree structure.
     * The value should be the id of the point which is the parent. If no points
     * has a matching id, or this option is undefined, then the parent will be
     * set to the root.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.parent
     */
    parent?: string;
    /**
     * (Highcharts, Highmaps) Point padding for a single point.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.pointPadding
     * @see https://api.highcharts.com/highmaps/series.treemap.data.pointPadding
     */
    pointPadding?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.selected
     * @see https://api.highcharts.com/highstock/series.treemap.data.selected
     * @see https://api.highcharts.com/gantt/series.treemap.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) The value of the point, resulting in a relative area of the
     * point in the treemap.
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data.value
     */
    value?: number;
}
/**
 * (Highcharts) A `treemap` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `treemap` series are defined in plotOptions.treemap.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.treemap
 */
export interface SeriesTreemapOptions extends PlotTreemapOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `treemap`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `value` options. Example:(see online documentation for
     * example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.treemap.data
     */
    data?: Array<(number|SeriesTreemapDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "treemap";
}
/**
 * (Highstock) A `TRIX` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `trix` series are defined in plotOptions.trix.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.trix
 */
export interface SeriesTrixOptions extends PlotTrixOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "trix";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragHandle
 */
export interface SeriesVariablepieDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.guideBox.default
 */
export interface SeriesVariablepieDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.guideBox
 */
export interface SeriesVariablepieDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.guideBox.default
     */
    default?: SeriesVariablepieDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop
 */
export interface SeriesVariablepieDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesVariablepieDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.guideBox
     */
    guideBox?: (SeriesVariablepieDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.variablepie.data.events
 * @see https://api.highcharts.com/highstock/series.variablepie.data.events
 * @see https://api.highcharts.com/gantt/series.variablepie.data.events
 */
export interface SeriesVariablepieDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events.click
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events.click
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.events.click
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events.drag
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.events.drag
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events.drop
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.events.drop
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events.remove
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.events.remove
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events.select
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events.select
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.events.select
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events.update
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events.update
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.events.update
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `variablepie`
 * series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 2 values. In this case, the numerical values will
 * be interpreted as `y, z` options. Example:(see online documentation for
 * example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.variablepie.data
 */
export interface SeriesVariablepieDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.className
     * @see https://api.highcharts.com/gantt/series.variablepie.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.color
     * @see https://api.highcharts.com/highstock/series.variablepie.data.color
     * @see https://api.highcharts.com/gantt/series.variablepie.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.variablepie.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.variablepie.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.variablepie.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.variablepie.data.dragDrop
     */
    dragDrop?: SeriesVariablepieDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.events
     * @see https://api.highcharts.com/highstock/series.variablepie.data.events
     * @see https://api.highcharts.com/gantt/series.variablepie.data.events
     */
    events?: SeriesVariablepieDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.id
     * @see https://api.highcharts.com/highstock/series.variablepie.data.id
     * @see https://api.highcharts.com/gantt/series.variablepie.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The sequential index of the data point in the legend.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.legendIndex
     */
    legendIndex?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.selected
     * @see https://api.highcharts.com/highstock/series.variablepie.data.selected
     * @see https://api.highcharts.com/gantt/series.variablepie.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) Whether to display a slice offset from the center.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.sliced
     */
    sliced?: boolean;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data.y
     * @see https://api.highcharts.com/highstock/series.variablepie.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `variablepie` series. If the type option is not specified, it
 * is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `variablepie` series are defined in
 * plotOptions.variablepie.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.variablepie
 */
export interface SeriesVariablepieOptions extends PlotVariablepieOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the
     * `variablepie` series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 2 values. In this case, the numerical values
     * will be interpreted as `y, z` options. Example:(see online documentation
     * for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.variablepie.data
     */
    data?: Array<([(number|string), number]|SeriesVariablepieDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "variablepie";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragHandle
 */
export interface SeriesVariwideDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.guideBox.default
 */
export interface SeriesVariwideDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.guideBox
 */
export interface SeriesVariwideDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.guideBox.default
     */
    default?: SeriesVariwideDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop
 */
export interface SeriesVariwideDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesVariwideDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.guideBox
     */
    guideBox?: (SeriesVariwideDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.variwide.data.events
 * @see https://api.highcharts.com/highstock/series.variwide.data.events
 * @see https://api.highcharts.com/gantt/series.variwide.data.events
 */
export interface SeriesVariwideDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events.click
     * @see https://api.highcharts.com/highstock/series.variwide.data.events.click
     * @see https://api.highcharts.com/highmaps/series.variwide.data.events.click
     * @see https://api.highcharts.com/gantt/series.variwide.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events.drag
     * @see https://api.highcharts.com/highstock/series.variwide.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.variwide.data.events.drag
     * @see https://api.highcharts.com/gantt/series.variwide.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.variwide.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.variwide.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.variwide.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events.drop
     * @see https://api.highcharts.com/highstock/series.variwide.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.variwide.data.events.drop
     * @see https://api.highcharts.com/gantt/series.variwide.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.variwide.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.variwide.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.variwide.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.variwide.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.variwide.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.variwide.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events.remove
     * @see https://api.highcharts.com/highstock/series.variwide.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.variwide.data.events.remove
     * @see https://api.highcharts.com/gantt/series.variwide.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events.select
     * @see https://api.highcharts.com/highstock/series.variwide.data.events.select
     * @see https://api.highcharts.com/highmaps/series.variwide.data.events.select
     * @see https://api.highcharts.com/gantt/series.variwide.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.variwide.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.variwide.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.variwide.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events.update
     * @see https://api.highcharts.com/highstock/series.variwide.data.events.update
     * @see https://api.highcharts.com/highmaps/series.variwide.data.events.update
     * @see https://api.highcharts.com/gantt/series.variwide.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `variwide`
 * series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 or 2 values. In this case, the values correspond
 * to `x,y,z`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred. The `x` value can also be omitted, in
 * which case the inner arrays should be of length 2. Then the `x` value is
 * automatically calculated, either starting at 0 and incremented by 1, or from
 * `pointStart` and `pointInterval` given in the series options.(see online
 * documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.variwide.data
 */
export interface SeriesVariwideDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.className
     * @see https://api.highcharts.com/gantt/series.variwide.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.color
     * @see https://api.highcharts.com/highstock/series.variwide.data.color
     * @see https://api.highcharts.com/gantt/series.variwide.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.variwide.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.variwide.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.variwide.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.variwide.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.variwide.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.variwide.data.dragDrop
     */
    dragDrop?: SeriesVariwideDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.events
     * @see https://api.highcharts.com/highstock/series.variwide.data.events
     * @see https://api.highcharts.com/gantt/series.variwide.data.events
     */
    events?: SeriesVariwideDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.id
     * @see https://api.highcharts.com/highstock/series.variwide.data.id
     * @see https://api.highcharts.com/gantt/series.variwide.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.selected
     * @see https://api.highcharts.com/highstock/series.variwide.data.selected
     * @see https://api.highcharts.com/gantt/series.variwide.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.x
     * @see https://api.highcharts.com/highstock/series.variwide.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.y
     * @see https://api.highcharts.com/highstock/series.variwide.data.y
     */
    y?: number;
    /**
     * (Highcharts) The relative width for each column. On a category axis, the
     * widths are distributed so they sum up to the X axis length. On linear and
     * datetime axes, the columns will be laid out from the X value and Z units
     * along the axis.
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data.z
     */
    z?: number;
}
/**
 * (Highcharts) A `variwide` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `variwide` series are defined in plotOptions.variwide.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.variwide
 */
export interface SeriesVariwideOptions extends PlotVariwideOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `variwide`
     * series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 or 2 values. In this case, the values
     * correspond to `x,y,z`. If the first value is a string, it is applied as
     * the name of the point, and the `x` value is inferred. The `x` value can
     * also be omitted, in which case the inner arrays should be of length 2.
     * Then the `x` value is automatically calculated, either starting at 0 and
     * incremented by 1, or from `pointStart` and `pointInterval` given in the
     * series options.(see online documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.variwide.data
     */
    data?: Array<([(number|string), number]|[(number|string), number, number]|SeriesVariwideDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "variwide";
}
/**
 * (Highstock) A `Volume By Price (VBP)` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `vbp` series are defined in plotOptions.vbp.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.vbp
 */
export interface SeriesVbpOptions extends PlotVbpOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "vbp";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragHandle
 */
export interface SeriesVectorDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.guideBox.default
 */
export interface SeriesVectorDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.guideBox
 */
export interface SeriesVectorDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.guideBox.default
     */
    default?: SeriesVectorDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop
 */
export interface SeriesVectorDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesVectorDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.guideBox
     */
    guideBox?: (SeriesVectorDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.events
 * @see https://api.highcharts.com/highstock/series.vector.data.events
 * @see https://api.highcharts.com/gantt/series.vector.data.events
 */
export interface SeriesVectorDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events.click
     * @see https://api.highcharts.com/highstock/series.vector.data.events.click
     * @see https://api.highcharts.com/highmaps/series.vector.data.events.click
     * @see https://api.highcharts.com/gantt/series.vector.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events.drag
     * @see https://api.highcharts.com/highstock/series.vector.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.vector.data.events.drag
     * @see https://api.highcharts.com/gantt/series.vector.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.vector.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.vector.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.vector.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events.drop
     * @see https://api.highcharts.com/highstock/series.vector.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.vector.data.events.drop
     * @see https://api.highcharts.com/gantt/series.vector.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.vector.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.vector.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.vector.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.vector.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.vector.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.vector.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events.remove
     * @see https://api.highcharts.com/highstock/series.vector.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.vector.data.events.remove
     * @see https://api.highcharts.com/gantt/series.vector.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events.select
     * @see https://api.highcharts.com/highstock/series.vector.data.events.select
     * @see https://api.highcharts.com/highmaps/series.vector.data.events.select
     * @see https://api.highcharts.com/gantt/series.vector.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.vector.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.vector.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.vector.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events.update
     * @see https://api.highcharts.com/highstock/series.vector.data.events.update
     * @see https://api.highcharts.com/highmaps/series.vector.data.events.update
     * @see https://api.highcharts.com/gantt/series.vector.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.marker
 * @see https://api.highcharts.com/highstock/series.vector.data.marker
 */
export interface SeriesVectorDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.height
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.height
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states
     */
    states?: SeriesVectorDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.width
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.width
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover.animation
 */
export interface SeriesVectorDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover
 */
export interface SeriesVectorDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesVectorDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.normal
 */
export interface SeriesVectorDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states
 * @see https://api.highcharts.com/highstock/series.vector.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states
 * @see https://api.highcharts.com/gantt/series.vector.data.marker.states
 */
export interface SeriesVectorDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.hover
     */
    hover?: SeriesVectorDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.normal
     */
    normal?: SeriesVectorDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.select
     */
    select?: SeriesVectorDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.select
 */
export interface SeriesVectorDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.vector.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.vector.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.vector.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `vector` series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 4 values. In this case, the values correspond to
 * to `x,y,length,direction`. If the first value is a string, it is applied as
 * the name of the point, and the `x` value is inferred.(see online
 * documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.vector.data
 * @see https://api.highcharts.com/highstock/series.vector.data
 */
export interface SeriesVectorDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.className
     * @see https://api.highcharts.com/gantt/series.vector.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.color
     * @see https://api.highcharts.com/highstock/series.vector.data.color
     * @see https://api.highcharts.com/gantt/series.vector.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.vector.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.vector.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.vector.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.description
     * @see https://api.highcharts.com/highstock/series.vector.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The vector direction in degrees, where 0 is north
     * (pointing towards south).
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.direction
     * @see https://api.highcharts.com/highstock/series.vector.data.direction
     */
    direction?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.vector.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.vector.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.vector.data.dragDrop
     */
    dragDrop?: SeriesVectorDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.events
     * @see https://api.highcharts.com/highstock/series.vector.data.events
     * @see https://api.highcharts.com/gantt/series.vector.data.events
     */
    events?: SeriesVectorDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.id
     * @see https://api.highcharts.com/highstock/series.vector.data.id
     * @see https://api.highcharts.com/gantt/series.vector.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.labelrank
     * @see https://api.highcharts.com/highstock/series.vector.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) The length of the vector. The rendered length
     * will relate to the `vectorLength` setting.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.length
     * @see https://api.highcharts.com/highstock/series.vector.data.length
     */
    length?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.marker
     * @see https://api.highcharts.com/highstock/series.vector.data.marker
     */
    marker?: SeriesVectorDataMarkerOptions;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.name
     * @see https://api.highcharts.com/highstock/series.vector.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.selected
     * @see https://api.highcharts.com/highstock/series.vector.data.selected
     * @see https://api.highcharts.com/gantt/series.vector.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.x
     * @see https://api.highcharts.com/highstock/series.vector.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data.y
     * @see https://api.highcharts.com/highstock/series.vector.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `vector` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `vector` series are defined in plotOptions.vector.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.vector
 * @see https://api.highcharts.com/highstock/series.vector
 */
export interface SeriesVectorOptions extends PlotVectorOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `vector` series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 4 values. In this case, the values correspond
     * to to `x,y,length,direction`. If the first value is a string, it is
     * applied as the name of the point, and the `x` value is inferred.(see
     * online documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.vector.data
     * @see https://api.highcharts.com/highstock/series.vector.data
     */
    data?: Array<([(number|string), number, number, number]|SeriesVectorDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "vector";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragHandle
 */
export interface SeriesVennDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.guideBox.default
 */
export interface SeriesVennDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.guideBox
 */
export interface SeriesVennDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.guideBox.default
     */
    default?: SeriesVennDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop
 */
export interface SeriesVennDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesVennDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.guideBox
     */
    guideBox?: (SeriesVennDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.venn.data.events
 * @see https://api.highcharts.com/highstock/series.venn.data.events
 * @see https://api.highcharts.com/gantt/series.venn.data.events
 */
export interface SeriesVennDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events.click
     * @see https://api.highcharts.com/highstock/series.venn.data.events.click
     * @see https://api.highcharts.com/highmaps/series.venn.data.events.click
     * @see https://api.highcharts.com/gantt/series.venn.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events.drag
     * @see https://api.highcharts.com/highstock/series.venn.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.venn.data.events.drag
     * @see https://api.highcharts.com/gantt/series.venn.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.venn.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.venn.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.venn.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events.drop
     * @see https://api.highcharts.com/highstock/series.venn.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.venn.data.events.drop
     * @see https://api.highcharts.com/gantt/series.venn.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.venn.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.venn.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.venn.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.venn.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.venn.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.venn.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events.remove
     * @see https://api.highcharts.com/highstock/series.venn.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.venn.data.events.remove
     * @see https://api.highcharts.com/gantt/series.venn.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events.select
     * @see https://api.highcharts.com/highstock/series.venn.data.events.select
     * @see https://api.highcharts.com/highmaps/series.venn.data.events.select
     * @see https://api.highcharts.com/gantt/series.venn.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.venn.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.venn.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.venn.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events.update
     * @see https://api.highcharts.com/highstock/series.venn.data.events.update
     * @see https://api.highcharts.com/highmaps/series.venn.data.events.update
     * @see https://api.highcharts.com/gantt/series.venn.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `scatter` series
 * type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.venn.data
 */
export interface SeriesVennDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.className
     * @see https://api.highcharts.com/gantt/series.venn.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.color
     * @see https://api.highcharts.com/highstock/series.venn.data.color
     * @see https://api.highcharts.com/gantt/series.venn.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.venn.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.venn.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.venn.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.venn.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.venn.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.venn.data.dragDrop
     */
    dragDrop?: SeriesVennDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.events
     * @see https://api.highcharts.com/highstock/series.venn.data.events
     * @see https://api.highcharts.com/gantt/series.venn.data.events
     */
    events?: SeriesVennDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.id
     * @see https://api.highcharts.com/highstock/series.venn.data.id
     * @see https://api.highcharts.com/gantt/series.venn.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point. Used in data labels and tooltip. If
     * name is not defined then it will default to the joined values in sets.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.name
     */
    name?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.selected
     * @see https://api.highcharts.com/highstock/series.venn.data.selected
     * @see https://api.highcharts.com/gantt/series.venn.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts) The set or sets the options will be applied to. If a single
     * entry is defined, then it will create a new set. If more than one entry
     * is defined, then it will define the overlap between the sets in the
     * array.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.sets
     */
    sets?: Array<string>;
    /**
     * (Highcharts) The value of the point, resulting in a relative area of the
     * circle, or area of overlap between two sets in the venn or euler diagram.
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data.value
     */
    value?: number;
}
/**
 * (Highcharts) A `venn` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `venn` series are defined in plotOptions.venn.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.venn
 */
export interface SeriesVennOptions extends PlotVennOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `scatter`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.venn.data
     */
    data?: Array<SeriesVennDataOptions>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "venn";
}
/**
 * (Highstock) A `Volume Weighted Average Price (VWAP)` series. If the type
 * option is not specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `vwap` series are defined in plotOptions.vwap.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.vwap
 */
export interface SeriesVwapOptions extends PlotVwapOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "vwap";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragHandle
 */
export interface SeriesWaterfallDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.guideBox.default
 */
export interface SeriesWaterfallDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.guideBox
 */
export interface SeriesWaterfallDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.guideBox.default
     */
    default?: SeriesWaterfallDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop
 */
export interface SeriesWaterfallDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesWaterfallDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.guideBox
     */
    guideBox?: (SeriesWaterfallDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.waterfall.data.events
 * @see https://api.highcharts.com/highstock/series.waterfall.data.events
 * @see https://api.highcharts.com/gantt/series.waterfall.data.events
 */
export interface SeriesWaterfallDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events.click
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events.click
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.events.click
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events.drag
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.events.drag
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events.drop
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.events.drop
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events.remove
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.events.remove
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events.select
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events.select
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.events.select
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events.update
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events.update
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.events.update
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `waterfall`
 * series type, points can be given in the following ways:
 *
 * 1. An array of numerical values. In this case, the numerical values will be
 * interpreted as `y` options. The `x` values will be automatically calculated,
 * either starting at 0 and incremented by 1, or from `pointStart` and
 * `pointInterval` given in the series options. If the axis has categories,
 * these will be used. Example:(see online documentation for example)
 *
 * 2. An array of arrays with 2 values. In this case, the values correspond to
 * `x,y`. If the first value is a string, it is applied as the name of the
 * point, and the `x` value is inferred.(see online documentation for example)
 *
 * 3. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.waterfall.data
 */
export interface SeriesWaterfallDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.className
     * @see https://api.highcharts.com/gantt/series.waterfall.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.color
     * @see https://api.highcharts.com/highstock/series.waterfall.data.color
     * @see https://api.highcharts.com/gantt/series.waterfall.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.waterfall.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.waterfall.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.waterfall.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.waterfall.data.dragDrop
     */
    dragDrop?: SeriesWaterfallDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.events
     * @see https://api.highcharts.com/highstock/series.waterfall.data.events
     * @see https://api.highcharts.com/gantt/series.waterfall.data.events
     */
    events?: SeriesWaterfallDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.id
     * @see https://api.highcharts.com/highstock/series.waterfall.data.id
     * @see https://api.highcharts.com/gantt/series.waterfall.data.id
     */
    id?: string;
    /**
     * (Highcharts) When this property is true, the points acts as a summary
     * column for the values added or substracted since the last intermediate
     * sum, or since the start of the series. The `y` value is ignored.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.isIntermediateSum
     */
    isIntermediateSum?: boolean;
    /**
     * (Highcharts) When this property is true, the point display the total sum
     * across the entire series. The `y` value is ignored.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.isSum
     */
    isSum?: boolean;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.selected
     * @see https://api.highcharts.com/highstock/series.waterfall.data.selected
     * @see https://api.highcharts.com/gantt/series.waterfall.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.x
     * @see https://api.highcharts.com/highstock/series.waterfall.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data.y
     * @see https://api.highcharts.com/highstock/series.waterfall.data.y
     */
    y?: number;
}
/**
 * (Highcharts) A `waterfall` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `waterfall` series are defined in plotOptions.waterfall.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.waterfall
 */
export interface SeriesWaterfallOptions extends PlotWaterfallOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `waterfall`
     * series type, points can be given in the following ways:
     *
     * 1. An array of numerical values. In this case, the numerical values will
     * be interpreted as `y` options. The `x` values will be automatically
     * calculated, either starting at 0 and incremented by 1, or from
     * `pointStart` and `pointInterval` given in the series options. If the axis
     * has categories, these will be used. Example:(see online documentation for
     * example)
     *
     * 2. An array of arrays with 2 values. In this case, the values correspond
     * to `x,y`. If the first value is a string, it is applied as the name of
     * the point, and the `x` value is inferred.(see online documentation for
     * example)
     *
     * 3. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.waterfall.data
     */
    data?: Array<(number|[(number|string), number]|SeriesWaterfallDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "waterfall";
}
/**
 * (Highstock) A `Williams %R Oscillator` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `williamsr` series are defined in plotOptions.williamsr.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.williamsr
 */
export interface SeriesWilliamsrOptions extends PlotWilliamsrOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "williamsr";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragHandle
 */
export interface SeriesWindbarbDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.guideBox.default
 */
export interface SeriesWindbarbDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.guideBox
 */
export interface SeriesWindbarbDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.guideBox.default
     */
    default?: SeriesWindbarbDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop
 */
export interface SeriesWindbarbDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesWindbarbDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.guideBox
     */
    guideBox?: (SeriesWindbarbDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.events
 * @see https://api.highcharts.com/highstock/series.windbarb.data.events
 * @see https://api.highcharts.com/gantt/series.windbarb.data.events
 */
export interface SeriesWindbarbDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events.click
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events.click
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.events.click
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events.drag
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.events.drag
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events.drop
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.events.drop
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events.remove
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.events.remove
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events.select
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events.select
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.events.select
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events.update
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events.update
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.events.update
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker
 * @see https://api.highcharts.com/highstock/series.windbarb.data.marker
 */
export interface SeriesWindbarbDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.height
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.height
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states
     */
    states?: SeriesWindbarbDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.width
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.width
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover.animation
 */
export interface SeriesWindbarbDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover
 */
export interface SeriesWindbarbDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesWindbarbDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.normal
 */
export interface SeriesWindbarbDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states
 * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states
 * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states
 */
export interface SeriesWindbarbDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.hover
     */
    hover?: SeriesWindbarbDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.normal
     */
    normal?: SeriesWindbarbDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.select
     */
    select?: SeriesWindbarbDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.select
 */
export interface SeriesWindbarbDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.windbarb.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock) An array of data points for the series. For the
 * `windbarb` series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 3 values. In this case, the values correspond to
 * `x,value,direction`. If the first value is a string, it is applied as the
 * name of the point, and the `x` value is inferred.(see online documentation
 * for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb.data
 * @see https://api.highcharts.com/highstock/series.windbarb.data
 */
export interface SeriesWindbarbDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.className
     * @see https://api.highcharts.com/gantt/series.windbarb.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.color
     * @see https://api.highcharts.com/highstock/series.windbarb.data.color
     * @see https://api.highcharts.com/gantt/series.windbarb.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.windbarb.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock) A description of the point to add to the screen
     * reader information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.description
     * @see https://api.highcharts.com/highstock/series.windbarb.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock) The wind direction in degrees, where 0 is north
     * (pointing towards south).
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.direction
     * @see https://api.highcharts.com/highstock/series.windbarb.data.direction
     */
    direction?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.windbarb.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.windbarb.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.windbarb.data.dragDrop
     */
    dragDrop?: SeriesWindbarbDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.events
     * @see https://api.highcharts.com/highstock/series.windbarb.data.events
     * @see https://api.highcharts.com/gantt/series.windbarb.data.events
     */
    events?: SeriesWindbarbDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.id
     * @see https://api.highcharts.com/highstock/series.windbarb.data.id
     * @see https://api.highcharts.com/gantt/series.windbarb.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock) The rank for this point's data label in case of
     * collision. If two data labels are about to overlap, only the one with the
     * highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.labelrank
     * @see https://api.highcharts.com/highstock/series.windbarb.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.marker
     * @see https://api.highcharts.com/highstock/series.windbarb.data.marker
     */
    marker?: SeriesWindbarbDataMarkerOptions;
    /**
     * (Highcharts, Highstock) The name of the point as shown in the legend,
     * tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.name
     * @see https://api.highcharts.com/highstock/series.windbarb.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.selected
     * @see https://api.highcharts.com/highstock/series.windbarb.data.selected
     * @see https://api.highcharts.com/gantt/series.windbarb.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock) The wind speed in meters per second.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.value
     * @see https://api.highcharts.com/highstock/series.windbarb.data.value
     */
    value?: number;
    /**
     * (Highcharts, Highstock) The x value of the point. For datetime axes, the
     * X value is the timestamp in milliseconds since 1970.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.x
     * @see https://api.highcharts.com/highstock/series.windbarb.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock) The y value of the point.
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data.y
     * @see https://api.highcharts.com/highstock/series.windbarb.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock) A `windbarb` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `windbarb` series are defined in plotOptions.windbarb.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.windbarb
 * @see https://api.highcharts.com/highstock/series.windbarb
 */
export interface SeriesWindbarbOptions extends PlotWindbarbOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock) An array of data points for the series. For the
     * `windbarb` series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 3 values. In this case, the values correspond
     * to `x,value,direction`. If the first value is a string, it is applied as
     * the name of the point, and the `x` value is inferred.(see online
     * documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.windbarb.data
     * @see https://api.highcharts.com/highstock/series.windbarb.data
     */
    data?: Array<([(number|string), number, number]|SeriesWindbarbDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "windbarb";
}
/**
 * (Highstock) A `WMA` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `wma` series are defined in plotOptions.wma.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.wma
 */
export interface SeriesWmaOptions extends PlotWmaOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "wma";
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragHandle
 */
export interface SeriesWordcloudDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.guideBox.default
 */
export interface SeriesWordcloudDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.guideBox
 */
export interface SeriesWordcloudDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.guideBox.default
     */
    default?: SeriesWordcloudDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop
 */
export interface SeriesWordcloudDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesWordcloudDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.guideBox
     */
    guideBox?: (SeriesWordcloudDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events
 * @see https://api.highcharts.com/highstock/series.wordcloud.data.events
 * @see https://api.highcharts.com/gantt/series.wordcloud.data.events
 */
export interface SeriesWordcloudDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events.click
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events.click
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.events.click
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events.drag
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.events.drag
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events.drop
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.events.drop
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events.remove
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.events.remove
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events.select
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events.select
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.events.select
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events.update
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events.update
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.events.update
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts) An array of data points for the series. For the `wordcloud`
 * series type, points can be given in the following ways:
 *
 * 1. An array of arrays with 2 values. In this case, the values correspond to
 * `name,weight`.(see online documentation for example)
 *
 * 2. An array of objects with named values. The following snippet shows only a
 * few settings, see the complete options set below. If the total number of data
 * points exceeds the series' turboThreshold, this option is not available.(see
 * online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.wordcloud.data
 */
export interface SeriesWordcloudDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.className
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.color
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.color
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts) A description of the point to add to the screen reader
     * information about the point. Requires the Accessibility module.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.wordcloud.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.dragDrop
     */
    dragDrop?: SeriesWordcloudDataDragDropOptions;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.events
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.events
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.events
     */
    events?: SeriesWordcloudDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.id
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.id
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.id
     */
    id?: string;
    /**
     * (Highcharts) The rank for this point's data label in case of collision.
     * If two data labels are about to overlap, only the one with the highest
     * `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts) The name of the point as shown in the legend, tooltip,
     * dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data.selected
     * @see https://api.highcharts.com/highstock/series.wordcloud.data.selected
     * @see https://api.highcharts.com/gantt/series.wordcloud.data.selected
     */
    selected?: boolean;
}
/**
 * (Highcharts) A `wordcloud` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `wordcloud` series are defined in plotOptions.wordcloud.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.wordcloud
 */
export interface SeriesWordcloudOptions extends PlotWordcloudOptions, SeriesOptions {
    /**
     * (Highcharts) An array of data points for the series. For the `wordcloud`
     * series type, points can be given in the following ways:
     *
     * 1. An array of arrays with 2 values. In this case, the values correspond
     * to `name,weight`.(see online documentation for example)
     *
     * 2. An array of objects with named values. The following snippet shows
     * only a few settings, see the complete options set below. If the total
     * number of data points exceeds the series' turboThreshold, this option is
     * not available.(see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/series.wordcloud.data
     */
    data?: Array<([string, number]|SeriesWordcloudDataOptions)>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "wordcloud";
}
/**
 * (Gantt) Marker options specific to the end markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker
 */
export interface SeriesXrangeDataConnectEndMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector end markers.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker.width
     */
    width?: number;
}
/**
 * (Gantt) Marker options for this chart's Pathfinder connectors. Note that this
 * option is overridden by the `startMarker` and `endMarker` options.
 *
 * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker
 */
export interface SeriesXrangeDataConnectMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker.radius
     */
    radius?: number;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker.width
     */
    width?: number;
}
/**
 * (Gantt) Connect to a point. Requires Highcharts Gantt to be loaded. This
 * option can be either a string, referring to the ID of another point, or an
 * object, or an array of either. If the option is an array, each element
 * defines a connection.
 *
 * @see https://api.highcharts.com/gantt/series.xrange.data.connect
 */
export interface SeriesXrangeDataConnectOptions {
    /**
     * (Gantt) Set the default dash style for this chart's connecting lines.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.dashStyle
     */
    dashStyle?: string;
    /**
     * (Gantt) Marker options specific to the end markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.endMarker
     */
    endMarker?: SeriesXrangeDataConnectEndMarkerOptions;
    /**
     * (Gantt) Set the default color for this chart's Pathfinder connecting
     * lines. Defaults to the color of the point being connected.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the default pixel width for this chart's Pathfinder
     * connecting lines.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Marker options for this chart's Pathfinder connectors. Note that
     * this option is overridden by the `startMarker` and `endMarker` options.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.marker
     */
    marker?: SeriesXrangeDataConnectMarkerOptions;
    /**
     * (Gantt) Marker options specific to the start markers for this chart's
     * Pathfinder connectors. Overrides the generic marker options.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker
     */
    startMarker?: SeriesXrangeDataConnectStartMarkerOptions;
    /**
     * (Gantt) The ID of the point to connect to.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.to
     */
    to?: string;
    /**
     * (Gantt) Set the default pathfinder algorithm to use for this chart. It is
     * possible to define your own algorithms by adding them to the
     * Highcharts.Pathfinder.prototype.algorithms object before the chart has
     * been created.
     *
     * The default algorithms are as follows:
     *
     * `straight`: Draws a straight line between the connecting points. Does not
     * avoid other points when drawing.
     *
     * `simpleConnect`: Finds a path between the points using right angles only.
     * Takes only starting/ending points into account, and will not avoid other
     * points.
     *
     * `fastAvoid`: Finds a path between the points using right angles only.
     * Will attempt to avoid other points, but its focus is performance over
     * accuracy. Works well with less dense datasets.
     *
     * Default value: `straight` is used as default for most series types, while
     * `simpleConnect` is used as default for Gantt series, to show dependencies
     * between points.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.type
     */
    type?: ("straight"|"fastAvoid"|"simpleConnect");
}
/**
 * (Gantt) Marker options specific to the start markers for this chart's
 * Pathfinder connectors. Overrides the generic marker options.
 *
 * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker
 */
export interface SeriesXrangeDataConnectStartMarkerOptions {
    /**
     * (Gantt) Horizontal alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.align
     */
    align?: string;
    /**
     * (Gantt) Set the color of the connector markers. By default this is the
     * same as the connector color.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.color
     */
    color?: (ColorString|GradientColorObject);
    /**
     * (Gantt) Enable markers for the connectors.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.enabled
     */
    enabled?: boolean;
    /**
     * (Gantt) Set the height of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.height
     */
    height?: number;
    /**
     * (Gantt) Whether or not to draw the markers inside the points.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.inside
     */
    inside?: boolean;
    /**
     * (Gantt) Set the line/border color of the connector markers. By default
     * this is the same as the marker color.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Gantt) Set the line/border width of the pathfinder markers.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Gantt) Set the radius of the connector markers. The default is
     * automatically computed based on the algorithmMargin setting.
     *
     * Setting marker.width and marker.height will override this setting.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.radius
     */
    radius?: number;
    /**
     * (Gantt) Set the symbol of the connector start markers.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.symbol
     */
    symbol?: string;
    /**
     * (Gantt) Vertical alignment of the markers relative to the points.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.verticalAlign
     */
    verticalAlign?: string;
    /**
     * (Gantt) Set the width of the connector markers. If not supplied, this is
     * inferred from the marker radius.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect.startMarker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragHandle
 * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragHandle
 */
export interface SeriesXrangeDataDragDropDragHandleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The class name of the drag
     * handles. Defaults to `highcharts-drag-handle`.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragHandle.className
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragHandle.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragHandle.color
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragHandle.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The mouse cursor to use for the
     * drag handles. By default this is intelligently switching between
     * `ew-resize` and `ns-resize` depending on the direction the point is being
     * dragged.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragHandle.cursor
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragHandle.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line color of the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragHandle.lineColor
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragHandle.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The line width for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragHandle.lineWidth
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragHandle.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Function to define the SVG path
     * to use for the drag handles. Takes the point as argument. Should return
     * an SVG path in array format. The SVG path is automatically positioned on
     * the point.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragHandle.pathFormatter
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragHandle.pathFormatter
     */
    pathFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The z index for the drag
     * handles.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragHandle.zIndex
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragHandle.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
 * default state.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.guideBox.default
 * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.guideBox.default
 */
export interface SeriesXrangeDataDragDropGuideBoxDefaultOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS class name of the guide box
     * in this state. Defaults to `highcharts-drag-box-default`.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.guideBox.default.className
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.guideBox.default.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box fill color.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.guideBox.default.color
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.guideBox.default.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box cursor.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.guideBox.default.cursor
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.guideBox.default.cursor
     */
    cursor?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the border around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.guideBox.default.lineColor
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.guideBox.default.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the line around the
     * guide box.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.guideBox.default.lineWidth
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.guideBox.default.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Guide box zIndex.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.guideBox.default.zIndex
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.guideBox.default.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box. The
 * guide box has one state by default, the `default` state.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.guideBox
 * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.guideBox
 */
export interface SeriesXrangeDataDragDropGuideBoxOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box
     * default state.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.guideBox.default
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.guideBox.default
     */
    default?: SeriesXrangeDataDragDropGuideBoxDefaultOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
 * draggable-points module. Overrides options on `series.dragDrop`.
 *
 * Requires the `draggable-points` module.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop
 * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop
 * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop
 * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop
 */
export interface SeriesXrangeDataDragDropOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the X
     * dimension.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.draggableX
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.draggableX
     */
    draggableX?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable dragging in the Y
     * dimension. Note that this is not supported for TreeGrid axes (the default
     * axis type in Gantt charts).
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.draggableY
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.draggableY
     */
    draggableY?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Options for the drag handles.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragHandle
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragHandle
     */
    dragHandle?: SeriesXrangeDataDragDropDragHandleOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragMaxX
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragMaxX
     */
    dragMaxX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the maximum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragMaxY
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragMaxY
     */
    dragMaxY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum X value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragMinX
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragMinX
     */
    dragMinX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Set the minimum Y value the
     * points can be moved to.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragMinY
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragMinY
     */
    dragMinY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The X precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragPrecisionX
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragPrecisionX
     */
    dragPrecisionX?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Y precision value to drag to
     * for this series. Set to 0 to disable. By default this is disabled, except
     * for category axes, where the default is 1.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragPrecisionY
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragPrecisionY
     */
    dragPrecisionY?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The amount of pixels to drag the
     * pointer before it counts as a drag operation. This prevents drag/drop to
     * fire when just clicking or selecting points.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.dragSensitivity
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.dragSensitivity
     */
    dragSensitivity?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Group the points by a property.
     * Points with the same property value will be grouped together when moving.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.groupBy
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.groupBy
     */
    groupBy?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Style options for the guide box.
     * The guide box has one state by default, the `default` state.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.guideBox
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.guideBox
     */
    guideBox?: (SeriesXrangeDataDragDropGuideBoxOptions|Dictionary<PlotSeriesDragDropGuideBoxDefaultOptions>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Update points as they are
     * dragged. If false, a guide box is drawn to illustrate the new point size.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop.liveRedraw
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop.liveRedraw
     */
    liveRedraw?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Individual point events
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.events
 * @see https://api.highcharts.com/highstock/series.xrange.data.events
 * @see https://api.highcharts.com/gantt/series.xrange.data.events
 */
export interface SeriesXrangeDataEventsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when a point is clicked.
     * One parameter, `event`, is passed to the function, containing common
     * event information.
     *
     * If the `series.allowPointSelect` option is true, the default action for
     * the point's click event is to toggle the point's select state. Returning
     * `false` cancels this action.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events.click
     * @see https://api.highcharts.com/highstock/series.xrange.data.events.click
     * @see https://api.highcharts.com/highmaps/series.xrange.data.events.click
     * @see https://api.highcharts.com/gantt/series.xrange.data.events.click
     */
    click?: SeriesPointClickCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires while
     * dragging a point. The mouse event is passed in as parameter. The original
     * data can be accessed from `e.origin`, and the new point values can be
     * accessed from `e.newPoints`. If there is only a single point being
     * updated, it can be accessed from `e.newPoint` for simplicity, and its ID
     * can be accessed from `e.newPointId`. The `this` context is the point
     * being dragged. To stop the default drag action, return false. See drag
     * and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events.drag
     * @see https://api.highcharts.com/highstock/series.xrange.data.events.drag
     * @see https://api.highcharts.com/highmaps/series.xrange.data.events.drag
     * @see https://api.highcharts.com/gantt/series.xrange.data.events.drag
     */
    drag?: SeriesPointDragCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when
     * starting to drag a point. The mouse event object is passed in as an
     * argument. If a drag handle is used, `e.updateProp` is set to the data
     * property being dragged. The `this` context is the point. See drag and
     * drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events.dragStart
     * @see https://api.highcharts.com/highstock/series.xrange.data.events.dragStart
     * @see https://api.highcharts.com/highmaps/series.xrange.data.events.dragStart
     * @see https://api.highcharts.com/gantt/series.xrange.data.events.dragStart
     */
    dragStart?: SeriesPointDragStartCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback that fires when the
     * point is dropped. The parameters passed are the same as for drag. To stop
     * the default drop action, return false. See drag and drop options.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events.drop
     * @see https://api.highcharts.com/highstock/series.xrange.data.events.drop
     * @see https://api.highcharts.com/highmaps/series.xrange.data.events.drop
     * @see https://api.highcharts.com/gantt/series.xrange.data.events.drop
     */
    drop?: SeriesPointDropCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse leaves the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events.mouseOut
     * @see https://api.highcharts.com/highstock/series.xrange.data.events.mouseOut
     * @see https://api.highcharts.com/highmaps/series.xrange.data.events.mouseOut
     * @see https://api.highcharts.com/gantt/series.xrange.data.events.mouseOut
     */
    mouseOut?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the mouse enters the
     * area close to the point. One parameter, `event`, is passed to the
     * function, containing common event information.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events.mouseOver
     * @see https://api.highcharts.com/highstock/series.xrange.data.events.mouseOver
     * @see https://api.highcharts.com/highmaps/series.xrange.data.events.mouseOver
     * @see https://api.highcharts.com/gantt/series.xrange.data.events.mouseOver
     */
    mouseOver?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is removed
     * using the `.remove()` method. One parameter, `event`, is passed to the
     * function. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events.remove
     * @see https://api.highcharts.com/highstock/series.xrange.data.events.remove
     * @see https://api.highcharts.com/highmaps/series.xrange.data.events.remove
     * @see https://api.highcharts.com/gantt/series.xrange.data.events.remove
     */
    remove?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is selected
     * either programmatically or following a click on the point. One parameter,
     * `event`, is passed to the function. Returning `false` cancels the
     * operation.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events.select
     * @see https://api.highcharts.com/highstock/series.xrange.data.events.select
     * @see https://api.highcharts.com/highmaps/series.xrange.data.events.select
     * @see https://api.highcharts.com/gantt/series.xrange.data.events.select
     */
    select?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is
     * unselected either programmatically or following a click on the point. One
     * parameter, `event`, is passed to the function. Returning `false` cancels
     * the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events.unselect
     * @see https://api.highcharts.com/highstock/series.xrange.data.events.unselect
     * @see https://api.highcharts.com/highmaps/series.xrange.data.events.unselect
     * @see https://api.highcharts.com/gantt/series.xrange.data.events.unselect
     */
    unselect?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the point is updated
     * programmatically through the `.update()` method. One parameter, `event`,
     * is passed to the function. The new point options can be accessed through
     * `event.options`. Returning `false` cancels the operation.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events.update
     * @see https://api.highcharts.com/highstock/series.xrange.data.events.update
     * @see https://api.highcharts.com/highmaps/series.xrange.data.events.update
     * @see https://api.highcharts.com/gantt/series.xrange.data.events.update
     */
    update?: () => void;
}
/**
 * (Highcharts, Highstock) Options for the point markers of line-like series.
 * Properties like `fillColor`, `lineColor` and `lineWidth` define the visual
 * appearance of the markers. Other series types, like column series, don't have
 * markers, but have visual options on the series level instead.
 *
 * In styled mode, the markers can be styled with the `.highcharts-point`,
 * `.highcharts-point-hover` and `.highcharts-point-select` class names.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.marker
 * @see https://api.highcharts.com/highstock/series.xrange.data.marker
 */
export interface SeriesXrangeDataMarkerOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker. If `undefined`, the markers are hidden when the data is dense,
     * and shown for more widespread data points.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.enabled
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.enabled
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.enabled
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The threshold for how dense the
     * point markers should be before they are hidden, given that `enabled` is
     * not defined. The number indicates the horizontal distance between the two
     * closest points in the series, as multiples of the `marker.radius`. In
     * other words, the default value of 2 means points are hidden if
     * overlapping horizontally.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.enabledThreshold
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.enabledThreshold
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.enabledThreshold
     */
    enabledThreshold?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.fillColor
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.fillColor
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.fillColor
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `width` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.height
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.height
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.height
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.height
     */
    height?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.lineColor
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.lineColor
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.lineColor
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.lineWidth
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.lineWidth
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.lineWidth
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.radius
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.radius
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.radius
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) States for a single point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states
     */
    states?: SeriesXrangeDataMarkerStatesOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A predefined shape or symbol for
     * the marker. When undefined, the symbol is pulled from options.symbols.
     * Other possible values are "circle", "square", "diamond", "triangle" and
     * "triangle-down".
     *
     * Additionally, the URL to a graphic can be given on this form:
     * "url(graphic.png)". Note that for the image to be applied to exported
     * charts, its URL needs to be accessible by the export server.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols`. The callback is then used by
     * its method name, as shown in the demo.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.symbol
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.symbol
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.symbol
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.symbol
     */
    symbol?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Image markers only. Set the
     * image width explicitly. When using this option, a `height` must also be
     * set.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.width
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.width
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.width
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.width
     */
    width?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover.animation
 * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover.animation
 * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover.animation
 */
export interface SeriesXrangeDataMarkerStatesHoverAnimationOptions {
    duration?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single point
 * marker.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover
 * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover
 * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover
 * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover
 */
export interface SeriesXrangeDataMarkerStatesHoverOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when hovering over the
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover.animation
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover.animation
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover.animation
     */
    animation?: (boolean|AnimationOptionsObject|SeriesXrangeDataMarkerStatesHoverAnimationOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover.enabled
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the marker in
     * hover state. When `undefined`, the series' or point's fillColor for
     * normal state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover.fillColor
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's lineColor for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover.lineColor
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline. When `undefined`, the series' or point's lineWidth for normal
     * state is used.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover.lineWidth
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The additional line width for a
     * hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover.lineWidthPlus
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover.lineWidthPlus
     */
    lineWidthPlus?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2 as per the
     * radiusPlus option.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover.radius
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover.radius
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover.radius
     */
    radius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of pixels to increase
     * the radius of the hovered point.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover.radiusPlus
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover.radiusPlus
     */
    radiusPlus?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single point
 * marker. Currently only used for setting animation when returning to normal
 * state from hover.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.normal
 * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.normal
 * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.normal
 * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.normal
 */
export interface SeriesXrangeDataMarkerStatesNormalOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Animation when returning to
     * normal state after hovering.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.normal.animation
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.normal.animation
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.normal.animation
     */
    animation?: (boolean|AnimationOptionsObject);
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) States for a single point marker.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states
 * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states
 * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states
 * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states
 */
export interface SeriesXrangeDataMarkerStatesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The hover state for a single
     * point marker.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.hover
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.hover
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.hover
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.hover
     */
    hover?: SeriesXrangeDataMarkerStatesHoverOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The normal state of a single
     * point marker. Currently only used for setting animation when returning to
     * normal state from hover.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.normal
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.normal
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.normal
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.normal
     */
    normal?: SeriesXrangeDataMarkerStatesNormalOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point
     * marker when selected. In order to allow a point to be selected, set the
     * `series.allowPointSelect` option to true.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.select
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.select
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.select
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.select
     */
    select?: SeriesXrangeDataMarkerStatesSelectOptions;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The appearance of the point marker
 * when selected. In order to allow a point to be selected, set the
 * `series.allowPointSelect` option to true.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.select
 * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.select
 * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.select
 * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.select
 */
export interface SeriesXrangeDataMarkerStatesSelectOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable visible
     * feedback for selection.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.select.enabled
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.select.enabled
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.select.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The fill color of the point
     * marker.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.select.fillColor
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.select.fillColor
     */
    fillColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the point marker's
     * outline. When `undefined`, the series' or point's color is used.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.select.lineColor
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.select.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the point marker's
     * outline.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.select.lineWidth
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.select.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the point marker.
     * In hover state, it defaults to the normal state's radius + 2.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker.states.select.radius
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker.states.select.radius
     * @see https://api.highcharts.com/highmaps/series.xrange.data.marker.states.select.radius
     * @see https://api.highcharts.com/gantt/series.xrange.data.marker.states.select.radius
     */
    radius?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of data points for the series. For
 * the `xrange` series type, points can be given in the following ways:
 *
 * 1. An array of objects with named values. The objects are point configuration
 * objects as seen below.(see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data
 * @see https://api.highcharts.com/highstock/series.xrange.data
 * @see https://api.highcharts.com/gantt/series.xrange.data
 */
export interface SeriesXrangeDataOptions {
    /**
     * (Highcharts, Gantt) An additional, individual class name for the data
     * point's graphic representation.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.className
     * @see https://api.highcharts.com/gantt/series.xrange.data.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual color for the point. By default
     * the color is pulled from the global `colors` array.
     *
     * In styled mode, the `color` option doesn't take effect. Instead, use
     * `colorIndex`.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.color
     * @see https://api.highcharts.com/highstock/series.xrange.data.color
     * @see https://api.highcharts.com/gantt/series.xrange.data.color
     */
    color?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highcharts, Gantt) A specific color index to use for the point, so its
     * graphic representations are given the class name `highcharts-color-{n}`.
     * In styled mode this will change the color of the graphic. In non-styled
     * mode, the color by is set by the `fill` attribute, so the change in class
     * name won't have a visual effect by default.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.colorIndex
     * @see https://api.highcharts.com/gantt/series.xrange.data.colorIndex
     */
    colorIndex?: number;
    /**
     * (Gantt) Connect to a point. Requires Highcharts Gantt to be loaded. This
     * option can be either a string, referring to the ID of another point, or
     * an object, or an array of either. If the option is an array, each element
     * defines a connection.
     *
     * @see https://api.highcharts.com/gantt/series.xrange.data.connect
     */
    connect?: (string|SeriesXrangeDataConnectOptions|Array<(string|SeriesXrangeDataConnectOptions)>);
    /**
     * (Highcharts, Highstock, Gantt) Individual data label for each point. The
     * options are the same as the ones for plotOptions.series.dataLabels.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dataLabels
     * @see https://api.highcharts.com/highstock/series.xrange.data.dataLabels
     * @see https://api.highcharts.com/gantt/series.xrange.data.dataLabels
     */
    dataLabels?: PlotSeriesDataLabelsOptions;
    /**
     * (Highcharts, Highstock, Gantt) A description of the point to add to the
     * screen reader information about the point. Requires the Accessibility
     * module.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.description
     * @see https://api.highcharts.com/highstock/series.xrange.data.description
     * @see https://api.highcharts.com/gantt/series.xrange.data.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Point specific options for the
     * draggable-points module. Overrides options on `series.dragDrop`.
     *
     * Requires the `draggable-points` module.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.dragDrop
     * @see https://api.highcharts.com/highstock/series.xrange.data.dragDrop
     * @see https://api.highcharts.com/highmaps/series.xrange.data.dragDrop
     * @see https://api.highcharts.com/gantt/series.xrange.data.dragDrop
     */
    dragDrop?: SeriesXrangeDataDragDropOptions;
    /**
     * (Highcharts) The `id` of a series in the drilldown.series array to use
     * for a drilldown for this point.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.drilldown
     */
    drilldown?: string;
    /**
     * (Highcharts, Highstock, Gantt) Individual point events
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.events
     * @see https://api.highcharts.com/highstock/series.xrange.data.events
     * @see https://api.highcharts.com/gantt/series.xrange.data.events
     */
    events?: SeriesXrangeDataEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) An id for the point. This can be used
     * after render time to get a pointer to the point object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.id
     * @see https://api.highcharts.com/highstock/series.xrange.data.id
     * @see https://api.highcharts.com/gantt/series.xrange.data.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Gantt) The rank for this point's data label in
     * case of collision. If two data labels are about to overlap, only the one
     * with the highest `labelrank` will be drawn.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.labelrank
     * @see https://api.highcharts.com/highstock/series.xrange.data.labelrank
     * @see https://api.highcharts.com/gantt/series.xrange.data.labelrank
     */
    labelrank?: number;
    /**
     * (Highcharts, Highstock) Options for the point markers of line-like
     * series. Properties like `fillColor`, `lineColor` and `lineWidth` define
     * the visual appearance of the markers. Other series types, like column
     * series, don't have markers, but have visual options on the series level
     * instead.
     *
     * In styled mode, the markers can be styled with the `.highcharts-point`,
     * `.highcharts-point-hover` and `.highcharts-point-select` class names.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.marker
     * @see https://api.highcharts.com/highstock/series.xrange.data.marker
     */
    marker?: SeriesXrangeDataMarkerOptions;
    /**
     * (Highcharts, Highstock, Gantt) The name of the point as shown in the
     * legend, tooltip, dataLabel etc.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.name
     * @see https://api.highcharts.com/highstock/series.xrange.data.name
     * @see https://api.highcharts.com/gantt/series.xrange.data.name
     */
    name?: string;
    /**
     * (Highcharts, Highstock, Gantt) A partial fill for each point, typically
     * used to visualize how much of a task is performed. The partial fill
     * object can be set either on series or point level.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.partialFill
     * @see https://api.highcharts.com/highstock/series.xrange.data.partialFill
     * @see https://api.highcharts.com/gantt/series.xrange.data.partialFill
     */
    partialFill?: SeriesXrangeDataPartialFillOptions;
    /**
     * (Highcharts, Highstock, Gantt) Whether the data point is selected
     * initially.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.selected
     * @see https://api.highcharts.com/highstock/series.xrange.data.selected
     * @see https://api.highcharts.com/gantt/series.xrange.data.selected
     */
    selected?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) The starting X value of the range point.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.x
     * @see https://api.highcharts.com/highstock/series.xrange.data.x
     * @see https://api.highcharts.com/gantt/series.xrange.data.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) The ending X value of the range point.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.x2
     * @see https://api.highcharts.com/highstock/series.xrange.data.x2
     * @see https://api.highcharts.com/gantt/series.xrange.data.x2
     */
    x2?: number;
    /**
     * (Highcharts, Highstock, Gantt) The Y value of the range point.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.y
     * @see https://api.highcharts.com/highstock/series.xrange.data.y
     * @see https://api.highcharts.com/gantt/series.xrange.data.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) A partial fill for each point, typically used
 * to visualize how much of a task is performed. The partial fill object can be
 * set either on series or point level.
 *
 * @see https://api.highcharts.com/highcharts/series.xrange.data.partialFill
 * @see https://api.highcharts.com/highstock/series.xrange.data.partialFill
 * @see https://api.highcharts.com/gantt/series.xrange.data.partialFill
 */
export interface SeriesXrangeDataPartialFillOptions {
    /**
     * (Highcharts, Highstock, Gantt) The amount of the X-range point to be
     * filled. Values can be 0-1 and are converted to percentages in the default
     * data label formatter.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.partialFill.amount
     * @see https://api.highcharts.com/highstock/series.xrange.data.partialFill.amount
     * @see https://api.highcharts.com/gantt/series.xrange.data.partialFill.amount
     */
    amount?: number;
    /**
     * (Highcharts, Highstock, Gantt) The fill color to be used for partial
     * fills. Defaults to a darker shade of the point color.
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data.partialFill.fill
     * @see https://api.highcharts.com/highstock/series.xrange.data.partialFill.fill
     * @see https://api.highcharts.com/gantt/series.xrange.data.partialFill.fill
     */
    fill?: ColorString;
}
/**
 * (Highcharts, Highstock, Gantt) An `xrange` series. If the type option is not
 * specified, it is inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `xrange` series are defined in plotOptions.xrange.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/series.xrange
 * @see https://api.highcharts.com/highstock/series.xrange
 * @see https://api.highcharts.com/gantt/series.xrange
 */
export interface SeriesXrangeOptions extends PlotXrangeOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Gantt) An array of data points for the series.
     * For the `xrange` series type, points can be given in the following ways:
     *
     * 1. An array of objects with named values. The objects are point
     * configuration objects as seen below.(see online documentation for
     * example)
     *
     * @see https://api.highcharts.com/highcharts/series.xrange.data
     * @see https://api.highcharts.com/highstock/series.xrange.data
     * @see https://api.highcharts.com/gantt/series.xrange.data
     */
    data?: Array<SeriesXrangeDataOptions>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "xrange";
}
/**
 * (Highstock) A `Zig Zag` series. If the type option is not specified, it is
 * inherited from chart.type.
 *
 * Configuration options for the series are given in three levels:
 *
 * 1. Options for all series in a chart are defined in the plotOptions.series
 * object.
 *
 * 2. Options for all `zigzag` series are defined in plotOptions.zigzag.
 *
 * 3. Options for one single series are given in the series instance array.
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highstock/series.zigzag
 */
export interface SeriesZigzagOptions extends PlotZigzagOptions, SeriesOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) This property is only in
     * TypeScript non-optional and might be `undefined` in series objects from
     * unknown sources.
     */
    type: "zigzag";
}
/**
 * The shadow options.
 */
export interface ShadowOptionsObject {
    /**
     * The shadow color.
     */
    color?: string;
    /**
     * The horizontal offset from the element.
     */
    offsetX?: number;
    /**
     * The vertical offset from the element.
     */
    offsetY?: number;
    /**
     * The shadow opacity.
     */
    opacity?: number;
    /**
     * The shadow width or distance from the element.
     */
    width?: number;
}
/**
 * A config object for bindings in Stock Tools module.
 */
export interface StockToolsBindingsObject {
    /**
     * ClassName of the element for a binding.
     */
    className?: string;
    /**
     * Last event to be fired after last step event.
     */
    end?: () => void;
    /**
     * Initial event, fired on a button click.
     */
    init?: () => void;
    /**
     * Event fired on first click on a chart.
     */
    start?: () => void;
    /**
     * Last event to be fired after last step event. Array of step events to be
     * called sequentially after each user click.
     */
    steps?: Array<() => void>;
}
export interface StockToolsGuiDefinitionsAdvancedFibonacciOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.advanced.fibonacci.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsAdvancedOptions {
    fibonacci?: StockToolsGuiDefinitionsAdvancedFibonacciOptions;
    /**
     * (Highstock) A collection of strings pointing to config options for the
     * items.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.advanced.items
     */
    items?: any[];
    parallelChannel?: StockToolsGuiDefinitionsAdvancedParallelChannelOptions;
    pitchfork?: StockToolsGuiDefinitionsAdvancedPitchforkOptions;
}
export interface StockToolsGuiDefinitionsAdvancedParallelChannelOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.advanced.parallelChannel.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsAdvancedPitchforkOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.advanced.pitchfork.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsCrookedLinesCrooked3Options {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.crookedLines.crooked3.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsCrookedLinesCrooked5Options {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.crookedLines.crooked5.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsCrookedLinesElliott3Options {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.crookedLines.elliott3.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsCrookedLinesElliott5Options {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.crookedLines.elliott5.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsCrookedLinesOptions {
    crooked3?: StockToolsGuiDefinitionsCrookedLinesCrooked3Options;
    crooked5?: StockToolsGuiDefinitionsCrookedLinesCrooked5Options;
    elliott3?: StockToolsGuiDefinitionsCrookedLinesElliott3Options;
    elliott5?: StockToolsGuiDefinitionsCrookedLinesElliott5Options;
    /**
     * (Highstock) A collection of strings pointing to config options for the
     * items.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.crookedLines.items
     */
    items?: any[];
}
export interface StockToolsGuiDefinitionsCurrentPriceIndicatorOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.currentPriceIndicator.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsFlagsFlagCirclepinOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.flags.flagCirclepin.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsFlagsFlagDiamondpinOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.flags.flagDiamondpin.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsFlagsFlagSimplepinOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.flags.flagSimplepin.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsFlagsFlagSquarepinOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.flags.flagSquarepin.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsFlagsOptions {
    flagCirclepin?: StockToolsGuiDefinitionsFlagsFlagCirclepinOptions;
    flagDiamondpin?: StockToolsGuiDefinitionsFlagsFlagDiamondpinOptions;
    flagSimplepin?: StockToolsGuiDefinitionsFlagsFlagSimplepinOptions;
    flagSquarepin?: StockToolsGuiDefinitionsFlagsFlagSquarepinOptions;
    /**
     * (Highstock) A collection of strings pointing to config options for the
     * items.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.flags.items
     */
    items?: any[];
}
export interface StockToolsGuiDefinitionsFullScreenOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.fullScreen.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsIndicatorsOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.indicators.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsLinesArrowLineOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.lines.arrowLine.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsLinesArrowRayOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.lines.arrowRay.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsLinesArrowSegmentOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.lines.arrowSegment.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsLinesHorizontalLineOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.lines.horizontalLine.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsLinesLineOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.lines.line.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsLinesOptions {
    arrowLine?: StockToolsGuiDefinitionsLinesArrowLineOptions;
    arrowRay?: StockToolsGuiDefinitionsLinesArrowRayOptions;
    arrowSegment?: StockToolsGuiDefinitionsLinesArrowSegmentOptions;
    horizontalLine?: StockToolsGuiDefinitionsLinesHorizontalLineOptions;
    /**
     * (Highstock) A collection of strings pointing to config options for the
     * items.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.lines.items
     */
    items?: any[];
    line?: StockToolsGuiDefinitionsLinesLineOptions;
    ray?: StockToolsGuiDefinitionsLinesRayOptions;
    segment?: StockToolsGuiDefinitionsLinesSegmentOptions;
    verticalLine?: StockToolsGuiDefinitionsLinesVerticalLineOptions;
}
export interface StockToolsGuiDefinitionsLinesRayOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.lines.ray.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsLinesSegmentOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.lines.segment.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsLinesVerticalLineOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.lines.verticalLine.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsMeasureMeasureXOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.measure.measureX.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsMeasureMeasureXYOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.measure.measureXY.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsMeasureMeasureYOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.measure.measureY.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsMeasureOptions {
    /**
     * (Highstock) A collection of strings pointing to config options for the
     * items.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.measure.items
     */
    items?: any[];
    measureX?: StockToolsGuiDefinitionsMeasureMeasureXOptions;
    measureXY?: StockToolsGuiDefinitionsMeasureMeasureXYOptions;
    measureY?: StockToolsGuiDefinitionsMeasureMeasureYOptions;
}
/**
 * (Highstock) An options object of the buttons definitions. Each name refers to
 * unique key from buttons array.
 *
 * @see https://api.highcharts.com/highstock/stockTools.gui.definitions
 */
export interface StockToolsGuiDefinitionsOptions {
    advanced?: StockToolsGuiDefinitionsAdvancedOptions;
    crookedLines?: StockToolsGuiDefinitionsCrookedLinesOptions;
    currentPriceIndicator?: StockToolsGuiDefinitionsCurrentPriceIndicatorOptions;
    flags?: StockToolsGuiDefinitionsFlagsOptions;
    fullScreen?: StockToolsGuiDefinitionsFullScreenOptions;
    indicators?: StockToolsGuiDefinitionsIndicatorsOptions;
    lines?: StockToolsGuiDefinitionsLinesOptions;
    measure?: StockToolsGuiDefinitionsMeasureOptions;
    saveChart?: StockToolsGuiDefinitionsSaveChartOptions;
    separator?: StockToolsGuiDefinitionsSeparatorOptions;
    simpleShapes?: StockToolsGuiDefinitionsSimpleShapesOptions;
    toggleAnnotations?: StockToolsGuiDefinitionsToggleAnnotationsOptions;
    typeChange?: StockToolsGuiDefinitionsTypeChangeOptions;
    verticalLabels?: StockToolsGuiDefinitionsVerticalLabelsOptions;
    zoomChange?: StockToolsGuiDefinitionsZoomChangeOptions;
}
export interface StockToolsGuiDefinitionsSaveChartOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.saveChart.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsSeparatorOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.separator.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsSimpleShapesCircleOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.simpleShapes.circle.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsSimpleShapesLabelOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.simpleShapes.label.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsSimpleShapesOptions {
    circle?: StockToolsGuiDefinitionsSimpleShapesCircleOptions;
    /**
     * (Highstock) A collection of strings pointing to config options for the
     * items.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.simpleShapes.items
     */
    items?: any[];
    label?: StockToolsGuiDefinitionsSimpleShapesLabelOptions;
    rectangle?: StockToolsGuiDefinitionsSimpleShapesRectangleOptions;
}
export interface StockToolsGuiDefinitionsSimpleShapesRectangleOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.simpleShapes.rectangle.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsToggleAnnotationsOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.toggleAnnotations.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsTypeChangeOptions {
    /**
     * (Highstock) A collection of strings pointing to config options for the
     * items.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.typeChange.items
     */
    items?: any[];
    typeCandlestick?: StockToolsGuiDefinitionsTypeChangeTypeCandlestickOptions;
    typeLine?: StockToolsGuiDefinitionsTypeChangeTypeLineOptions;
    typeOHLC?: StockToolsGuiDefinitionsTypeChangeTypeOHLCOptions;
}
export interface StockToolsGuiDefinitionsTypeChangeTypeCandlestickOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.typeChange.typeCandlestick.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsTypeChangeTypeLineOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.typeChange.typeLine.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsTypeChangeTypeOHLCOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.typeChange.typeOHLC.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsVerticalLabelsOptions {
    /**
     * (Highstock) A collection of strings pointing to config options for the
     * items.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.verticalLabels.items
     */
    items?: any[];
    verticalArrow?: StockToolsGuiDefinitionsVerticalLabelsVerticalArrowOptions;
    verticalCounter?: StockToolsGuiDefinitionsVerticalLabelsVerticalCounterOptions;
    verticalLabel?: StockToolsGuiDefinitionsVerticalLabelsVerticalLabelOptions;
}
export interface StockToolsGuiDefinitionsVerticalLabelsVerticalArrowOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.verticalLabels.verticalArrow.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsVerticalLabelsVerticalCounterOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.verticalLabels.verticalCounter.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsVerticalLabelsVerticalLabelOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.verticalLabels.verticalLabel.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsZoomChangeOptions {
    /**
     * (Highstock) A collection of strings pointing to config options for the
     * items.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.zoomChange.items
     */
    items?: any[];
    zoomX?: StockToolsGuiDefinitionsZoomChangeZoomXOptions;
    zoomXY?: StockToolsGuiDefinitionsZoomChangeZoomXYOptions;
    zoomY?: StockToolsGuiDefinitionsZoomChangeZoomYOptions;
}
export interface StockToolsGuiDefinitionsZoomChangeZoomXOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.zoomChange.zoomX.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsZoomChangeZoomXYOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.zoomChange.zoomXY.symbol
     */
    symbol?: string;
}
export interface StockToolsGuiDefinitionsZoomChangeZoomYOptions {
    /**
     * (Highstock) A predefined background symbol for the button.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions.zoomChange.zoomY.symbol
     */
    symbol?: string;
}
/**
 * (Highstock) Definitions of buttons in Stock Tools GUI.
 *
 * @see https://api.highcharts.com/highstock/stockTools.gui
 */
export interface StockToolsGuiOptions {
    /**
     * (Highstock) A collection of strings pointing to config options for the
     * toolbar items. Each name refers to unique key from definitions object.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.buttons
     */
    buttons?: any[];
    /**
     * (Highstock) A CSS class name to apply to the stocktools' div, allowing
     * unique CSS styling for each chart.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.className
     */
    className?: string;
    /**
     * (Highstock) An options object of the buttons definitions. Each name
     * refers to unique key from buttons array.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.definitions
     */
    definitions?: (object|StockToolsGuiDefinitionsOptions);
    /**
     * (Highstock) Enable or disable the stockTools gui.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) Path where Highcharts will look for icons. Change this to use
     * icons from a different server.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.iconsURL
     */
    iconsURL?: string;
    /**
     * (Highstock) A CSS class name to apply to the container of buttons,
     * allowing unique CSS styling for each chart.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui.toolbarClassName
     */
    toolbarClassName?: string;
}
/**
 * (Highstock) Configure the stockTools gui strings in the chart. Requires the
 * [stockTools module]() to be loaded. For a description of the module and
 * information on its features, see [Highcharts StockTools]().
 *
 * @see https://api.highcharts.com/highstock/stockTools
 */
export interface StockToolsOptions {
    /**
     * (Highstock) Definitions of buttons in Stock Tools GUI.
     *
     * @see https://api.highcharts.com/highstock/stockTools.gui
     */
    gui?: StockToolsGuiOptions;
}
/**
 * The chart subtitle. The subtitle has an `update` method that allows modifying
 * the options directly or indirectly via `chart.update`.
 */
export interface SubtitleObject extends SVGElement {
    /**
     * Modify options for the subtitle.
     *
     * @param subtitleOptions
     *        Options to modify.
     *
     * @param redraw
     *        Whether to redraw the chart after the subtitle is altered. If
     *        doing more operations on the chart, it is a good idea to set
     *        redraw to false and call Chart#redraw after.
     */
    update(subtitleOptions: SubtitleOptions, redraw?: boolean): void;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The chart's subtitle. This can be
 * used both to display a subtitle below the main title, and to display random
 * text anywhere in the chart. The subtitle can be updated after chart
 * initialization through the `Chart.setTitle` method.
 *
 * @see https://api.highcharts.com/highcharts/subtitle
 * @see https://api.highcharts.com/highstock/subtitle
 * @see https://api.highcharts.com/highmaps/subtitle
 * @see https://api.highcharts.com/gantt/subtitle
 */
export interface SubtitleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The horizontal alignment of the
     * subtitle. Can be one of "left", "center" and "right".
     *
     * @see https://api.highcharts.com/highcharts/subtitle.align
     * @see https://api.highcharts.com/highstock/subtitle.align
     * @see https://api.highcharts.com/highmaps/subtitle.align
     * @see https://api.highcharts.com/gantt/subtitle.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When the subtitle is floating,
     * the plot area will not move to make space for it.
     *
     * @see https://api.highcharts.com/highcharts/subtitle.floating
     * @see https://api.highcharts.com/highstock/subtitle.floating
     * @see https://api.highcharts.com/highmaps/subtitle.floating
     * @see https://api.highcharts.com/gantt/subtitle.floating
     */
    floating?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the title.
     *
     * In styled mode, the subtitle style is given in the `.highcharts-subtitle`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/subtitle.style
     * @see https://api.highcharts.com/highstock/subtitle.style
     * @see https://api.highcharts.com/highmaps/subtitle.style
     * @see https://api.highcharts.com/gantt/subtitle.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The subtitle of the chart.
     *
     * @see https://api.highcharts.com/highcharts/subtitle.text
     * @see https://api.highcharts.com/highstock/subtitle.text
     * @see https://api.highcharts.com/highmaps/subtitle.text
     * @see https://api.highcharts.com/gantt/subtitle.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render
     * the text.
     *
     * @see https://api.highcharts.com/highcharts/subtitle.useHTML
     * @see https://api.highcharts.com/highstock/subtitle.useHTML
     * @see https://api.highcharts.com/highmaps/subtitle.useHTML
     * @see https://api.highcharts.com/gantt/subtitle.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical alignment of the
     * title. Can be one of "top", "middle" and "bottom". When a value is given,
     * the title behaves as floating.
     *
     * @see https://api.highcharts.com/highcharts/subtitle.verticalAlign
     * @see https://api.highcharts.com/highstock/subtitle.verticalAlign
     * @see https://api.highcharts.com/highmaps/subtitle.verticalAlign
     * @see https://api.highcharts.com/gantt/subtitle.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Adjustment made to the subtitle
     * width, normally to reserve space for the exporting burger menu.
     *
     * @see https://api.highcharts.com/highcharts/subtitle.widthAdjust
     * @see https://api.highcharts.com/highstock/subtitle.widthAdjust
     * @see https://api.highcharts.com/highmaps/subtitle.widthAdjust
     * @see https://api.highcharts.com/gantt/subtitle.widthAdjust
     */
    widthAdjust?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position of the subtitle
     * relative to the alignment within `chart.spacingLeft` and
     * `chart.spacingRight`.
     *
     * @see https://api.highcharts.com/highcharts/subtitle.x
     * @see https://api.highcharts.com/highstock/subtitle.x
     * @see https://api.highcharts.com/highmaps/subtitle.x
     * @see https://api.highcharts.com/gantt/subtitle.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position of the subtitle
     * relative to the alignment within `chart.spacingTop` and
     * `chart.spacingBottom`. By default the subtitle is laid out below the
     * title unless the title is floating.
     *
     * @see https://api.highcharts.com/highcharts/subtitle.y
     * @see https://api.highcharts.com/highstock/subtitle.y
     * @see https://api.highcharts.com/highmaps/subtitle.y
     * @see https://api.highcharts.com/gantt/subtitle.y
     */
    y?: number;
}
/**
 * An object of key-value pairs for SVG attributes. Attributes in Highcharts
 * elements for the most parts correspond to SVG, but some are specific to
 * Highcharts, like `zIndex`, `rotation`, `rotationOriginX`, `rotationOriginY`,
 * `translateX`, `translateY`, `scaleX` and `scaleY`. SVG attributes containing
 * a hyphen are _not_ camel-cased, they should be quoted to preserve the hyphen.
 */
export interface SVGAttributes {
    [key: string]: (boolean|number|string|Array<(number|string)>|undefined);
    d?: (string|SVGPathArray);
    inverted?: boolean;
    matrix?: Array<number>;
    rotation?: string;
    rotationOriginX?: number;
    rotationOriginY?: number;
    scaleX?: number;
    scaleY?: number;
    stroke?: ColorString;
    translateX?: number;
    translateY?: number;
    zIndex?: number;
}
/**
 * Serialized form of an SVG definition, including children. Some key property
 * names are reserved: tagName, textContent, and children.
 */
export interface SVGDefinitionObject {
    [key: string]: (number|string|Array<SVGDefinitionObject>|undefined);
    children?: Array<SVGDefinitionObject>;
    tagName?: string;
    textContent?: string;
}
/**
 * Additional options, depending on the actual symbol drawn.
 */
export interface SymbolOptionsObject {
    /**
     * The anchor X position for the `callout` symbol. This is where the chevron
     * points to.
     */
    anchorX: number;
    /**
     * The anchor Y position for the `callout` symbol. This is where the chevron
     * points to.
     */
    anchorY: number;
    /**
     * The end angle of an `arc` symbol.
     */
    end: number;
    /**
     * Whether to draw `arc` symbol open or closed.
     */
    open: boolean;
    /**
     * The radius of an `arc` symbol, or the border radius for the `callout`
     * symbol.
     */
    r: number;
    /**
     * Whether to draw rounded edges.
     */
    rounded?: boolean;
    /**
     * The start angle of an `arc` symbol.
     */
    start: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Time options that can apply globally
 * or to individual charts. These settings affect how `datetime` axes are laid
 * out, how tooltips are formatted, how series pointIntervalUnit works and how
 * the Highstock range selector handles time.
 *
 * The common use case is that all charts in the same Highcharts object share
 * the same time settings, in which case the global settings are set using
 * `setOptions`.(see online documentation for example)
 *
 * Since v6.0.5, the time options were moved from the `global` obect to the
 * `time` object, and time options can be set on each individual chart.
 *
 * @see https://api.highcharts.com/highcharts/time
 * @see https://api.highcharts.com/highstock/time
 * @see https://api.highcharts.com/highmaps/time
 * @see https://api.highcharts.com/gantt/time
 */
export interface TimeOptions {
    /**
     * (Highcharts, Highstock, Gantt) A custom `Date` class for advanced date
     * handling. For example, JDate can be hooked in to handle Jalali dates.
     *
     * @see https://api.highcharts.com/highcharts/time.Date
     * @see https://api.highcharts.com/highstock/time.Date
     * @see https://api.highcharts.com/gantt/time.Date
     */
    Date?: any;
    /**
     * (Highcharts, Highstock, Gantt) A callback to return the time zone offset
     * for a given datetime. It takes the timestamp in terms of milliseconds
     * since January 1 1970, and returns the timezone offset in minutes. This
     * provides a hook for drawing time based charts in specific time zones
     * using their local DST crossover dates, with the help of external
     * libraries.
     *
     * @see https://api.highcharts.com/highcharts/time.getTimezoneOffset
     * @see https://api.highcharts.com/highstock/time.getTimezoneOffset
     * @see https://api.highcharts.com/gantt/time.getTimezoneOffset
     */
    getTimezoneOffset?: () => void;
    /**
     * (Highcharts, Highstock, Gantt) Requires moment.js. If the timezone option
     * is specified, it creates a default getTimezoneOffset function that looks
     * up the specified timezone in moment.js. If moment.js is not included,
     * this throws a Highcharts error in the console, but does not crash the
     * chart.
     *
     * @see https://api.highcharts.com/highcharts/time.timezone
     * @see https://api.highcharts.com/highstock/time.timezone
     * @see https://api.highcharts.com/gantt/time.timezone
     */
    timezone?: string;
    /**
     * (Highcharts, Highstock, Gantt) The timezone offset in minutes. Positive
     * values are west, negative values are east of UTC, as in the ECMAScript
     * getTimezoneOffset method. Use this to display UTC based data in a
     * predefined time zone.
     *
     * @see https://api.highcharts.com/highcharts/time.timezoneOffset
     * @see https://api.highcharts.com/highstock/time.timezoneOffset
     * @see https://api.highcharts.com/gantt/time.timezoneOffset
     */
    timezoneOffset?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to use UTC time for axis
     * scaling, tickmark placement and time display in `Highcharts.dateFormat`.
     * Advantages of using UTC is that the time displays equally regardless of
     * the user agent's time zone settings. Local time can be used when the data
     * is loaded in real time or when correct Daylight Saving Time transitions
     * are required.
     *
     * @see https://api.highcharts.com/highcharts/time.useUTC
     * @see https://api.highcharts.com/highstock/time.useUTC
     * @see https://api.highcharts.com/highmaps/time.useUTC
     * @see https://api.highcharts.com/gantt/time.useUTC
     */
    useUTC?: boolean;
}
/**
 * Additonal time tick information.
 */
export interface TimeTicksInfoObject extends NormalizedIntervalObject {
    higherRanks: Array<string>;
    totalRange: number;
}
/**
 * Time ticks.
 */
export interface TimeTicksObject extends Array<number> {
    info: TimeTicksInfoObject;
}
/**
 * The chart title. The title has an `update` method that allows modifying the
 * options directly or indirectly via `chart.update`.
 */
export interface TitleObject extends SVGElement {
    /**
     * Modify options for the title.
     *
     * @param titleOptions
     *        Options to modify.
     *
     * @param redraw
     *        Whether to redraw the chart after the title is altered. If doing
     *        more operations on the chart, it is a good idea to set redraw to
     *        false and call Chart#redraw after.
     */
    update(titleOptions: TitleOptions, redraw?: boolean): void;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The chart's main title.
 *
 * @see https://api.highcharts.com/highcharts/title
 * @see https://api.highcharts.com/highstock/title
 * @see https://api.highcharts.com/highmaps/title
 * @see https://api.highcharts.com/gantt/title
 */
export interface TitleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The horizontal alignment of the
     * title. Can be one of "left", "center" and "right".
     *
     * @see https://api.highcharts.com/highcharts/title.align
     * @see https://api.highcharts.com/highstock/title.align
     * @see https://api.highcharts.com/highmaps/title.align
     * @see https://api.highcharts.com/gantt/title.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When the title is floating, the
     * plot area will not move to make space for it.
     *
     * @see https://api.highcharts.com/highcharts/title.floating
     * @see https://api.highcharts.com/highstock/title.floating
     * @see https://api.highcharts.com/highmaps/title.floating
     * @see https://api.highcharts.com/gantt/title.floating
     */
    floating?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The margin between the title and
     * the plot area, or if a subtitle is present, the margin between the
     * subtitle and the plot area.
     *
     * @see https://api.highcharts.com/highcharts/title.margin
     * @see https://api.highcharts.com/highstock/title.margin
     * @see https://api.highcharts.com/highmaps/title.margin
     * @see https://api.highcharts.com/gantt/title.margin
     */
    margin?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the title. Use
     * this for font styling, but use `align`, `x` and `y` for text alignment.
     *
     * In styled mode, the title style is given in the `.highcharts-title`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/title.style
     * @see https://api.highcharts.com/highstock/title.style
     * @see https://api.highcharts.com/highmaps/title.style
     * @see https://api.highcharts.com/gantt/title.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The title of the chart. To
     * disable the title, set the `text` to `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/title.text
     * @see https://api.highcharts.com/highstock/title.text
     * @see https://api.highcharts.com/highmaps/title.text
     * @see https://api.highcharts.com/gantt/title.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render
     * the text.
     *
     * @see https://api.highcharts.com/highcharts/title.useHTML
     * @see https://api.highcharts.com/highstock/title.useHTML
     * @see https://api.highcharts.com/highmaps/title.useHTML
     * @see https://api.highcharts.com/gantt/title.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The vertical alignment of the
     * title. Can be one of `"top"`, `"middle"` and `"bottom"`. When a value is
     * given, the title behaves as if floating were `true`.
     *
     * @see https://api.highcharts.com/highcharts/title.verticalAlign
     * @see https://api.highcharts.com/highstock/title.verticalAlign
     * @see https://api.highcharts.com/highmaps/title.verticalAlign
     * @see https://api.highcharts.com/gantt/title.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Adjustment made to the title
     * width, normally to reserve space for the exporting burger menu.
     *
     * @see https://api.highcharts.com/highcharts/title.widthAdjust
     * @see https://api.highcharts.com/highstock/title.widthAdjust
     * @see https://api.highcharts.com/highmaps/title.widthAdjust
     * @see https://api.highcharts.com/gantt/title.widthAdjust
     */
    widthAdjust?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position of the title
     * relative to the alignment within `chart.spacingLeft` and
     * `chart.spacingRight`.
     *
     * @see https://api.highcharts.com/highcharts/title.x
     * @see https://api.highcharts.com/highstock/title.x
     * @see https://api.highcharts.com/highmaps/title.x
     * @see https://api.highcharts.com/gantt/title.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position of the title
     * relative to the alignment within chart.spacingTop and
     * chart.spacingBottom. By default it depends on the font size.
     *
     * @see https://api.highcharts.com/highcharts/title.y
     * @see https://api.highcharts.com/highstock/title.y
     * @see https://api.highcharts.com/highmaps/title.y
     * @see https://api.highcharts.com/gantt/title.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date format
 * in the tooltip's header will by default be guessed based on the closest data
 * points. This member gives the default string representations used for each
 * unit. For an overview of the replacement codes, see dateFormat.
 *
 * @see https://api.highcharts.com/highcharts/tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/tooltip.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/tooltip.dateTimeLabelFormats
 */
export interface TooltipDateTimeLabelFormatsOptions {
    day?: string;
    hour?: string;
    millisecond?: string;
    minute?: string;
    month?: string;
    second?: string;
    week?: string;
    year?: string;
}
export interface TooltipFormatterContextObject {
    color: ColorString;
    colorIndex?: number;
    key: number;
    percentage?: number;
    point: Point;
    series: Series;
    total?: number;
    x: number;
    y: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Options for the tooltip that appears
 * when the user hovers over a series or point.
 *
 * @see https://api.highcharts.com/highcharts/tooltip
 * @see https://api.highcharts.com/highstock/tooltip
 * @see https://api.highcharts.com/highmaps/tooltip
 * @see https://api.highcharts.com/gantt/tooltip
 */
export interface TooltipOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable animation of
     * the tooltip.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.animation
     * @see https://api.highcharts.com/highstock/tooltip.animation
     * @see https://api.highcharts.com/highmaps/tooltip.animation
     * @see https://api.highcharts.com/gantt/tooltip.animation
     */
    animation?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The background color or gradient
     * for the tooltip.
     *
     * In styled mode, the stroke width is set in the `.highcharts-tooltip-box`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.backgroundColor
     * @see https://api.highcharts.com/highstock/tooltip.backgroundColor
     * @see https://api.highcharts.com/highmaps/tooltip.backgroundColor
     * @see https://api.highcharts.com/gantt/tooltip.backgroundColor
     */
    backgroundColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the tooltip border.
     * When `undefined`, the border takes the color of the corresponding series
     * or point.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.borderColor
     * @see https://api.highcharts.com/highstock/tooltip.borderColor
     * @see https://api.highcharts.com/highmaps/tooltip.borderColor
     * @see https://api.highcharts.com/gantt/tooltip.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The radius of the rounded border
     * corners.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.borderRadius
     * @see https://api.highcharts.com/highstock/tooltip.borderRadius
     * @see https://api.highcharts.com/highmaps/tooltip.borderRadius
     * @see https://api.highcharts.com/gantt/tooltip.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the tooltip
     * border.
     *
     * In styled mode, the stroke width is set in the `.highcharts-tooltip-box`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.borderWidth
     * @see https://api.highcharts.com/highstock/tooltip.borderWidth
     * @see https://api.highcharts.com/highmaps/tooltip.borderWidth
     * @see https://api.highcharts.com/gantt/tooltip.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) How many decimals to show for the `point.change` value when
     * the `series.compare` option is set. This is overridable in each series'
     * tooltip options object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highstock/tooltip.changeDecimals
     */
    changeDecimals?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Since 4.1, the crosshair
     * definitions are moved to the Axis object in order for a better separation
     * from the tooltip. See xAxis.crosshair(see online documentation for
     * example)
     *
     * @see https://api.highcharts.com/highcharts/tooltip.crosshairs
     * @see https://api.highcharts.com/highstock/tooltip.crosshairs
     * @see https://api.highcharts.com/highmaps/tooltip.crosshairs
     * @see https://api.highcharts.com/gantt/tooltip.crosshairs
     */
    crosshairs?: any;
    /**
     * (Highcharts, Highstock, Gantt) For series on a datetime axes, the date
     * format in the tooltip's header will by default be guessed based on the
     * closest data points. This member gives the default string representations
     * used for each unit. For an overview of the replacement codes, see
     * dateFormat.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/tooltip.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/tooltip.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: (TooltipDateTimeLabelFormatsOptions|Dictionary<string>);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the tooltip.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.enabled
     * @see https://api.highcharts.com/highstock/tooltip.enabled
     * @see https://api.highcharts.com/highmaps/tooltip.enabled
     * @see https://api.highcharts.com/gantt/tooltip.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether the tooltip should
     * follow the mouse as it moves across columns, pie slices and other point
     * types with an extent. By default it behaves this way for scatter, bubble
     * and pie series by override in the `plotOptions` for those series types.
     *
     * For touch moves to behave the same way, followTouchMove must be `true`
     * also.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.followPointer
     * @see https://api.highcharts.com/highstock/tooltip.followPointer
     * @see https://api.highcharts.com/highmaps/tooltip.followPointer
     * @see https://api.highcharts.com/gantt/tooltip.followPointer
     */
    followPointer?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether the tooltip should
     * update as the finger moves on a touch device. If this is `true` and
     * chart.panning is set,`followTouchMove` will take over one-finger touches,
     * so the user needs to use two fingers for zooming and panning.
     *
     * Note the difference to followPointer that only defines the _position_ of
     * the tooltip. If `followPointer` is false in for example a column series,
     * the tooltip will show above or below the column, but as `followTouchMove`
     * is true, the tooltip will jump from column to column as the user swipes
     * across the plot area.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.followTouchMove
     * @see https://api.highcharts.com/highstock/tooltip.followTouchMove
     * @see https://api.highcharts.com/highmaps/tooltip.followTouchMove
     * @see https://api.highcharts.com/gantt/tooltip.followTouchMove
     */
    followTouchMove?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A string to append to the
     * tooltip format.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.footerFormat
     * @see https://api.highcharts.com/highstock/tooltip.footerFormat
     * @see https://api.highcharts.com/highmaps/tooltip.footerFormat
     * @see https://api.highcharts.com/gantt/tooltip.footerFormat
     */
    footerFormat?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback function to format the
     * text of the tooltip from scratch. Return `false` to disable tooltip for a
     * specific point on series.
     *
     * A subset of HTML is supported. Unless `useHTML` is true, the HTML of the
     * tooltip is parsed and converted to SVG, therefore this isn't a complete
     * HTML renderer. The following tags are supported: `<b>`, `<strong>`,
     * `<i>`, `<em>`, `<br/>`, `<span>`. Spans can be styled with a `style`
     * attribute, but only text-related CSS that is shared with SVG is handled.
     *
     * Since version 2.1 the tooltip can be shared between multiple series
     * through the `shared` option. The available data in the formatter differ a
     * bit depending on whether the tooltip is shared or not. In a shared
     * tooltip, all properties except `x`, which is common for all points, are
     * kept in an array, `this.points`.
     *
     * Available data are:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/tooltip.formatter
     * @see https://api.highcharts.com/highstock/tooltip.formatter
     * @see https://api.highcharts.com/highmaps/tooltip.formatter
     * @see https://api.highcharts.com/gantt/tooltip.formatter
     */
    formatter?: FormatterCallbackFunction<TooltipFormatterContextObject>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The HTML of the tooltip header
     * line. Variables are enclosed by curly brackets. Available variables are
     * `point.key`, `series.name`, `series.color` and other members from the
     * `point` and `series` objects. The `point.key` variable contains the
     * category name, x value or datetime string depending on the type of axis.
     * For datetime axes, the `point.key` date format can be set using
     * `tooltip.xDateFormat`.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.headerFormat
     * @see https://api.highcharts.com/highstock/tooltip.headerFormat
     * @see https://api.highcharts.com/highmaps/tooltip.headerFormat
     * @see https://api.highcharts.com/gantt/tooltip.headerFormat
     */
    headerFormat?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The name of a symbol to use for
     * the border around the tooltip header. Applies only when tooltip.split is
     * enabled.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.headerShape
     * @see https://api.highcharts.com/highstock/tooltip.headerShape
     * @see https://api.highcharts.com/highmaps/tooltip.headerShape
     * @see https://api.highcharts.com/gantt/tooltip.headerShape
     */
    headerShape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The number of milliseconds to
     * wait until the tooltip is hidden when mouse out from a point or chart.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.hideDelay
     * @see https://api.highcharts.com/highstock/tooltip.hideDelay
     * @see https://api.highcharts.com/highmaps/tooltip.hideDelay
     * @see https://api.highcharts.com/gantt/tooltip.hideDelay
     */
    hideDelay?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to allow the tooltip to
     * render outside the chart's SVG element box. By default (`false`), the
     * tooltip is rendered within the chart's SVG element, which results in the
     * tooltip being aligned inside the chart area. For small charts, this may
     * result in clipping or overlapping. When `true`, a separate SVG element is
     * created and overlaid on the page, allowing the tooltip to be aligned
     * inside the page itself.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.outside
     * @see https://api.highcharts.com/highstock/tooltip.outside
     * @see https://api.highcharts.com/highmaps/tooltip.outside
     * @see https://api.highcharts.com/gantt/tooltip.outside
     */
    outside?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Padding inside the tooltip, in
     * pixels.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.padding
     * @see https://api.highcharts.com/highstock/tooltip.padding
     * @see https://api.highcharts.com/highmaps/tooltip.padding
     * @see https://api.highcharts.com/gantt/tooltip.padding
     */
    padding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The HTML of the point's line in
     * the tooltip. Variables are enclosed by curly brackets. Available
     * variables are point.x, point.y, series. name and series.color and other
     * properties on the same form. Furthermore, `point.y` can be extended by
     * the `tooltip.valuePrefix` and `tooltip.valueSuffix` variables. This can
     * also be overridden for each series, which makes it a good hook for
     * displaying units.
     *
     * In styled mode, the dot is colored by a class name rather than the point
     * color.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.pointFormat
     * @see https://api.highcharts.com/highstock/tooltip.pointFormat
     * @see https://api.highcharts.com/highmaps/tooltip.pointFormat
     * @see https://api.highcharts.com/gantt/tooltip.pointFormat
     */
    pointFormat?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A callback function for
     * formatting the HTML output for a single point in the tooltip. Like the
     * `pointFormat` string, but with more flexibility.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.pointFormatter
     * @see https://api.highcharts.com/highstock/tooltip.pointFormatter
     * @see https://api.highcharts.com/highmaps/tooltip.pointFormatter
     * @see https://api.highcharts.com/gantt/tooltip.pointFormatter
     */
    pointFormatter?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A callback function to place the
     * tooltip in a default position. The callback receives three parameters:
     * `labelWidth`, `labelHeight` and `point`, where point contains values for
     * `plotX` and `plotY` telling where the reference point is in the plot
     * area. Add `chart.plotLeft` and `chart.plotTop` to get the full
     * coordinates.
     *
     * Since v7, when tooltip.split option is enabled, positioner is called for
     * each of the boxes separately, including xAxis header. xAxis header is not
     * a point, instead `point` argument contains info: `{ plotX: Number, plotY:
     * Number, isHeader: Boolean }`
     *
     * The return should be an object containing x and y values, for example `{
     * x: 100, y: 100 }`.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.positioner
     * @see https://api.highcharts.com/highstock/tooltip.positioner
     * @see https://api.highcharts.com/highmaps/tooltip.positioner
     * @see https://api.highcharts.com/gantt/tooltip.positioner
     */
    positioner?: () => void;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to apply a drop shadow
     * to the tooltip.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.shadow
     * @see https://api.highcharts.com/highstock/tooltip.shadow
     * @see https://api.highcharts.com/highmaps/tooltip.shadow
     * @see https://api.highcharts.com/gantt/tooltip.shadow
     */
    shadow?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The name of a symbol to use for
     * the border around the tooltip. Can be one of: `"callout"`, `"circle"` or
     * `"square"`. When tooltip.split option is enabled, shape is applied to all
     * boxes except header, which is controlled by tooltip.headerShape.
     *
     * Custom callbacks for symbol path generation can also be added to
     * `Highcharts.SVGRenderer.prototype.symbols` the same way as for
     * series.marker.symbol.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.shape
     * @see https://api.highcharts.com/highstock/tooltip.shape
     * @see https://api.highcharts.com/highmaps/tooltip.shape
     * @see https://api.highcharts.com/gantt/tooltip.shape
     */
    shape?: ("callout"|"square");
    /**
     * (Highcharts, Highstock) When the tooltip is shared, the entire plot area
     * will capture mouse movement or touch events. Tooltip texts for series
     * types with ordered data (not pie, scatter, flags etc) will be shown in a
     * single bubble. This is recommended for single series charts and for
     * tablet/mobile optimized charts.
     *
     * See also tooltip.split, that is better suited for charts with many
     * series, especially line-type series. The `tooltip.split` option takes
     * precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.shared
     * @see https://api.highcharts.com/highstock/tooltip.shared
     */
    shared?: boolean;
    /**
     * (Highcharts, Highstock) Proximity snap for graphs or single points. It
     * defaults to 10 for mouse-powered devices and 25 for touch devices.
     *
     * Note that in most cases the whole plot area captures the mouse movement,
     * and in these cases `tooltip.snap` doesn't make sense. This applies when
     * stickyTracking is `true` (default) and when the tooltip is shared or
     * split.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.snap
     * @see https://api.highcharts.com/highstock/tooltip.snap
     */
    snap?: number;
    /**
     * (Highcharts, Highstock) Split the tooltip into one label per series, with
     * the header close to the axis. This is recommended over shared tooltips
     * for charts with multiple line series, generally making them easier to
     * read. This option takes precedence over `tooltip.shared`.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.split
     * @see https://api.highcharts.com/highstock/tooltip.split
     */
    split?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the tooltip. The
     * tooltip can also be styled through the CSS class `.highcharts-tooltip`.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.style
     * @see https://api.highcharts.com/highstock/tooltip.style
     * @see https://api.highcharts.com/highmaps/tooltip.style
     * @see https://api.highcharts.com/gantt/tooltip.style
     */
    style?: (CSSObject|TooltipStyleOptions);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Use HTML to render the contents
     * of the tooltip instead of SVG. Using HTML allows advanced formatting like
     * tables and images in the tooltip. It is also recommended for rtl
     * languages as it works around rtl bugs in early Firefox.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.useHTML
     * @see https://api.highcharts.com/highstock/tooltip.useHTML
     * @see https://api.highcharts.com/highmaps/tooltip.useHTML
     * @see https://api.highcharts.com/gantt/tooltip.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) How many decimals to show in
     * each series' y value. This is overridable in each series' tooltip options
     * object. The default is to preserve all decimals.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.valueDecimals
     * @see https://api.highcharts.com/highstock/tooltip.valueDecimals
     * @see https://api.highcharts.com/highmaps/tooltip.valueDecimals
     * @see https://api.highcharts.com/gantt/tooltip.valueDecimals
     */
    valueDecimals?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A string to prepend to each
     * series' y value. Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.valuePrefix
     * @see https://api.highcharts.com/highstock/tooltip.valuePrefix
     * @see https://api.highcharts.com/highmaps/tooltip.valuePrefix
     * @see https://api.highcharts.com/gantt/tooltip.valuePrefix
     */
    valuePrefix?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A string to append to each
     * series' y value. Overridable in each series' tooltip options object.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.valueSuffix
     * @see https://api.highcharts.com/highstock/tooltip.valueSuffix
     * @see https://api.highcharts.com/highmaps/tooltip.valueSuffix
     * @see https://api.highcharts.com/gantt/tooltip.valueSuffix
     */
    valueSuffix?: string;
    /**
     * (Highcharts, Highstock, Gantt) The format for the date in the tooltip
     * header if the X axis is a datetime axis. The default is a best guess
     * based on the smallest distance between points in the chart.
     *
     * @see https://api.highcharts.com/highcharts/tooltip.xDateFormat
     * @see https://api.highcharts.com/highstock/tooltip.xDateFormat
     * @see https://api.highcharts.com/gantt/tooltip.xDateFormat
     */
    xDateFormat?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the tooltip. The
 * tooltip can also be styled through the CSS class `.highcharts-tooltip`.
 *
 * @see https://api.highcharts.com/highcharts/tooltip.style
 * @see https://api.highcharts.com/highstock/tooltip.style
 * @see https://api.highcharts.com/highmaps/tooltip.style
 * @see https://api.highcharts.com/gantt/tooltip.style
 */
export interface TooltipStyleOptions {
    whiteSpace?: string;
}
/**
 * (Highcharts, Highstock, Gantt) An array defining breaks in the axis, the
 * sections defined will be left out and all the points shifted closer to each
 * other.
 *
 * @see https://api.highcharts.com/highcharts/xAxis.breaks
 * @see https://api.highcharts.com/highstock/xAxis.breaks
 * @see https://api.highcharts.com/gantt/xAxis.breaks
 */
export interface XAxisBreaksOptions {
    /**
     * (Highcharts, Highstock, Gantt) A number indicating how much space should
     * be left between the start and the end of the break. The break size is
     * given in axis units, so for instance on a `datetime` axis, a break size
     * of 3600000 would indicate the equivalent of an hour.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.breaks.breakSize
     * @see https://api.highcharts.com/highstock/xAxis.breaks.breakSize
     * @see https://api.highcharts.com/gantt/xAxis.breaks.breakSize
     */
    breakSize?: number;
    /**
     * (Highcharts, Highstock, Gantt) The point where the break starts.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.breaks.from
     * @see https://api.highcharts.com/highstock/xAxis.breaks.from
     * @see https://api.highcharts.com/gantt/xAxis.breaks.from
     */
    from?: number;
    /**
     * (Highcharts, Highstock, Gantt) Defines an interval after which the break
     * appears again. By default the breaks do not repeat.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.breaks.repeat
     * @see https://api.highcharts.com/highstock/xAxis.breaks.repeat
     * @see https://api.highcharts.com/gantt/xAxis.breaks.repeat
     */
    repeat?: number;
    /**
     * (Highcharts, Highstock, Gantt) The point where the break ends.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.breaks.to
     * @see https://api.highcharts.com/highstock/xAxis.breaks.to
     * @see https://api.highcharts.com/gantt/xAxis.breaks.to
     */
    to?: number;
}
/**
 * (Highstock) A label on the axis next to the crosshair.
 *
 * In styled mode, the label is styled with the `.highcharts-crosshair-label`
 * class.
 *
 * @see https://api.highcharts.com/highstock/xAxis.crosshair.label
 */
export interface XAxisCrosshairLabelOptions {
    /**
     * (Highstock) Alignment of the label compared to the axis. Defaults to
     * `left` for right-side axes, `right` for left-side axes and `center` for
     * horizontal axes.
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label.align
     */
    align?: string;
    /**
     * (Highstock) The background color for the label. Defaults to the related
     * series color, or `#666666` if that is not available.
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the crosshair label
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border corner radius of the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width for the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A format string for the crosshair label. Defaults to
     * `{value}` for numeric axes and `{value:%b %d, %Y}` for datetime axes.
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label.format
     */
    format?: string;
    /**
     * (Highstock) Formatter function for the label text.
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label.formatter
     */
    formatter?: FormatterCallbackFunction<object>;
    /**
     * (Highstock) Padding inside the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label.padding
     */
    padding?: number;
    /**
     * (Highstock) The shape to use for the label box.
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label.shape
     */
    shape?: string;
    /**
     * (Highstock) Text styles for the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label.style
     */
    style?: CSSObject;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Configure a crosshair that follows
 * either the mouse pointer or the hovered point.
 *
 * In styled mode, the crosshairs are styled in the `.highcharts-crosshair`,
 * `.highcharts-crosshair-thin` or `.highcharts-xaxis-category` classes.
 *
 * @see https://api.highcharts.com/highcharts/xAxis.crosshair
 * @see https://api.highcharts.com/highstock/xAxis.crosshair
 * @see https://api.highcharts.com/highmaps/xAxis.crosshair
 * @see https://api.highcharts.com/gantt/xAxis.crosshair
 */
export interface XAxisCrosshairOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A class name for the crosshair,
     * especially as a hook for styling.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.crosshair.className
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.className
     * @see https://api.highcharts.com/highmaps/xAxis.crosshair.className
     * @see https://api.highcharts.com/gantt/xAxis.crosshair.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the crosshair.
     * Defaults to `#cccccc` for numeric and datetime axes, and
     * `rgba(204,214,235,0.25)` for category axes, where the crosshair by
     * default highlights the whole category.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.crosshair.color
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.color
     * @see https://api.highcharts.com/highmaps/xAxis.crosshair.color
     * @see https://api.highcharts.com/gantt/xAxis.crosshair.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The dash style for the
     * crosshair. See series.dashStyle for possible values.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.crosshair.dashStyle
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.dashStyle
     * @see https://api.highcharts.com/highmaps/xAxis.crosshair.dashStyle
     * @see https://api.highcharts.com/gantt/xAxis.crosshair.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) A label on the axis next to the crosshair.
     *
     * In styled mode, the label is styled with the
     * `.highcharts-crosshair-label` class.
     *
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.label
     */
    label?: XAxisCrosshairLabelOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether the crosshair should
     * snap to the point or follow the pointer independent of points.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.crosshair.snap
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.snap
     * @see https://api.highcharts.com/highmaps/xAxis.crosshair.snap
     * @see https://api.highcharts.com/gantt/xAxis.crosshair.snap
     */
    snap?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the
     * crosshair. Defaults to 1 for numeric or datetime axes, and for one
     * category width for category axes.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.crosshair.width
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.width
     * @see https://api.highcharts.com/highmaps/xAxis.crosshair.width
     * @see https://api.highcharts.com/gantt/xAxis.crosshair.width
     */
    width?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Z index of the crosshair.
     * Higher Z indices allow drawing the crosshair on top of the series or
     * behind the grid lines.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.crosshair.zIndex
     * @see https://api.highcharts.com/highstock/xAxis.crosshair.zIndex
     * @see https://api.highcharts.com/highmaps/xAxis.crosshair.zIndex
     * @see https://api.highcharts.com/gantt/xAxis.crosshair.zIndex
     */
    zIndex?: number;
}
/**
 * (Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label
 */
export interface XAxisCurrentDateIndicatorLabelOptions {
    /**
     * (Gantt) Horizontal alignment of the label. Can be one of "left", "center"
     * or "right".
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Gantt) Rotation of the text label in degrees. Defaults to 0 for
     * horizontal plot lines and 90 for vertical lines.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label.rotation
     */
    rotation?: number;
    /**
     * (Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-line-label` class.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label.style
     */
    style?: CSSObject;
    /**
     * (Gantt) The text itself. A subset of HTML is supported.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label.text
     */
    text?: string;
    /**
     * (Gantt) The text alignment for the label. While `align` determines where
     * the texts anchor point is placed within the plot band, `textAlign`
     * determines how the text is aligned against its anchor point. Possible
     * values are "left", "center" and "right". Defaults to the same as the
     * `align` option.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label.textAlign
     */
    textAlign?: string;
    /**
     * (Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Gantt) Vertical alignment of the label relative to the plot line. Can be
     * one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Gantt) Horizontal position relative the alignment. Default varies by
     * orientation.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label.x
     */
    x?: number;
    /**
     * (Gantt) Vertical position of the text baseline relative to the alignment.
     * Default varies by orientation.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label.y
     */
    y?: number;
}
/**
 * (Gantt) Show an indicator on the axis for the current date and time. Can be a
 * boolean or a configuration object similar to xAxis.plotLines.
 *
 * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator
 */
export interface XAxisCurrentDateIndicatorOptions {
    /**
     * (Gantt) A custom class name, in addition to the default
     * `highcharts-plot-line`, to apply to each individual line.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.className
     */
    className?: string;
    /**
     * (Gantt) The color of the line.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.color
     */
    color?: ColorString;
    /**
     * (Gantt) The dashing or dot style for the plot line. For possible values
     * see this overview.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Gantt) An object defining mouse events for the plot line. Supported
     * properties are `click`, `mouseover`, `mouseout`, `mousemove`.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.events
     */
    events?: any;
    /**
     * (Gantt) An id used for identifying the plot line in Axis.removePlotLine.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.id
     */
    id?: string;
    /**
     * (Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.label
     */
    label?: XAxisCurrentDateIndicatorLabelOptions;
    /**
     * (Gantt) The width or thickness of the plot line.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.width
     */
    width?: number;
    /**
     * (Gantt) The z index of the plot line within the chart.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator.zIndex
     */
    zIndex?: number;
}
export interface XAxisDateTimeLabelFormatsDayOptions {
    main?: string;
}
export interface XAxisDateTimeLabelFormatsHourOptions {
    main?: string;
    range?: boolean;
}
export interface XAxisDateTimeLabelFormatsMillisecondOptions {
    main?: string;
    range?: boolean;
}
export interface XAxisDateTimeLabelFormatsMinuteOptions {
    main?: string;
    range?: boolean;
}
export interface XAxisDateTimeLabelFormatsMonthOptions {
    main?: string;
}
/**
 * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
 * automatically adjust to the appropriate unit. This member gives the default
 * string representations used for each unit. For intermediate values, different
 * units may be used, for example the `day` unit can be used on midnight and
 * `hour` unit be used for intermediate values on the same axis. For an overview
 * of the replacement codes, see dateFormat. Defaults to:
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/xAxis.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/xAxis.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/xAxis.dateTimeLabelFormats
 */
export interface XAxisDateTimeLabelFormatsOptions {
    day?: XAxisDateTimeLabelFormatsDayOptions;
    hour?: XAxisDateTimeLabelFormatsHourOptions;
    millisecond?: XAxisDateTimeLabelFormatsMillisecondOptions;
    minute?: XAxisDateTimeLabelFormatsMinuteOptions;
    month?: XAxisDateTimeLabelFormatsMonthOptions;
    second?: XAxisDateTimeLabelFormatsSecondOptions;
    week?: XAxisDateTimeLabelFormatsWeekOptions;
    year?: XAxisDateTimeLabelFormatsYearOptions;
}
export interface XAxisDateTimeLabelFormatsSecondOptions {
    main?: string;
    range?: boolean;
}
export interface XAxisDateTimeLabelFormatsWeekOptions {
    main?: string;
}
export interface XAxisDateTimeLabelFormatsYearOptions {
    main?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Event handlers for the axis.
 *
 * @see https://api.highcharts.com/highcharts/xAxis.events
 * @see https://api.highcharts.com/highstock/xAxis.events
 * @see https://api.highcharts.com/highmaps/xAxis.events
 * @see https://api.highcharts.com/gantt/xAxis.events
 */
export interface XAxisEventsOptions {
    /**
     * (Highcharts, Gantt) An event fired after the breaks have rendered.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.events.afterBreaks
     * @see https://api.highcharts.com/gantt/xAxis.events.afterBreaks
     */
    afterBreaks?: AxisEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) As opposed to the `setExtremes`
     * event, this event fires after the final min and max values are computed
     * and corrected for `minRange`.
     *
     * Fires when the minimum and maximum is set for the axis, either by calling
     * the `.setExtremes()` method or by selecting an area in the chart. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in axis
     * values. The actual data extremes are found in `event.dataMin` and
     * `event.dataMax`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.events.afterSetExtremes
     * @see https://api.highcharts.com/highstock/xAxis.events.afterSetExtremes
     * @see https://api.highcharts.com/highmaps/xAxis.events.afterSetExtremes
     * @see https://api.highcharts.com/gantt/xAxis.events.afterSetExtremes
     */
    afterSetExtremes?: AxisEventCallbackFunction;
    /**
     * (Highcharts, Gantt) An event fired when a break from this axis occurs on
     * a point.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.events.pointBreak
     * @see https://api.highcharts.com/gantt/xAxis.events.pointBreak
     */
    pointBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) An event fired when a point falls inside a
     * break from this axis.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.events.pointInBreak
     * @see https://api.highcharts.com/highstock/xAxis.events.pointInBreak
     * @see https://api.highcharts.com/gantt/xAxis.events.pointInBreak
     */
    pointInBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the minimum and
     * maximum is set for the axis, either by calling the `.setExtremes()`
     * method or by selecting an area in the chart. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in data
     * values. When an axis is zoomed all the way out from the "Reset zoom"
     * button, `event.min` and `event.max` are null, and the new extremes are
     * set based on `this.dataMin` and `this.dataMax`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.events.setExtremes
     * @see https://api.highcharts.com/highstock/xAxis.events.setExtremes
     * @see https://api.highcharts.com/highmaps/xAxis.events.setExtremes
     * @see https://api.highcharts.com/gantt/xAxis.events.setExtremes
     */
    setExtremes?: AxisSetExtremesEventCallbackFunction;
}
/**
 * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
 *
 * @see https://api.highcharts.com/gantt/xAxis.grid
 */
export interface XAxisGridOptions {
    /**
     * (Gantt) Set border color for the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/xAxis.grid.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Gantt) Set border width of the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/xAxis.grid.borderWidth
     */
    borderWidth?: number;
    /**
     * (Gantt) Set cell height for grid axis labels. By default this is
     * calculated from font size.
     *
     * @see https://api.highcharts.com/gantt/xAxis.grid.cellHeight
     */
    cellHeight?: number;
    /**
     * (Gantt) Set specific options for each column (or row for horizontal axes)
     * in the grid. Each extra column/row is its own axis, and the axis options
     * can be set here.
     *
     * @see https://api.highcharts.com/gantt/xAxis.grid.columns
     */
    columns?: Array<XAxisOptions>;
    /**
     * (Gantt) Enable grid on the axis labels. Defaults to true for Gantt
     * charts.
     *
     * @see https://api.highcharts.com/gantt/xAxis.grid.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The axis labels show the number or
 * category for each tick.
 *
 * @see https://api.highcharts.com/highcharts/xAxis.labels
 * @see https://api.highcharts.com/highstock/xAxis.labels
 * @see https://api.highcharts.com/highmaps/xAxis.labels
 * @see https://api.highcharts.com/gantt/xAxis.labels
 */
export interface XAxisLabelsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) What part of the string the
     * given position is anchored to. If `left`, the left side of the string is
     * at the axis position. Can be one of `"left"`, `"center"` or `"right"`.
     * Defaults to an intelligent guess based on which side of the chart the
     * axis is on and the rotation of the label.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.align
     * @see https://api.highcharts.com/highstock/xAxis.labels.align
     * @see https://api.highcharts.com/highmaps/xAxis.labels.align
     * @see https://api.highcharts.com/gantt/xAxis.labels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) For horizontal axes, the allowed degrees
     * of label rotation to prevent overlapping labels. If there is enough
     * space, labels are not rotated. As the chart gets narrower, it will start
     * rotating the labels -45 degrees, then remove every second label and try
     * again with rotations 0 and -45 etc. Set it to `false` to disable
     * rotation, which will cause the labels to word-wrap if possible.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.autoRotation
     * @see https://api.highcharts.com/highstock/xAxis.labels.autoRotation
     * @see https://api.highcharts.com/gantt/xAxis.labels.autoRotation
     */
    autoRotation?: Array<number>;
    /**
     * (Highcharts, Gantt) When each category width is more than this many
     * pixels, we don't apply auto rotation. Instead, we lay out the axis label
     * with word wrap. A lower limit makes sense when the label contains
     * multiple short words that don't extend the available horizontal space for
     * each label.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.autoRotationLimit
     * @see https://api.highcharts.com/gantt/xAxis.labels.autoRotationLimit
     */
    autoRotationLimit?: number;
    /**
     * (Highcharts, Gantt) Polar charts only. The label's pixel distance from
     * the perimeter of the plot area.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.distance
     * @see https://api.highcharts.com/gantt/xAxis.labels.distance
     */
    distance?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the axis
     * labels.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.enabled
     * @see https://api.highcharts.com/highstock/xAxis.labels.enabled
     * @see https://api.highcharts.com/highmaps/xAxis.labels.enabled
     * @see https://api.highcharts.com/gantt/xAxis.labels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A format string for the axis
     * label.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.format
     * @see https://api.highcharts.com/highstock/xAxis.labels.format
     * @see https://api.highcharts.com/highmaps/xAxis.labels.format
     * @see https://api.highcharts.com/gantt/xAxis.labels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback JavaScript function to
     * format the label. The value is given by `this.value`. Additional
     * properties for `this` are `axis`, `chart`, `isFirst` and `isLast`. The
     * value of the default label formatter can be retrieved by calling
     * `this.axis.defaultLabelFormatter.call(this)` within the function.
     *
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.formatter
     * @see https://api.highcharts.com/highstock/xAxis.labels.formatter
     * @see https://api.highcharts.com/highmaps/xAxis.labels.formatter
     * @see https://api.highcharts.com/gantt/xAxis.labels.formatter
     */
    formatter?: FormatterCallbackFunction<AxisLabelsFormatterContextObject>;
    /**
     * (Gantt) The number of pixels to indent the labels per level in a treegrid
     * axis.
     *
     * @see https://api.highcharts.com/gantt/xAxis.labels.indentation
     */
    indentation?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Horizontal axis only. When
     * `staggerLines` is not set, `maxStaggerLines` defines how many lines the
     * axis is allowed to add to automatically avoid overlapping X labels. Set
     * to `1` to disable overlap detection.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.maxStaggerLines
     * @see https://api.highcharts.com/highstock/xAxis.labels.maxStaggerLines
     * @see https://api.highcharts.com/highmaps/xAxis.labels.maxStaggerLines
     * @see https://api.highcharts.com/gantt/xAxis.labels.maxStaggerLines
     */
    maxStaggerLines?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) How to handle overflowing labels
     * on horizontal axis. If set to `"allow"`, it will not be aligned at all.
     * By default it `"justify"` labels inside the chart area. If there is room
     * to move it, it will be aligned to the edge, else it will be removed.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.overflow
     * @see https://api.highcharts.com/highstock/xAxis.labels.overflow
     * @see https://api.highcharts.com/highmaps/xAxis.labels.overflow
     * @see https://api.highcharts.com/gantt/xAxis.labels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Gantt) The pixel padding for axis labels, to ensure white
     * space between them.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.padding
     * @see https://api.highcharts.com/gantt/xAxis.labels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Defines how the labels are be repositioned according to the
     * 3D chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho");
    /**
     * (Highcharts, Gantt) Whether to reserve space for the labels. By default,
     * space is reserved for the labels in these cases:
     *
     * * On all horizontal axes.
     *
     * * On vertical axes if `label.align` is `right` on a left-side axis or
     * `left` on a right-side axis.
     *
     * * On vertical axes if `label.align` is `center`.
     *
     * This can be turned off when for example the labels are rendered inside
     * the plot area instead of outside.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.reserveSpace
     * @see https://api.highcharts.com/gantt/xAxis.labels.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Rotation of the labels in
     * degrees.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.rotation
     * @see https://api.highcharts.com/highstock/xAxis.labels.rotation
     * @see https://api.highcharts.com/highmaps/xAxis.labels.rotation
     * @see https://api.highcharts.com/gantt/xAxis.labels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis labels will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `labels.position3d`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.skew3d
     */
    skew3d?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Horizontal axes only. The number
     * of lines to spread the labels over to make room or tighter labels.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.staggerLines
     * @see https://api.highcharts.com/highstock/xAxis.labels.staggerLines
     * @see https://api.highcharts.com/highmaps/xAxis.labels.staggerLines
     * @see https://api.highcharts.com/gantt/xAxis.labels.staggerLines
     */
    staggerLines?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) To show only every _n_'th label
     * on the axis, set the step to _n_. Setting the step to 2 shows every other
     * label.
     *
     * By default, the step is calculated automatically to avoid overlap. To
     * prevent this, set it to 1\. This usually only happens on a category axis,
     * and is often a sign that you have chosen the wrong axis type.
     *
     * Read more at Axis docs => What axis should I use?
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.step
     * @see https://api.highcharts.com/highstock/xAxis.labels.step
     * @see https://api.highcharts.com/highmaps/xAxis.labels.step
     * @see https://api.highcharts.com/gantt/xAxis.labels.step
     */
    step?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the label. Use
     * `whiteSpace: 'nowrap'` to prevent wrapping of category labels. Use
     * `textOverflow: 'none'` to prevent ellipsis (dots).
     *
     * In styled mode, the labels are styled with the `.highcharts-axis-labels`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.style
     * @see https://api.highcharts.com/highstock/xAxis.labels.style
     * @see https://api.highcharts.com/highmaps/xAxis.labels.style
     * @see https://api.highcharts.com/gantt/xAxis.labels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render
     * the labels.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.useHTML
     * @see https://api.highcharts.com/highstock/xAxis.labels.useHTML
     * @see https://api.highcharts.com/highmaps/xAxis.labels.useHTML
     * @see https://api.highcharts.com/gantt/xAxis.labels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position offset of the
     * label relative to the tick position on the axis.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.x
     * @see https://api.highcharts.com/highstock/xAxis.labels.x
     * @see https://api.highcharts.com/highmaps/xAxis.labels.x
     * @see https://api.highcharts.com/gantt/xAxis.labels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position offset of the
     * label relative to the tick position on the axis. The default makes it
     * adapt to the font size on bottom axis.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.y
     * @see https://api.highcharts.com/highstock/xAxis.labels.y
     * @see https://api.highcharts.com/highmaps/xAxis.labels.y
     * @see https://api.highcharts.com/gantt/xAxis.labels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Z index for the axis labels.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels.zIndex
     * @see https://api.highcharts.com/highstock/xAxis.labels.zIndex
     * @see https://api.highcharts.com/highmaps/xAxis.labels.zIndex
     * @see https://api.highcharts.com/gantt/xAxis.labels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The X axis or category axis.
 * Normally this is the horizontal axis, though if the chart is inverted this is
 * the vertical axis. In case of multiple axes, the xAxis node is an array of
 * configuration objects.
 *
 * See the Axis class for programmatic access to the axis.
 *
 * @see https://api.highcharts.com/highcharts/xAxis
 * @see https://api.highcharts.com/highstock/xAxis
 * @see https://api.highcharts.com/highmaps/xAxis
 * @see https://api.highcharts.com/gantt/xAxis
 */
export interface XAxisOptions {
    /**
     * (Highcharts, Highstock, Gantt) When using multiple axis, the ticks of two
     * or more opposite axes will automatically be aligned by adding ticks to
     * the axis or axes with the least ticks, as if `tickAmount` were specified.
     *
     * This can be prevented by setting `alignTicks` to false. If the grid lines
     * look messy, it's a good idea to hide them for the secondary axis by
     * setting `gridLineWidth` to 0.
     *
     * If `startOnTick` or `endOnTick` in an Axis options are set to false, then
     * the `alignTicks ` will be disabled for the Axis.
     *
     * Disabled for logarithmic axes.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.alignTicks
     * @see https://api.highcharts.com/highstock/xAxis.alignTicks
     * @see https://api.highcharts.com/gantt/xAxis.alignTicks
     */
    alignTicks?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to allow decimals in
     * this axis' ticks. When counting integers, like persons or hits on a web
     * page, decimals should be avoided in the labels.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.allowDecimals
     * @see https://api.highcharts.com/highstock/xAxis.allowDecimals
     * @see https://api.highcharts.com/highmaps/xAxis.allowDecimals
     * @see https://api.highcharts.com/gantt/xAxis.allowDecimals
     */
    allowDecimals?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When using an alternate grid
     * color, a band is painted across the plot area between every other grid
     * line.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.alternateGridColor
     * @see https://api.highcharts.com/highstock/xAxis.alternateGridColor
     * @see https://api.highcharts.com/highmaps/xAxis.alternateGridColor
     * @see https://api.highcharts.com/gantt/xAxis.alternateGridColor
     */
    alternateGridColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) An array defining breaks in the axis, the
     * sections defined will be left out and all the points shifted closer to
     * each other.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.breaks
     * @see https://api.highcharts.com/highstock/xAxis.breaks
     * @see https://api.highcharts.com/gantt/xAxis.breaks
     */
    breaks?: Array<XAxisBreaksOptions>;
    /**
     * (Highcharts, Gantt) If categories are present for the xAxis, names are
     * used instead of numbers for that axis. Since Highcharts 3.0, categories
     * can also be extracted by giving each point a name and setting axis type
     * to `category`. However, if you have multiple series, best practice
     * remains defining the `categories` array.
     *
     * Example:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/xAxis.categories
     * @see https://api.highcharts.com/gantt/xAxis.categories
     */
    categories?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) The highest allowed value for
     * automatically computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.ceiling
     * @see https://api.highcharts.com/highstock/xAxis.ceiling
     * @see https://api.highcharts.com/gantt/xAxis.ceiling
     */
    ceiling?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A class name that opens for
     * styling the axis by CSS, especially in Highcharts styled mode. The class
     * name is applied to group elements for the grid, axis elements and labels.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.className
     * @see https://api.highcharts.com/highstock/xAxis.className
     * @see https://api.highcharts.com/highmaps/xAxis.className
     * @see https://api.highcharts.com/gantt/xAxis.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Configure a crosshair that
     * follows either the mouse pointer or the hovered point.
     *
     * In styled mode, the crosshairs are styled in the `.highcharts-crosshair`,
     * `.highcharts-crosshair-thin` or `.highcharts-xaxis-category` classes.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.crosshair
     * @see https://api.highcharts.com/highstock/xAxis.crosshair
     * @see https://api.highcharts.com/highmaps/xAxis.crosshair
     * @see https://api.highcharts.com/gantt/xAxis.crosshair
     */
    crosshair?: (boolean|XAxisCrosshairOptions);
    /**
     * (Gantt) Show an indicator on the axis for the current date and time. Can
     * be a boolean or a configuration object similar to xAxis.plotLines.
     *
     * @see https://api.highcharts.com/gantt/xAxis.currentDateIndicator
     */
    currentDateIndicator?: (boolean|XAxisCurrentDateIndicatorOptions);
    /**
     * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
     * automatically adjust to the appropriate unit. This member gives the
     * default string representations used for each unit. For intermediate
     * values, different units may be used, for example the `day` unit can be
     * used on midnight and `hour` unit be used for intermediate values on the
     * same axis. For an overview of the replacement codes, see dateFormat.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/xAxis.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/xAxis.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/xAxis.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: XAxisDateTimeLabelFormatsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) _Requires Accessibility module_
     *
     * Description of the axis to screen reader users.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.description
     * @see https://api.highcharts.com/highstock/xAxis.description
     * @see https://api.highcharts.com/highmaps/xAxis.description
     * @see https://api.highcharts.com/gantt/xAxis.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to force the axis to end
     * on a tick. Use this option with the `maxPadding` option to control the
     * axis end.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.endOnTick
     * @see https://api.highcharts.com/highstock/xAxis.endOnTick
     * @see https://api.highcharts.com/highmaps/xAxis.endOnTick
     * @see https://api.highcharts.com/gantt/xAxis.endOnTick
     */
    endOnTick?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Event handlers for the axis.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.events
     * @see https://api.highcharts.com/highstock/xAxis.events
     * @see https://api.highcharts.com/highmaps/xAxis.events
     * @see https://api.highcharts.com/gantt/xAxis.events
     */
    events?: XAxisEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) The lowest allowed value for automatically
     * computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.floor
     * @see https://api.highcharts.com/highstock/xAxis.floor
     * @see https://api.highcharts.com/gantt/xAxis.floor
     */
    floor?: number;
    /**
     * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
     *
     * @see https://api.highcharts.com/gantt/xAxis.grid
     */
    grid?: XAxisGridOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the grid lines
     * extending the ticks across the plot area.
     *
     * In styled mode, the stroke is given in the `.highcharts-grid-line` class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.gridLineColor
     * @see https://api.highcharts.com/highstock/xAxis.gridLineColor
     * @see https://api.highcharts.com/highmaps/xAxis.gridLineColor
     * @see https://api.highcharts.com/gantt/xAxis.gridLineColor
     */
    gridLineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The dash or dot style of the
     * grid lines. For possible values, see this demonstration.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.gridLineDashStyle
     * @see https://api.highcharts.com/highstock/xAxis.gridLineDashStyle
     * @see https://api.highcharts.com/highmaps/xAxis.gridLineDashStyle
     * @see https://api.highcharts.com/gantt/xAxis.gridLineDashStyle
     */
    gridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the grid lines
     * extending the ticks across the plot area.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.gridLineWidth
     * @see https://api.highcharts.com/highstock/xAxis.gridLineWidth
     * @see https://api.highcharts.com/highmaps/xAxis.gridLineWidth
     * @see https://api.highcharts.com/gantt/xAxis.gridLineWidth
     */
    gridLineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The Z index of the grid lines.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.gridZIndex
     * @see https://api.highcharts.com/highstock/xAxis.gridZIndex
     * @see https://api.highcharts.com/gantt/xAxis.gridZIndex
     */
    gridZIndex?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An id for the axis. This can be
     * used after render time to get a pointer to the axis object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.id
     * @see https://api.highcharts.com/highstock/xAxis.id
     * @see https://api.highcharts.com/highmaps/xAxis.id
     * @see https://api.highcharts.com/gantt/xAxis.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The axis labels show the number
     * or category for each tick.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.labels
     * @see https://api.highcharts.com/highstock/xAxis.labels
     * @see https://api.highcharts.com/highmaps/xAxis.labels
     * @see https://api.highcharts.com/gantt/xAxis.labels
     */
    labels?: XAxisLabelsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the line marking
     * the axis itself.
     *
     * In styled mode, the line stroke is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.lineColor
     * @see https://api.highcharts.com/highstock/xAxis.lineColor
     * @see https://api.highcharts.com/highmaps/xAxis.lineColor
     * @see https://api.highcharts.com/gantt/xAxis.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the line marking
     * the axis itself.
     *
     * In styled mode, the stroke width is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.lineWidth
     * @see https://api.highcharts.com/highstock/xAxis.lineWidth
     * @see https://api.highcharts.com/highmaps/xAxis.lineWidth
     * @see https://api.highcharts.com/gantt/xAxis.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Index of another axis that this axis is
     * linked to. When an axis is linked to a master axis, it will take the same
     * extremes as the master, but as assigned by min or max or by setExtremes.
     * It can be used to show additional info, or to ease reading the chart by
     * duplicating the scales.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.linkedTo
     * @see https://api.highcharts.com/highstock/xAxis.linkedTo
     * @see https://api.highcharts.com/gantt/xAxis.linkedTo
     */
    linkedTo?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The maximum value of the axis.
     * If `null`, the max value is automatically calculated.
     *
     * If the endOnTick option is true, the `max` value might be rounded up.
     *
     * If a tickAmount is set, the axis may be extended beyond the set max in
     * order to reach the given number of ticks. The same may happen in a chart
     * with multiple axes, determined by chart. alignTicks, where a `tickAmount`
     * is applied internally.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.max
     * @see https://api.highcharts.com/highstock/xAxis.max
     * @see https://api.highcharts.com/highmaps/xAxis.max
     * @see https://api.highcharts.com/gantt/xAxis.max
     */
    max?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Padding of the max value
     * relative to the length of the axis. A padding of 0.05 will make a 100px
     * axis 5px longer. This is useful when you don't want the highest data
     * value to appear on the edge of the plot area. When the axis' `max` option
     * is set or a max extreme is set using `axis.setExtremes()`, the maxPadding
     * will be ignored.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.maxPadding
     * @see https://api.highcharts.com/highstock/xAxis.maxPadding
     * @see https://api.highcharts.com/highmaps/xAxis.maxPadding
     * @see https://api.highcharts.com/gantt/xAxis.maxPadding
     */
    maxPadding?: number;
    /**
     * (Highstock) Maximum range which can be set using the navigator's handles.
     * Opposite of xAxis.minRange.
     *
     * @see https://api.highcharts.com/highstock/xAxis.maxRange
     */
    maxRange?: number;
    /**
     * (Highcharts, Highstock) Deprecated. Use `minRange` instead.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.maxZoom
     * @see https://api.highcharts.com/highstock/xAxis.maxZoom
     */
    maxZoom?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The minimum value of the axis.
     * If `null` the min value is automatically calculated.
     *
     * If the startOnTick option is true (default), the `min` value might be
     * rounded down.
     *
     * The automatically calculated minimum value is also affected by floor,
     * softMin, minPadding, minRange as well as series.threshold and
     * series.softThreshold.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.min
     * @see https://api.highcharts.com/highstock/xAxis.min
     * @see https://api.highcharts.com/highmaps/xAxis.min
     * @see https://api.highcharts.com/gantt/xAxis.min
     */
    min?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the minor, secondary
     * grid lines.
     *
     * In styled mode, the stroke width is given in the
     * `.highcharts-minor-grid-line` class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minorGridLineColor
     * @see https://api.highcharts.com/highstock/xAxis.minorGridLineColor
     * @see https://api.highcharts.com/highmaps/xAxis.minorGridLineColor
     * @see https://api.highcharts.com/gantt/xAxis.minorGridLineColor
     */
    minorGridLineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The dash or dot style of the
     * minor grid lines. For possible values, see this demonstration.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minorGridLineDashStyle
     * @see https://api.highcharts.com/highstock/xAxis.minorGridLineDashStyle
     * @see https://api.highcharts.com/highmaps/xAxis.minorGridLineDashStyle
     * @see https://api.highcharts.com/gantt/xAxis.minorGridLineDashStyle
     */
    minorGridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the minor, secondary
     * grid lines.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minorGridLineWidth
     * @see https://api.highcharts.com/highstock/xAxis.minorGridLineWidth
     * @see https://api.highcharts.com/highmaps/xAxis.minorGridLineWidth
     * @see https://api.highcharts.com/gantt/xAxis.minorGridLineWidth
     */
    minorGridLineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color for the minor tick marks.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minorTickColor
     * @see https://api.highcharts.com/highstock/xAxis.minorTickColor
     * @see https://api.highcharts.com/highmaps/xAxis.minorTickColor
     * @see https://api.highcharts.com/gantt/xAxis.minorTickColor
     */
    minorTickColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Specific tick interval in axis
     * units for the minor ticks. On a linear axis, if `"auto"`, the minor tick
     * interval is calculated as a fifth of the tickInterval. If `null` or
     * `undefined`, minor ticks are not shown.
     *
     * On logarithmic axes, the unit is the power of the value. For example,
     * setting the minorTickInterval to 1 puts one tick on each of 0.1, 1, 10,
     * 100 etc. Setting the minorTickInterval to 0.1 produces 9 ticks between 1
     * and 10, 10 and 100 etc.
     *
     * If user settings dictate minor ticks to become too dense, they don't make
     * sense, and will be ignored to prevent performance problems.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minorTickInterval
     * @see https://api.highcharts.com/highstock/xAxis.minorTickInterval
     * @see https://api.highcharts.com/highmaps/xAxis.minorTickInterval
     * @see https://api.highcharts.com/gantt/xAxis.minorTickInterval
     */
    minorTickInterval?: (number|string|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel length of the minor
     * tick marks.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minorTickLength
     * @see https://api.highcharts.com/highstock/xAxis.minorTickLength
     * @see https://api.highcharts.com/highmaps/xAxis.minorTickLength
     * @see https://api.highcharts.com/gantt/xAxis.minorTickLength
     */
    minorTickLength?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The position of the minor tick
     * marks relative to the axis line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minorTickPosition
     * @see https://api.highcharts.com/highstock/xAxis.minorTickPosition
     * @see https://api.highcharts.com/highmaps/xAxis.minorTickPosition
     * @see https://api.highcharts.com/gantt/xAxis.minorTickPosition
     */
    minorTickPosition?: ("inside"|"outside");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable minor ticks.
     * Unless minorTickInterval is set, the tick interval is calculated as a
     * fifth of the `tickInterval`.
     *
     * On a logarithmic axis, minor ticks are laid out based on a best guess,
     * attempting to enter approximately 5 minor ticks between each major tick.
     *
     * Prior to v6.0.0, ticks were unabled in auto layout by setting
     * `minorTickInterval` to `"auto"`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minorTicks
     * @see https://api.highcharts.com/highstock/xAxis.minorTicks
     * @see https://api.highcharts.com/highmaps/xAxis.minorTicks
     * @see https://api.highcharts.com/gantt/xAxis.minorTicks
     */
    minorTicks?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the minor
     * tick mark.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minorTickWidth
     * @see https://api.highcharts.com/highstock/xAxis.minorTickWidth
     * @see https://api.highcharts.com/highmaps/xAxis.minorTickWidth
     * @see https://api.highcharts.com/gantt/xAxis.minorTickWidth
     */
    minorTickWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Padding of the min value relative to the
     * length of the axis. A padding of 0.05 will make a 100px axis 5px longer.
     * This is useful when you don't want the lowest data value to appear on the
     * edge of the plot area. When the axis' `min` option is set or a min
     * extreme is set using `axis.setExtremes()`, the minPadding will be
     * ignored.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minPadding
     * @see https://api.highcharts.com/highstock/xAxis.minPadding
     * @see https://api.highcharts.com/gantt/xAxis.minPadding
     */
    minPadding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The minimum range to display on
     * this axis. The entire axis will not be allowed to span over a smaller
     * interval than this. For example, for a datetime axis the main unit is
     * milliseconds. If minRange is set to 3600000, you can't zoom in more than
     * to one hour.
     *
     * The default minRange for the x axis is five times the smallest interval
     * between any of the data points.
     *
     * On a logarithmic axis, the unit for the minimum range is the power. So a
     * minRange of 1 means that the axis can be zoomed to 10-100, 100-1000,
     * 1000-10000 etc.
     *
     * Note that the `minPadding`, `maxPadding`, `startOnTick` and `endOnTick`
     * settings also affect how the extremes of the axis are computed.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minRange
     * @see https://api.highcharts.com/highstock/xAxis.minRange
     * @see https://api.highcharts.com/highmaps/xAxis.minRange
     * @see https://api.highcharts.com/gantt/xAxis.minRange
     */
    minRange?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The minimum tick interval
     * allowed in axis values. For example on zooming in on an axis with daily
     * data, this can be used to prevent the axis from showing hours. Defaults
     * to the closest distance between two points on the axis.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.minTickInterval
     * @see https://api.highcharts.com/highstock/xAxis.minTickInterval
     * @see https://api.highcharts.com/highmaps/xAxis.minTickInterval
     * @see https://api.highcharts.com/gantt/xAxis.minTickInterval
     */
    minTickInterval?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The distance in pixels from the
     * plot area to the axis line. A positive offset moves the axis with it's
     * line, labels and ticks away from the plot area. This is typically used
     * when two or more axes are displayed on the same side of the plot. With
     * multiple axes the offset is dynamically adjusted to avoid collision, this
     * can be overridden by setting offset explicitly.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.offset
     * @see https://api.highcharts.com/highstock/xAxis.offset
     * @see https://api.highcharts.com/highmaps/xAxis.offset
     * @see https://api.highcharts.com/gantt/xAxis.offset
     */
    offset?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to display the axis on
     * the opposite side of the normal. The normal is on the left side for
     * vertical axes and bottom for horizontal, so the opposite sides will be
     * right and top respectively. This is typically used with dual or multiple
     * axes.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.opposite
     * @see https://api.highcharts.com/highstock/xAxis.opposite
     * @see https://api.highcharts.com/highmaps/xAxis.opposite
     * @see https://api.highcharts.com/gantt/xAxis.opposite
     */
    opposite?: boolean;
    /**
     * (Highstock) In an ordinal axis, the points are equally spaced in the
     * chart regardless of the actual time or x distance between them. This
     * means that missing data periods (e.g. nights or weekends for a stock
     * chart) will not take up space in the chart. Having `ordinal: false` will
     * show any gaps created by the `gapSize` setting proportionate to their
     * duration.
     *
     * In stock charts the X axis is ordinal by default, unless the boost module
     * is used and at least one of the series' data length exceeds the
     * boostThreshold.
     *
     * @see https://api.highcharts.com/highstock/xAxis.ordinal
     */
    ordinal?: boolean;
    /**
     * (Highstock) Additional range on the right side of the xAxis. Works
     * similar to `xAxis.maxPadding`, but value is set in milliseconds. Can be
     * set for both main `xAxis` and the navigator's `xAxis`.
     *
     * @see https://api.highcharts.com/highstock/xAxis.overscroll
     */
    overscroll?: number;
    /**
     * (Highcharts) Refers to the index in the panes array. Used for circular
     * gauges and polar charts. When the option is not set then first pane will
     * be used.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.pane
     */
    pane?: number;
    /**
     * (Highcharts, Highstock, Gantt) An array of colored bands stretching
     * across the plot area marking an interval on the axis.
     *
     * In styled mode, the plot bands are styled by the `.highcharts-plot-band`
     * class in addition to the `className` option.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands
     * @see https://api.highcharts.com/highstock/xAxis.plotBands
     * @see https://api.highcharts.com/gantt/xAxis.plotBands
     */
    plotBands?: Array<XAxisPlotBandsOptions>;
    /**
     * (Highcharts, Highstock, Gantt) An array of lines stretching across the
     * plot area, marking a specific value on one of the axes.
     *
     * In styled mode, the plot lines are styled by the `.highcharts-plot-line`
     * class in addition to the `className` option.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines
     * @see https://api.highcharts.com/highstock/xAxis.plotLines
     * @see https://api.highcharts.com/gantt/xAxis.plotLines
     */
    plotLines?: Array<XAxisPlotLinesOptions>;
    /**
     * (Highstock) The zoomed range to display when only defining one or none of
     * `min` or `max`. For example, to show the latest month, a range of one
     * month can be set.
     *
     * @see https://api.highcharts.com/highstock/xAxis.range
     */
    range?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to reverse the axis so
     * that the highest number is closest to the origin. If the chart is
     * inverted, the x axis is reversed by default.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.reversed
     * @see https://api.highcharts.com/highstock/xAxis.reversed
     * @see https://api.highcharts.com/highmaps/xAxis.reversed
     * @see https://api.highcharts.com/gantt/xAxis.reversed
     */
    reversed?: boolean;
    /**
     * (Highcharts, Highstock) This option determines how stacks should be
     * ordered within a group. For example reversed xAxis also reverses stacks,
     * so first series comes last in a group. To keep order like for
     * non-reversed xAxis enable this option.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.reversedStacks
     * @see https://api.highcharts.com/highstock/xAxis.reversedStacks
     */
    reversedStacks?: boolean;
    /**
     * (Highstock) An optional scrollbar to display on the X axis in response to
     * limiting the minimum and maximum of the axis values.
     *
     * In styled mode, all the presentational options for the scrollbar are
     * replaced by the classes `.highcharts-scrollbar-thumb`,
     * `.highcharts-scrollbar-arrow`, `.highcharts-scrollbar-button`,
     * `.highcharts-scrollbar-rifles` and `.highcharts-scrollbar-track`.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar
     */
    scrollbar?: XAxisScrollbarOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to show the axis line
     * and title when the axis has no data.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.showEmpty
     * @see https://api.highcharts.com/highstock/xAxis.showEmpty
     * @see https://api.highcharts.com/highmaps/xAxis.showEmpty
     * @see https://api.highcharts.com/gantt/xAxis.showEmpty
     */
    showEmpty?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to show the first tick
     * label.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.showFirstLabel
     * @see https://api.highcharts.com/highstock/xAxis.showFirstLabel
     * @see https://api.highcharts.com/highmaps/xAxis.showFirstLabel
     * @see https://api.highcharts.com/gantt/xAxis.showFirstLabel
     */
    showFirstLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to show the last tick label.
     * Defaults to `true` on cartesian charts, and `false` on polar charts.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.showLastLabel
     * @see https://api.highcharts.com/highstock/xAxis.showLastLabel
     * @see https://api.highcharts.com/gantt/xAxis.showLastLabel
     */
    showLastLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A soft maximum for the axis. If the series
     * data maximum is less than this, the axis will stay at this maximum, but
     * if the series data maximum is higher, the axis will flex to show all
     * data.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.softMax
     * @see https://api.highcharts.com/highstock/xAxis.softMax
     * @see https://api.highcharts.com/gantt/xAxis.softMax
     */
    softMax?: number;
    /**
     * (Highcharts, Highstock, Gantt) A soft minimum for the axis. If the series
     * data minimum is greater than this, the axis will stay at this minimum,
     * but if the series data minimum is lower, the axis will flex to show all
     * data.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.softMin
     * @see https://api.highcharts.com/highstock/xAxis.softMin
     * @see https://api.highcharts.com/gantt/xAxis.softMin
     */
    softMin?: number;
    /**
     * (Highcharts, Highstock, Gantt) For datetime axes, this decides where to
     * put the tick between weeks. 0 = Sunday, 1 = Monday.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.startOfWeek
     * @see https://api.highcharts.com/highstock/xAxis.startOfWeek
     * @see https://api.highcharts.com/gantt/xAxis.startOfWeek
     */
    startOfWeek?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to force the axis to
     * start on a tick. Use this option with the `minPadding` option to control
     * the axis start.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.startOnTick
     * @see https://api.highcharts.com/highstock/xAxis.startOnTick
     * @see https://api.highcharts.com/highmaps/xAxis.startOnTick
     * @see https://api.highcharts.com/gantt/xAxis.startOnTick
     */
    startOnTick?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) The amount of ticks to draw on the axis.
     * This opens up for aligning the ticks of multiple charts or panes within a
     * chart. This option overrides the `tickPixelInterval` option.
     *
     * This option only has an effect on linear axes. Datetime, logarithmic or
     * category axes are not affected.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.tickAmount
     * @see https://api.highcharts.com/highstock/xAxis.tickAmount
     * @see https://api.highcharts.com/gantt/xAxis.tickAmount
     */
    tickAmount?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color for the main tick marks.
     *
     * In styled mode, the stroke is given in the `.highcharts-tick` class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.tickColor
     * @see https://api.highcharts.com/highstock/xAxis.tickColor
     * @see https://api.highcharts.com/highmaps/xAxis.tickColor
     * @see https://api.highcharts.com/gantt/xAxis.tickColor
     */
    tickColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The interval of the tick marks
     * in axis units. When `undefined`, the tick interval is computed to
     * approximately follow the tickPixelInterval on linear and datetime axes.
     * On categorized axes, a `undefined` tickInterval will default to 1, one
     * category. Note that datetime axes are based on milliseconds, so for
     * example an interval of one day is expressed as `24 * 3600 * 1000`.
     *
     * On logarithmic axes, the tickInterval is based on powers, so a
     * tickInterval of 1 means one tick on each of 0.1, 1, 10, 100 etc. A
     * tickInterval of 2 means a tick of 0.1, 10, 1000 etc. A tickInterval of
     * 0.2 puts a tick on 0.1, 0.2, 0.4, 0.6, 0.8, 1, 2, 4, 6, 8, 10, 20, 40
     * etc.
     *
     * If the tickInterval is too dense for labels to be drawn, Highcharts may
     * remove ticks.
     *
     * If the chart has multiple axes, the alignTicks option may interfere with
     * the `tickInterval` setting.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.tickInterval
     * @see https://api.highcharts.com/highstock/xAxis.tickInterval
     * @see https://api.highcharts.com/highmaps/xAxis.tickInterval
     * @see https://api.highcharts.com/gantt/xAxis.tickInterval
     */
    tickInterval?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel length of the main
     * tick marks.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.tickLength
     * @see https://api.highcharts.com/highstock/xAxis.tickLength
     * @see https://api.highcharts.com/highmaps/xAxis.tickLength
     * @see https://api.highcharts.com/gantt/xAxis.tickLength
     */
    tickLength?: number;
    /**
     * (Highcharts, Gantt) For categorized axes only. If `on` the tick mark is
     * placed in the center of the category, if `between` the tick mark is
     * placed between categories. The default is `between` if the `tickInterval`
     * is 1, else `on`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.tickmarkPlacement
     * @see https://api.highcharts.com/gantt/xAxis.tickmarkPlacement
     */
    tickmarkPlacement?: ("between"|"on");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) If tickInterval is `null` this
     * option sets the approximate pixel interval of the tick marks. Not
     * applicable to categorized axis.
     *
     * The tick interval is also influenced by the minTickInterval option, that,
     * by default prevents ticks from being denser than the data points.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.tickPixelInterval
     * @see https://api.highcharts.com/highstock/xAxis.tickPixelInterval
     * @see https://api.highcharts.com/highmaps/xAxis.tickPixelInterval
     * @see https://api.highcharts.com/gantt/xAxis.tickPixelInterval
     */
    tickPixelInterval?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The position of the major tick
     * marks relative to the axis line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.tickPosition
     * @see https://api.highcharts.com/highstock/xAxis.tickPosition
     * @see https://api.highcharts.com/highmaps/xAxis.tickPosition
     * @see https://api.highcharts.com/gantt/xAxis.tickPosition
     */
    tickPosition?: ("inside"|"outside");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A callback function returning
     * array defining where the ticks are laid out on the axis. This overrides
     * the default behaviour of tickPixelInterval and tickInterval. The
     * automatic tick positions are accessible through `this.tickPositions` and
     * can be modified by the callback.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.tickPositioner
     * @see https://api.highcharts.com/highstock/xAxis.tickPositioner
     * @see https://api.highcharts.com/highmaps/xAxis.tickPositioner
     * @see https://api.highcharts.com/gantt/xAxis.tickPositioner
     */
    tickPositioner?: AxisTickPositionerCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array defining where the
     * ticks are laid out on the axis. This overrides the default behaviour of
     * tickPixelInterval and tickInterval.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.tickPositions
     * @see https://api.highcharts.com/highstock/xAxis.tickPositions
     * @see https://api.highcharts.com/highmaps/xAxis.tickPositions
     * @see https://api.highcharts.com/gantt/xAxis.tickPositions
     */
    tickPositions?: Array<number>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the major
     * tick marks.
     *
     * In styled mode, the stroke width is given in the `.highcharts-tick`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.tickWidth
     * @see https://api.highcharts.com/highstock/xAxis.tickWidth
     * @see https://api.highcharts.com/highmaps/xAxis.tickWidth
     * @see https://api.highcharts.com/gantt/xAxis.tickWidth
     */
    tickWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The axis title, showing next to
     * the axis line.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title
     * @see https://api.highcharts.com/highstock/xAxis.title
     * @see https://api.highcharts.com/highmaps/xAxis.title
     * @see https://api.highcharts.com/gantt/xAxis.title
     */
    title?: XAxisTitleOptions;
    /**
     * (Highcharts, Gantt) The type of axis. Can be one of `linear`,
     * `logarithmic`, `datetime` or `category`. In a datetime axis, the numbers
     * are given in milliseconds, and tick marks are placed on appropriate
     * values like full hours or days. In a category axis, the point names of
     * the chart's series are used for categories, if not a categories array is
     * defined.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.type
     * @see https://api.highcharts.com/gantt/xAxis.type
     */
    type?: ("category"|"datetime"|"linear"|"logarithmic");
    /**
     * (Highcharts, Gantt) Applies only when the axis `type` is `category`. When
     * `uniqueNames` is true, points are placed on the X axis according to their
     * names. If the same point name is repeated in the same or another series,
     * the point is placed on the same X position as other points of the same
     * name. When `uniqueNames` is false, the points are laid out in increasing
     * X positions regardless of their names, and the X axis category will take
     * the name of the last point in each position.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.uniqueNames
     * @see https://api.highcharts.com/gantt/xAxis.uniqueNames
     */
    uniqueNames?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Datetime axis only. An array determining
     * what time intervals the ticks are allowed to fall on. Each array item is
     * an array where the first value is the time unit and the second value
     * another array of allowed multiples. Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/xAxis.units
     * @see https://api.highcharts.com/highstock/xAxis.units
     * @see https://api.highcharts.com/gantt/xAxis.units
     */
    units?: Array<[string, (Array<number>|null)]>;
    /**
     * (Highcharts, Highstock, Gantt) Whether axis, including axis title, line,
     * ticks and labels, should be visible.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.visible
     * @see https://api.highcharts.com/highstock/xAxis.visible
     * @see https://api.highcharts.com/gantt/xAxis.visible
     */
    visible?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label
 * @see https://api.highcharts.com/highstock/xAxis.plotBands.label
 * @see https://api.highcharts.com/gantt/xAxis.plotBands.label
 */
export interface XAxisPlotBandsLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label. Can be
     * one of "left", "center" or "right".
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label.align
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.label.align
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.label.align
     */
    align?: string;
    /**
     * (Highcharts, Highstock, Gantt) Rotation of the text label in degrees .
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label.rotation
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.label.rotation
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.label.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-band-label` class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label.style
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.label.style
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.label.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The string text itself. A subset of HTML
     * is supported.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label.text
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.label.text
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.label.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text alignment for the label. While
     * `align` determines where the texts anchor point is placed within the plot
     * band, `textAlign` determines how the text is aligned against its anchor
     * point. Possible values are "left", "center" and "right". Defaults to the
     * same as the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label.textAlign
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.label.textAlign
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.label.textAlign
     */
    textAlign?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label.useHTML
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.label.useHTML
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label relative
     * to the plot band. Can be one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label.verticalAlign
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.label.verticalAlign
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal position relative the
     * alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label.x
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.label.x
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.label.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical position of the text baseline
     * relative to the alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label.y
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.label.y
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.label.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of colored bands stretching across
 * the plot area marking an interval on the axis.
 *
 * In styled mode, the plot bands are styled by the `.highcharts-plot-band`
 * class in addition to the `className` option.
 *
 * @see https://api.highcharts.com/highcharts/xAxis.plotBands
 * @see https://api.highcharts.com/highstock/xAxis.plotBands
 * @see https://api.highcharts.com/gantt/xAxis.plotBands
 */
export interface XAxisPlotBandsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Border color for the plot band. Also
     * requires `borderWidth` to be set.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.borderColor
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.borderColor
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) Border width for the plot band. Also
     * requires `borderColor` to be set.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.borderWidth
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.borderWidth
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A custom class name, in addition to the
     * default `highcharts-plot-band`, to apply to each individual band.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.className
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.className
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The color of the plot band.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.color
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.color
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) An object defining mouse events for the
     * plot band. Supported properties are `click`, `mouseover`, `mouseout`,
     * `mousemove`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.events
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.events
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.events
     */
    events?: object;
    /**
     * (Highcharts, Highstock, Gantt) The start position of the plot band in
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.from
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.from
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.from
     */
    from?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id used for identifying the plot band
     * in Axis.removePlotBand.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.id
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.id
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.label
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.label
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.label
     */
    label?: XAxisPlotBandsLabelOptions;
    /**
     * (Highcharts, Highstock, Gantt) The end position of the plot band in axis
     * units.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.to
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.to
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.to
     */
    to?: number;
    /**
     * (Highcharts, Highstock, Gantt) The z index of the plot band within the
     * chart, relative to other elements. Using the same z index as another
     * element may give unpredictable results, as the last rendered element will
     * be on top. Values from 0 to 20 make sense.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotBands.zIndex
     * @see https://api.highcharts.com/highstock/xAxis.plotBands.zIndex
     * @see https://api.highcharts.com/gantt/xAxis.plotBands.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label
 * @see https://api.highcharts.com/highstock/xAxis.plotLines.label
 * @see https://api.highcharts.com/gantt/xAxis.plotLines.label
 */
export interface XAxisPlotLinesLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label. Can be
     * one of "left", "center" or "right".
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label.align
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.label.align
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.label.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Rotation of the text label in degrees.
     * Defaults to 0 for horizontal plot lines and 90 for vertical lines.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label.rotation
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.label.rotation
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.label.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-line-label` class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label.style
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.label.style
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.label.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The text itself. A subset of HTML is
     * supported.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label.text
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.label.text
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.label.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text alignment for the label. While
     * `align` determines where the texts anchor point is placed within the plot
     * band, `textAlign` determines how the text is aligned against its anchor
     * point. Possible values are "left", "center" and "right". Defaults to the
     * same as the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label.textAlign
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.label.textAlign
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.label.textAlign
     */
    textAlign?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label.useHTML
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.label.useHTML
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label relative
     * to the plot line. Can be one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label.verticalAlign
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.label.verticalAlign
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal position relative the
     * alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label.x
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.label.x
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.label.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical position of the text baseline
     * relative to the alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label.y
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.label.y
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.label.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of lines stretching across the plot
 * area, marking a specific value on one of the axes.
 *
 * In styled mode, the plot lines are styled by the `.highcharts-plot-line`
 * class in addition to the `className` option.
 *
 * @see https://api.highcharts.com/highcharts/xAxis.plotLines
 * @see https://api.highcharts.com/highstock/xAxis.plotLines
 * @see https://api.highcharts.com/gantt/xAxis.plotLines
 */
export interface XAxisPlotLinesOptions {
    /**
     * (Highcharts, Highstock, Gantt) A custom class name, in addition to the
     * default `highcharts-plot-line`, to apply to each individual line.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.className
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.className
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The color of the line.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.color
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.color
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The dashing or dot style for the plot
     * line. For possible values see this overview.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.dashStyle
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.dashStyle
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highstock, Gantt) An object defining mouse events for the
     * plot line. Supported properties are `click`, `mouseover`, `mouseout`,
     * `mousemove`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.events
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.events
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.events
     */
    events?: any;
    /**
     * (Highcharts, Highstock, Gantt) An id used for identifying the plot line
     * in Axis.removePlotLine.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.id
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.id
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.label
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.label
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.label
     */
    label?: XAxisPlotLinesLabelOptions;
    /**
     * (Highcharts, Highstock, Gantt) The position of the line in axis units.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.value
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.value
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.value
     */
    value?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width or thickness of the plot line.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.width
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.width
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.width
     */
    width?: number;
    /**
     * (Highcharts, Highstock, Gantt) The z index of the plot line within the
     * chart.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.plotLines.zIndex
     * @see https://api.highcharts.com/highstock/xAxis.plotLines.zIndex
     * @see https://api.highcharts.com/gantt/xAxis.plotLines.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) An optional scrollbar to display on the X axis in response to
 * limiting the minimum and maximum of the axis values.
 *
 * In styled mode, all the presentational options for the scrollbar are replaced
 * by the classes `.highcharts-scrollbar-thumb`, `.highcharts-scrollbar-arrow`,
 * `.highcharts-scrollbar-button`, `.highcharts-scrollbar-rifles` and
 * `.highcharts-scrollbar-track`.
 *
 * @see https://api.highcharts.com/highstock/xAxis.scrollbar
 */
export interface XAxisScrollbarOptions {
    /**
     * (Highstock) The background color of the scrollbar itself.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.barBackgroundColor
     */
    barBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the scrollbar's border.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.barBorderColor
     */
    barBorderColor?: ColorString;
    /**
     * (Highstock) The border rounding radius of the bar.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.barBorderRadius
     */
    barBorderRadius?: number;
    /**
     * (Highstock) The width of the bar's border.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.barBorderWidth
     */
    barBorderWidth?: number;
    /**
     * (Highstock) The color of the small arrow inside the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.buttonArrowColor
     */
    buttonArrowColor?: ColorString;
    /**
     * (Highstock) The color of scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.buttonBackgroundColor
     */
    buttonBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the border of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.buttonBorderColor
     */
    buttonBorderColor?: ColorString;
    /**
     * (Highstock) The corner radius of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.buttonBorderRadius
     */
    buttonBorderRadius?: number;
    /**
     * (Highstock) The border width of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.buttonBorderWidth
     */
    buttonBorderWidth?: number;
    /**
     * (Highstock) Enable or disable the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The height of the scrollbar. The height also applies to the
     * width of the scroll arrows so that they are always squares. Defaults to
     * 20 for touch devices and 14 for mouse devices.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.height
     */
    height?: number;
    /**
     * (Highstock) Whether to redraw the main chart as the scrollbar or the
     * navigator zoomed window is moved. Defaults to `true` for modern browsers
     * and `false` for legacy IE browsers as well as mobile devices.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.liveRedraw
     */
    liveRedraw?: boolean;
    /**
     * (Highstock) The margin between the scrollbar and its axis when the
     * scrollbar is applied directly to an axis.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.margin
     */
    margin?: number;
    /**
     * (Highstock) The minimum width of the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.minWidth
     */
    minWidth?: number;
    /**
     * (Highstock) The color of the small rifles in the middle of the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.rifleColor
     */
    rifleColor?: ColorString;
    /**
     * (Highstock) Whether to show or hide the scrollbar when the scrolled
     * content is zoomed out to it full extent.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.showFull
     */
    showFull?: boolean;
    step?: number;
    /**
     * (Highstock) The color of the track background.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.trackBackgroundColor
     */
    trackBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.trackBorderColor
     */
    trackBorderColor?: ColorString;
    /**
     * (Highstock) The corner radius of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.trackBorderRadius
     */
    trackBorderRadius?: number;
    /**
     * (Highstock) The width of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.trackBorderWidth
     */
    trackBorderWidth?: number;
    /**
     * (Highstock) The z index of the scrollbar group.
     *
     * @see https://api.highcharts.com/highstock/xAxis.scrollbar.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The axis title, showing next to the
 * axis line.
 *
 * @see https://api.highcharts.com/highcharts/xAxis.title
 * @see https://api.highcharts.com/highstock/xAxis.title
 * @see https://api.highcharts.com/highmaps/xAxis.title
 * @see https://api.highcharts.com/gantt/xAxis.title
 */
export interface XAxisTitleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Alignment of the title relative
     * to the axis values. Possible values are "low", "middle" or "high".
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.align
     * @see https://api.highcharts.com/highstock/xAxis.title.align
     * @see https://api.highcharts.com/highmaps/xAxis.title.align
     * @see https://api.highcharts.com/gantt/xAxis.title.align
     */
    align?: ("high"|"low"|"middle");
    /**
     * (Highcharts) Deprecated. Set the `text` to `null` to disable the title.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.enabled
     */
    enabled?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel distance between the
     * axis labels or line and the title. Defaults to 0 for horizontal axes, 10
     * for vertical
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.margin
     * @see https://api.highcharts.com/highstock/xAxis.title.margin
     * @see https://api.highcharts.com/highmaps/xAxis.title.margin
     * @see https://api.highcharts.com/gantt/xAxis.title.margin
     */
    margin?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The distance of the axis title
     * from the axis line. By default, this distance is computed from the offset
     * width of the labels, the labels' distance from the axis and the title's
     * margin. However when the offset option is set, it overrides all this.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.offset
     * @see https://api.highcharts.com/highstock/xAxis.title.offset
     * @see https://api.highcharts.com/highmaps/xAxis.title.offset
     * @see https://api.highcharts.com/gantt/xAxis.title.offset
     */
    offset?: number;
    /**
     * (Highcharts) Defines how the title is repositioned according to the 3D
     * chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * - `undefined`: Will use the config from `labels.position3d`
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho"|null);
    /**
     * (Highcharts, Highstock, Gantt) Whether to reserve space for the title
     * when laying out the axis.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.reserveSpace
     * @see https://api.highcharts.com/highstock/xAxis.title.reserveSpace
     * @see https://api.highcharts.com/gantt/xAxis.title.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The rotation of the text in
     * degrees. 0 is horizontal, 270 is vertical reading from bottom to top.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.rotation
     * @see https://api.highcharts.com/highstock/xAxis.title.rotation
     * @see https://api.highcharts.com/highmaps/xAxis.title.rotation
     * @see https://api.highcharts.com/gantt/xAxis.title.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis title will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `title.position3d`.
     *
     * A `null` value will use the config from `labels.skew3d`.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.skew3d
     */
    skew3d?: (boolean|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the title. If the
     * title text is longer than the axis length, it will wrap to multiple lines
     * by default. This can be customized by setting `textOverflow: 'ellipsis'`,
     * by setting a specific `width` or by setting `whiteSpace: 'nowrap'`.
     *
     * In styled mode, the stroke width is given in the `.highcharts-axis-title`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.style
     * @see https://api.highcharts.com/highstock/xAxis.title.style
     * @see https://api.highcharts.com/highmaps/xAxis.title.style
     * @see https://api.highcharts.com/gantt/xAxis.title.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The actual text of the axis
     * title. It can contain basic HTML text markup like <b>, <i> and spans with
     * style.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.text
     * @see https://api.highcharts.com/highstock/xAxis.title.text
     * @see https://api.highcharts.com/highmaps/xAxis.title.text
     * @see https://api.highcharts.com/gantt/xAxis.title.text
     */
    text?: (string|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Alignment of the text, can be
     * `"left"`, `"right"` or `"center"`. Default alignment depends on the
     * title.align:
     *
     * Horizontal axes:
     *
     * - for `align` = `"low"`, `textAlign` is set to `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"`, `textAlign` is set to `right`
     *
     * Vertical axes:
     *
     * - for `align` = `"low"` and `opposite` = `true`, `textAlign` is set to
     * `right`
     *
     * - for `align` = `"low"` and `opposite` = `false`, `textAlign` is set to
     * `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"` and `opposite` = `true` `textAlign` is set to
     * `left`
     *
     * - for `align` = `"high"` and `opposite` = `false` `textAlign` is set to
     * `right`
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.textAlign
     * @see https://api.highcharts.com/highstock/xAxis.title.textAlign
     * @see https://api.highcharts.com/highmaps/xAxis.title.textAlign
     * @see https://api.highcharts.com/gantt/xAxis.title.textAlign
     */
    textAlign?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the axis
     * title.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.useHTML
     * @see https://api.highcharts.com/highstock/xAxis.title.useHTML
     * @see https://api.highcharts.com/gantt/xAxis.title.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Horizontal pixel offset of the title
     * position.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.x
     * @see https://api.highcharts.com/highstock/xAxis.title.x
     * @see https://api.highcharts.com/gantt/xAxis.title.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical pixel offset of the title
     * position.
     *
     * @see https://api.highcharts.com/highcharts/xAxis.title.y
     * @see https://api.highcharts.com/highstock/xAxis.title.y
     * @see https://api.highcharts.com/gantt/xAxis.title.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array defining breaks in the axis, the
 * sections defined will be left out and all the points shifted closer to each
 * other.
 *
 * @see https://api.highcharts.com/highcharts/yAxis.breaks
 * @see https://api.highcharts.com/highstock/yAxis.breaks
 * @see https://api.highcharts.com/gantt/yAxis.breaks
 */
export interface YAxisBreaksOptions {
    /**
     * (Highcharts, Highstock, Gantt) A number indicating how much space should
     * be left between the start and the end of the break. The break size is
     * given in axis units, so for instance on a `datetime` axis, a break size
     * of 3600000 would indicate the equivalent of an hour.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.breaks.breakSize
     * @see https://api.highcharts.com/highstock/yAxis.breaks.breakSize
     * @see https://api.highcharts.com/gantt/yAxis.breaks.breakSize
     */
    breakSize?: number;
    /**
     * (Highcharts, Highstock, Gantt) The point where the break starts.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.breaks.from
     * @see https://api.highcharts.com/highstock/yAxis.breaks.from
     * @see https://api.highcharts.com/gantt/yAxis.breaks.from
     */
    from?: number;
    /**
     * (Highcharts, Highstock, Gantt) Defines an interval after which the break
     * appears again. By default the breaks do not repeat.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.breaks.repeat
     * @see https://api.highcharts.com/highstock/yAxis.breaks.repeat
     * @see https://api.highcharts.com/gantt/yAxis.breaks.repeat
     */
    repeat?: number;
    /**
     * (Highcharts, Highstock, Gantt) The point where the break ends.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.breaks.to
     * @see https://api.highcharts.com/highstock/yAxis.breaks.to
     * @see https://api.highcharts.com/gantt/yAxis.breaks.to
     */
    to?: number;
}
/**
 * (Highstock) A label on the axis next to the crosshair.
 *
 * In styled mode, the label is styled with the `.highcharts-crosshair-label`
 * class.
 *
 * @see https://api.highcharts.com/highstock/yAxis.crosshair.label
 */
export interface YAxisCrosshairLabelOptions {
    /**
     * (Highstock) Alignment of the label compared to the axis. Defaults to
     * `left` for right-side axes, `right` for left-side axes and `center` for
     * horizontal axes.
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label.align
     */
    align?: string;
    /**
     * (Highstock) The background color for the label. Defaults to the related
     * series color, or `#666666` if that is not available.
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label.backgroundColor
     */
    backgroundColor?: (ColorString|GradientColorObject|PatternObject);
    /**
     * (Highstock) The border color for the crosshair label
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highstock) The border corner radius of the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label.borderRadius
     */
    borderRadius?: number;
    /**
     * (Highstock) The border width for the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highstock) A format string for the crosshair label. Defaults to
     * `{value}` for numeric axes and `{value:%b %d, %Y}` for datetime axes.
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label.format
     */
    format?: string;
    /**
     * (Highstock) Formatter function for the label text.
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label.formatter
     */
    formatter?: FormatterCallbackFunction<object>;
    /**
     * (Highstock) Padding inside the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label.padding
     */
    padding?: number;
    /**
     * (Highstock) The shape to use for the label box.
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label.shape
     */
    shape?: string;
    /**
     * (Highstock) Text styles for the crosshair label.
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label.style
     */
    style?: CSSObject;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Configure a crosshair that follows
 * either the mouse pointer or the hovered point.
 *
 * In styled mode, the crosshairs are styled in the `.highcharts-crosshair`,
 * `.highcharts-crosshair-thin` or `.highcharts-xaxis-category` classes.
 *
 * @see https://api.highcharts.com/highcharts/yAxis.crosshair
 * @see https://api.highcharts.com/highstock/yAxis.crosshair
 * @see https://api.highcharts.com/highmaps/yAxis.crosshair
 * @see https://api.highcharts.com/gantt/yAxis.crosshair
 */
export interface YAxisCrosshairOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A class name for the crosshair,
     * especially as a hook for styling.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.crosshair.className
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.className
     * @see https://api.highcharts.com/highmaps/yAxis.crosshair.className
     * @see https://api.highcharts.com/gantt/yAxis.crosshair.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the crosshair.
     * Defaults to `#cccccc` for numeric and datetime axes, and
     * `rgba(204,214,235,0.25)` for category axes, where the crosshair by
     * default highlights the whole category.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.crosshair.color
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.color
     * @see https://api.highcharts.com/highmaps/yAxis.crosshair.color
     * @see https://api.highcharts.com/gantt/yAxis.crosshair.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The dash style for the
     * crosshair. See series.dashStyle for possible values.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.crosshair.dashStyle
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.dashStyle
     * @see https://api.highcharts.com/highmaps/yAxis.crosshair.dashStyle
     * @see https://api.highcharts.com/gantt/yAxis.crosshair.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highstock) A label on the axis next to the crosshair.
     *
     * In styled mode, the label is styled with the
     * `.highcharts-crosshair-label` class.
     *
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.label
     */
    label?: YAxisCrosshairLabelOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether the crosshair should
     * snap to the point or follow the pointer independent of points.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.crosshair.snap
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.snap
     * @see https://api.highcharts.com/highmaps/yAxis.crosshair.snap
     * @see https://api.highcharts.com/gantt/yAxis.crosshair.snap
     */
    snap?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the
     * crosshair. Defaults to 1 for numeric or datetime axes, and for one
     * category width for category axes.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.crosshair.width
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.width
     * @see https://api.highcharts.com/highmaps/yAxis.crosshair.width
     * @see https://api.highcharts.com/gantt/yAxis.crosshair.width
     */
    width?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Z index of the crosshair.
     * Higher Z indices allow drawing the crosshair on top of the series or
     * behind the grid lines.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.crosshair.zIndex
     * @see https://api.highcharts.com/highstock/yAxis.crosshair.zIndex
     * @see https://api.highcharts.com/highmaps/yAxis.crosshair.zIndex
     * @see https://api.highcharts.com/gantt/yAxis.crosshair.zIndex
     */
    zIndex?: number;
}
export interface YAxisDateTimeLabelFormatsDayOptions {
    main?: string;
}
export interface YAxisDateTimeLabelFormatsHourOptions {
    main?: string;
    range?: boolean;
}
export interface YAxisDateTimeLabelFormatsMillisecondOptions {
    main?: string;
    range?: boolean;
}
export interface YAxisDateTimeLabelFormatsMinuteOptions {
    main?: string;
    range?: boolean;
}
export interface YAxisDateTimeLabelFormatsMonthOptions {
    main?: string;
}
/**
 * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
 * automatically adjust to the appropriate unit. This member gives the default
 * string representations used for each unit. For intermediate values, different
 * units may be used, for example the `day` unit can be used on midnight and
 * `hour` unit be used for intermediate values on the same axis. For an overview
 * of the replacement codes, see dateFormat. Defaults to:
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/yAxis.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/yAxis.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/yAxis.dateTimeLabelFormats
 */
export interface YAxisDateTimeLabelFormatsOptions {
    day?: YAxisDateTimeLabelFormatsDayOptions;
    hour?: YAxisDateTimeLabelFormatsHourOptions;
    millisecond?: YAxisDateTimeLabelFormatsMillisecondOptions;
    minute?: YAxisDateTimeLabelFormatsMinuteOptions;
    month?: YAxisDateTimeLabelFormatsMonthOptions;
    second?: YAxisDateTimeLabelFormatsSecondOptions;
    week?: YAxisDateTimeLabelFormatsWeekOptions;
    year?: YAxisDateTimeLabelFormatsYearOptions;
}
export interface YAxisDateTimeLabelFormatsSecondOptions {
    main?: string;
    range?: boolean;
}
export interface YAxisDateTimeLabelFormatsWeekOptions {
    main?: string;
}
export interface YAxisDateTimeLabelFormatsYearOptions {
    main?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Event handlers for the axis.
 *
 * @see https://api.highcharts.com/highcharts/yAxis.events
 * @see https://api.highcharts.com/highstock/yAxis.events
 * @see https://api.highcharts.com/highmaps/yAxis.events
 * @see https://api.highcharts.com/gantt/yAxis.events
 */
export interface YAxisEventsOptions {
    /**
     * (Highcharts, Gantt) An event fired after the breaks have rendered.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.events.afterBreaks
     * @see https://api.highcharts.com/gantt/yAxis.events.afterBreaks
     */
    afterBreaks?: AxisEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) As opposed to the `setExtremes`
     * event, this event fires after the final min and max values are computed
     * and corrected for `minRange`.
     *
     * Fires when the minimum and maximum is set for the axis, either by calling
     * the `.setExtremes()` method or by selecting an area in the chart. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in axis
     * values. The actual data extremes are found in `event.dataMin` and
     * `event.dataMax`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.events.afterSetExtremes
     * @see https://api.highcharts.com/highstock/yAxis.events.afterSetExtremes
     * @see https://api.highcharts.com/highmaps/yAxis.events.afterSetExtremes
     * @see https://api.highcharts.com/gantt/yAxis.events.afterSetExtremes
     */
    afterSetExtremes?: AxisEventCallbackFunction;
    /**
     * (Highcharts, Gantt) An event fired when a break from this axis occurs on
     * a point.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.events.pointBreak
     * @see https://api.highcharts.com/gantt/yAxis.events.pointBreak
     */
    pointBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) An event fired when a point falls inside a
     * break from this axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.events.pointInBreak
     * @see https://api.highcharts.com/highstock/yAxis.events.pointInBreak
     * @see https://api.highcharts.com/gantt/yAxis.events.pointInBreak
     */
    pointInBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the minimum and
     * maximum is set for the axis, either by calling the `.setExtremes()`
     * method or by selecting an area in the chart. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in data
     * values. When an axis is zoomed all the way out from the "Reset zoom"
     * button, `event.min` and `event.max` are null, and the new extremes are
     * set based on `this.dataMin` and `this.dataMax`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.events.setExtremes
     * @see https://api.highcharts.com/highstock/yAxis.events.setExtremes
     * @see https://api.highcharts.com/highmaps/yAxis.events.setExtremes
     * @see https://api.highcharts.com/gantt/yAxis.events.setExtremes
     */
    setExtremes?: AxisSetExtremesEventCallbackFunction;
}
/**
 * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
 *
 * @see https://api.highcharts.com/gantt/yAxis.grid
 */
export interface YAxisGridOptions {
    /**
     * (Gantt) Set border color for the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/yAxis.grid.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Gantt) Set border width of the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/yAxis.grid.borderWidth
     */
    borderWidth?: number;
    /**
     * (Gantt) Set cell height for grid axis labels. By default this is
     * calculated from font size.
     *
     * @see https://api.highcharts.com/gantt/yAxis.grid.cellHeight
     */
    cellHeight?: number;
    /**
     * (Gantt) Set specific options for each column (or row for horizontal axes)
     * in the grid. Each extra column/row is its own axis, and the axis options
     * can be set here.
     *
     * @see https://api.highcharts.com/gantt/yAxis.grid.columns
     */
    columns?: Array<XAxisOptions>;
    /**
     * (Gantt) Enable grid on the axis labels. Defaults to true for Gantt
     * charts.
     *
     * @see https://api.highcharts.com/gantt/yAxis.grid.enabled
     */
    enabled?: boolean;
}
/**
 * (Gantt) Set options on specific levels in a tree grid axis. Takes precedence
 * over labels options.
 *
 * @see https://api.highcharts.com/gantt/yAxis.labels.levels
 */
export interface YAxisLabelsLevelsOptions {
    /**
     * (Gantt) Specify the level which the options within this object applies
     * to.
     *
     * @see https://api.highcharts.com/gantt/yAxis.labels.levels.level
     */
    level?: number;
    style?: CSSObject;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The axis labels show the number or
 * category for each tick.
 *
 * @see https://api.highcharts.com/highcharts/yAxis.labels
 * @see https://api.highcharts.com/highstock/yAxis.labels
 * @see https://api.highcharts.com/highmaps/yAxis.labels
 * @see https://api.highcharts.com/gantt/yAxis.labels
 */
export interface YAxisLabelsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) What part of the string the
     * given position is anchored to. Can be one of `"left"`, `"center"` or
     * `"right"`. The exact position also depends on the `labels.x` setting.
     *
     * Angular gauges and solid gauges defaults to `center`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.align
     * @see https://api.highcharts.com/highstock/yAxis.labels.align
     * @see https://api.highcharts.com/highmaps/yAxis.labels.align
     * @see https://api.highcharts.com/gantt/yAxis.labels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) For horizontal axes, the allowed degrees
     * of label rotation to prevent overlapping labels. If there is enough
     * space, labels are not rotated. As the chart gets narrower, it will start
     * rotating the labels -45 degrees, then remove every second label and try
     * again with rotations 0 and -45 etc. Set it to `false` to disable
     * rotation, which will cause the labels to word-wrap if possible.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.autoRotation
     * @see https://api.highcharts.com/highstock/yAxis.labels.autoRotation
     * @see https://api.highcharts.com/gantt/yAxis.labels.autoRotation
     */
    autoRotation?: Array<number>;
    /**
     * (Highcharts, Gantt) When each category width is more than this many
     * pixels, we don't apply auto rotation. Instead, we lay out the axis label
     * with word wrap. A lower limit makes sense when the label contains
     * multiple short words that don't extend the available horizontal space for
     * each label.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.autoRotationLimit
     * @see https://api.highcharts.com/gantt/yAxis.labels.autoRotationLimit
     */
    autoRotationLimit?: number;
    /**
     * (Highcharts) Angular gauges and solid gauges only. The label's pixel
     * distance from the perimeter of the plot area.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.distance
     */
    distance?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the axis
     * labels.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.enabled
     * @see https://api.highcharts.com/highstock/yAxis.labels.enabled
     * @see https://api.highcharts.com/highmaps/yAxis.labels.enabled
     * @see https://api.highcharts.com/gantt/yAxis.labels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A format string for the axis
     * label.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.format
     * @see https://api.highcharts.com/highstock/yAxis.labels.format
     * @see https://api.highcharts.com/highmaps/yAxis.labels.format
     * @see https://api.highcharts.com/gantt/yAxis.labels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback JavaScript function to
     * format the label. The value is given by `this.value`. Additional
     * properties for `this` are `axis`, `chart`, `isFirst` and `isLast`. The
     * value of the default label formatter can be retrieved by calling
     * `this.axis.defaultLabelFormatter.call(this)` within the function.
     *
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.formatter
     * @see https://api.highcharts.com/highstock/yAxis.labels.formatter
     * @see https://api.highcharts.com/highmaps/yAxis.labels.formatter
     * @see https://api.highcharts.com/gantt/yAxis.labels.formatter
     */
    formatter?: FormatterCallbackFunction<AxisLabelsFormatterContextObject>;
    /**
     * (Gantt) The number of pixels to indent the labels per level in a treegrid
     * axis.
     *
     * @see https://api.highcharts.com/gantt/yAxis.labels.indentation
     */
    indentation?: number;
    /**
     * (Gantt) Set options on specific levels in a tree grid axis. Takes
     * precedence over labels options.
     *
     * @see https://api.highcharts.com/gantt/yAxis.labels.levels
     */
    levels?: Array<YAxisLabelsLevelsOptions>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Horizontal axis only. When
     * `staggerLines` is not set, `maxStaggerLines` defines how many lines the
     * axis is allowed to add to automatically avoid overlapping X labels. Set
     * to `1` to disable overlap detection.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.maxStaggerLines
     * @see https://api.highcharts.com/highstock/yAxis.labels.maxStaggerLines
     * @see https://api.highcharts.com/highmaps/yAxis.labels.maxStaggerLines
     * @see https://api.highcharts.com/gantt/yAxis.labels.maxStaggerLines
     */
    maxStaggerLines?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) How to handle overflowing labels
     * on horizontal axis. If set to `"allow"`, it will not be aligned at all.
     * By default it `"justify"` labels inside the chart area. If there is room
     * to move it, it will be aligned to the edge, else it will be removed.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.overflow
     * @see https://api.highcharts.com/highstock/yAxis.labels.overflow
     * @see https://api.highcharts.com/highmaps/yAxis.labels.overflow
     * @see https://api.highcharts.com/gantt/yAxis.labels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Gantt) The pixel padding for axis labels, to ensure white
     * space between them.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.padding
     * @see https://api.highcharts.com/gantt/yAxis.labels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Defines how the labels are be repositioned according to the
     * 3D chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho");
    /**
     * (Highcharts, Gantt) Whether to reserve space for the labels. By default,
     * space is reserved for the labels in these cases:
     *
     * * On all horizontal axes.
     *
     * * On vertical axes if `label.align` is `right` on a left-side axis or
     * `left` on a right-side axis.
     *
     * * On vertical axes if `label.align` is `center`.
     *
     * This can be turned off when for example the labels are rendered inside
     * the plot area instead of outside.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.reserveSpace
     * @see https://api.highcharts.com/gantt/yAxis.labels.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Rotation of the labels in
     * degrees.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.rotation
     * @see https://api.highcharts.com/highstock/yAxis.labels.rotation
     * @see https://api.highcharts.com/highmaps/yAxis.labels.rotation
     * @see https://api.highcharts.com/gantt/yAxis.labels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis labels will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `labels.position3d`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.skew3d
     */
    skew3d?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Horizontal axes only. The number
     * of lines to spread the labels over to make room or tighter labels.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.staggerLines
     * @see https://api.highcharts.com/highstock/yAxis.labels.staggerLines
     * @see https://api.highcharts.com/highmaps/yAxis.labels.staggerLines
     * @see https://api.highcharts.com/gantt/yAxis.labels.staggerLines
     */
    staggerLines?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) To show only every _n_'th label
     * on the axis, set the step to _n_. Setting the step to 2 shows every other
     * label.
     *
     * By default, the step is calculated automatically to avoid overlap. To
     * prevent this, set it to 1\. This usually only happens on a category axis,
     * and is often a sign that you have chosen the wrong axis type.
     *
     * Read more at Axis docs => What axis should I use?
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.step
     * @see https://api.highcharts.com/highstock/yAxis.labels.step
     * @see https://api.highcharts.com/highmaps/yAxis.labels.step
     * @see https://api.highcharts.com/gantt/yAxis.labels.step
     */
    step?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the label. Use
     * `whiteSpace: 'nowrap'` to prevent wrapping of category labels. Use
     * `textOverflow: 'none'` to prevent ellipsis (dots).
     *
     * In styled mode, the labels are styled with the `.highcharts-axis-labels`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.style
     * @see https://api.highcharts.com/highstock/yAxis.labels.style
     * @see https://api.highcharts.com/highmaps/yAxis.labels.style
     * @see https://api.highcharts.com/gantt/yAxis.labels.style
     */
    style?: CSSObject;
    /**
     * (Gantt) The symbol for the collapse and expand icon in a treegrid.
     *
     * @see https://api.highcharts.com/gantt/yAxis.labels.symbol
     */
    symbol?: YAxisLabelsSymbolOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render
     * the labels.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.useHTML
     * @see https://api.highcharts.com/highstock/yAxis.labels.useHTML
     * @see https://api.highcharts.com/highmaps/yAxis.labels.useHTML
     * @see https://api.highcharts.com/gantt/yAxis.labels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position offset of the
     * label relative to the tick position on the axis. Defaults to -15 for left
     * axis, 15 for right axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.x
     * @see https://api.highcharts.com/highstock/yAxis.labels.x
     * @see https://api.highcharts.com/highmaps/yAxis.labels.x
     * @see https://api.highcharts.com/gantt/yAxis.labels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position offset of the
     * label relative to the tick position on the axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.y
     * @see https://api.highcharts.com/highstock/yAxis.labels.y
     * @see https://api.highcharts.com/highmaps/yAxis.labels.y
     * @see https://api.highcharts.com/gantt/yAxis.labels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Z index for the axis labels.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels.zIndex
     * @see https://api.highcharts.com/highstock/yAxis.labels.zIndex
     * @see https://api.highcharts.com/highmaps/yAxis.labels.zIndex
     * @see https://api.highcharts.com/gantt/yAxis.labels.zIndex
     */
    zIndex?: number;
}
/**
 * (Gantt) The symbol for the collapse and expand icon in a treegrid.
 *
 * @see https://api.highcharts.com/gantt/yAxis.labels.symbol
 */
export interface YAxisLabelsSymbolOptions {
    height?: number;
    padding?: number;
    /**
     * (Gantt) The symbol type. Points to a definition function in the
     * `Highcharts.Renderer.symbols` collection.
     *
     * @see https://api.highcharts.com/gantt/yAxis.labels.symbol.type
     */
    type?: ("arc"|"circle"|"diamond"|"square"|"triangle"|"triangle-down");
    width?: number;
    x?: number;
    y?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The Y axis or value axis. Normally
 * this is the vertical axis, though if the chart is inverted this is the
 * horizontal axis. In case of multiple axes, the yAxis node is an array of
 * configuration objects.
 *
 * See the Axis object for programmatic access to the axis.
 *
 * @see https://api.highcharts.com/highcharts/yAxis
 * @see https://api.highcharts.com/highstock/yAxis
 * @see https://api.highcharts.com/highmaps/yAxis
 * @see https://api.highcharts.com/gantt/yAxis
 */
export interface YAxisOptions {
    /**
     * (Highcharts, Highstock, Gantt) When using multiple axis, the ticks of two
     * or more opposite axes will automatically be aligned by adding ticks to
     * the axis or axes with the least ticks, as if `tickAmount` were specified.
     *
     * This can be prevented by setting `alignTicks` to false. If the grid lines
     * look messy, it's a good idea to hide them for the secondary axis by
     * setting `gridLineWidth` to 0.
     *
     * If `startOnTick` or `endOnTick` in an Axis options are set to false, then
     * the `alignTicks ` will be disabled for the Axis.
     *
     * Disabled for logarithmic axes.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.alignTicks
     * @see https://api.highcharts.com/highstock/yAxis.alignTicks
     * @see https://api.highcharts.com/gantt/yAxis.alignTicks
     */
    alignTicks?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to allow decimals in
     * this axis' ticks. When counting integers, like persons or hits on a web
     * page, decimals should be avoided in the labels.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.allowDecimals
     * @see https://api.highcharts.com/highstock/yAxis.allowDecimals
     * @see https://api.highcharts.com/highmaps/yAxis.allowDecimals
     * @see https://api.highcharts.com/gantt/yAxis.allowDecimals
     */
    allowDecimals?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When using an alternate grid
     * color, a band is painted across the plot area between every other grid
     * line.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.alternateGridColor
     * @see https://api.highcharts.com/highstock/yAxis.alternateGridColor
     * @see https://api.highcharts.com/highmaps/yAxis.alternateGridColor
     * @see https://api.highcharts.com/gantt/yAxis.alternateGridColor
     */
    alternateGridColor?: ColorString;
    /**
     * (Highcharts) In a polar chart, this is the angle of the Y axis in
     * degrees, where 0 is up and 90 is right. The angle determines the position
     * of the axis line and the labels, though the coordinate system is
     * unaffected.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.angle
     */
    angle?: number;
    /**
     * (Highcharts, Highstock, Gantt) An array defining breaks in the axis, the
     * sections defined will be left out and all the points shifted closer to
     * each other.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.breaks
     * @see https://api.highcharts.com/highstock/yAxis.breaks
     * @see https://api.highcharts.com/gantt/yAxis.breaks
     */
    breaks?: Array<YAxisBreaksOptions>;
    /**
     * (Highcharts, Gantt) If categories are present for the xAxis, names are
     * used instead of numbers for that axis. Since Highcharts 3.0, categories
     * can also be extracted by giving each point a name and setting axis type
     * to `category`. However, if you have multiple series, best practice
     * remains defining the `categories` array.
     *
     * Example:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/yAxis.categories
     * @see https://api.highcharts.com/gantt/yAxis.categories
     */
    categories?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) The highest allowed value for
     * automatically computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.ceiling
     * @see https://api.highcharts.com/highstock/yAxis.ceiling
     * @see https://api.highcharts.com/gantt/yAxis.ceiling
     */
    ceiling?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A class name that opens for
     * styling the axis by CSS, especially in Highcharts styled mode. The class
     * name is applied to group elements for the grid, axis elements and labels.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.className
     * @see https://api.highcharts.com/highstock/yAxis.className
     * @see https://api.highcharts.com/highmaps/yAxis.className
     * @see https://api.highcharts.com/gantt/yAxis.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Configure a crosshair that
     * follows either the mouse pointer or the hovered point.
     *
     * In styled mode, the crosshairs are styled in the `.highcharts-crosshair`,
     * `.highcharts-crosshair-thin` or `.highcharts-xaxis-category` classes.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.crosshair
     * @see https://api.highcharts.com/highstock/yAxis.crosshair
     * @see https://api.highcharts.com/highmaps/yAxis.crosshair
     * @see https://api.highcharts.com/gantt/yAxis.crosshair
     */
    crosshair?: (boolean|YAxisCrosshairOptions);
    /**
     * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
     * automatically adjust to the appropriate unit. This member gives the
     * default string representations used for each unit. For intermediate
     * values, different units may be used, for example the `day` unit can be
     * used on midnight and `hour` unit be used for intermediate values on the
     * same axis. For an overview of the replacement codes, see dateFormat.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/yAxis.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/yAxis.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/yAxis.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: YAxisDateTimeLabelFormatsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) _Requires Accessibility module_
     *
     * Description of the axis to screen reader users.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.description
     * @see https://api.highcharts.com/highstock/yAxis.description
     * @see https://api.highcharts.com/highmaps/yAxis.description
     * @see https://api.highcharts.com/gantt/yAxis.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to force the axis to end
     * on a tick. Use this option with the `maxPadding` option to control the
     * axis end.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.endOnTick
     * @see https://api.highcharts.com/highstock/yAxis.endOnTick
     * @see https://api.highcharts.com/highmaps/yAxis.endOnTick
     * @see https://api.highcharts.com/gantt/yAxis.endOnTick
     */
    endOnTick?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Event handlers for the axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.events
     * @see https://api.highcharts.com/highstock/yAxis.events
     * @see https://api.highcharts.com/highmaps/yAxis.events
     * @see https://api.highcharts.com/gantt/yAxis.events
     */
    events?: YAxisEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) The lowest allowed value for automatically
     * computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.floor
     * @see https://api.highcharts.com/highstock/yAxis.floor
     * @see https://api.highcharts.com/gantt/yAxis.floor
     */
    floor?: number;
    /**
     * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
     *
     * @see https://api.highcharts.com/gantt/yAxis.grid
     */
    grid?: YAxisGridOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the grid lines
     * extending the ticks across the plot area.
     *
     * In styled mode, the stroke is given in the `.highcharts-grid-line` class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.gridLineColor
     * @see https://api.highcharts.com/highstock/yAxis.gridLineColor
     * @see https://api.highcharts.com/highmaps/yAxis.gridLineColor
     * @see https://api.highcharts.com/gantt/yAxis.gridLineColor
     */
    gridLineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The dash or dot style of the
     * grid lines. For possible values, see this demonstration.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.gridLineDashStyle
     * @see https://api.highcharts.com/highstock/yAxis.gridLineDashStyle
     * @see https://api.highcharts.com/highmaps/yAxis.gridLineDashStyle
     * @see https://api.highcharts.com/gantt/yAxis.gridLineDashStyle
     */
    gridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts) Polar charts only. Whether the grid lines should draw as a
     * polygon with straight lines between categories, or as circles. Can be
     * either `circle` or `polygon`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.gridLineInterpolation
     */
    gridLineInterpolation?: ("circle"|"polygon");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the grid lines
     * extending the ticks across the plot area.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.gridLineWidth
     * @see https://api.highcharts.com/highstock/yAxis.gridLineWidth
     * @see https://api.highcharts.com/highmaps/yAxis.gridLineWidth
     * @see https://api.highcharts.com/gantt/yAxis.gridLineWidth
     */
    gridLineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The Z index of the grid lines.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.gridZIndex
     * @see https://api.highcharts.com/highstock/yAxis.gridZIndex
     * @see https://api.highcharts.com/gantt/yAxis.gridZIndex
     */
    gridZIndex?: number;
    /**
     * (Highstock) The height of the Y axis. If it's a number, it is interpreted
     * as pixels.
     *
     * Since Highstock 2: If it's a percentage string, it is interpreted as
     * percentages of the total plot height.
     *
     * @see https://api.highcharts.com/highstock/yAxis.height
     */
    height?: (number|string);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An id for the axis. This can be
     * used after render time to get a pointer to the axis object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.id
     * @see https://api.highcharts.com/highstock/yAxis.id
     * @see https://api.highcharts.com/highmaps/yAxis.id
     * @see https://api.highcharts.com/gantt/yAxis.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The axis labels show the number
     * or category for each tick.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.labels
     * @see https://api.highcharts.com/highstock/yAxis.labels
     * @see https://api.highcharts.com/highmaps/yAxis.labels
     * @see https://api.highcharts.com/gantt/yAxis.labels
     */
    labels?: YAxisLabelsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The color of the line marking
     * the axis itself.
     *
     * In styled mode, the line stroke is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.lineColor
     * @see https://api.highcharts.com/highstock/yAxis.lineColor
     * @see https://api.highcharts.com/highmaps/yAxis.lineColor
     * @see https://api.highcharts.com/gantt/yAxis.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the line marking
     * the axis itself.
     *
     * In styled mode, the stroke width is given in the `.highcharts-axis-line`
     * or `.highcharts-xaxis-line` class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.lineWidth
     * @see https://api.highcharts.com/highstock/yAxis.lineWidth
     * @see https://api.highcharts.com/highmaps/yAxis.lineWidth
     * @see https://api.highcharts.com/gantt/yAxis.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Index of another axis that this axis is
     * linked to. When an axis is linked to a master axis, it will take the same
     * extremes as the master, but as assigned by min or max or by setExtremes.
     * It can be used to show additional info, or to ease reading the chart by
     * duplicating the scales.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.linkedTo
     * @see https://api.highcharts.com/highstock/yAxis.linkedTo
     * @see https://api.highcharts.com/gantt/yAxis.linkedTo
     */
    linkedTo?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The maximum value of the axis.
     * If `null`, the max value is automatically calculated.
     *
     * If the endOnTick option is true, the `max` value might be rounded up.
     *
     * If a tickAmount is set, the axis may be extended beyond the set max in
     * order to reach the given number of ticks. The same may happen in a chart
     * with multiple axes, determined by chart. alignTicks, where a `tickAmount`
     * is applied internally.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.max
     * @see https://api.highcharts.com/highstock/yAxis.max
     * @see https://api.highcharts.com/highmaps/yAxis.max
     * @see https://api.highcharts.com/gantt/yAxis.max
     */
    max?: number;
    /**
     * (Highcharts) Solid gauge only. Unless stops are set, the color to
     * represent the maximum value of the Y axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.maxColor
     */
    maxColor?: ColorString;
    /**
     * (Highstock) Maximal size of a resizable axis. Could be set as a percent
     * of plot area or pixel size.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.maxLength
     */
    maxLength?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) Padding of the max value relative to the
     * length of the axis. A padding of 0.05 will make a 100px axis 5px longer.
     * This is useful when you don't want the highest data value to appear on
     * the edge of the plot area. When the axis' `max` option is set or a max
     * extreme is set using `axis.setExtremes()`, the maxPadding will be
     * ignored.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.maxPadding
     * @see https://api.highcharts.com/highstock/yAxis.maxPadding
     * @see https://api.highcharts.com/gantt/yAxis.maxPadding
     */
    maxPadding?: number;
    /**
     * (Highstock) Maximum range which can be set using the navigator's handles.
     * Opposite of xAxis.minRange.
     *
     * @see https://api.highcharts.com/highstock/yAxis.maxRange
     */
    maxRange?: number;
    /**
     * (Highcharts, Highstock) Deprecated. Use `minRange` instead.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.maxZoom
     * @see https://api.highcharts.com/highstock/yAxis.maxZoom
     */
    maxZoom?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The minimum value of the axis.
     * If `null` the min value is automatically calculated.
     *
     * If the startOnTick option is true (default), the `min` value might be
     * rounded down.
     *
     * The automatically calculated minimum value is also affected by floor,
     * softMin, minPadding, minRange as well as series.threshold and
     * series.softThreshold.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.min
     * @see https://api.highcharts.com/highstock/yAxis.min
     * @see https://api.highcharts.com/highmaps/yAxis.min
     * @see https://api.highcharts.com/gantt/yAxis.min
     */
    min?: number;
    /**
     * (Highcharts) Solid gauge only. Unless stops are set, the color to
     * represent the minimum value of the Y axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minColor
     */
    minColor?: ColorString;
    /**
     * (Highstock) Minimal size of a resizable axis. Could be set as a percent
     * of plot area or pixel size.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.minLength
     */
    minLength?: (number|string);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the minor, secondary
     * grid lines.
     *
     * In styled mode, the stroke width is given in the
     * `.highcharts-minor-grid-line` class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minorGridLineColor
     * @see https://api.highcharts.com/highstock/yAxis.minorGridLineColor
     * @see https://api.highcharts.com/highmaps/yAxis.minorGridLineColor
     * @see https://api.highcharts.com/gantt/yAxis.minorGridLineColor
     */
    minorGridLineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The dash or dot style of the
     * minor grid lines. For possible values, see this demonstration.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minorGridLineDashStyle
     * @see https://api.highcharts.com/highstock/yAxis.minorGridLineDashStyle
     * @see https://api.highcharts.com/highmaps/yAxis.minorGridLineDashStyle
     * @see https://api.highcharts.com/gantt/yAxis.minorGridLineDashStyle
     */
    minorGridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the minor, secondary
     * grid lines.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minorGridLineWidth
     * @see https://api.highcharts.com/highstock/yAxis.minorGridLineWidth
     * @see https://api.highcharts.com/highmaps/yAxis.minorGridLineWidth
     * @see https://api.highcharts.com/gantt/yAxis.minorGridLineWidth
     */
    minorGridLineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color for the minor tick marks.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minorTickColor
     * @see https://api.highcharts.com/highstock/yAxis.minorTickColor
     * @see https://api.highcharts.com/highmaps/yAxis.minorTickColor
     * @see https://api.highcharts.com/gantt/yAxis.minorTickColor
     */
    minorTickColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Specific tick interval in axis
     * units for the minor ticks. On a linear axis, if `"auto"`, the minor tick
     * interval is calculated as a fifth of the tickInterval. If `null` or
     * `undefined`, minor ticks are not shown.
     *
     * On logarithmic axes, the unit is the power of the value. For example,
     * setting the minorTickInterval to 1 puts one tick on each of 0.1, 1, 10,
     * 100 etc. Setting the minorTickInterval to 0.1 produces 9 ticks between 1
     * and 10, 10 and 100 etc.
     *
     * If user settings dictate minor ticks to become too dense, they don't make
     * sense, and will be ignored to prevent performance problems.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minorTickInterval
     * @see https://api.highcharts.com/highstock/yAxis.minorTickInterval
     * @see https://api.highcharts.com/highmaps/yAxis.minorTickInterval
     * @see https://api.highcharts.com/gantt/yAxis.minorTickInterval
     */
    minorTickInterval?: (number|string|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel length of the minor
     * tick marks.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minorTickLength
     * @see https://api.highcharts.com/highstock/yAxis.minorTickLength
     * @see https://api.highcharts.com/highmaps/yAxis.minorTickLength
     * @see https://api.highcharts.com/gantt/yAxis.minorTickLength
     */
    minorTickLength?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The position of the minor tick
     * marks relative to the axis line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minorTickPosition
     * @see https://api.highcharts.com/highstock/yAxis.minorTickPosition
     * @see https://api.highcharts.com/highmaps/yAxis.minorTickPosition
     * @see https://api.highcharts.com/gantt/yAxis.minorTickPosition
     */
    minorTickPosition?: ("inside"|"outside");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable minor ticks.
     * Unless minorTickInterval is set, the tick interval is calculated as a
     * fifth of the `tickInterval`.
     *
     * On a logarithmic axis, minor ticks are laid out based on a best guess,
     * attempting to enter approximately 5 minor ticks between each major tick.
     *
     * Prior to v6.0.0, ticks were unabled in auto layout by setting
     * `minorTickInterval` to `"auto"`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minorTicks
     * @see https://api.highcharts.com/highstock/yAxis.minorTicks
     * @see https://api.highcharts.com/highmaps/yAxis.minorTicks
     * @see https://api.highcharts.com/gantt/yAxis.minorTicks
     */
    minorTicks?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the minor
     * tick mark.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minorTickWidth
     * @see https://api.highcharts.com/highstock/yAxis.minorTickWidth
     * @see https://api.highcharts.com/highmaps/yAxis.minorTickWidth
     * @see https://api.highcharts.com/gantt/yAxis.minorTickWidth
     */
    minorTickWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Padding of the min value relative to the
     * length of the axis. A padding of 0.05 will make a 100px axis 5px longer.
     * This is useful when you don't want the lowest data value to appear on the
     * edge of the plot area. When the axis' `min` option is set or a max
     * extreme is set using `axis.setExtremes()`, the maxPadding will be
     * ignored.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minPadding
     * @see https://api.highcharts.com/highstock/yAxis.minPadding
     * @see https://api.highcharts.com/gantt/yAxis.minPadding
     */
    minPadding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The minimum range to display on
     * this axis. The entire axis will not be allowed to span over a smaller
     * interval than this. For example, for a datetime axis the main unit is
     * milliseconds. If minRange is set to 3600000, you can't zoom in more than
     * to one hour.
     *
     * The default minRange for the x axis is five times the smallest interval
     * between any of the data points.
     *
     * On a logarithmic axis, the unit for the minimum range is the power. So a
     * minRange of 1 means that the axis can be zoomed to 10-100, 100-1000,
     * 1000-10000 etc.
     *
     * Note that the `minPadding`, `maxPadding`, `startOnTick` and `endOnTick`
     * settings also affect how the extremes of the axis are computed.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minRange
     * @see https://api.highcharts.com/highstock/yAxis.minRange
     * @see https://api.highcharts.com/highmaps/yAxis.minRange
     * @see https://api.highcharts.com/gantt/yAxis.minRange
     */
    minRange?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The minimum tick interval
     * allowed in axis values. For example on zooming in on an axis with daily
     * data, this can be used to prevent the axis from showing hours. Defaults
     * to the closest distance between two points on the axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.minTickInterval
     * @see https://api.highcharts.com/highstock/yAxis.minTickInterval
     * @see https://api.highcharts.com/highmaps/yAxis.minTickInterval
     * @see https://api.highcharts.com/gantt/yAxis.minTickInterval
     */
    minTickInterval?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The distance in pixels from the
     * plot area to the axis line. A positive offset moves the axis with it's
     * line, labels and ticks away from the plot area. This is typically used
     * when two or more axes are displayed on the same side of the plot. With
     * multiple axes the offset is dynamically adjusted to avoid collision, this
     * can be overridden by setting offset explicitly.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.offset
     * @see https://api.highcharts.com/highstock/yAxis.offset
     * @see https://api.highcharts.com/highmaps/yAxis.offset
     * @see https://api.highcharts.com/gantt/yAxis.offset
     */
    offset?: number;
    /**
     * (Highstock, Highcharts, Gantt) Whether to display the axis on the
     * opposite side of the normal. The normal is on the left side for vertical
     * axes and bottom for horizontal, so the opposite sides will be right and
     * top respectively. This is typically used with dual or multiple axes.
     *
     * @see https://api.highcharts.com/highstock/yAxis.opposite
     * @see https://api.highcharts.com/highcharts/yAxis.opposite
     * @see https://api.highcharts.com/gantt/yAxis.opposite
     */
    opposite?: boolean;
    /**
     * (Highcharts) Refers to the index in the panes array. Used for circular
     * gauges and polar charts. When the option is not set then first pane will
     * be used.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.pane
     */
    pane?: number;
    /**
     * (Highcharts, Highstock, Gantt) An array of objects defining plot bands on
     * the Y axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands
     * @see https://api.highcharts.com/highstock/yAxis.plotBands
     * @see https://api.highcharts.com/gantt/yAxis.plotBands
     */
    plotBands?: Array<YAxisPlotBandsOptions>;
    /**
     * (Highcharts, Highstock, Gantt) An array of objects representing plot
     * lines on the X axis
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines
     * @see https://api.highcharts.com/highstock/yAxis.plotLines
     * @see https://api.highcharts.com/gantt/yAxis.plotLines
     */
    plotLines?: Array<YAxisPlotLinesOptions>;
    /**
     * (Highstock) The zoomed range to display when only defining one or none of
     * `min` or `max`. For example, to show the latest month, a range of one
     * month can be set.
     *
     * @see https://api.highcharts.com/highstock/yAxis.range
     */
    range?: number;
    /**
     * (Highstock) Options for axis resizing. This feature requires the
     * `drag-panes.js` - classic or styled mode - module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize
     */
    resize?: YAxisResizeOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to reverse the axis so
     * that the highest number is closest to the origin.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.reversed
     * @see https://api.highcharts.com/highstock/yAxis.reversed
     * @see https://api.highcharts.com/highmaps/yAxis.reversed
     * @see https://api.highcharts.com/gantt/yAxis.reversed
     */
    reversed?: boolean;
    /**
     * (Highcharts, Highstock) If `true`, the first series in a stack will be
     * drawn on top in a positive, non-reversed Y axis. If `false`, the first
     * series is in the base of the stack.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.reversedStacks
     * @see https://api.highcharts.com/highstock/yAxis.reversedStacks
     */
    reversedStacks?: boolean;
    /**
     * (Highstock) An optional scrollbar to display on the Y axis in response to
     * limiting the minimum an maximum of the axis values.
     *
     * In styled mode, all the presentational options for the scrollbar are
     * replaced by the classes `.highcharts-scrollbar-thumb`,
     * `.highcharts-scrollbar-arrow`, `.highcharts-scrollbar-button`,
     * `.highcharts-scrollbar-rifles` and `.highcharts-scrollbar-track`.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar
     */
    scrollbar?: YAxisScrollbarOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to show the axis line
     * and title when the axis has no data.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.showEmpty
     * @see https://api.highcharts.com/highstock/yAxis.showEmpty
     * @see https://api.highcharts.com/highmaps/yAxis.showEmpty
     * @see https://api.highcharts.com/gantt/yAxis.showEmpty
     */
    showEmpty?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to show the first tick
     * label.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.showFirstLabel
     * @see https://api.highcharts.com/highstock/yAxis.showFirstLabel
     * @see https://api.highcharts.com/highmaps/yAxis.showFirstLabel
     * @see https://api.highcharts.com/gantt/yAxis.showFirstLabel
     */
    showFirstLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to show the last tick label.
     * Defaults to `true` on cartesian charts, and `false` on polar charts.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.showLastLabel
     * @see https://api.highcharts.com/highstock/yAxis.showLastLabel
     * @see https://api.highcharts.com/gantt/yAxis.showLastLabel
     */
    showLastLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A soft maximum for the axis. If the series
     * data maximum is less than this, the axis will stay at this maximum, but
     * if the series data maximum is higher, the axis will flex to show all
     * data.
     *
     * **Note**: The series.softThreshold option takes precedence over this
     * option.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.softMax
     * @see https://api.highcharts.com/highstock/yAxis.softMax
     * @see https://api.highcharts.com/gantt/yAxis.softMax
     */
    softMax?: number;
    /**
     * (Highcharts, Highstock, Gantt) A soft minimum for the axis. If the series
     * data minimum is greater than this, the axis will stay at this minimum,
     * but if the series data minimum is lower, the axis will flex to show all
     * data.
     *
     * **Note**: The series.softThreshold option takes precedence over this
     * option.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.softMin
     * @see https://api.highcharts.com/highstock/yAxis.softMin
     * @see https://api.highcharts.com/gantt/yAxis.softMin
     */
    softMin?: number;
    /**
     * (Highcharts) The stack labels show the total value for each bar in a
     * stacked column or bar chart. The label will be placed on top of positive
     * columns and below negative columns. In case of an inverted column chart
     * or a bar chart the label is placed to the right of positive bars and to
     * the left of negative bars.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels
     */
    stackLabels?: YAxisStackLabelsOptions;
    /**
     * (Highcharts, Highstock, Gantt) For datetime axes, this decides where to
     * put the tick between weeks. 0 = Sunday, 1 = Monday.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.startOfWeek
     * @see https://api.highcharts.com/highstock/yAxis.startOfWeek
     * @see https://api.highcharts.com/gantt/yAxis.startOfWeek
     */
    startOfWeek?: number;
    /**
     * (Highcharts, Highstock, Gantt) Whether to force the axis to start on a
     * tick. Use this option with the `maxPadding` option to control the axis
     * start.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.startOnTick
     * @see https://api.highcharts.com/highstock/yAxis.startOnTick
     * @see https://api.highcharts.com/gantt/yAxis.startOnTick
     */
    startOnTick?: boolean;
    /**
     * (Gantt) For vertical axes only. Setting the static scale ensures that
     * each tick unit is translated into a fixed pixel height. For example,
     * setting the static scale to 24 results in each Y axis category taking up
     * 24 pixels, and the height of the chart adjusts. Adding or removing items
     * will make the chart resize.
     *
     * @see https://api.highcharts.com/gantt/yAxis.staticScale
     */
    staticScale?: number;
    /**
     * (Highcharts) Solid gauge series only. Color stops for the solid gauge.
     * Use this in cases where a linear gradient between a `minColor` and
     * `maxColor` is not sufficient. The stops is an array of tuples, where the
     * first item is a float between 0 and 1 assigning the relative position in
     * the gradient, and the second item is the color.
     *
     * For solid gauges, the Y axis also inherits the concept of data classes
     * from the Highmaps color axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stops
     */
    stops?: Array<[number, ColorString]>;
    /**
     * (Highcharts, Highstock, Gantt) The amount of ticks to draw on the axis.
     * This opens up for aligning the ticks of multiple charts or panes within a
     * chart. This option overrides the `tickPixelInterval` option.
     *
     * This option only has an effect on linear axes. Datetime, logarithmic or
     * category axes are not affected.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tickAmount
     * @see https://api.highcharts.com/highstock/yAxis.tickAmount
     * @see https://api.highcharts.com/gantt/yAxis.tickAmount
     */
    tickAmount?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color for the main tick marks.
     *
     * In styled mode, the stroke is given in the `.highcharts-tick` class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tickColor
     * @see https://api.highcharts.com/highstock/yAxis.tickColor
     * @see https://api.highcharts.com/highmaps/yAxis.tickColor
     * @see https://api.highcharts.com/gantt/yAxis.tickColor
     */
    tickColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The interval of the tick marks
     * in axis units. When `undefined`, the tick interval is computed to
     * approximately follow the tickPixelInterval on linear and datetime axes.
     * On categorized axes, a `undefined` tickInterval will default to 1, one
     * category. Note that datetime axes are based on milliseconds, so for
     * example an interval of one day is expressed as `24 * 3600 * 1000`.
     *
     * On logarithmic axes, the tickInterval is based on powers, so a
     * tickInterval of 1 means one tick on each of 0.1, 1, 10, 100 etc. A
     * tickInterval of 2 means a tick of 0.1, 10, 1000 etc. A tickInterval of
     * 0.2 puts a tick on 0.1, 0.2, 0.4, 0.6, 0.8, 1, 2, 4, 6, 8, 10, 20, 40
     * etc.
     *
     * If the tickInterval is too dense for labels to be drawn, Highcharts may
     * remove ticks.
     *
     * If the chart has multiple axes, the alignTicks option may interfere with
     * the `tickInterval` setting.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tickInterval
     * @see https://api.highcharts.com/highstock/yAxis.tickInterval
     * @see https://api.highcharts.com/highmaps/yAxis.tickInterval
     * @see https://api.highcharts.com/gantt/yAxis.tickInterval
     */
    tickInterval?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel length of the main
     * tick marks.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tickLength
     * @see https://api.highcharts.com/highstock/yAxis.tickLength
     * @see https://api.highcharts.com/highmaps/yAxis.tickLength
     * @see https://api.highcharts.com/gantt/yAxis.tickLength
     */
    tickLength?: number;
    /**
     * (Highcharts, Gantt) For categorized axes only. If `on` the tick mark is
     * placed in the center of the category, if `between` the tick mark is
     * placed between categories. The default is `between` if the `tickInterval`
     * is 1, else `on`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tickmarkPlacement
     * @see https://api.highcharts.com/gantt/yAxis.tickmarkPlacement
     */
    tickmarkPlacement?: ("between"|"on");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) If tickInterval is `null` this
     * option sets the approximate pixel interval of the tick marks. Not
     * applicable to categorized axis.
     *
     * The tick interval is also influenced by the minTickInterval option, that,
     * by default prevents ticks from being denser than the data points.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tickPixelInterval
     * @see https://api.highcharts.com/highstock/yAxis.tickPixelInterval
     * @see https://api.highcharts.com/highmaps/yAxis.tickPixelInterval
     * @see https://api.highcharts.com/gantt/yAxis.tickPixelInterval
     */
    tickPixelInterval?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The position of the major tick
     * marks relative to the axis line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tickPosition
     * @see https://api.highcharts.com/highstock/yAxis.tickPosition
     * @see https://api.highcharts.com/highmaps/yAxis.tickPosition
     * @see https://api.highcharts.com/gantt/yAxis.tickPosition
     */
    tickPosition?: ("inside"|"outside");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A callback function returning
     * array defining where the ticks are laid out on the axis. This overrides
     * the default behaviour of tickPixelInterval and tickInterval. The
     * automatic tick positions are accessible through `this.tickPositions` and
     * can be modified by the callback.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tickPositioner
     * @see https://api.highcharts.com/highstock/yAxis.tickPositioner
     * @see https://api.highcharts.com/highmaps/yAxis.tickPositioner
     * @see https://api.highcharts.com/gantt/yAxis.tickPositioner
     */
    tickPositioner?: AxisTickPositionerCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array defining where the
     * ticks are laid out on the axis. This overrides the default behaviour of
     * tickPixelInterval and tickInterval.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tickPositions
     * @see https://api.highcharts.com/highstock/yAxis.tickPositions
     * @see https://api.highcharts.com/highmaps/yAxis.tickPositions
     * @see https://api.highcharts.com/gantt/yAxis.tickPositions
     */
    tickPositions?: Array<number>;
    /**
     * (Highcharts, Highstock, Gantt) The pixel width of the major tick marks.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tickWidth
     * @see https://api.highcharts.com/highstock/yAxis.tickWidth
     * @see https://api.highcharts.com/gantt/yAxis.tickWidth
     */
    tickWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The axis title, showing next to
     * the axis line.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title
     * @see https://api.highcharts.com/highstock/yAxis.title
     * @see https://api.highcharts.com/highmaps/yAxis.title
     * @see https://api.highcharts.com/gantt/yAxis.title
     */
    title?: YAxisTitleOptions;
    /**
     * (Highcharts) Parallel coordinates only. Format that will be used for
     * point.y and available in tooltip.pointFormat as `{point.formattedValue}`.
     * If not set, `{point.formattedValue}` will use other options, in this
     * order:
     *
     * 1. yAxis.labels.format will be used if set
     *
     * 2. If yAxis is a category, then category name will be displayed
     *
     * 3. If yAxis is a datetime, then value will use the same format as yAxis
     * labels
     *
     * 4. If yAxis is linear/logarithmic type, then simple value will be used
     *
     * @see https://api.highcharts.com/highcharts/yAxis.tooltipValueFormat
     */
    tooltipValueFormat?: string;
    /**
     * (Highstock) The top position of the Y axis. If it's a number, it is
     * interpreted as pixel position relative to the chart.
     *
     * Since Highstock 2: If it's a percentage string, it is interpreted as
     * percentages of the plot height, offset from plot area top.
     *
     * @see https://api.highcharts.com/highstock/yAxis.top
     */
    top?: (number|string);
    /**
     * (Highcharts, Gantt) The type of axis. Can be one of `linear`,
     * `logarithmic`, `datetime`, `category` or `treegrid`. Defaults to
     * `treegrid` for Gantt charts, `linear` for other chart types.
     *
     * In a datetime axis, the numbers are given in milliseconds, and tick marks
     * are placed on appropriate values, like full hours or days. In a category
     * or treegrid axis, the point names of the chart's series are used for
     * categories, if a categories array is not defined.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.type
     * @see https://api.highcharts.com/gantt/yAxis.type
     */
    type?: ("category"|"datetime"|"linear"|"logarithmic"|"treegrid");
    /**
     * (Highcharts, Gantt) Applies only when the axis `type` is `category`. When
     * `uniqueNames` is true, points are placed on the X axis according to their
     * names. If the same point name is repeated in the same or another series,
     * the point is placed on the same X position as other points of the same
     * name. When `uniqueNames` is false, the points are laid out in increasing
     * X positions regardless of their names, and the X axis category will take
     * the name of the last point in each position.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.uniqueNames
     * @see https://api.highcharts.com/gantt/yAxis.uniqueNames
     */
    uniqueNames?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Datetime axis only. An array determining
     * what time intervals the ticks are allowed to fall on. Each array item is
     * an array where the first value is the time unit and the second value
     * another array of allowed multiples. Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/yAxis.units
     * @see https://api.highcharts.com/highstock/yAxis.units
     * @see https://api.highcharts.com/gantt/yAxis.units
     */
    units?: Array<[string, (Array<number>|null)]>;
    /**
     * (Highcharts, Highstock, Gantt) Whether axis, including axis title, line,
     * ticks and labels, should be visible.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.visible
     * @see https://api.highcharts.com/highstock/yAxis.visible
     * @see https://api.highcharts.com/gantt/yAxis.visible
     */
    visible?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label
 * @see https://api.highcharts.com/highstock/yAxis.plotBands.label
 * @see https://api.highcharts.com/gantt/yAxis.plotBands.label
 */
export interface YAxisPlotBandsLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label. Can be
     * one of "left", "center" or "right".
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label.align
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.label.align
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.label.align
     */
    align?: string;
    /**
     * (Highcharts, Highstock, Gantt) Rotation of the text label in degrees .
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label.rotation
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.label.rotation
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.label.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-band-label` class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label.style
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.label.style
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.label.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The string text itself. A subset of HTML
     * is supported.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label.text
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.label.text
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.label.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text alignment for the label. While
     * `align` determines where the texts anchor point is placed within the plot
     * band, `textAlign` determines how the text is aligned against its anchor
     * point. Possible values are "left", "center" and "right". Defaults to the
     * same as the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label.textAlign
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.label.textAlign
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.label.textAlign
     */
    textAlign?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label.useHTML
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.label.useHTML
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label relative
     * to the plot band. Can be one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label.verticalAlign
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.label.verticalAlign
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal position relative the
     * alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label.x
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.label.x
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.label.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical position of the text baseline
     * relative to the alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label.y
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.label.y
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.label.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of objects defining plot bands on the
 * Y axis.
 *
 * @see https://api.highcharts.com/highcharts/yAxis.plotBands
 * @see https://api.highcharts.com/highstock/yAxis.plotBands
 * @see https://api.highcharts.com/gantt/yAxis.plotBands
 */
export interface YAxisPlotBandsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Border color for the plot band. Also
     * requires `borderWidth` to be set.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.borderColor
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.borderColor
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) Border width for the plot band. Also
     * requires `borderColor` to be set.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.borderWidth
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.borderWidth
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A custom class name, in addition to the
     * default `highcharts-plot-band`, to apply to each individual band.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.className
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.className
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The color of the plot band.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.color
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.color
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) An object defining mouse events for the
     * plot band. Supported properties are `click`, `mouseover`, `mouseout`,
     * `mousemove`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.events
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.events
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.events
     */
    events?: object;
    /**
     * (Highcharts, Highstock, Gantt) The start position of the plot band in
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.from
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.from
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.from
     */
    from?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id used for identifying the plot band
     * in Axis.removePlotBand.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.id
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.id
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.id
     */
    id?: string;
    /**
     * (Highcharts) In a gauge chart, this option determines the inner radius of
     * the plot band that stretches along the perimeter. It can be given as a
     * percentage string, like `"100%"`, or as a pixel number, like `100`. By
     * default, the inner radius is controlled by the thickness option.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.innerRadius
     */
    innerRadius?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.label
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.label
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.label
     */
    label?: YAxisPlotBandsLabelOptions;
    /**
     * (Highcharts) In a gauge chart, this option determines the outer radius of
     * the plot band that stretches along the perimeter. It can be given as a
     * percentage string, like `"100%"`, or as a pixel number, like `100`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.outerRadius
     */
    outerRadius?: (number|string);
    /**
     * (Highcharts) In a gauge chart, this option sets the width of the plot
     * band stretching along the perimeter. It can be given as a percentage
     * string, like `"10%"`, or as a pixel number, like `10`. The default value
     * 10 is the same as the default tickLength, thus making the plot band act
     * as a background for the tick markers.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.thickness
     */
    thickness?: (number|string);
    /**
     * (Highcharts, Highstock, Gantt) The end position of the plot band in axis
     * units.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.to
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.to
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.to
     */
    to?: number;
    /**
     * (Highcharts, Highstock, Gantt) The z index of the plot band within the
     * chart, relative to other elements. Using the same z index as another
     * element may give unpredictable results, as the last rendered element will
     * be on top. Values from 0 to 20 make sense.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotBands.zIndex
     * @see https://api.highcharts.com/highstock/yAxis.plotBands.zIndex
     * @see https://api.highcharts.com/gantt/yAxis.plotBands.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label
 * @see https://api.highcharts.com/highstock/yAxis.plotLines.label
 * @see https://api.highcharts.com/gantt/yAxis.plotLines.label
 */
export interface YAxisPlotLinesLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label. Can be
     * one of "left", "center" or "right".
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label.align
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.label.align
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.label.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Rotation of the text label in degrees.
     * Defaults to 0 for horizontal plot lines and 90 for vertical lines.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label.rotation
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.label.rotation
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.label.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-line-label` class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label.style
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.label.style
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.label.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The text itself. A subset of HTML is
     * supported.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label.text
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.label.text
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.label.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text alignment for the label. While
     * `align` determines where the texts anchor point is placed within the plot
     * band, `textAlign` determines how the text is aligned against its anchor
     * point. Possible values are "left", "center" and "right". Defaults to the
     * same as the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label.textAlign
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.label.textAlign
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.label.textAlign
     */
    textAlign?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label.useHTML
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.label.useHTML
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label relative
     * to the plot line. Can be one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label.verticalAlign
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.label.verticalAlign
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal position relative the
     * alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label.x
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.label.x
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.label.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical position of the text baseline
     * relative to the alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label.y
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.label.y
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.label.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of objects representing plot lines on
 * the X axis
 *
 * @see https://api.highcharts.com/highcharts/yAxis.plotLines
 * @see https://api.highcharts.com/highstock/yAxis.plotLines
 * @see https://api.highcharts.com/gantt/yAxis.plotLines
 */
export interface YAxisPlotLinesOptions {
    /**
     * (Highcharts, Highstock, Gantt) A custom class name, in addition to the
     * default `highcharts-plot-line`, to apply to each individual line.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.className
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.className
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The color of the line.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.color
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.color
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The dashing or dot style for the plot
     * line. For possible values see this overview.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.dashStyle
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.dashStyle
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highstock, Gantt) An object defining mouse events for the
     * plot line. Supported properties are `click`, `mouseover`, `mouseout`,
     * `mousemove`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.events
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.events
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.events
     */
    events?: any;
    /**
     * (Highcharts, Highstock, Gantt) An id used for identifying the plot line
     * in Axis.removePlotLine.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.id
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.id
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.label
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.label
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.label
     */
    label?: YAxisPlotLinesLabelOptions;
    /**
     * (Highcharts, Highstock, Gantt) The position of the line in axis units.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.value
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.value
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.value
     */
    value?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width or thickness of the plot line.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.width
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.width
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.width
     */
    width?: number;
    /**
     * (Highcharts, Highstock, Gantt) The z index of the plot line within the
     * chart.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.plotLines.zIndex
     * @see https://api.highcharts.com/highstock/yAxis.plotLines.zIndex
     * @see https://api.highcharts.com/gantt/yAxis.plotLines.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) Contains two arrays of axes that are controlled by control line
 * of the axis.
 *
 * This feature requires the `drag-panes.js` module.
 *
 * @see https://api.highcharts.com/highstock/yAxis.resize.controlledAxis
 */
export interface YAxisResizeControlledAxisOptions {
    /**
     * (Highstock) Array of axes that should move out of the way of resizing
     * being done for the current axis. If not set, the next axis will be used.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize.controlledAxis.next
     */
    next?: Array<(string|number)>;
    /**
     * (Highstock) Array of axes that should move with the current axis while
     * resizing.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize.controlledAxis.prev
     */
    prev?: Array<(string|number)>;
}
/**
 * (Highstock) Options for axis resizing. This feature requires the
 * `drag-panes.js` - classic or styled mode - module.
 *
 * @see https://api.highcharts.com/highstock/yAxis.resize
 */
export interface YAxisResizeOptions {
    /**
     * (Highstock) Contains two arrays of axes that are controlled by control
     * line of the axis.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize.controlledAxis
     */
    controlledAxis?: YAxisResizeControlledAxisOptions;
    /**
     * (Highstock) Cursor style for the control line.
     *
     * In styled mode use class `highcharts-axis-resizer` instead.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize.cursor
     */
    cursor?: string;
    /**
     * (Highstock) Enable or disable resize by drag for the axis.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) Color of the control line.
     *
     * In styled mode use class `highcharts-axis-resizer` instead.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize.lineColor
     */
    lineColor?: ColorString;
    /**
     * (Highstock) Dash style of the control line.
     *
     * In styled mode use class `highcharts-axis-resizer` instead.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize.lineDashStyle
     */
    lineDashStyle?: string;
    /**
     * (Highstock) Width of the control line.
     *
     * In styled mode use class `highcharts-axis-resizer` instead.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize.lineWidth
     */
    lineWidth?: number;
    /**
     * (Highstock) Horizontal offset of the control line.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize.x
     */
    x?: number;
    /**
     * (Highstock) Vertical offset of the control line.
     *
     * This feature requires the `drag-panes.js` module.
     *
     * @see https://api.highcharts.com/highstock/yAxis.resize.y
     */
    y?: number;
}
/**
 * (Highstock) An optional scrollbar to display on the Y axis in response to
 * limiting the minimum an maximum of the axis values.
 *
 * In styled mode, all the presentational options for the scrollbar are replaced
 * by the classes `.highcharts-scrollbar-thumb`, `.highcharts-scrollbar-arrow`,
 * `.highcharts-scrollbar-button`, `.highcharts-scrollbar-rifles` and
 * `.highcharts-scrollbar-track`.
 *
 * @see https://api.highcharts.com/highstock/yAxis.scrollbar
 */
export interface YAxisScrollbarOptions {
    /**
     * (Highstock) The background color of the scrollbar itself.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.barBackgroundColor
     */
    barBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the scrollbar's border.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.barBorderColor
     */
    barBorderColor?: ColorString;
    /**
     * (Highstock) The border rounding radius of the bar.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.barBorderRadius
     */
    barBorderRadius?: number;
    /**
     * (Highstock) The width of the bar's border.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.barBorderWidth
     */
    barBorderWidth?: number;
    /**
     * (Highstock) The color of the small arrow inside the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.buttonArrowColor
     */
    buttonArrowColor?: ColorString;
    /**
     * (Highstock) The color of scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.buttonBackgroundColor
     */
    buttonBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the border of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.buttonBorderColor
     */
    buttonBorderColor?: ColorString;
    /**
     * (Highstock) The corner radius of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.buttonBorderRadius
     */
    buttonBorderRadius?: number;
    /**
     * (Highstock) The border width of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.buttonBorderWidth
     */
    buttonBorderWidth?: number;
    /**
     * (Highstock) Enable the scrollbar on the Y axis.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) Whether to redraw the main chart as the scrollbar or the
     * navigator zoomed window is moved. Defaults to `true` for modern browsers
     * and `false` for legacy IE browsers as well as mobile devices.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.liveRedraw
     */
    liveRedraw?: boolean;
    /**
     * (Highstock) Pixel margin between the scrollbar and the axis elements.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.margin
     */
    margin?: number;
    /**
     * (Highstock) The minimum width of the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.minWidth
     */
    minWidth?: number;
    /**
     * (Highstock) The color of the small rifles in the middle of the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.rifleColor
     */
    rifleColor?: ColorString;
    /**
     * (Highstock) Whether to show the scrollbar when it is fully zoomed out at
     * max range. Setting it to `false` on the Y axis makes the scrollbar stay
     * hidden until the user zooms in, like common in browsers.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.showFull
     */
    showFull?: boolean;
    /**
     * (Highstock) The width of a vertical scrollbar or height of a horizontal
     * scrollbar. Defaults to 20 on touch devices.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.size
     */
    size?: number;
    step?: number;
    /**
     * (Highstock) The color of the track background.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.trackBackgroundColor
     */
    trackBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.trackBorderColor
     */
    trackBorderColor?: ColorString;
    /**
     * (Highstock) The corner radius of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.trackBorderRadius
     */
    trackBorderRadius?: number;
    /**
     * (Highstock) The width of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.trackBorderWidth
     */
    trackBorderWidth?: number;
    /**
     * (Highstock) Z index of the scrollbar elements.
     *
     * @see https://api.highcharts.com/highstock/yAxis.scrollbar.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) The stack labels show the total value for each bar in a stacked
 * column or bar chart. The label will be placed on top of positive columns and
 * below negative columns. In case of an inverted column chart or a bar chart
 * the label is placed to the right of positive bars and to the left of negative
 * bars.
 *
 * @see https://api.highcharts.com/highcharts/yAxis.stackLabels
 */
export interface YAxisStackLabelsOptions {
    /**
     * (Highcharts) Defines the horizontal alignment of the stack total label.
     * Can be one of `"left"`, `"center"` or `"right"`. The default value is
     * calculated at runtime and depends on orientation and whether the stack is
     * positive or negative.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts) Allow the stack labels to overlap.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.allowOverlap
     */
    allowOverlap?: boolean;
    /**
     * (Highcharts) Enable or disable the stack total labels.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock) A format string for the data label. Available
     * variables are the same as for `formatter`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.format
     * @see https://api.highcharts.com/highstock/yAxis.stackLabels.format
     */
    format?: string;
    /**
     * (Highcharts) Callback JavaScript function to format the label. The value
     * is given by `this.total`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.formatter
     */
    formatter?: FormatterCallbackFunction<object>;
    /**
     * (Highcharts) Rotation of the labels in degrees.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) CSS styles for the label.
     *
     * In styled mode, the styles are set in the `.highcharts-stack-label`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts) The text alignment for the label. While `align` determines
     * where the texts anchor point is placed with regards to the stack,
     * `textAlign` determines how the text is aligned against its anchor point.
     * Possible values are `"left"`, `"center"` and `"right"`. The default value
     * is calculated at runtime and depends on orientation and whether the stack
     * is positive or negative.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.textAlign
     */
    textAlign?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.useHTML
     * @see https://api.highcharts.com/highstock/yAxis.stackLabels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts) Defines the vertical alignment of the stack total label. Can
     * be one of `"top"`, `"middle"` or `"bottom"`. The default value is
     * calculated at runtime and depends on orientation and whether the stack is
     * positive or negative.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts) The x position offset of the label relative to the left of
     * the stacked bar. The default value is calculated at runtime and depends
     * on orientation and whether the stack is positive or negative.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.x
     */
    x?: number;
    /**
     * (Highcharts) The y position offset of the label relative to the tick
     * position on the axis. The default value is calculated at runtime and
     * depends on orientation and whether the stack is positive or negative.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.stackLabels.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The axis title, showing next to the
 * axis line.
 *
 * @see https://api.highcharts.com/highcharts/yAxis.title
 * @see https://api.highcharts.com/highstock/yAxis.title
 * @see https://api.highcharts.com/highmaps/yAxis.title
 * @see https://api.highcharts.com/gantt/yAxis.title
 */
export interface YAxisTitleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Alignment of the title relative
     * to the axis values. Possible values are "low", "middle" or "high".
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.align
     * @see https://api.highcharts.com/highstock/yAxis.title.align
     * @see https://api.highcharts.com/highmaps/yAxis.title.align
     * @see https://api.highcharts.com/gantt/yAxis.title.align
     */
    align?: ("high"|"low"|"middle");
    /**
     * (Highcharts) Deprecated. Set the `text` to `null` to disable the title.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.enabled
     */
    enabled?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel distance between the
     * axis labels and the title. Positive values are outside the axis line,
     * negative are inside.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.margin
     * @see https://api.highcharts.com/highstock/yAxis.title.margin
     * @see https://api.highcharts.com/highmaps/yAxis.title.margin
     * @see https://api.highcharts.com/gantt/yAxis.title.margin
     */
    margin?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The distance of the axis title
     * from the axis line. By default, this distance is computed from the offset
     * width of the labels, the labels' distance from the axis and the title's
     * margin. However when the offset option is set, it overrides all this.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.offset
     * @see https://api.highcharts.com/highstock/yAxis.title.offset
     * @see https://api.highcharts.com/highmaps/yAxis.title.offset
     * @see https://api.highcharts.com/gantt/yAxis.title.offset
     */
    offset?: number;
    /**
     * (Highcharts) Defines how the title is repositioned according to the 3D
     * chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * - `undefined`: Will use the config from `labels.position3d`
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho"|null);
    /**
     * (Highcharts, Highstock, Gantt) Whether to reserve space for the title
     * when laying out the axis.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.reserveSpace
     * @see https://api.highcharts.com/highstock/yAxis.title.reserveSpace
     * @see https://api.highcharts.com/gantt/yAxis.title.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The rotation of the text in
     * degrees. 0 is horizontal, 270 is vertical reading from bottom to top.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.rotation
     * @see https://api.highcharts.com/highstock/yAxis.title.rotation
     * @see https://api.highcharts.com/highmaps/yAxis.title.rotation
     * @see https://api.highcharts.com/gantt/yAxis.title.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis title will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `title.position3d`.
     *
     * A `null` value will use the config from `labels.skew3d`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.skew3d
     */
    skew3d?: (boolean|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the title. If the
     * title text is longer than the axis length, it will wrap to multiple lines
     * by default. This can be customized by setting `textOverflow: 'ellipsis'`,
     * by setting a specific `width` or by setting `whiteSpace: 'nowrap'`.
     *
     * In styled mode, the stroke width is given in the `.highcharts-axis-title`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.style
     * @see https://api.highcharts.com/highstock/yAxis.title.style
     * @see https://api.highcharts.com/highmaps/yAxis.title.style
     * @see https://api.highcharts.com/gantt/yAxis.title.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The actual text of the axis title.
     * Horizontal texts can contain HTML, but rotated texts are painted using
     * vector techniques and must be clean text. The Y axis title is disabled by
     * setting the `text` option to `undefined`.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.text
     * @see https://api.highcharts.com/highstock/yAxis.title.text
     * @see https://api.highcharts.com/gantt/yAxis.title.text
     */
    text?: (string|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Alignment of the text, can be
     * `"left"`, `"right"` or `"center"`. Default alignment depends on the
     * title.align:
     *
     * Horizontal axes:
     *
     * - for `align` = `"low"`, `textAlign` is set to `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"`, `textAlign` is set to `right`
     *
     * Vertical axes:
     *
     * - for `align` = `"low"` and `opposite` = `true`, `textAlign` is set to
     * `right`
     *
     * - for `align` = `"low"` and `opposite` = `false`, `textAlign` is set to
     * `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"` and `opposite` = `true` `textAlign` is set to
     * `left`
     *
     * - for `align` = `"high"` and `opposite` = `false` `textAlign` is set to
     * `right`
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.textAlign
     * @see https://api.highcharts.com/highstock/yAxis.title.textAlign
     * @see https://api.highcharts.com/highmaps/yAxis.title.textAlign
     * @see https://api.highcharts.com/gantt/yAxis.title.textAlign
     */
    textAlign?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the axis
     * title.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.useHTML
     * @see https://api.highcharts.com/highstock/yAxis.title.useHTML
     * @see https://api.highcharts.com/gantt/yAxis.title.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Horizontal pixel offset of the title
     * position.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.x
     * @see https://api.highcharts.com/highstock/yAxis.title.x
     * @see https://api.highcharts.com/gantt/yAxis.title.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical pixel offset of the title
     * position.
     *
     * @see https://api.highcharts.com/highcharts/yAxis.title.y
     * @see https://api.highcharts.com/highstock/yAxis.title.y
     * @see https://api.highcharts.com/gantt/yAxis.title.y
     */
    y?: number;
}
/**
 * (Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label
 */
export interface ZAxisCurrentDateIndicatorLabelOptions {
    /**
     * (Gantt) Horizontal alignment of the label. Can be one of "left", "center"
     * or "right".
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Gantt) Rotation of the text label in degrees. Defaults to 0 for
     * horizontal plot lines and 90 for vertical lines.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label.rotation
     */
    rotation?: number;
    /**
     * (Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-line-label` class.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label.style
     */
    style?: CSSObject;
    /**
     * (Gantt) The text itself. A subset of HTML is supported.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label.text
     */
    text?: string;
    /**
     * (Gantt) The text alignment for the label. While `align` determines where
     * the texts anchor point is placed within the plot band, `textAlign`
     * determines how the text is aligned against its anchor point. Possible
     * values are "left", "center" and "right". Defaults to the same as the
     * `align` option.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label.textAlign
     */
    textAlign?: string;
    /**
     * (Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Gantt) Vertical alignment of the label relative to the plot line. Can be
     * one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Gantt) Horizontal position relative the alignment. Default varies by
     * orientation.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label.x
     */
    x?: number;
    /**
     * (Gantt) Vertical position of the text baseline relative to the alignment.
     * Default varies by orientation.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label.y
     */
    y?: number;
}
/**
 * (Gantt) Show an indicator on the axis for the current date and time. Can be a
 * boolean or a configuration object similar to xAxis.plotLines.
 *
 * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator
 */
export interface ZAxisCurrentDateIndicatorOptions {
    /**
     * (Gantt) A custom class name, in addition to the default
     * `highcharts-plot-line`, to apply to each individual line.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.className
     */
    className?: string;
    /**
     * (Gantt) The color of the line.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.color
     */
    color?: ColorString;
    /**
     * (Gantt) The dashing or dot style for the plot line. For possible values
     * see this overview.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Gantt) An object defining mouse events for the plot line. Supported
     * properties are `click`, `mouseover`, `mouseout`, `mousemove`.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.events
     */
    events?: any;
    /**
     * (Gantt) An id used for identifying the plot line in Axis.removePlotLine.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.id
     */
    id?: string;
    /**
     * (Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.label
     */
    label?: ZAxisCurrentDateIndicatorLabelOptions;
    /**
     * (Gantt) The width or thickness of the plot line.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.width
     */
    width?: number;
    /**
     * (Gantt) The z index of the plot line within the chart.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator.zIndex
     */
    zIndex?: number;
}
export interface ZAxisDateTimeLabelFormatsDayOptions {
    main?: string;
}
export interface ZAxisDateTimeLabelFormatsHourOptions {
    main?: string;
    range?: boolean;
}
export interface ZAxisDateTimeLabelFormatsMillisecondOptions {
    main?: string;
    range?: boolean;
}
export interface ZAxisDateTimeLabelFormatsMinuteOptions {
    main?: string;
    range?: boolean;
}
export interface ZAxisDateTimeLabelFormatsMonthOptions {
    main?: string;
}
/**
 * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
 * automatically adjust to the appropriate unit. This member gives the default
 * string representations used for each unit. For intermediate values, different
 * units may be used, for example the `day` unit can be used on midnight and
 * `hour` unit be used for intermediate values on the same axis. For an overview
 * of the replacement codes, see dateFormat. Defaults to:
 *
 * (see online documentation for example)
 *
 * @see https://api.highcharts.com/highcharts/zAxis.dateTimeLabelFormats
 * @see https://api.highcharts.com/highstock/zAxis.dateTimeLabelFormats
 * @see https://api.highcharts.com/gantt/zAxis.dateTimeLabelFormats
 */
export interface ZAxisDateTimeLabelFormatsOptions {
    day?: ZAxisDateTimeLabelFormatsDayOptions;
    hour?: ZAxisDateTimeLabelFormatsHourOptions;
    millisecond?: ZAxisDateTimeLabelFormatsMillisecondOptions;
    minute?: ZAxisDateTimeLabelFormatsMinuteOptions;
    month?: ZAxisDateTimeLabelFormatsMonthOptions;
    second?: ZAxisDateTimeLabelFormatsSecondOptions;
    week?: ZAxisDateTimeLabelFormatsWeekOptions;
    year?: ZAxisDateTimeLabelFormatsYearOptions;
}
export interface ZAxisDateTimeLabelFormatsSecondOptions {
    main?: string;
    range?: boolean;
}
export interface ZAxisDateTimeLabelFormatsWeekOptions {
    main?: string;
}
export interface ZAxisDateTimeLabelFormatsYearOptions {
    main?: string;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) Event handlers for the axis.
 *
 * @see https://api.highcharts.com/highcharts/zAxis.events
 * @see https://api.highcharts.com/highstock/zAxis.events
 * @see https://api.highcharts.com/highmaps/zAxis.events
 * @see https://api.highcharts.com/gantt/zAxis.events
 */
export interface ZAxisEventsOptions {
    /**
     * (Highcharts, Gantt) An event fired after the breaks have rendered.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.events.afterBreaks
     * @see https://api.highcharts.com/gantt/zAxis.events.afterBreaks
     */
    afterBreaks?: AxisEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) As opposed to the `setExtremes`
     * event, this event fires after the final min and max values are computed
     * and corrected for `minRange`.
     *
     * Fires when the minimum and maximum is set for the axis, either by calling
     * the `.setExtremes()` method or by selecting an area in the chart. One
     * parameter, `event`, is passed to the function, containing common event
     * information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in axis
     * values. The actual data extremes are found in `event.dataMin` and
     * `event.dataMax`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.events.afterSetExtremes
     * @see https://api.highcharts.com/highstock/zAxis.events.afterSetExtremes
     * @see https://api.highcharts.com/highmaps/zAxis.events.afterSetExtremes
     * @see https://api.highcharts.com/gantt/zAxis.events.afterSetExtremes
     */
    afterSetExtremes?: AxisEventCallbackFunction;
    /**
     * (Highcharts, Gantt) An event fired when a break from this axis occurs on
     * a point.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.events.pointBreak
     * @see https://api.highcharts.com/gantt/zAxis.events.pointBreak
     */
    pointBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Gantt) An event fired when a point falls inside a
     * break from this axis.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.events.pointInBreak
     * @see https://api.highcharts.com/highstock/zAxis.events.pointInBreak
     * @see https://api.highcharts.com/gantt/zAxis.events.pointInBreak
     */
    pointInBreak?: AxisPointBreakEventCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Fires when the minimum and
     * maximum is set for the axis, either by calling the `.setExtremes()`
     * method or by selecting an area in the chart. One parameter, `event`, is
     * passed to the function, containing common event information.
     *
     * The new user set minimum and maximum values can be found by `event.min`
     * and `event.max`. These reflect the axis minimum and maximum in data
     * values. When an axis is zoomed all the way out from the "Reset zoom"
     * button, `event.min` and `event.max` are null, and the new extremes are
     * set based on `this.dataMin` and `this.dataMax`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.events.setExtremes
     * @see https://api.highcharts.com/highstock/zAxis.events.setExtremes
     * @see https://api.highcharts.com/highmaps/zAxis.events.setExtremes
     * @see https://api.highcharts.com/gantt/zAxis.events.setExtremes
     */
    setExtremes?: AxisSetExtremesEventCallbackFunction;
}
/**
 * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
 *
 * @see https://api.highcharts.com/gantt/zAxis.grid
 */
export interface ZAxisGridOptions {
    /**
     * (Gantt) Set border color for the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/zAxis.grid.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Gantt) Set border width of the label grid lines.
     *
     * @see https://api.highcharts.com/gantt/zAxis.grid.borderWidth
     */
    borderWidth?: number;
    /**
     * (Gantt) Set cell height for grid axis labels. By default this is
     * calculated from font size.
     *
     * @see https://api.highcharts.com/gantt/zAxis.grid.cellHeight
     */
    cellHeight?: number;
    /**
     * (Gantt) Set specific options for each column (or row for horizontal axes)
     * in the grid. Each extra column/row is its own axis, and the axis options
     * can be set here.
     *
     * @see https://api.highcharts.com/gantt/zAxis.grid.columns
     */
    columns?: Array<XAxisOptions>;
    /**
     * (Gantt) Enable grid on the axis labels. Defaults to true for Gantt
     * charts.
     *
     * @see https://api.highcharts.com/gantt/zAxis.grid.enabled
     */
    enabled?: boolean;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The axis labels show the number or
 * category for each tick.
 *
 * @see https://api.highcharts.com/highcharts/zAxis.labels
 * @see https://api.highcharts.com/highstock/zAxis.labels
 * @see https://api.highcharts.com/highmaps/zAxis.labels
 * @see https://api.highcharts.com/gantt/zAxis.labels
 */
export interface ZAxisLabelsOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) What part of the string the
     * given position is anchored to. If `left`, the left side of the string is
     * at the axis position. Can be one of `"left"`, `"center"` or `"right"`.
     * Defaults to an intelligent guess based on which side of the chart the
     * axis is on and the rotation of the label.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.align
     * @see https://api.highcharts.com/highstock/zAxis.labels.align
     * @see https://api.highcharts.com/highmaps/zAxis.labels.align
     * @see https://api.highcharts.com/gantt/zAxis.labels.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) For horizontal axes, the allowed degrees
     * of label rotation to prevent overlapping labels. If there is enough
     * space, labels are not rotated. As the chart gets narrower, it will start
     * rotating the labels -45 degrees, then remove every second label and try
     * again with rotations 0 and -45 etc. Set it to `false` to disable
     * rotation, which will cause the labels to word-wrap if possible.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.autoRotation
     * @see https://api.highcharts.com/highstock/zAxis.labels.autoRotation
     * @see https://api.highcharts.com/gantt/zAxis.labels.autoRotation
     */
    autoRotation?: Array<number>;
    /**
     * (Highcharts, Gantt) When each category width is more than this many
     * pixels, we don't apply auto rotation. Instead, we lay out the axis label
     * with word wrap. A lower limit makes sense when the label contains
     * multiple short words that don't extend the available horizontal space for
     * each label.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.autoRotationLimit
     * @see https://api.highcharts.com/gantt/zAxis.labels.autoRotationLimit
     */
    autoRotationLimit?: number;
    /**
     * (Highcharts, Gantt) Polar charts only. The label's pixel distance from
     * the perimeter of the plot area.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.distance
     * @see https://api.highcharts.com/gantt/zAxis.labels.distance
     */
    distance?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable the axis
     * labels.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.enabled
     * @see https://api.highcharts.com/highstock/zAxis.labels.enabled
     * @see https://api.highcharts.com/highmaps/zAxis.labels.enabled
     * @see https://api.highcharts.com/gantt/zAxis.labels.enabled
     */
    enabled?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A format string for the axis
     * label.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.format
     * @see https://api.highcharts.com/highstock/zAxis.labels.format
     * @see https://api.highcharts.com/highmaps/zAxis.labels.format
     * @see https://api.highcharts.com/gantt/zAxis.labels.format
     */
    format?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Callback JavaScript function to
     * format the label. The value is given by `this.value`. Additional
     * properties for `this` are `axis`, `chart`, `isFirst` and `isLast`. The
     * value of the default label formatter can be retrieved by calling
     * `this.axis.defaultLabelFormatter.call(this)` within the function.
     *
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.formatter
     * @see https://api.highcharts.com/highstock/zAxis.labels.formatter
     * @see https://api.highcharts.com/highmaps/zAxis.labels.formatter
     * @see https://api.highcharts.com/gantt/zAxis.labels.formatter
     */
    formatter?: FormatterCallbackFunction<AxisLabelsFormatterContextObject>;
    /**
     * (Gantt) The number of pixels to indent the labels per level in a treegrid
     * axis.
     *
     * @see https://api.highcharts.com/gantt/zAxis.labels.indentation
     */
    indentation?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Horizontal axis only. When
     * `staggerLines` is not set, `maxStaggerLines` defines how many lines the
     * axis is allowed to add to automatically avoid overlapping X labels. Set
     * to `1` to disable overlap detection.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.maxStaggerLines
     * @see https://api.highcharts.com/highstock/zAxis.labels.maxStaggerLines
     * @see https://api.highcharts.com/highmaps/zAxis.labels.maxStaggerLines
     * @see https://api.highcharts.com/gantt/zAxis.labels.maxStaggerLines
     */
    maxStaggerLines?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) How to handle overflowing labels
     * on horizontal axis. If set to `"allow"`, it will not be aligned at all.
     * By default it `"justify"` labels inside the chart area. If there is room
     * to move it, it will be aligned to the edge, else it will be removed.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.overflow
     * @see https://api.highcharts.com/highstock/zAxis.labels.overflow
     * @see https://api.highcharts.com/highmaps/zAxis.labels.overflow
     * @see https://api.highcharts.com/gantt/zAxis.labels.overflow
     */
    overflow?: ("allow"|"justify");
    /**
     * (Highcharts, Gantt) The pixel padding for axis labels, to ensure white
     * space between them.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.padding
     * @see https://api.highcharts.com/gantt/zAxis.labels.padding
     */
    padding?: number;
    /**
     * (Highcharts) Defines how the labels are be repositioned according to the
     * 3D chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho");
    /**
     * (Highcharts, Gantt) Whether to reserve space for the labels. By default,
     * space is reserved for the labels in these cases:
     *
     * * On all horizontal axes.
     *
     * * On vertical axes if `label.align` is `right` on a left-side axis or
     * `left` on a right-side axis.
     *
     * * On vertical axes if `label.align` is `center`.
     *
     * This can be turned off when for example the labels are rendered inside
     * the plot area instead of outside.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.reserveSpace
     * @see https://api.highcharts.com/gantt/zAxis.labels.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Rotation of the labels in
     * degrees.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.rotation
     * @see https://api.highcharts.com/highstock/zAxis.labels.rotation
     * @see https://api.highcharts.com/highmaps/zAxis.labels.rotation
     * @see https://api.highcharts.com/gantt/zAxis.labels.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis labels will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `labels.position3d`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.skew3d
     */
    skew3d?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Horizontal axes only. The number
     * of lines to spread the labels over to make room or tighter labels.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.staggerLines
     * @see https://api.highcharts.com/highstock/zAxis.labels.staggerLines
     * @see https://api.highcharts.com/highmaps/zAxis.labels.staggerLines
     * @see https://api.highcharts.com/gantt/zAxis.labels.staggerLines
     */
    staggerLines?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) To show only every _n_'th label
     * on the axis, set the step to _n_. Setting the step to 2 shows every other
     * label.
     *
     * By default, the step is calculated automatically to avoid overlap. To
     * prevent this, set it to 1\. This usually only happens on a category axis,
     * and is often a sign that you have chosen the wrong axis type.
     *
     * Read more at Axis docs => What axis should I use?
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.step
     * @see https://api.highcharts.com/highstock/zAxis.labels.step
     * @see https://api.highcharts.com/highmaps/zAxis.labels.step
     * @see https://api.highcharts.com/gantt/zAxis.labels.step
     */
    step?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the label. Use
     * `whiteSpace: 'nowrap'` to prevent wrapping of category labels. Use
     * `textOverflow: 'none'` to prevent ellipsis (dots).
     *
     * In styled mode, the labels are styled with the `.highcharts-axis-labels`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.style
     * @see https://api.highcharts.com/highstock/zAxis.labels.style
     * @see https://api.highcharts.com/highmaps/zAxis.labels.style
     * @see https://api.highcharts.com/gantt/zAxis.labels.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render
     * the labels.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.useHTML
     * @see https://api.highcharts.com/highstock/zAxis.labels.useHTML
     * @see https://api.highcharts.com/highmaps/zAxis.labels.useHTML
     * @see https://api.highcharts.com/gantt/zAxis.labels.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The x position offset of the
     * label relative to the tick position on the axis.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.x
     * @see https://api.highcharts.com/highstock/zAxis.labels.x
     * @see https://api.highcharts.com/highmaps/zAxis.labels.x
     * @see https://api.highcharts.com/gantt/zAxis.labels.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The y position offset of the
     * label relative to the tick position on the axis. The default makes it
     * adapt to the font size on bottom axis.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.y
     * @see https://api.highcharts.com/highstock/zAxis.labels.y
     * @see https://api.highcharts.com/highmaps/zAxis.labels.y
     * @see https://api.highcharts.com/gantt/zAxis.labels.y
     */
    y?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The Z index for the axis labels.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels.zIndex
     * @see https://api.highcharts.com/highstock/zAxis.labels.zIndex
     * @see https://api.highcharts.com/highmaps/zAxis.labels.zIndex
     * @see https://api.highcharts.com/gantt/zAxis.labels.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts) The Z axis or depth axis for 3D plots.
 *
 * See the Axis class for programmatic access to the axis.
 *
 * @see https://api.highcharts.com/highcharts/zAxis
 */
export interface ZAxisOptions {
    /**
     * (Highcharts, Highstock, Gantt) When using multiple axis, the ticks of two
     * or more opposite axes will automatically be aligned by adding ticks to
     * the axis or axes with the least ticks, as if `tickAmount` were specified.
     *
     * This can be prevented by setting `alignTicks` to false. If the grid lines
     * look messy, it's a good idea to hide them for the secondary axis by
     * setting `gridLineWidth` to 0.
     *
     * If `startOnTick` or `endOnTick` in an Axis options are set to false, then
     * the `alignTicks ` will be disabled for the Axis.
     *
     * Disabled for logarithmic axes.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.alignTicks
     * @see https://api.highcharts.com/highstock/zAxis.alignTicks
     * @see https://api.highcharts.com/gantt/zAxis.alignTicks
     */
    alignTicks?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to allow decimals in
     * this axis' ticks. When counting integers, like persons or hits on a web
     * page, decimals should be avoided in the labels.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.allowDecimals
     * @see https://api.highcharts.com/highstock/zAxis.allowDecimals
     * @see https://api.highcharts.com/highmaps/zAxis.allowDecimals
     * @see https://api.highcharts.com/gantt/zAxis.allowDecimals
     */
    allowDecimals?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) When using an alternate grid
     * color, a band is painted across the plot area between every other grid
     * line.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.alternateGridColor
     * @see https://api.highcharts.com/highstock/zAxis.alternateGridColor
     * @see https://api.highcharts.com/highmaps/zAxis.alternateGridColor
     * @see https://api.highcharts.com/gantt/zAxis.alternateGridColor
     */
    alternateGridColor?: ColorString;
    /**
     * (Highcharts, Gantt) If categories are present for the xAxis, names are
     * used instead of numbers for that axis. Since Highcharts 3.0, categories
     * can also be extracted by giving each point a name and setting axis type
     * to `category`. However, if you have multiple series, best practice
     * remains defining the `categories` array.
     *
     * Example:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/zAxis.categories
     * @see https://api.highcharts.com/gantt/zAxis.categories
     */
    categories?: Array<string>;
    /**
     * (Highcharts, Highstock, Gantt) The highest allowed value for
     * automatically computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.ceiling
     * @see https://api.highcharts.com/highstock/zAxis.ceiling
     * @see https://api.highcharts.com/gantt/zAxis.ceiling
     */
    ceiling?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A class name that opens for
     * styling the axis by CSS, especially in Highcharts styled mode. The class
     * name is applied to group elements for the grid, axis elements and labels.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.className
     * @see https://api.highcharts.com/highstock/zAxis.className
     * @see https://api.highcharts.com/highmaps/zAxis.className
     * @see https://api.highcharts.com/gantt/zAxis.className
     */
    className?: string;
    /**
     * (Gantt) Show an indicator on the axis for the current date and time. Can
     * be a boolean or a configuration object similar to xAxis.plotLines.
     *
     * @see https://api.highcharts.com/gantt/zAxis.currentDateIndicator
     */
    currentDateIndicator?: (boolean|ZAxisCurrentDateIndicatorOptions);
    /**
     * (Highcharts, Highstock, Gantt) For a datetime axis, the scale will
     * automatically adjust to the appropriate unit. This member gives the
     * default string representations used for each unit. For intermediate
     * values, different units may be used, for example the `day` unit can be
     * used on midnight and `hour` unit be used for intermediate values on the
     * same axis. For an overview of the replacement codes, see dateFormat.
     * Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/zAxis.dateTimeLabelFormats
     * @see https://api.highcharts.com/highstock/zAxis.dateTimeLabelFormats
     * @see https://api.highcharts.com/gantt/zAxis.dateTimeLabelFormats
     */
    dateTimeLabelFormats?: ZAxisDateTimeLabelFormatsOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) _Requires Accessibility module_
     *
     * Description of the axis to screen reader users.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.description
     * @see https://api.highcharts.com/highstock/zAxis.description
     * @see https://api.highcharts.com/highmaps/zAxis.description
     * @see https://api.highcharts.com/gantt/zAxis.description
     */
    description?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to force the axis to end
     * on a tick. Use this option with the `maxPadding` option to control the
     * axis end.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.endOnTick
     * @see https://api.highcharts.com/highstock/zAxis.endOnTick
     * @see https://api.highcharts.com/highmaps/zAxis.endOnTick
     * @see https://api.highcharts.com/gantt/zAxis.endOnTick
     */
    endOnTick?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Event handlers for the axis.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.events
     * @see https://api.highcharts.com/highstock/zAxis.events
     * @see https://api.highcharts.com/highmaps/zAxis.events
     * @see https://api.highcharts.com/gantt/zAxis.events
     */
    events?: ZAxisEventsOptions;
    /**
     * (Highcharts, Highstock, Gantt) The lowest allowed value for automatically
     * computed axis extremes.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.floor
     * @see https://api.highcharts.com/highstock/zAxis.floor
     * @see https://api.highcharts.com/gantt/zAxis.floor
     */
    floor?: number;
    /**
     * (Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.
     *
     * @see https://api.highcharts.com/gantt/zAxis.grid
     */
    grid?: ZAxisGridOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the grid lines
     * extending the ticks across the plot area.
     *
     * In styled mode, the stroke is given in the `.highcharts-grid-line` class.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.gridLineColor
     * @see https://api.highcharts.com/highstock/zAxis.gridLineColor
     * @see https://api.highcharts.com/highmaps/zAxis.gridLineColor
     * @see https://api.highcharts.com/gantt/zAxis.gridLineColor
     */
    gridLineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The dash or dot style of the
     * grid lines. For possible values, see this demonstration.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.gridLineDashStyle
     * @see https://api.highcharts.com/highstock/zAxis.gridLineDashStyle
     * @see https://api.highcharts.com/highmaps/zAxis.gridLineDashStyle
     * @see https://api.highcharts.com/gantt/zAxis.gridLineDashStyle
     */
    gridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The width of the grid lines
     * extending the ticks across the plot area.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.gridLineWidth
     * @see https://api.highcharts.com/highstock/zAxis.gridLineWidth
     * @see https://api.highcharts.com/highmaps/zAxis.gridLineWidth
     * @see https://api.highcharts.com/gantt/zAxis.gridLineWidth
     */
    gridLineWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) The Z index of the grid lines.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.gridZIndex
     * @see https://api.highcharts.com/highstock/zAxis.gridZIndex
     * @see https://api.highcharts.com/gantt/zAxis.gridZIndex
     */
    gridZIndex?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An id for the axis. This can be
     * used after render time to get a pointer to the axis object through
     * `chart.get()`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.id
     * @see https://api.highcharts.com/highstock/zAxis.id
     * @see https://api.highcharts.com/highmaps/zAxis.id
     * @see https://api.highcharts.com/gantt/zAxis.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The axis labels show the number
     * or category for each tick.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.labels
     * @see https://api.highcharts.com/highstock/zAxis.labels
     * @see https://api.highcharts.com/highmaps/zAxis.labels
     * @see https://api.highcharts.com/gantt/zAxis.labels
     */
    labels?: ZAxisLabelsOptions;
    /**
     * (Highcharts, Highstock, Gantt) Index of another axis that this axis is
     * linked to. When an axis is linked to a master axis, it will take the same
     * extremes as the master, but as assigned by min or max or by setExtremes.
     * It can be used to show additional info, or to ease reading the chart by
     * duplicating the scales.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.linkedTo
     * @see https://api.highcharts.com/highstock/zAxis.linkedTo
     * @see https://api.highcharts.com/gantt/zAxis.linkedTo
     */
    linkedTo?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The maximum value of the axis.
     * If `null`, the max value is automatically calculated.
     *
     * If the endOnTick option is true, the `max` value might be rounded up.
     *
     * If a tickAmount is set, the axis may be extended beyond the set max in
     * order to reach the given number of ticks. The same may happen in a chart
     * with multiple axes, determined by chart. alignTicks, where a `tickAmount`
     * is applied internally.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.max
     * @see https://api.highcharts.com/highstock/zAxis.max
     * @see https://api.highcharts.com/highmaps/zAxis.max
     * @see https://api.highcharts.com/gantt/zAxis.max
     */
    max?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Padding of the max value
     * relative to the length of the axis. A padding of 0.05 will make a 100px
     * axis 5px longer. This is useful when you don't want the highest data
     * value to appear on the edge of the plot area. When the axis' `max` option
     * is set or a max extreme is set using `axis.setExtremes()`, the maxPadding
     * will be ignored.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.maxPadding
     * @see https://api.highcharts.com/highstock/zAxis.maxPadding
     * @see https://api.highcharts.com/highmaps/zAxis.maxPadding
     * @see https://api.highcharts.com/gantt/zAxis.maxPadding
     */
    maxPadding?: number;
    /**
     * (Highstock) Maximum range which can be set using the navigator's handles.
     * Opposite of xAxis.minRange.
     *
     * @see https://api.highcharts.com/highstock/zAxis.maxRange
     */
    maxRange?: number;
    /**
     * (Highcharts, Highstock) Deprecated. Use `minRange` instead.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.maxZoom
     * @see https://api.highcharts.com/highstock/zAxis.maxZoom
     */
    maxZoom?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The minimum value of the axis.
     * If `null` the min value is automatically calculated.
     *
     * If the startOnTick option is true (default), the `min` value might be
     * rounded down.
     *
     * The automatically calculated minimum value is also affected by floor,
     * softMin, minPadding, minRange as well as series.threshold and
     * series.softThreshold.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.min
     * @see https://api.highcharts.com/highstock/zAxis.min
     * @see https://api.highcharts.com/highmaps/zAxis.min
     * @see https://api.highcharts.com/gantt/zAxis.min
     */
    min?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color of the minor, secondary
     * grid lines.
     *
     * In styled mode, the stroke width is given in the
     * `.highcharts-minor-grid-line` class.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minorGridLineColor
     * @see https://api.highcharts.com/highstock/zAxis.minorGridLineColor
     * @see https://api.highcharts.com/highmaps/zAxis.minorGridLineColor
     * @see https://api.highcharts.com/gantt/zAxis.minorGridLineColor
     */
    minorGridLineColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The dash or dot style of the
     * minor grid lines. For possible values, see this demonstration.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minorGridLineDashStyle
     * @see https://api.highcharts.com/highstock/zAxis.minorGridLineDashStyle
     * @see https://api.highcharts.com/highmaps/zAxis.minorGridLineDashStyle
     * @see https://api.highcharts.com/gantt/zAxis.minorGridLineDashStyle
     */
    minorGridLineDashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Width of the minor, secondary
     * grid lines.
     *
     * In styled mode, the stroke width is given in the `.highcharts-grid-line`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minorGridLineWidth
     * @see https://api.highcharts.com/highstock/zAxis.minorGridLineWidth
     * @see https://api.highcharts.com/highmaps/zAxis.minorGridLineWidth
     * @see https://api.highcharts.com/gantt/zAxis.minorGridLineWidth
     */
    minorGridLineWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color for the minor tick marks.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minorTickColor
     * @see https://api.highcharts.com/highstock/zAxis.minorTickColor
     * @see https://api.highcharts.com/highmaps/zAxis.minorTickColor
     * @see https://api.highcharts.com/gantt/zAxis.minorTickColor
     */
    minorTickColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Specific tick interval in axis
     * units for the minor ticks. On a linear axis, if `"auto"`, the minor tick
     * interval is calculated as a fifth of the tickInterval. If `null` or
     * `undefined`, minor ticks are not shown.
     *
     * On logarithmic axes, the unit is the power of the value. For example,
     * setting the minorTickInterval to 1 puts one tick on each of 0.1, 1, 10,
     * 100 etc. Setting the minorTickInterval to 0.1 produces 9 ticks between 1
     * and 10, 10 and 100 etc.
     *
     * If user settings dictate minor ticks to become too dense, they don't make
     * sense, and will be ignored to prevent performance problems.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minorTickInterval
     * @see https://api.highcharts.com/highstock/zAxis.minorTickInterval
     * @see https://api.highcharts.com/highmaps/zAxis.minorTickInterval
     * @see https://api.highcharts.com/gantt/zAxis.minorTickInterval
     */
    minorTickInterval?: (number|string|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel length of the minor
     * tick marks.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minorTickLength
     * @see https://api.highcharts.com/highstock/zAxis.minorTickLength
     * @see https://api.highcharts.com/highmaps/zAxis.minorTickLength
     * @see https://api.highcharts.com/gantt/zAxis.minorTickLength
     */
    minorTickLength?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The position of the minor tick
     * marks relative to the axis line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minorTickPosition
     * @see https://api.highcharts.com/highstock/zAxis.minorTickPosition
     * @see https://api.highcharts.com/highmaps/zAxis.minorTickPosition
     * @see https://api.highcharts.com/gantt/zAxis.minorTickPosition
     */
    minorTickPosition?: ("inside"|"outside");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Enable or disable minor ticks.
     * Unless minorTickInterval is set, the tick interval is calculated as a
     * fifth of the `tickInterval`.
     *
     * On a logarithmic axis, minor ticks are laid out based on a best guess,
     * attempting to enter approximately 5 minor ticks between each major tick.
     *
     * Prior to v6.0.0, ticks were unabled in auto layout by setting
     * `minorTickInterval` to `"auto"`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minorTicks
     * @see https://api.highcharts.com/highstock/zAxis.minorTicks
     * @see https://api.highcharts.com/highmaps/zAxis.minorTicks
     * @see https://api.highcharts.com/gantt/zAxis.minorTicks
     */
    minorTicks?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the minor
     * tick mark.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minorTickWidth
     * @see https://api.highcharts.com/highstock/zAxis.minorTickWidth
     * @see https://api.highcharts.com/highmaps/zAxis.minorTickWidth
     * @see https://api.highcharts.com/gantt/zAxis.minorTickWidth
     */
    minorTickWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) Padding of the min value relative to the
     * length of the axis. A padding of 0.05 will make a 100px axis 5px longer.
     * This is useful when you don't want the lowest data value to appear on the
     * edge of the plot area. When the axis' `min` option is set or a min
     * extreme is set using `axis.setExtremes()`, the minPadding will be
     * ignored.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minPadding
     * @see https://api.highcharts.com/highstock/zAxis.minPadding
     * @see https://api.highcharts.com/gantt/zAxis.minPadding
     */
    minPadding?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The minimum range to display on
     * this axis. The entire axis will not be allowed to span over a smaller
     * interval than this. For example, for a datetime axis the main unit is
     * milliseconds. If minRange is set to 3600000, you can't zoom in more than
     * to one hour.
     *
     * The default minRange for the x axis is five times the smallest interval
     * between any of the data points.
     *
     * On a logarithmic axis, the unit for the minimum range is the power. So a
     * minRange of 1 means that the axis can be zoomed to 10-100, 100-1000,
     * 1000-10000 etc.
     *
     * Note that the `minPadding`, `maxPadding`, `startOnTick` and `endOnTick`
     * settings also affect how the extremes of the axis are computed.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minRange
     * @see https://api.highcharts.com/highstock/zAxis.minRange
     * @see https://api.highcharts.com/highmaps/zAxis.minRange
     * @see https://api.highcharts.com/gantt/zAxis.minRange
     */
    minRange?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The minimum tick interval
     * allowed in axis values. For example on zooming in on an axis with daily
     * data, this can be used to prevent the axis from showing hours. Defaults
     * to the closest distance between two points on the axis.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.minTickInterval
     * @see https://api.highcharts.com/highstock/zAxis.minTickInterval
     * @see https://api.highcharts.com/highmaps/zAxis.minTickInterval
     * @see https://api.highcharts.com/gantt/zAxis.minTickInterval
     */
    minTickInterval?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The distance in pixels from the
     * plot area to the axis line. A positive offset moves the axis with it's
     * line, labels and ticks away from the plot area. This is typically used
     * when two or more axes are displayed on the same side of the plot. With
     * multiple axes the offset is dynamically adjusted to avoid collision, this
     * can be overridden by setting offset explicitly.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.offset
     * @see https://api.highcharts.com/highstock/zAxis.offset
     * @see https://api.highcharts.com/highmaps/zAxis.offset
     * @see https://api.highcharts.com/gantt/zAxis.offset
     */
    offset?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to display the axis on
     * the opposite side of the normal. The normal is on the left side for
     * vertical axes and bottom for horizontal, so the opposite sides will be
     * right and top respectively. This is typically used with dual or multiple
     * axes.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.opposite
     * @see https://api.highcharts.com/highstock/zAxis.opposite
     * @see https://api.highcharts.com/highmaps/zAxis.opposite
     * @see https://api.highcharts.com/gantt/zAxis.opposite
     */
    opposite?: boolean;
    /**
     * (Highstock) In an ordinal axis, the points are equally spaced in the
     * chart regardless of the actual time or x distance between them. This
     * means that missing data periods (e.g. nights or weekends for a stock
     * chart) will not take up space in the chart. Having `ordinal: false` will
     * show any gaps created by the `gapSize` setting proportionate to their
     * duration.
     *
     * In stock charts the X axis is ordinal by default, unless the boost module
     * is used and at least one of the series' data length exceeds the
     * boostThreshold.
     *
     * @see https://api.highcharts.com/highstock/zAxis.ordinal
     */
    ordinal?: boolean;
    /**
     * (Highstock) Additional range on the right side of the xAxis. Works
     * similar to `xAxis.maxPadding`, but value is set in milliseconds. Can be
     * set for both main `xAxis` and the navigator's `xAxis`.
     *
     * @see https://api.highcharts.com/highstock/zAxis.overscroll
     */
    overscroll?: number;
    /**
     * (Highcharts) Refers to the index in the panes array. Used for circular
     * gauges and polar charts. When the option is not set then first pane will
     * be used.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.pane
     */
    pane?: number;
    /**
     * (Highcharts, Highstock, Gantt) An array of colored bands stretching
     * across the plot area marking an interval on the axis.
     *
     * In styled mode, the plot bands are styled by the `.highcharts-plot-band`
     * class in addition to the `className` option.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands
     * @see https://api.highcharts.com/highstock/zAxis.plotBands
     * @see https://api.highcharts.com/gantt/zAxis.plotBands
     */
    plotBands?: Array<ZAxisPlotBandsOptions>;
    /**
     * (Highcharts, Highstock, Gantt) An array of lines stretching across the
     * plot area, marking a specific value on one of the axes.
     *
     * In styled mode, the plot lines are styled by the `.highcharts-plot-line`
     * class in addition to the `className` option.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines
     * @see https://api.highcharts.com/highstock/zAxis.plotLines
     * @see https://api.highcharts.com/gantt/zAxis.plotLines
     */
    plotLines?: Array<ZAxisPlotLinesOptions>;
    /**
     * (Highstock) The zoomed range to display when only defining one or none of
     * `min` or `max`. For example, to show the latest month, a range of one
     * month can be set.
     *
     * @see https://api.highcharts.com/highstock/zAxis.range
     */
    range?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to reverse the axis so
     * that the highest number is closest to the origin. If the chart is
     * inverted, the x axis is reversed by default.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.reversed
     * @see https://api.highcharts.com/highstock/zAxis.reversed
     * @see https://api.highcharts.com/highmaps/zAxis.reversed
     * @see https://api.highcharts.com/gantt/zAxis.reversed
     */
    reversed?: boolean;
    /**
     * (Highcharts, Highstock) This option determines how stacks should be
     * ordered within a group. For example reversed xAxis also reverses stacks,
     * so first series comes last in a group. To keep order like for
     * non-reversed xAxis enable this option.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.reversedStacks
     * @see https://api.highcharts.com/highstock/zAxis.reversedStacks
     */
    reversedStacks?: boolean;
    /**
     * (Highstock) An optional scrollbar to display on the X axis in response to
     * limiting the minimum and maximum of the axis values.
     *
     * In styled mode, all the presentational options for the scrollbar are
     * replaced by the classes `.highcharts-scrollbar-thumb`,
     * `.highcharts-scrollbar-arrow`, `.highcharts-scrollbar-button`,
     * `.highcharts-scrollbar-rifles` and `.highcharts-scrollbar-track`.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar
     */
    scrollbar?: ZAxisScrollbarOptions;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to show the first tick
     * label.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.showFirstLabel
     * @see https://api.highcharts.com/highstock/zAxis.showFirstLabel
     * @see https://api.highcharts.com/highmaps/zAxis.showFirstLabel
     * @see https://api.highcharts.com/gantt/zAxis.showFirstLabel
     */
    showFirstLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Whether to show the last tick label.
     * Defaults to `true` on cartesian charts, and `false` on polar charts.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.showLastLabel
     * @see https://api.highcharts.com/highstock/zAxis.showLastLabel
     * @see https://api.highcharts.com/gantt/zAxis.showLastLabel
     */
    showLastLabel?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) A soft maximum for the axis. If the series
     * data maximum is less than this, the axis will stay at this maximum, but
     * if the series data maximum is higher, the axis will flex to show all
     * data.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.softMax
     * @see https://api.highcharts.com/highstock/zAxis.softMax
     * @see https://api.highcharts.com/gantt/zAxis.softMax
     */
    softMax?: number;
    /**
     * (Highcharts, Highstock, Gantt) A soft minimum for the axis. If the series
     * data minimum is greater than this, the axis will stay at this minimum,
     * but if the series data minimum is lower, the axis will flex to show all
     * data.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.softMin
     * @see https://api.highcharts.com/highstock/zAxis.softMin
     * @see https://api.highcharts.com/gantt/zAxis.softMin
     */
    softMin?: number;
    /**
     * (Highcharts, Highstock, Gantt) For datetime axes, this decides where to
     * put the tick between weeks. 0 = Sunday, 1 = Monday.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.startOfWeek
     * @see https://api.highcharts.com/highstock/zAxis.startOfWeek
     * @see https://api.highcharts.com/gantt/zAxis.startOfWeek
     */
    startOfWeek?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Whether to force the axis to
     * start on a tick. Use this option with the `minPadding` option to control
     * the axis start.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.startOnTick
     * @see https://api.highcharts.com/highstock/zAxis.startOnTick
     * @see https://api.highcharts.com/highmaps/zAxis.startOnTick
     * @see https://api.highcharts.com/gantt/zAxis.startOnTick
     */
    startOnTick?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) The amount of ticks to draw on the axis.
     * This opens up for aligning the ticks of multiple charts or panes within a
     * chart. This option overrides the `tickPixelInterval` option.
     *
     * This option only has an effect on linear axes. Datetime, logarithmic or
     * category axes are not affected.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.tickAmount
     * @see https://api.highcharts.com/highstock/zAxis.tickAmount
     * @see https://api.highcharts.com/gantt/zAxis.tickAmount
     */
    tickAmount?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Color for the main tick marks.
     *
     * In styled mode, the stroke is given in the `.highcharts-tick` class.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.tickColor
     * @see https://api.highcharts.com/highstock/zAxis.tickColor
     * @see https://api.highcharts.com/highmaps/zAxis.tickColor
     * @see https://api.highcharts.com/gantt/zAxis.tickColor
     */
    tickColor?: ColorString;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The interval of the tick marks
     * in axis units. When `undefined`, the tick interval is computed to
     * approximately follow the tickPixelInterval on linear and datetime axes.
     * On categorized axes, a `undefined` tickInterval will default to 1, one
     * category. Note that datetime axes are based on milliseconds, so for
     * example an interval of one day is expressed as `24 * 3600 * 1000`.
     *
     * On logarithmic axes, the tickInterval is based on powers, so a
     * tickInterval of 1 means one tick on each of 0.1, 1, 10, 100 etc. A
     * tickInterval of 2 means a tick of 0.1, 10, 1000 etc. A tickInterval of
     * 0.2 puts a tick on 0.1, 0.2, 0.4, 0.6, 0.8, 1, 2, 4, 6, 8, 10, 20, 40
     * etc.
     *
     * If the tickInterval is too dense for labels to be drawn, Highcharts may
     * remove ticks.
     *
     * If the chart has multiple axes, the alignTicks option may interfere with
     * the `tickInterval` setting.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.tickInterval
     * @see https://api.highcharts.com/highstock/zAxis.tickInterval
     * @see https://api.highcharts.com/highmaps/zAxis.tickInterval
     * @see https://api.highcharts.com/gantt/zAxis.tickInterval
     */
    tickInterval?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel length of the main
     * tick marks.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.tickLength
     * @see https://api.highcharts.com/highstock/zAxis.tickLength
     * @see https://api.highcharts.com/highmaps/zAxis.tickLength
     * @see https://api.highcharts.com/gantt/zAxis.tickLength
     */
    tickLength?: number;
    /**
     * (Highcharts, Gantt) For categorized axes only. If `on` the tick mark is
     * placed in the center of the category, if `between` the tick mark is
     * placed between categories. The default is `between` if the `tickInterval`
     * is 1, else `on`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.tickmarkPlacement
     * @see https://api.highcharts.com/gantt/zAxis.tickmarkPlacement
     */
    tickmarkPlacement?: ("between"|"on");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) If tickInterval is `null` this
     * option sets the approximate pixel interval of the tick marks. Not
     * applicable to categorized axis.
     *
     * The tick interval is also influenced by the minTickInterval option, that,
     * by default prevents ticks from being denser than the data points.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.tickPixelInterval
     * @see https://api.highcharts.com/highstock/zAxis.tickPixelInterval
     * @see https://api.highcharts.com/highmaps/zAxis.tickPixelInterval
     * @see https://api.highcharts.com/gantt/zAxis.tickPixelInterval
     */
    tickPixelInterval?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The position of the major tick
     * marks relative to the axis line. Can be one of `inside` and `outside`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.tickPosition
     * @see https://api.highcharts.com/highstock/zAxis.tickPosition
     * @see https://api.highcharts.com/highmaps/zAxis.tickPosition
     * @see https://api.highcharts.com/gantt/zAxis.tickPosition
     */
    tickPosition?: ("inside"|"outside");
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) A callback function returning
     * array defining where the ticks are laid out on the axis. This overrides
     * the default behaviour of tickPixelInterval and tickInterval. The
     * automatic tick positions are accessible through `this.tickPositions` and
     * can be modified by the callback.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.tickPositioner
     * @see https://api.highcharts.com/highstock/zAxis.tickPositioner
     * @see https://api.highcharts.com/highmaps/zAxis.tickPositioner
     * @see https://api.highcharts.com/gantt/zAxis.tickPositioner
     */
    tickPositioner?: AxisTickPositionerCallbackFunction;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) An array defining where the
     * ticks are laid out on the axis. This overrides the default behaviour of
     * tickPixelInterval and tickInterval.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.tickPositions
     * @see https://api.highcharts.com/highstock/zAxis.tickPositions
     * @see https://api.highcharts.com/highmaps/zAxis.tickPositions
     * @see https://api.highcharts.com/gantt/zAxis.tickPositions
     */
    tickPositions?: Array<number>;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel width of the major
     * tick marks.
     *
     * In styled mode, the stroke width is given in the `.highcharts-tick`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.tickWidth
     * @see https://api.highcharts.com/highstock/zAxis.tickWidth
     * @see https://api.highcharts.com/highmaps/zAxis.tickWidth
     * @see https://api.highcharts.com/gantt/zAxis.tickWidth
     */
    tickWidth?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The axis title, showing next to
     * the axis line.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title
     * @see https://api.highcharts.com/highstock/zAxis.title
     * @see https://api.highcharts.com/highmaps/zAxis.title
     * @see https://api.highcharts.com/gantt/zAxis.title
     */
    title?: ZAxisTitleOptions;
    /**
     * (Highcharts, Gantt) The type of axis. Can be one of `linear`,
     * `logarithmic`, `datetime` or `category`. In a datetime axis, the numbers
     * are given in milliseconds, and tick marks are placed on appropriate
     * values like full hours or days. In a category axis, the point names of
     * the chart's series are used for categories, if not a categories array is
     * defined.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.type
     * @see https://api.highcharts.com/gantt/zAxis.type
     */
    type?: ("category"|"datetime"|"linear"|"logarithmic");
    /**
     * (Highcharts, Gantt) Applies only when the axis `type` is `category`. When
     * `uniqueNames` is true, points are placed on the X axis according to their
     * names. If the same point name is repeated in the same or another series,
     * the point is placed on the same X position as other points of the same
     * name. When `uniqueNames` is false, the points are laid out in increasing
     * X positions regardless of their names, and the X axis category will take
     * the name of the last point in each position.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.uniqueNames
     * @see https://api.highcharts.com/gantt/zAxis.uniqueNames
     */
    uniqueNames?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Datetime axis only. An array determining
     * what time intervals the ticks are allowed to fall on. Each array item is
     * an array where the first value is the time unit and the second value
     * another array of allowed multiples. Defaults to:
     *
     * (see online documentation for example)
     *
     * @see https://api.highcharts.com/highcharts/zAxis.units
     * @see https://api.highcharts.com/highstock/zAxis.units
     * @see https://api.highcharts.com/gantt/zAxis.units
     */
    units?: Array<[string, (Array<number>|null)]>;
    /**
     * (Highcharts, Highstock, Gantt) Whether axis, including axis title, line,
     * ticks and labels, should be visible.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.visible
     * @see https://api.highcharts.com/highstock/zAxis.visible
     * @see https://api.highcharts.com/gantt/zAxis.visible
     */
    visible?: boolean;
}
/**
 * (Highcharts, Highstock, Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label
 * @see https://api.highcharts.com/highstock/zAxis.plotBands.label
 * @see https://api.highcharts.com/gantt/zAxis.plotBands.label
 */
export interface ZAxisPlotBandsLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label. Can be
     * one of "left", "center" or "right".
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label.align
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.label.align
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.label.align
     */
    align?: string;
    /**
     * (Highcharts, Highstock, Gantt) Rotation of the text label in degrees .
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label.rotation
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.label.rotation
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.label.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-band-label` class.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label.style
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.label.style
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.label.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The string text itself. A subset of HTML
     * is supported.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label.text
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.label.text
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.label.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text alignment for the label. While
     * `align` determines where the texts anchor point is placed within the plot
     * band, `textAlign` determines how the text is aligned against its anchor
     * point. Possible values are "left", "center" and "right". Defaults to the
     * same as the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label.textAlign
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.label.textAlign
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.label.textAlign
     */
    textAlign?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label.useHTML
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.label.useHTML
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label relative
     * to the plot band. Can be one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label.verticalAlign
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.label.verticalAlign
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal position relative the
     * alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label.x
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.label.x
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.label.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical position of the text baseline
     * relative to the alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label.y
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.label.y
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.label.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of colored bands stretching across
 * the plot area marking an interval on the axis.
 *
 * In styled mode, the plot bands are styled by the `.highcharts-plot-band`
 * class in addition to the `className` option.
 *
 * @see https://api.highcharts.com/highcharts/zAxis.plotBands
 * @see https://api.highcharts.com/highstock/zAxis.plotBands
 * @see https://api.highcharts.com/gantt/zAxis.plotBands
 */
export interface ZAxisPlotBandsOptions {
    /**
     * (Highcharts, Highstock, Gantt) Border color for the plot band. Also
     * requires `borderWidth` to be set.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.borderColor
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.borderColor
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.borderColor
     */
    borderColor?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) Border width for the plot band. Also
     * requires `borderColor` to be set.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.borderWidth
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.borderWidth
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.borderWidth
     */
    borderWidth?: number;
    /**
     * (Highcharts, Highstock, Gantt) A custom class name, in addition to the
     * default `highcharts-plot-band`, to apply to each individual band.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.className
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.className
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The color of the plot band.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.color
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.color
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) An object defining mouse events for the
     * plot band. Supported properties are `click`, `mouseover`, `mouseout`,
     * `mousemove`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.events
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.events
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.events
     */
    events?: object;
    /**
     * (Highcharts, Highstock, Gantt) The start position of the plot band in
     * axis units.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.from
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.from
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.from
     */
    from?: number;
    /**
     * (Highcharts, Highstock, Gantt) An id used for identifying the plot band
     * in Axis.removePlotBand.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.id
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.id
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.label
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.label
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.label
     */
    label?: ZAxisPlotBandsLabelOptions;
    /**
     * (Highcharts, Highstock, Gantt) The end position of the plot band in axis
     * units.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.to
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.to
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.to
     */
    to?: number;
    /**
     * (Highcharts, Highstock, Gantt) The z index of the plot band within the
     * chart, relative to other elements. Using the same z index as another
     * element may give unpredictable results, as the last rendered element will
     * be on top. Values from 0 to 20 make sense.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotBands.zIndex
     * @see https://api.highcharts.com/highstock/zAxis.plotBands.zIndex
     * @see https://api.highcharts.com/gantt/zAxis.plotBands.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Gantt) Text labels for the plot bands
 *
 * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label
 * @see https://api.highcharts.com/highstock/zAxis.plotLines.label
 * @see https://api.highcharts.com/gantt/zAxis.plotLines.label
 */
export interface ZAxisPlotLinesLabelOptions {
    /**
     * (Highcharts, Highstock, Gantt) Horizontal alignment of the label. Can be
     * one of "left", "center" or "right".
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label.align
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.label.align
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.label.align
     */
    align?: ("center"|"left"|"right");
    /**
     * (Highcharts, Highstock, Gantt) Rotation of the text label in degrees.
     * Defaults to 0 for horizontal plot lines and 90 for vertical lines.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label.rotation
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.label.rotation
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.label.rotation
     */
    rotation?: number;
    /**
     * (Highcharts, Highstock, Gantt) CSS styles for the text label.
     *
     * In styled mode, the labels are styled by the
     * `.highcharts-plot-line-label` class.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label.style
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.label.style
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.label.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Gantt) The text itself. A subset of HTML is
     * supported.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label.text
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.label.text
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.label.text
     */
    text?: string;
    /**
     * (Highcharts, Highstock, Gantt) The text alignment for the label. While
     * `align` determines where the texts anchor point is placed within the plot
     * band, `textAlign` determines how the text is aligned against its anchor
     * point. Possible values are "left", "center" and "right". Defaults to the
     * same as the `align` option.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label.textAlign
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.label.textAlign
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.label.textAlign
     */
    textAlign?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the labels.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label.useHTML
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.label.useHTML
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.label.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Vertical alignment of the label relative
     * to the plot line. Can be one of "top", "middle" or "bottom".
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label.verticalAlign
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.label.verticalAlign
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.label.verticalAlign
     */
    verticalAlign?: ("bottom"|"middle"|"top");
    /**
     * (Highcharts, Highstock, Gantt) Horizontal position relative the
     * alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label.x
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.label.x
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.label.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical position of the text baseline
     * relative to the alignment. Default varies by orientation.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label.y
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.label.y
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.label.y
     */
    y?: number;
}
/**
 * (Highcharts, Highstock, Gantt) An array of lines stretching across the plot
 * area, marking a specific value on one of the axes.
 *
 * In styled mode, the plot lines are styled by the `.highcharts-plot-line`
 * class in addition to the `className` option.
 *
 * @see https://api.highcharts.com/highcharts/zAxis.plotLines
 * @see https://api.highcharts.com/highstock/zAxis.plotLines
 * @see https://api.highcharts.com/gantt/zAxis.plotLines
 */
export interface ZAxisPlotLinesOptions {
    /**
     * (Highcharts, Highstock, Gantt) A custom class name, in addition to the
     * default `highcharts-plot-line`, to apply to each individual line.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.className
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.className
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.className
     */
    className?: string;
    /**
     * (Highcharts, Highstock, Gantt) The color of the line.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.color
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.color
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.color
     */
    color?: ColorString;
    /**
     * (Highcharts, Highstock, Gantt) The dashing or dot style for the plot
     * line. For possible values see this overview.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.dashStyle
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.dashStyle
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.dashStyle
     */
    dashStyle?: ("Dash"|"DashDot"|"Dot"|"LongDash"|"LongDashDot"|"LongDashDotDot"|"ShortDash"|"ShortDashDot"|"ShortDashDotDot"|"ShortDot"|"Solid");
    /**
     * (Highcharts, Highstock, Gantt) An object defining mouse events for the
     * plot line. Supported properties are `click`, `mouseover`, `mouseout`,
     * `mousemove`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.events
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.events
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.events
     */
    events?: any;
    /**
     * (Highcharts, Highstock, Gantt) An id used for identifying the plot line
     * in Axis.removePlotLine.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.id
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.id
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.id
     */
    id?: string;
    /**
     * (Highcharts, Highstock, Gantt) Text labels for the plot bands
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.label
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.label
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.label
     */
    label?: ZAxisPlotLinesLabelOptions;
    /**
     * (Highcharts, Highstock, Gantt) The position of the line in axis units.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.value
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.value
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.value
     */
    value?: number;
    /**
     * (Highcharts, Highstock, Gantt) The width or thickness of the plot line.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.width
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.width
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.width
     */
    width?: number;
    /**
     * (Highcharts, Highstock, Gantt) The z index of the plot line within the
     * chart.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.plotLines.zIndex
     * @see https://api.highcharts.com/highstock/zAxis.plotLines.zIndex
     * @see https://api.highcharts.com/gantt/zAxis.plotLines.zIndex
     */
    zIndex?: number;
}
/**
 * (Highstock) An optional scrollbar to display on the X axis in response to
 * limiting the minimum and maximum of the axis values.
 *
 * In styled mode, all the presentational options for the scrollbar are replaced
 * by the classes `.highcharts-scrollbar-thumb`, `.highcharts-scrollbar-arrow`,
 * `.highcharts-scrollbar-button`, `.highcharts-scrollbar-rifles` and
 * `.highcharts-scrollbar-track`.
 *
 * @see https://api.highcharts.com/highstock/zAxis.scrollbar
 */
export interface ZAxisScrollbarOptions {
    /**
     * (Highstock) The background color of the scrollbar itself.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.barBackgroundColor
     */
    barBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the scrollbar's border.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.barBorderColor
     */
    barBorderColor?: ColorString;
    /**
     * (Highstock) The border rounding radius of the bar.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.barBorderRadius
     */
    barBorderRadius?: number;
    /**
     * (Highstock) The width of the bar's border.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.barBorderWidth
     */
    barBorderWidth?: number;
    /**
     * (Highstock) The color of the small arrow inside the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.buttonArrowColor
     */
    buttonArrowColor?: ColorString;
    /**
     * (Highstock) The color of scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.buttonBackgroundColor
     */
    buttonBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the border of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.buttonBorderColor
     */
    buttonBorderColor?: ColorString;
    /**
     * (Highstock) The corner radius of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.buttonBorderRadius
     */
    buttonBorderRadius?: number;
    /**
     * (Highstock) The border width of the scrollbar buttons.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.buttonBorderWidth
     */
    buttonBorderWidth?: number;
    /**
     * (Highstock) Enable or disable the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.enabled
     */
    enabled?: boolean;
    /**
     * (Highstock) The height of the scrollbar. The height also applies to the
     * width of the scroll arrows so that they are always squares. Defaults to
     * 20 for touch devices and 14 for mouse devices.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.height
     */
    height?: number;
    /**
     * (Highstock) Whether to redraw the main chart as the scrollbar or the
     * navigator zoomed window is moved. Defaults to `true` for modern browsers
     * and `false` for legacy IE browsers as well as mobile devices.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.liveRedraw
     */
    liveRedraw?: boolean;
    /**
     * (Highstock) The margin between the scrollbar and its axis when the
     * scrollbar is applied directly to an axis.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.margin
     */
    margin?: number;
    /**
     * (Highstock) The minimum width of the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.minWidth
     */
    minWidth?: number;
    /**
     * (Highstock) The color of the small rifles in the middle of the scrollbar.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.rifleColor
     */
    rifleColor?: ColorString;
    /**
     * (Highstock) Whether to show or hide the scrollbar when the scrolled
     * content is zoomed out to it full extent.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.showFull
     */
    showFull?: boolean;
    step?: number;
    /**
     * (Highstock) The color of the track background.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.trackBackgroundColor
     */
    trackBackgroundColor?: ColorString;
    /**
     * (Highstock) The color of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.trackBorderColor
     */
    trackBorderColor?: ColorString;
    /**
     * (Highstock) The corner radius of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.trackBorderRadius
     */
    trackBorderRadius?: number;
    /**
     * (Highstock) The width of the border of the scrollbar track.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.trackBorderWidth
     */
    trackBorderWidth?: number;
    /**
     * (Highstock) The z index of the scrollbar group.
     *
     * @see https://api.highcharts.com/highstock/zAxis.scrollbar.zIndex
     */
    zIndex?: number;
}
/**
 * (Highcharts, Highstock, Highmaps, Gantt) The axis title, showing next to the
 * axis line.
 *
 * @see https://api.highcharts.com/highcharts/zAxis.title
 * @see https://api.highcharts.com/highstock/zAxis.title
 * @see https://api.highcharts.com/highmaps/zAxis.title
 * @see https://api.highcharts.com/gantt/zAxis.title
 */
export interface ZAxisTitleOptions {
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Alignment of the title relative
     * to the axis values. Possible values are "low", "middle" or "high".
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.align
     * @see https://api.highcharts.com/highstock/zAxis.title.align
     * @see https://api.highcharts.com/highmaps/zAxis.title.align
     * @see https://api.highcharts.com/gantt/zAxis.title.align
     */
    align?: ("high"|"low"|"middle");
    /**
     * (Highcharts) Deprecated. Set the `text` to `null` to disable the title.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.enabled
     */
    enabled?: string;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The pixel distance between the
     * axis labels or line and the title. Defaults to 0 for horizontal axes, 10
     * for vertical
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.margin
     * @see https://api.highcharts.com/highstock/zAxis.title.margin
     * @see https://api.highcharts.com/highmaps/zAxis.title.margin
     * @see https://api.highcharts.com/gantt/zAxis.title.margin
     */
    margin?: number;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The distance of the axis title
     * from the axis line. By default, this distance is computed from the offset
     * width of the labels, the labels' distance from the axis and the title's
     * margin. However when the offset option is set, it overrides all this.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.offset
     * @see https://api.highcharts.com/highstock/zAxis.title.offset
     * @see https://api.highcharts.com/highmaps/zAxis.title.offset
     * @see https://api.highcharts.com/gantt/zAxis.title.offset
     */
    offset?: number;
    /**
     * (Highcharts) Defines how the title is repositioned according to the 3D
     * chart orientation.
     *
     * - `'offset'`: Maintain a fixed horizontal/vertical distance from the tick
     * marks, despite the chart orientation. This is the backwards compatible
     * behavior, and causes skewing of X and Z axes.
     *
     * - `'chart'`: Preserve 3D position relative to the chart. This looks nice,
     * but hard to read if the text isn't forward-facing.
     *
     * - `'flap'`: Rotated text along the axis to compensate for the chart
     * orientation. This tries to maintain text as legible as possible on all
     * orientations.
     *
     * - `'ortho'`: Rotated text along the axis direction so that the labels are
     * orthogonal to the axis. This is very similar to `'flap'`, but prevents
     * skewing the labels (X and Y scaling are still present).
     *
     * - `undefined`: Will use the config from `labels.position3d`
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.position3d
     */
    position3d?: ("chart"|"flap"|"offset"|"ortho"|null);
    /**
     * (Highcharts, Highstock, Gantt) Whether to reserve space for the title
     * when laying out the axis.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.reserveSpace
     * @see https://api.highcharts.com/highstock/zAxis.title.reserveSpace
     * @see https://api.highcharts.com/gantt/zAxis.title.reserveSpace
     */
    reserveSpace?: boolean;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The rotation of the text in
     * degrees. 0 is horizontal, 270 is vertical reading from bottom to top.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.rotation
     * @see https://api.highcharts.com/highstock/zAxis.title.rotation
     * @see https://api.highcharts.com/highmaps/zAxis.title.rotation
     * @see https://api.highcharts.com/gantt/zAxis.title.rotation
     */
    rotation?: number;
    /**
     * (Highcharts) If enabled, the axis title will skewed to follow the
     * perspective.
     *
     * This will fix overlapping labels and titles, but texts become less
     * legible due to the distortion.
     *
     * The final appearance depends heavily on `title.position3d`.
     *
     * A `null` value will use the config from `labels.skew3d`.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.skew3d
     */
    skew3d?: (boolean|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) CSS styles for the title. If the
     * title text is longer than the axis length, it will wrap to multiple lines
     * by default. This can be customized by setting `textOverflow: 'ellipsis'`,
     * by setting a specific `width` or by setting `whiteSpace: 'nowrap'`.
     *
     * In styled mode, the stroke width is given in the `.highcharts-axis-title`
     * class.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.style
     * @see https://api.highcharts.com/highstock/zAxis.title.style
     * @see https://api.highcharts.com/highmaps/zAxis.title.style
     * @see https://api.highcharts.com/gantt/zAxis.title.style
     */
    style?: CSSObject;
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) The actual text of the axis
     * title. It can contain basic HTML text markup like <b>, <i> and spans with
     * style.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.text
     * @see https://api.highcharts.com/highstock/zAxis.title.text
     * @see https://api.highcharts.com/highmaps/zAxis.title.text
     * @see https://api.highcharts.com/gantt/zAxis.title.text
     */
    text?: (string|null);
    /**
     * (Highcharts, Highstock, Highmaps, Gantt) Alignment of the text, can be
     * `"left"`, `"right"` or `"center"`. Default alignment depends on the
     * title.align:
     *
     * Horizontal axes:
     *
     * - for `align` = `"low"`, `textAlign` is set to `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"`, `textAlign` is set to `right`
     *
     * Vertical axes:
     *
     * - for `align` = `"low"` and `opposite` = `true`, `textAlign` is set to
     * `right`
     *
     * - for `align` = `"low"` and `opposite` = `false`, `textAlign` is set to
     * `left`
     *
     * - for `align` = `"middle"`, `textAlign` is set to `center`
     *
     * - for `align` = `"high"` and `opposite` = `true` `textAlign` is set to
     * `left`
     *
     * - for `align` = `"high"` and `opposite` = `false` `textAlign` is set to
     * `right`
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.textAlign
     * @see https://api.highcharts.com/highstock/zAxis.title.textAlign
     * @see https://api.highcharts.com/highmaps/zAxis.title.textAlign
     * @see https://api.highcharts.com/gantt/zAxis.title.textAlign
     */
    textAlign?: string;
    /**
     * (Highcharts, Highstock, Gantt) Whether to use HTML to render the axis
     * title.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.useHTML
     * @see https://api.highcharts.com/highstock/zAxis.title.useHTML
     * @see https://api.highcharts.com/gantt/zAxis.title.useHTML
     */
    useHTML?: boolean;
    /**
     * (Highcharts, Highstock, Gantt) Horizontal pixel offset of the title
     * position.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.x
     * @see https://api.highcharts.com/highstock/zAxis.title.x
     * @see https://api.highcharts.com/gantt/zAxis.title.x
     */
    x?: number;
    /**
     * (Highcharts, Highstock, Gantt) Vertical pixel offset of the title
     * position.
     *
     * @see https://api.highcharts.com/highcharts/zAxis.title.y
     * @see https://api.highcharts.com/highstock/zAxis.title.y
     * @see https://api.highcharts.com/gantt/zAxis.title.y
     */
    y?: number;
}
/**
 * Create a new axis object. Called internally when instanciating a new chart or
 * adding axes by Highcharts.Chart#addAxis.
 *
 * A chart can have from 0 axes (pie chart) to multiples. In a normal, single
 * series cartesian chart, there is one X axis and one Y axis.
 *
 * The X axis or axes are referenced by Highcharts.Chart.xAxis, which is an
 * array of Axis objects. If there is only one axis, it can be referenced
 * through `chart.xAxis[0]`, and multiple axes have increasing indices. The same
 * pattern goes for Y axes.
 *
 * If you need to get the axes from a series object, use the `series.xAxis` and
 * `series.yAxis` properties. These are not arrays, as one series can only be
 * associated to one X and one Y axis.
 *
 * A third way to reference the axis programmatically is by `id`. Add an `id` in
 * the axis configuration options, and get the axis by Highcharts.Chart#get.
 *
 * Configuration options for the axes are given in options.xAxis and
 * options.yAxis.
 */
export class Axis {
    /**
     * Create a new axis object. Called internally when instanciating a new
     * chart or adding axes by Highcharts.Chart#addAxis.
     *
     * A chart can have from 0 axes (pie chart) to multiples. In a normal,
     * single series cartesian chart, there is one X axis and one Y axis.
     *
     * The X axis or axes are referenced by Highcharts.Chart.xAxis, which is an
     * array of Axis objects. If there is only one axis, it can be referenced
     * through `chart.xAxis[0]`, and multiple axes have increasing indices. The
     * same pattern goes for Y axes.
     *
     * If you need to get the axes from a series object, use the `series.xAxis`
     * and `series.yAxis` properties. These are not arrays, as one series can
     * only be associated to one X and one Y axis.
     *
     * A third way to reference the axis programmatically is by `id`. Add an
     * `id` in the axis configuration options, and get the axis by
     * Highcharts.Chart#get.
     *
     * Configuration options for the axes are given in options.xAxis and
     * options.yAxis.
     *
     * @param chart
     *        The Chart instance to apply the axis on.
     *
     * @param options
     *        Axis options.
     */
    constructor(chart: Chart, options: AxisOptions);
    /**
     * The Chart that the axis belongs to.
     */
    chart: Chart;
    /**
     * The collection where the axis belongs, for example `xAxis`, `yAxis` or
     * `colorAxis`. Corresponds to properties on Chart, for example Chart.xAxis.
     */
    coll: string;
    /**
     * The processed crosshair options.
     */
    crosshair: (boolean|AxisCrosshairOptions);
    /**
     * Whether the axis is horizontal.
     */
    horiz: boolean;
    /**
     * Whether the axis is the x-axis.
     */
    isXAxis?: boolean;
    /**
     * The maximum value of the axis. In a logarithmic axis, this is the
     * logarithm of the real value, and the real value can be obtained from
     * Axis#getExtremes.
     */
    max: (number|null);
    /**
     * The minimum value of the axis. In a logarithmic axis, this is the
     * logarithm of the real value, and the real value can be obtained from
     * Axis#getExtremes.
     */
    min: (number|null);
    /**
     * Whether the axis is reversed. Based on the `axis.reversed`, option, but
     * inverted charts have reversed xAxis by default.
     */
    reversed: boolean;
    /**
     * All series associated to the axis.
     */
    series: Array<Series>;
    /**
     * The side on which the axis is rendered. 0 is top, 1 is right, 2 is bottom
     * and 3 is left.
     */
    side: number;
    /**
     * Add a plot band after render time.
     *
     * @param options
     *        A configuration object for the plot band, as defined in
     *        xAxis.plotBands.
     *
     * @return The added plot band.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Axis#addPlotBand
     */
    addPlotBand(options: AxisPlotBandsOptions): (PlotLineOrBand|undefined);
    /**
     * Add a plot line after render time.
     *
     * @param options
     *        A configuration object for the plot line, as defined in
     *        xAxis.plotLines.
     *
     * @return The added plot line.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Axis#addPlotLine
     */
    addPlotLine(options: AxisPlotLinesOptions): (PlotLineOrBand|undefined);
    /**
     * Adds the title defined in axis.options.title.
     *
     * @param display
     *        Whether or not to display the title.
     */
    addTitle(display: boolean): void;
    /**
     * Internal function to draw a crosshair.
     *
     * @param e
     *        The event arguments from the modified pointer event, extended with
     *        `chartX` and `chartY`
     *
     * @param point
     *        The Point object if the crosshair snaps to points.
     *
     * @fires Highcharts.Axis#afterDrawCrosshair
     * @fires Highcharts.Axis#drawCrosshair
     */
    drawCrosshair(e?: PointerEventObject, point?: Point): void;
    /**
     * Get the current extremes for the axis.
     *
     * @return An object containing extremes information.
     */
    getExtremes(): ExtremesObject;
    /**
     * Internal function to et the tick positions of a linear axis to round
     * values like whole tens or every five.
     *
     * @param tickInterval
     *        The normalized tick interval.
     *
     * @param min
     *        Axis minimum.
     *
     * @param max
     *        Axis maximum.
     *
     * @return An array of axis values where ticks should be placed.
     */
    getLinearTickPositions(tickInterval: number, min: number, max: number): Array<number>;
    /**
     * Internal function to get the path for the axis line. Extended for polar
     * charts.
     *
     * @param lineWidth
     *        The line width in pixels.
     *
     * @return The SVG path definition in array form.
     */
    getLinePath(lineWidth: number): SVGPathArray;
    /**
     * Resolve the new minorTicks/minorTickInterval options into the legacy
     * loosely typed minorTickInterval option.
     */
    getMinorTickInterval(): ("auto"|number|null);
    /**
     * Internal function to return the minor tick positions. For logarithmic
     * axes, the same logic as for major ticks is reused.
     *
     * @return An array of axis values where ticks should be placed.
     */
    getMinorTickPositions(): Array<number>;
    /**
     * Internal function to create the SVG path definition for a plot band.
     *
     * @param from
     *        The axis value to start from.
     *
     * @param to
     *        The axis value to end on.
     *
     * @return The SVG path definition in array form.
     */
    getPlotBandPath(from: number, to: number): SVGPathArray;
    /**
     * Create the path for a plot line that goes from the given value on this
     * axis, across the plot to the opposite side. Also used internally for grid
     * lines and crosshairs.
     *
     * @param value
     *        Axis value.
     *
     * @param lineWidth
     *        Used for calculation crisp line coordinates.
     *
     * @param old
     *        Use old coordinates (for resizing and rescaling).
     *
     * @param force
     *        If `false`, the function will return null when it falls outside
     *        the axis bounds. If `true`, the function will return a path
     *        aligned to the plot area sides if it falls outside. If `pass`, it
     *        will return a path outside.
     *
     * @param translatedValue
     *        If given, return the plot line path of a pixel position on the
     *        axis.
     *
     * @return The SVG path definition for the plot line.
     */
    getPlotLinePath(value: number, lineWidth?: number, old?: boolean, force?: (boolean|string), translatedValue?: number): Array<(string|number)>;
    /**
     * Get the zero plane either based on zero or on the min or max value. Used
     * in bar and area plots.
     *
     * @param threshold
     *        The threshold in axis values.
     *
     * @return The translated threshold position in terms of pixels, and
     *         corrected to stay within the axis bounds.
     */
    getThreshold(threshold: number): number;
    /**
     * Return true if the axis has associated data.
     *
     * @return True if the axis has associated visible series and those series
     *         have either valid data points or explicit `min` and `max`
     *         settings.
     */
    hasData(): boolean;
    /**
     * Hide the crosshair if visible.
     */
    hideCrosshair(): void;
    /**
     * Overrideable function to initialize the axis.
     *
     *
     *
     * @fires Highcharts.Axis#afterInit
     * @fires Highcharts.Axis#init
     */
    init(chart: Chart, userOptions: Options): void;
    /**
     * Remove the axis from the chart.
     *
     * @param redraw
     *        Whether to redraw the chart following the remove.
     */
    remove(redraw?: boolean): void;
    /**
     * Remove a plot band by its id.
     *
     * @param id
     *        The plot band's `id` as given in the original configuration object
     *        or in the `addPlotBand` option.
     */
    removePlotBand(id: string): void;
    /**
     * Remove a plot line by its id.
     *
     * @param id
     *        The plot line's `id` as given in the original configuration object
     *        or in the `addPlotLine` option.
     */
    removePlotLine(id: string): void;
    /**
     * Render the axis line. Called internally when rendering and redrawing the
     * axis.
     */
    renderLine(): void;
    /**
     * Render a minor tick into the given position. If a minor tick already
     * exists in this position, move it.
     *
     * @param pos
     *        The position in axis values.
     */
    renderMinorTick(pos: number): void;
    /**
     * Render a major tick into the given position. If a tick already exists in
     * this position, move it.
     *
     * @param pos
     *        The position in axis values.
     *
     * @param i
     *        The tick index.
     */
    renderTick(pos: number, i: number): void;
    /**
     * Set new axis categories and optionally redraw.
     *
     * @param categories
     *        The new categories.
     *
     * @param redraw
     *        Whether to redraw the chart.
     */
    setCategories(categories: Array<string>, redraw?: boolean): void;
    /**
     * Set the minimum and maximum of the axes after render time. If the
     * `startOnTick` and `endOnTick` options are true, the minimum and maximum
     * values are rounded off to the nearest tick. To prevent this, these
     * options can be set to false before calling setExtremes. Also, setExtremes
     * will not allow a range lower than the `minRange` option, which by default
     * is the range of five points.
     *
     * @param newMin
     *        The new minimum value.
     *
     * @param newMax
     *        The new maximum value.
     *
     * @param redraw
     *        Whether to redraw the chart or wait for an explicit call to
     *        Highcharts.Chart#redraw
     *
     * @param animation
     *        Enable or modify animations.
     *
     * @param eventArguments
     *        Arguments to be accessed in event handler.
     *
     * @fires Highcharts.Axis#setExtremes
     */
    setExtremes(newMin?: number, newMax?: number, redraw?: boolean, animation?: (boolean|AnimationOptionsObject), eventArguments?: any): void;
    /**
     * Now we have computed the normalized tickInterval, get the tick positions
     *
     * @fires Highcharts.Axis#afterSetTickPositions
     */
    setTickPositions(): void;
    /**
     * Update the axis title by options after render time.
     *
     * @param titleOptions
     *        The additional title options.
     *
     * @param redraw
     *        Whether to redraw the chart after setting the title.
     */
    setTitle(titleOptions: (XAxisTitleOptions|YAxisTitleOptions|ZAxisTitleOptions), redraw?: boolean): void;
    /**
     * Translate a value in terms of axis units into pixels within the chart.
     *
     * @param value
     *        A value in terms of axis units.
     *
     * @param paneCoordinates
     *        Whether to return the pixel coordinate relative to the chart or
     *        just the axis/pane itself.
     *
     * @return Pixel position of the value on the chart or axis.
     */
    toPixels(value: number, paneCoordinates: boolean): number;
    /**
     * Translate a pixel position along the axis to a value in terms of axis
     * units.
     *
     * @param pixel
     *        The pixel value coordinate.
     *
     * @param paneCoordiantes
     *        Whether the input pixel is relative to the chart or just the
     *        axis/pane itself.
     *
     * @return The axis value.
     */
    toValue(pixel: number, paneCoordiantes: boolean): number;
    /**
     * Update an axis object with a new set of options. The options are merged
     * with the existing options, so only new or altered options need to be
     * specified.
     *
     * @param options
     *        The new options that will be merged in with existing options on
     *        the axis.
     *
     * @param redraw
     *        Whether to redraw the chart after the axis is altered. If doing
     *        more operations on the chart, it is a good idea to set redraw to
     *        false and call Chart#redraw after.
     */
    update(options: (XAxisOptions|YAxisOptions|ZAxisOptions), redraw?: boolean): void;
}
/**
 * The Chart class. The recommended constructor is Highcharts#chart.
 */
export class Chart {
    /**
     * The Chart class. The recommended constructor is Highcharts#chart.
     *
     * @param options
     *        The chart options structure.
     *
     * @param callback
     *        Function to run when the chart has loaded and and all external
     *        images are loaded. Defining a chart.event.load handler is
     *        equivalent.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Chart#constructor
     */
    constructor(options: Options, callback?: ChartCallbackFunction);
    /**
     * The Chart class. The recommended constructor is Highcharts#chart.
     *
     * @param renderTo
     *        The DOM element to render to, or its id.
     *
     * @param options
     *        The chart options structure.
     *
     * @param callback
     *        Function to run when the chart has loaded and and all external
     *        images are loaded. Defining a chart.event.load handler is
     *        equivalent.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Chart#constructor
     */
    constructor(renderTo: (string|HTMLDOMElement), options: Options, callback?: ChartCallbackFunction);
    /**
     * All the axes in the chart.
     */
    axes: Array<Axis>;
    /**
     * The current pixel height of the chart.
     */
    chartHeight: number;
    /**
     * The current pixel width of the chart.
     */
    chartWidth: number;
    /**
     * These collections (arrays) implement update() methods with support for
     * one-to-one option.
     */
    collectionsWithUpdate: any;
    /**
     * The containing HTML element of the chart. The container is dynamically
     * inserted into the element given as the `renderTo` parameter in the
     * Highcharts#chart constructor.
     */
    container: HTMLDOMElement;
    /**
     * The chart's credits label. The label has an `update` method that allows
     * setting new options as per the credits options set.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Chart#.credits
     */
    credits: SVGElement;
    /**
     * The overview of the chart's series.
     */
    legend: Legend;
    /**
     * The options structure for the chart. It contains members for the sub
     * elements like series, legend, tooltip etc.
     */
    options: Options;
    /**
     * The current height of the plot area in pixels.
     */
    plotHeight: number;
    /**
     * The current left position of the plot area in pixels.
     */
    plotLeft: number;
    /**
     * The current top position of the plot area in pixels.
     */
    plotTop: number;
    /**
     * The current width of the plot area in pixels.
     */
    plotWidth: number;
    /**
     * The Pointer that keeps track of mouse and touch interaction.
     */
    pointer: Pointer;
    /**
     * These properties cause isDirtyBox to be set to true when updating. Can be
     * extended from plugins.
     */
    propsRequireDirtyBox: any;
    /**
     * These properties cause all series to be updated when updating. Can be
     * extended from plugins.
     */
    propsRequireUpdateSeries: any;
    /**
     * The renderer instance of the chart. Each chart instance has only one
     * associated renderer.
     */
    renderer: SVGRenderer;
    /**
     * All the current series in the chart.
     */
    series: Array<Series>;
    /**
     * Whether the chart is in styled mode, meaning all presentatinoal
     * attributes are avoided.
     */
    styledMode: boolean;
    /**
     * The chart subtitle. The subtitle has an `update` method that allows
     * modifying the options directly or indirectly via `chart.update`.
     */
    subtitle: SubtitleObject;
    /**
     * The `Time` object associated with the chart. Since v6.0.5, time settings
     * can be applied individually for each chart. If no individual settings
     * apply, the `Time` object is shared by all instances.
     */
    time: Time;
    /**
     * The chart title. The title has an `update` method that allows modifying
     * the options directly or indirectly via `chart.update`.
     */
    title: TitleObject;
    /**
     * Tooltip object for points of series.
     */
    tooltip: Tooltip;
    /**
     * A collection of the X axes in the chart.
     */
    xAxis: Array<Axis>;
    /**
     * A collection of the Y axes in the chart.
     */
    yAxis: Array<Axis>;
    /**
     * Add an axis to the chart after render time. Note that this method should
     * never be used when adding data synchronously at chart render time, as it
     * adds expense to the calculations and rendering. When adding data at the
     * same time as the chart is initialized, add the axis as a configuration
     * option instead.
     *
     * @param options
     *        The axis options.
     *
     * @param isX
     *        Whether it is an X axis or a value axis.
     *
     * @param redraw
     *        Whether to redraw the chart after adding.
     *
     * @param animation
     *        Whether and how to apply animation in the redraw.
     *
     * @return The newly generated Axis object.
     */
    addAxis(options: (XAxisOptions|YAxisOptions|ZAxisOptions), isX?: boolean, redraw?: boolean, animation?: (boolean|AnimationOptionsObject)): Axis;
    /**
     * Set a new credits label for the chart.
     *
     * @param options
     *        A configuration object for the new credits.
     */
    addCredits(options: CreditsOptions): void;
    /**
     * Add a series to the chart after render time. Note that this method should
     * never be used when adding data synchronously at chart render time, as it
     * adds expense to the calculations and rendering. When adding data at the
     * same time as the chart is initialized, add the series as a configuration
     * option instead. With multiple axes, the `offset` is dynamically adjusted.
     *
     * @param options
     *        The config options for the series.
     *
     * @param redraw
     *        Whether to redraw the chart after adding.
     *
     * @param animation
     *        Whether to apply animation, and optionally animation
     *        configuration.
     *
     * @return The newly created series object.
     *
     * @fires Highcharts.Chart#addSeries
     * @fires Highcharts.Chart#afterAddSeries
     */
    addSeries(options: SeriesOptionsType, redraw?: boolean, animation?: (boolean|AnimationOptionsObject)): Series;
    /**
     * Remove the chart and purge memory. This method is called internally
     * before adding a second chart into the same container, as well as on
     * window unload to prevent leaks.
     *
     * @fires Highcharts.Chart#destroy
     */
    destroy(): void;
    /**
     * Get an axis, series or point object by `id` as given in the configuration
     * options. Returns `undefined` if no item is found.
     *
     * @param id
     *        The id as given in the configuration options.
     *
     * @return The retrieved item.
     */
    get(id: string): (Axis|Point|Series|undefined);
    /**
     * Internal function to get the chart width and height according to options
     * and container size. Sets Chart.chartWidth and Chart.chartHeight.
     */
    getChartSize(): void;
    /**
     * Returns an array of all currently selected points in the chart. Points
     * can be selected by clicking or programmatically by the
     * Highcharts.Point#select function.
     *
     * @return The currently selected points.
     */
    getSelectedPoints(): Array<Point>;
    /**
     * Returns an array of all currently selected series in the chart. Series
     * can be selected either programmatically by the Highcharts.Series#select
     * function or by checking the checkbox next to the legend item if
     * series.showCheckBox is true.
     *
     * @return The currently selected series.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Chart#getSelectedSeries
     */
    getSelectedSeries(): Array<Series>;
    /**
     * Hide the loading layer.
     */
    hideLoading(): void;
    /**
     * Overridable function that initializes the chart. The constructor's
     * arguments are passed on directly.
     *
     * @param userOptions
     *        Custom options.
     *
     * @param callback
     *        Function to run when the chart has loaded and and all external
     *        images are loaded.
     *
     * @fires Highcharts.Chart#init
     * @fires Highcharts.Chart#afterInit
     */
    init(userOptions: Options, callback?: () => void): void;
    /**
     * Check whether a given point is within the plot area.
     *
     * @param plotX
     *        Pixel x relative to the plot area.
     *
     * @param plotY
     *        Pixel y relative to the plot area.
     *
     * @param inverted
     *        Whether the chart is inverted.
     *
     * @return Returns true if the given point is inside the plot area.
     */
    isInsidePlot(plotX: number, plotY: number, inverted: boolean): boolean;
    /**
     * Redraw the chart after changes have been done to the data, axis extremes
     * chart size or chart elements. All methods for updating axes, series or
     * points have a parameter for redrawing the chart. This is `true` by
     * default. But in many cases you want to do more than one operation on the
     * chart before redrawing, for example add a number of points. In those
     * cases it is a waste of resources to redraw the chart for each new point
     * added. So you add the points and call `chart.redraw()` after.
     *
     * @param animation
     *        If or how to apply animation to the redraw.
     *
     * @fires Highcharts.Chart#afterSetExtremes
     * @fires Highcharts.Chart#beforeRedraw
     * @fires Highcharts.Chart#predraw
     * @fires Highcharts.Chart#redraw
     * @fires Highcharts.Chart#render
     * @fires Highcharts.Chart#updatedData
     */
    redraw(animation?: (boolean|AnimationOptionsObject)): void;
    /**
     * Reflows the chart to its container. By default, the chart reflows
     * automatically to its container following a `window.resize` event, as per
     * the chart.reflow option. However, there are no reliable events for div
     * resize, so if the container is resized without a window resize event,
     * this must be called explicitly.
     *
     * @param e
     *        Event arguments. Used primarily when the function is called
     *        internally as a response to window resize.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Chart#reflow
     */
    reflow(e?: Event): void;
    /**
     * Set the chart container's class name, in addition to
     * `highcharts-container`.
     */
    setClassName(className: string): void;
    /**
     * Resize the chart to a given width and height. In order to set the width
     * only, the height argument may be skipped. To set the height only, pass
     * `undefined` for the width.
     *
     * @param width
     *        The new pixel width of the chart. Since v4.2.6, the argument can
     *        be `undefined` in order to preserve the current value (when
     *        setting height only), or `null` to adapt to the width of the
     *        containing element.
     *
     * @param height
     *        The new pixel height of the chart. Since v4.2.6, the argument can
     *        be `undefined` in order to preserve the current value, or `null`
     *        in order to adapt to the height of the containing element.
     *
     * @param animation
     *        Whether and how to apply animation.
     *
     * @fires Highcharts.Chart#endResize
     * @fires Highcharts.Chart#resize
     */
    setSize(width?: (number|null), height?: (number|null), animation?: AnimationOptionsObject): void;
    /**
     * Shortcut to set the subtitle options. This can also be done from
     * Chart#update or Chart#setTitle.
     *
     * @param options
     *        New subtitle options. The subtitle text itself is set by the
     *        `options.text` property.
     */
    setSubtitle(options: SubtitleOptions): void;
    /**
     * Set a new title or subtitle for the chart.
     *
     * @param titleOptions
     *        New title options. The title text itself is set by the
     *        `titleOptions.text` property.
     *
     * @param subtitleOptions
     *        New subtitle options. The subtitle text itself is set by the
     *        `subtitleOptions.text` property.
     *
     * @param redraw
     *        Whether to redraw the chart or wait for a later call to
     *        `chart.redraw()`.
     */
    setTitle(titleOptions: TitleOptions, subtitleOptions: SubtitleOptions, redraw: boolean): void;
    /**
     * Dim the chart and show a loading text or symbol. Options for the loading
     * screen are defined in the loading options.
     *
     * @param str
     *        An optional text to show in the loading label instead of the
     *        default one. The default text is set in lang.loading.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Chart#showLoading
     */
    showLoading(str: string): void;
    /**
     * A generic function to update any element of the chart. Elements can be
     * enabled and disabled, moved, re-styled, re-formatted etc.
     *
     * A special case is configuration objects that take arrays, for example
     * xAxis, yAxis or series. For these collections, an `id` option is used to
     * map the new option set to an existing object. If an existing object of
     * the same id is not found, the corresponding item is updated. So for
     * example, running `chart.update` with a series item without an id, will
     * cause the existing chart's series with the same index in the series array
     * to be updated. When the `oneToOne` parameter is true, `chart.update` will
     * also take care of adding and removing items from the collection. Read
     * more under the parameter description below.
     *
     * See also the responsive option set. Switching between `responsive.rules`
     * basically runs `chart.update` under the hood.
     *
     * @param options
     *        A configuration object for the new chart options.
     *
     * @param redraw
     *        Whether to redraw the chart.
     *
     * @param oneToOne
     *        When `true`, the `series`, `xAxis` and `yAxis` collections will be
     *        updated one to one, and items will be either added or removed to
     *        match the new updated options. For example, if the chart has two
     *        series and we call `chart.update` with a configuration containing
     *        three series, one will be added. If we call `chart.update` with
     *        one series, one will be removed. Setting an empty `series` array
     *        will remove all series, but leaving out the `series` property will
     *        leave all series untouched. If the series have id's, the new
     *        series options will be matched by id, and the remaining ones
     *        removed.
     *
     * @param animation
     *        Whether to apply animation, and optionally animation
     *        configuration.
     *
     * @fires Highcharts.Chart#update
     * @fires Highcharts.Chart#afterUpdate
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Chart#update
     */
    update(options: Options, redraw?: boolean, oneToOne?: boolean, animation?: (boolean|AnimationOptionsObject)): void;
    /**
     * Zoom the chart out after a user has zoomed in. See also Axis.setExtremes.
     *
     * @fires Highcharts.Chart#selection
     */
    zoomOut(): void;
}
/**
 * The overview of the chart's series. The legend object is instanciated
 * internally in the chart constructor, and is available from the `chart.legend`
 * property. Each chart has only one legend.
 */
export class Legend {
    /**
     * The overview of the chart's series. The legend object is instanciated
     * internally in the chart constructor, and is available from the
     * `chart.legend` property. Each chart has only one legend.
     *
     * @param chart
     *        The chart instance.
     *
     * @param options
     *        Legend options.
     */
    constructor(chart: Chart, options: LegendOptions);
    /**
     * All items for the legend, which is an array of series for most series and
     * an array of points for pie series and its derivatives.
     */
    allItems: Array<(Point|Series)>;
    /**
     * SVG element of the legend box.
     */
    box: SVGElement;
    /**
     * Chart of this legend.
     */
    chart: Chart;
    /**
     * SVG group of the legend.
     */
    group: SVGElement;
    /**
     * Legend options.
     */
    options: LegendOptions;
    /**
     * SVG element of the legend title.
     */
    title: SVGElement;
    /**
     * Set the legend item text.
     *
     * @param item
     *        The item for which to update the text in the legend.
     */
    setText(item: (Point|Series)): void;
    /**
     * Update the legend with new options. Equivalent to running `chart.update`
     * with a legend configuration option.
     *
     * @param options
     *        Legend options.
     *
     * @param redraw
     *        Whether to redraw the chart after the axis is altered. If doing
     *        more operations on the chart, it is a good idea to set redraw to
     *        false and call Chart#redraw after. Whether to redraw the chart.
     *
     * @fires Highcharts.Legends#afterUpdate
     */
    update(options: LegendOptions, redraw?: boolean): void;
}
/**
 * The object wrapper for plot lines and plot bands
 */
export class PlotLineOrBand {
    /**
     * The object wrapper for plot lines and plot bands
     *
     *
     */
    constructor(axis: Axis, options: (AxisPlotBandsOptions|AxisPlotLinesOptions));
    /**
     * SVG element of the label.
     */
    label: SVGElement;
    /**
     * SVG element of the plot line or band.
     */
    svgElement: SVGElement;
    /**
     * Remove the plot line or band.
     */
    destroy(): void;
}
/**
 * The Point object. The point objects are generated from the `series.data`
 * configuration objects or raw numbers. They can be accessed from the
 * `Series.points` array. Other ways to instantiate points are through
 * Highcharts.Series#addPoint or Highcharts.Series#setData.
 */
export class Point {
    /**
     * The point's current color.
     */
    color: (ColorString|GradientColorObject|PatternObject);
    /**
     * The point's current color index, used in styled mode instead of `color`.
     * The color index is inserted in class names used for styling.
     */
    colorIndex: number;
    /**
     * (Highstock) Highstock only. If a point object is created by data
     * grouping, it doesn't reflect actual points in the raw data. In this case,
     * the `dataGroup` property holds information that points back to the raw
     * data.
     *
     * - `dataGroup.start` is the index of the first raw data point in the
     * group.
     *
     * - `dataGroup.length` is the amount of points in the group.
     */
    dataGroup?: SVGElement;
    /**
     * The point's options as applied in the initial configuration, or extended
     * through `Point.update`.
     */
    options: object;
    /**
     * Whether the point is selected or not.
     */
    selected: boolean;
    /**
     * The series object associated with the point.
     */
    series: Series;
    /**
     * For certain series types, like pie charts, where individual points can be
     * shown or hidden.
     */
    visible: boolean;
    /**
     * The x value of the point.
     */
    x: number;
    /**
     * The y value of the point.
     */
    y?: number;
    /**
     * Get the CSS class names for individual points. Used internally where the
     * returned value is set on every point.
     *
     * @return The class names.
     */
    getClassName(): string;
    /**
     * Return the configuration hash needed for the data label and tooltip
     * formatters.
     *
     * @return Abstract object used in formatters and formats.
     */
    getLabelConfig(): PointLabelObject;
    /**
     * In a series with `zones`, return the zone that the point belongs to.
     *
     * @return The zone item.
     */
    getZone(): PlotSeriesZonesOptions;
    /**
     * Get the path definition for the halo, which is usually a shadow-like
     * circle around the currently hovered point.
     *
     * @param size
     *        The radius of the circular halo.
     *
     * @return The path definition.
     */
    haloPath(size: number): SVGPathArray;
    /**
     * Initialize the point. Called internally based on the `series.data`
     * option.
     *
     * @param series
     *        The series object containing this point.
     *
     * @param options
     *        The data in either number, array or object format.
     *
     * @param x
     *        Optionally, the X value of the point.
     *
     * @return The Point instance.
     *
     * @fires Highcharts.Point#afterInit
     */
    init(series: Series, options: (number|object|Array<(number|string)>|null), x?: number): Point;
    /**
     * Runs on mouse out from the point. Called internally from mouse and touch
     * events.
     *
     * @fires Highcharts.Point#mouseOut
     */
    onMouseOut(): void;
    /**
     * Runs on mouse over the point. Called internally from mouse and touch
     * events.
     *
     * @param e
     *        The event arguments.
     */
    onMouseOver(e: PointerEventObject): void;
    /**
     * Transform number or array configs into objects. Used internally to unify
     * the different configuration formats for points. For example, a simple
     * number `10` in a line series will be transformed to `{ y: 10 }`, and an
     * array config like `[1, 10]` in a scatter series will be transformed to `{
     * x: 1, y: 10 }`.
     *
     * @param options
     *        The input option.
     *
     * @return Transformed options.
     */
    optionsToObject(options: (number|object|Array<(number|string)>|null)): object;
    /**
     * Remove a point and optionally redraw the series and if necessary the axes
     *
     * @param redraw
     *        Whether to redraw the chart or wait for an explicit call. When
     *        doing more operations on the chart, for example running
     *        `point.remove()` in a loop, it is best practice to set `redraw` to
     *        false and call `chart.redraw()` after.
     *
     * @param animation
     *        Whether to apply animation, and optionally animation
     *        configuration.
     */
    remove(redraw: boolean, animation?: (boolean|AnimationOptionsObject)): void;
    /**
     * Toggle the selection status of a point.
     *
     * @param selected
     *        When `true`, the point is selected. When `false`, the point is
     *        unselected. When `null` or `undefined`, the selection state is
     *        toggled.
     *
     * @param accumulate
     *        When `true`, the selection is added to other selected points. When
     *        `false`, other selected points are deselected. Internally in
     *        Highcharts, when allowPointSelect is `true`, selected points are
     *        accumulated on Control, Shift or Cmd clicking the point.
     *
     * @fires Highcharts.Point#select
     * @fires Highcharts.Point#unselect
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Point#select
     */
    select(selected?: boolean, accumulate?: boolean): void;
    /**
     * Set a value in an object, on the property defined by key. The key
     * supports nested properties using dot notation. The function modifies the
     * input object and does not make a copy.
     *
     * @param object
     *        The object to set the value on.
     *
     * @param value
     *        The value to set.
     *
     * @param key
     *        Key to the property to set.
     *
     * @return The modified object.
     */
    setNestedProperty(object: object, value: any, key: string): object;
    /**
     * Set the point's state.
     *
     * @param state
     *        The new state, can be one of `''` (an empty string), `hover` or
     *        `select`.
     *
     * @param move
     *        State for animation.
     *
     * @fires Highcharts.Point#afterSetState
     */
    setState(state?: string, move?: boolean): void;
    /**
     * Extendable method for formatting each point's tooltip line.
     *
     * @param pointFormat
     *        The point format.
     *
     * @return A string to be concatenated in to the common tooltip text.
     */
    tooltipFormatter(pointFormat: string): string;
    /**
     * Update point with new options (typically x/y data) and optionally redraw
     * the series.
     *
     * @param options
     *        The point options. Point options are handled as described under
     *        the `series.type.data` item for each series type. For example for
     *        a line series, if options is a single number, the point will be
     *        given that number as the marin y value. If it is an array, it will
     *        be interpreted as x and y values respectively. If it is an object,
     *        advanced options are applied.
     *
     * @param redraw
     *        Whether to redraw the chart after the point is updated. If doing
     *        more operations on the chart, it is best practice to set `redraw`
     *        to false and call `chart.redraw()` after.
     *
     * @param animation
     *        Whether to apply animation, and optionally animation
     *        configuration.
     *
     * @fires Highcharts.Point#update
     */
    update(options: (number|object|Array<(number|string)>|null), redraw?: boolean, animation?: (boolean|AnimationOptionsObject)): void;
}
/**
 * The mouse and touch tracker object. Each Chart item has one assosiated
 * Pointer item that can be accessed from the Chart.pointer property.
 */
export class Pointer {
    /**
     * The mouse and touch tracker object. Each Chart item has one assosiated
     * Pointer item that can be accessed from the Chart.pointer property.
     *
     * @param chart
     *        The Chart instance.
     *
     * @param options
     *        The root options object. The pointer uses options from the chart
     *        and tooltip structures.
     */
    constructor(chart: Chart, options: Options);
    /**
     * Destroys the Pointer object and disconnects DOM events.
     */
    destroy(): void;
    /**
     * Finds the closest point to a set of coordinates, using the k-d-tree
     * algorithm.
     *
     * @param series
     *        All the series to search in.
     *
     * @param shared
     *        Whether it is a shared tooltip or not.
     *
     * @param coordinates
     *        Chart coordinates of the pointer.
     *
     * @return The point closest to given coordinates.
     */
    findNearestKDPoints(series: Array<Series>, shared: boolean, coordinates: PointerCoordinatesObject): (Point|undefined);
    /**
     * Get the click position in terms of axis values.
     *
     * @param e
     *        Pointer event, extended with `chartX` and `chartY` properties.
     */
    getCoordinates(e: PointerEventObject): PointerAxisCoordinatesObject;
    /**
     * Utility to detect whether an element has, or has a parent with, a
     * specificclass name. Used on detection of tracker objects and on deciding
     * whether hovering the tooltip should cause the active series to mouse out.
     *
     * @param element
     *        The element to investigate.
     *
     * @param className
     *        The class name to look for.
     *
     * @return True if either the element or one of its parents has the given
     *         class name.
     */
    inClass(element: (HTMLDOMElement|SVGDOMElement), className: string): boolean;
    /**
     * Takes a browser event object and extends it with custom Highcharts
     * properties `chartX` and `chartY` in order to work on the internal
     * coordinate system.
     *
     * @param e
     *        Event object in standard browsers.
     *
     * @return A browser event with extended properties `chartX` and `chartY`.
     */
    normalize(e: Event): PointerEventObject;
    /**
     * Reset the tracking by hiding the tooltip, the hover series state and the
     * hover point
     *
     * @param allowMove
     *        Instead of destroying the tooltip altogether, allow moving it if
     *        possible.
     *
     */
    reset(allowMove: boolean, delay: number): void;
}
/**
 * This is the base series prototype that all other series types inherit from. A
 * new series is initialized either through the series option structure, or
 * after the chart is initialized, through Highcharts.Chart#addSeries.
 *
 * The object can be accessed in a number of ways. All series and point event
 * handlers give a reference to the `series` object. The chart object has a
 * series property that is a collection of all the chart's series. The point
 * objects and axis objects also have the same reference.
 *
 * Another way to reference the series programmatically is by `id`. Add an id in
 * the series configuration options, and get the series object by
 * Highcharts.Chart#get.
 *
 * Configuration options for the series are given in three levels. Options for
 * all series in a chart are given in the plotOptions.series object. Then
 * options for all series of a specific type are given in the plotOptions of
 * that type, for example `plotOptions.line`. Next, options for one single
 * series are given in the series array, or as arguments to `chart.addSeries`.
 *
 * The data in the series is stored in various arrays.
 *
 * - First, `series.options.data` contains all the original config options for
 * each point whether added by options or methods like `series.addPoint`.
 *
 * - Next, `series.data` contains those values converted to points, but in case
 * the series data length exceeds the `cropThreshold`, or if the data is
 * grouped, `series.data` doesn't contain all the points. It only contains the
 * points that have been created on demand.
 *
 * - Then there's `series.points` that contains all currently visible point
 * objects. In case of cropping, the cropped-away points are not part of this
 * array. The `series.points` array starts at `series.cropStart` compared to
 * `series.data` and `series.options.data`. If however the series data is
 * grouped, these can't be correlated one to one.
 *
 * - `series.xData` and `series.processedXData` contain clean x values,
 * equivalent to `series.data` and `series.points`.
 *
 * - `series.yData` and `series.processedYData` contain clean y values,
 * equivalent to `series.data` and `series.points`.
 */
export class Series {
    /**
     * This is the base series prototype that all other series types inherit
     * from. A new series is initialized either through the series option
     * structure, or after the chart is initialized, through
     * Highcharts.Chart#addSeries.
     *
     * The object can be accessed in a number of ways. All series and point
     * event handlers give a reference to the `series` object. The chart object
     * has a series property that is a collection of all the chart's series. The
     * point objects and axis objects also have the same reference.
     *
     * Another way to reference the series programmatically is by `id`. Add an
     * id in the series configuration options, and get the series object by
     * Highcharts.Chart#get.
     *
     * Configuration options for the series are given in three levels. Options
     * for all series in a chart are given in the plotOptions.series object.
     * Then options for all series of a specific type are given in the
     * plotOptions of that type, for example `plotOptions.line`. Next, options
     * for one single series are given in the series array, or as arguments to
     * `chart.addSeries`.
     *
     * The data in the series is stored in various arrays.
     *
     * - First, `series.options.data` contains all the original config options
     * for each point whether added by options or methods like
     * `series.addPoint`.
     *
     * - Next, `series.data` contains those values converted to points, but in
     * case the series data length exceeds the `cropThreshold`, or if the data
     * is grouped, `series.data` doesn't contain all the points. It only
     * contains the points that have been created on demand.
     *
     * - Then there's `series.points` that contains all currently visible point
     * objects. In case of cropping, the cropped-away points are not part of
     * this array. The `series.points` array starts at `series.cropStart`
     * compared to `series.data` and `series.options.data`. If however the
     * series data is grouped, these can't be correlated one to one.
     *
     * - `series.xData` and `series.processedXData` contain clean x values,
     * equivalent to `series.data` and `series.points`.
     *
     * - `series.yData` and `series.processedYData` contain clean y values,
     * equivalent to `series.data` and `series.points`.
     *
     * @param chart
     *        The chart instance.
     *
     * @param options
     *        The series options.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Series#constructor
     */
    constructor(chart: Chart, options: (object|SeriesOptionsType));
    /**
     * Read only. The chart that the series belongs to.
     */
    chart: Chart;
    /**
     * Read only. An array containing those values converted to points. In case
     * the series data length exceeds the `cropThreshold`, or if the data is
     * grouped, `series.data` doesn't contain all the points. Also, in case a
     * series is hidden, the `data` array may be empty. To access raw values,
     * `series.options.data` will always be up to date. `Series.data` only
     * contains the points that have been created on demand. To modify the data,
     * use Highcharts.Series#setData or Highcharts.Point#update.
     */
    data: Array<Point>;
    /**
     * The series name as given in the options. Defaults to "Series {n}".
     */
    name: string;
    /**
     * Read only. The series' current options. To update, use Series#update.
     */
    options: SeriesOptionsType;
    /**
     * An array containing all currently visible point objects. In case of
     * cropping, the cropped-away points are not part of this array. The
     * `series.points` array starts at `series.cropStart` compared to
     * `series.data` and `series.options.data`. If however the series data is
     * grouped, these can't be correlated one to one. To modify the data, use
     * Highcharts.Series#setData or Highcharts.Point#update.
     */
    points: Array<Point>;
    /**
     * Read only. The series' selected state as set by Highcharts.Series#select.
     */
    selected: boolean;
    /**
     * Read only. The series' type, like "line", "area", "column" etc. The type
     * in the series options anc can be altered using Series#update.
     */
    type: string;
    /**
     * Read only. The series' visibility state as set by Series#show,
     * Series#hide, or in the initial configuration.
     */
    visible: boolean;
    /**
     * Read only. The unique xAxis object associated with the series.
     */
    xAxis: Axis;
    /**
     * Read only. The unique yAxis object associated with the series.
     */
    yAxis: Axis;
    /**
     * Add a point to the series after render time. The point can be added at
     * the end, or by giving it an X value, to the start or in the middle of the
     * series.
     *
     * @param options
     *        The point options. If options is a single number, a point with
     *        that y value is appended to the series. If it is an array, it will
     *        be interpreted as x and y values respectively. If it is an object,
     *        advanced options as outlined under `series.data` are applied.
     *
     * @param redraw
     *        Whether to redraw the chart after the point is added. When adding
     *        more than one point, it is highly recommended that the redraw
     *        option be set to false, and instead Chart#redraw is explicitly
     *        called after the adding of points is finished. Otherwise, the
     *        chart will redraw after adding each point.
     *
     * @param shift
     *        If true, a point is shifted off the start of the series as one is
     *        appended to the end.
     *
     * @param animation
     *        Whether to apply animation, and optionally animation
     *        configuration.
     */
    addPoint(options: (number|object|Array<(number|string)>|null), redraw?: boolean, shift?: boolean, animation?: (boolean|AnimationOptionsObject)): void;
    /**
     * Animate in the series. Called internally twice. First with the `init`
     * parameter set to true, which sets up the initial state of the animation.
     * Then when ready, it is called with the `init` parameter undefined, in
     * order to perform the actual animation. After the second run, the function
     * is removed.
     *
     * @param init
     *        Initialize the animation.
     */
    animate(init: boolean): void;
    /**
     * Draw the graph. Called internally when rendering line-like series types.
     * The first time it generates the `series.graph` item and optionally other
     * series-wide items like `series.area` for area charts. On subsequent calls
     * these items are updated with new positions and attributes.
     */
    drawGraph(): void;
    /**
     * Draw the markers for line-like series types, and columns or other
     * graphical representation for Point objects for other series types. The
     * resulting element is typically stored as Point.graphic, and is created on
     * the first call and updated and moved on subsequent calls.
     */
    drawPoints(): void;
    /**
     * Get the series' color based on either the options or pulled from global
     * options.
     */
    getColor(): void;
    /**
     * Calculate Y extremes for the visible data. The result is set as `dataMin`
     * and `dataMax` on the Series item.
     *
     * @param yData
     *        The data to inspect. Defaults to the current data within the
     *        visible range.
     */
    getExtremes(yData?: Array<number>): void;
    /**
     * Return series name in "Series {Number}" format or the one defined by a
     * user. This method can be simply overridden as series name format can vary
     * (e.g. technical indicators).
     *
     * @return The series name.
     */
    getName(): string;
    /**
     * Get the translation and scale for the plot area of this series.
     */
    getPlotBox(): SeriesPlotBoxObject;
    /**
     * Get the series' symbol based on either the options or pulled from global
     * options.
     */
    getSymbol(): void;
    /**
     * Return the series points with null points filtered out.
     *
     * @param points
     *        The points to inspect, defaults to Series.points.
     *
     * @param insideOnly
     *        Whether to inspect only the points that are inside the visible
     *        view.
     *
     * @return The valid points.
     */
    getValidPoints(points?: Array<Point>, insideOnly?: boolean): Array<Point>;
    /**
     * Hide the series if visible. If the chart.ignoreHiddenSeries option is
     * true, the chart is redrawn without this series.
     *
     * @fires Highcharts.Series#hide
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Series#hide
     */
    hide(): void;
    /**
     * Get non-presentational attributes for a point. Used internally for both
     * styled mode and classic. Can be overridden for different series types.
     *
     * @param point
     *        The Point to inspect.
     *
     * @param state
     *        The state, can be either `hover`, `select` or undefined.
     *
     * @return A hash containing those attributes that are not settable from
     *         CSS.
     */
    markerAttribs(point: Point, state?: string): SVGAttributes;
    /**
     * Runs on mouse out of the series graphical items.
     *
     * @fires Highcharts.Series#mouseOut
     */
    onMouseOut(): void;
    /**
     * Runs on mouse over the series graphical items.
     *
     * @fires Highcharts.Series#mouseOver
     */
    onMouseOver(): void;
    /**
     * Remove a series and optionally redraw the chart.
     *
     * @param redraw
     *        Whether to redraw the chart or wait for an explicit call to
     *        Highcharts.Chart#redraw.
     *
     * @param animation
     *        Whether to apply animation, and optionally animation
     *        configuration.
     *
     * @param withEvent
     *        Used internally, whether to fire the series `remove` event.
     *
     * @fires Highcharts.Series#remove
     */
    remove(redraw?: boolean, animation?: (boolean|AnimationOptionsObject), withEvent?: boolean): void;
    /**
     * Remove a point from the series. Unlike the Highcharts.Point#remove
     * method, this can also be done on a point that is not instanciated because
     * it is outside the view or subject to Highstock data grouping.
     *
     * @param i
     *        The index of the point in the data array.
     *
     * @param redraw
     *        Whether to redraw the chart after the point is added. When
     *        removing more than one point, it is highly recommended that the
     *        `redraw` option be set to `false`, and instead
     *        Highcharts.Chart#redraw is explicitly called after the adding of
     *        points is finished.
     *
     * @param animation
     *        Whether and optionally how the series should be animated.
     *
     * @fires Highcharts.Point#remove
     */
    removePoint(i: number, redraw?: boolean, animation?: (boolean|AnimationOptionsObject)): void;
    /**
     * Render the graph and markers. Called internally when first rendering and
     * later when redrawing the chart. This function can be extended in plugins,
     * but normally shouldn't be called directly.
     *
     * @fires Highcharts.Series#afterRender
     */
    render(): void;
    /**
     * Select or unselect the series. This means its selected property is set,
     * the checkbox in the legend is toggled and when selected, the series is
     * returned by the Highcharts.Chart#getSelectedSeries function.
     *
     * @param selected
     *        True to select the series, false to unselect. If undefined, the
     *        selection state is toggled.
     *
     * @fires Highcharts.Series#select
     * @fires Highcharts.Series#unselect
     */
    select(selected?: boolean): void;
    /**
     * Apply a new set of data to the series and optionally redraw it. The new
     * data array is passed by reference (except in case of `updatePoints`), and
     * may later be mutated when updating the chart data.
     *
     * Note the difference in behaviour when setting the same amount of points,
     * or a different amount of points, as handled by the `updatePoints`
     * parameter.
     *
     * @param data
     *        Takes an array of data in the same format as described under
     *        `series.{type}.data` for the given series type, for example a line
     *        series would take data in the form described under
     *        series.line.data.
     *
     * @param redraw
     *        Whether to redraw the chart after the series is altered. If doing
     *        more operations on the chart, it is a good idea to set redraw to
     *        false and call Chart#redraw after.
     *
     * @param animation
     *        When the updated data is the same length as the existing data,
     *        points will be updated by default, and animation visualizes how
     *        the points are changed. Set false to disable animation, or a
     *        configuration object to set duration or easing.
     *
     * @param updatePoints
     *        When this is true, points will be updated instead of replaced
     *        whenever possible. This occurs a) when the updated data is the
     *        same length as the existing data, b) when points are matched by
     *        their id's, or c) when points can be matched by X values. This
     *        allows updating with animation and performs better. In this case,
     *        the original array is not passed by reference. Set `false` to
     *        prevent.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Series#setData
     */
    setData(data: Array<any>, redraw?: boolean, animation?: AnimationOptionsObject, updatePoints?: boolean): void;
    /**
     * Set the series options by merging from the options tree. Called
     * internally on initiating and updating series. This function will not
     * redraw the series. For API usage, use Series#update.
     *
     * @param itemOptions
     *        The series options.
     *
     * @fires Highcharts.Series#afterSetOptions
     */
    setOptions(itemOptions: SeriesOptionsType): SeriesOptionsType;
    /**
     * Set the state of the series. Called internally on mouse interaction
     * operations, but it can also be called directly to visually highlight a
     * series.
     *
     * @param state
     *        Can be either `hover` or undefined to set to normal state.
     */
    setState(state?: string): void;
    /**
     * Show or hide the series.
     *
     * @param visible
     *        True to show the series, false to hide. If undefined, the
     *        visibility is toggled.
     *
     * @param redraw
     *        Whether to redraw the chart after the series is altered. If doing
     *        more operations on the chart, it is a good idea to set redraw to
     *        false and call chart.redraw() after.
     *
     * @fires Highcharts.Series#hide
     * @fires Highcharts.Series#show
     */
    setVisible(visible?: boolean, redraw?: boolean): void;
    /**
     * Show the series if hidden.
     *
     * @fires Highcharts.Series#show
     */
    show(): void;
    /**
     * Translate data points from raw data values to chart specific positioning
     * data needed later in the `drawPoints` and `drawGraph` functions. This
     * function can be overridden in plugins and custom series type
     * implementations.
     *
     * @fires Highcharts.Series#events:translate
     */
    translate(): void;
    /**
     * Update the series with a new set of options. For a clean and precise
     * handling of new options, all methods and elements from the series are
     * removed, and it is initiated from scratch. Therefore, this method is more
     * performance expensive than some other utility methods like Series#setData
     * or Series#setVisible.
     *
     * @param options
     *        New options that will be merged with the series' existing options.
     *
     * @param redraw
     *        Whether to redraw the chart after the series is altered. If doing
     *        more operations on the chart, it is a good idea to set redraw to
     *        false and call Chart#redraw after.
     *
     * @fires Highcharts.Series#afterUpdate
     */
    update(options: SeriesOptionsType, redraw?: boolean): void;
}
/**
 * The SVGElement prototype is a JavaScript wrapper for SVG elements used in the
 * rendering layer of Highcharts. Combined with the Highcharts.SVGRenderer
 * object, these prototypes allow freeform annotation in the charts or even in
 * HTML pages without instanciating a chart. The SVGElement can also wrap HTML
 * labels, when `text` or `label` elements are created with the `useHTML`
 * parameter.
 *
 * The SVGElement instances are created through factory functions on the
 * Highcharts.SVGRenderer object, like rect, path, text, label, g and more.
 */
export class SVGElement {
    /**
     * The primary DOM node. Each `SVGElement` instance wraps a main DOM node,
     * but may also represent more nodes.
     */
    element: (HTMLDOMElement|SVGDOMElement);
    /**
     * The renderer that the SVGElement belongs to.
     */
    renderer: SVGRenderer;
    /**
     * Add the element to the DOM. All elements must be added this way.
     *
     * @param parent
     *        The parent item to add it to. If undefined, the element is added
     *        to the Highcharts.SVGRenderer.box.
     *
     * @return Returns the SVGElement for chaining.
     */
    add(parent?: (SVGDOMElement|SVGElement)): SVGElement;
    /**
     * Add a class name to an element.
     *
     * @param className
     *        The new class name to add.
     *
     * @param replace
     *        When true, the existing class name(s) will be overwritten with the
     *        new one. When false, the new one is added.
     *
     * @return Return the SVG element for chainability.
     */
    addClass(className: string, replace?: boolean): SVGElement;
    /**
     * Align the element relative to the chart or another box.
     *
     * @param alignOptions
     *        The alignment options. The function can be called without this
     *        parameter in order to re-align an element after the box has been
     *        updated.
     *
     * @param alignByTranslate
     *        Align element by translation.
     *
     * @param box
     *        The box to align to, needs a width and height. When the box is a
     *        string, it refers to an object in the Renderer. For example, when
     *        box is `spacingBox`, it refers to `Renderer.spacingBox` which
     *        holds `width`, `height`, `x` and `y` properties.
     *
     * @return Returns the SVGElement for chaining.
     */
    align(alignOptions?: AlignObject, alignByTranslate?: boolean, box?: (string|BBoxObject)): SVGElement;
    /**
     * Animate to given attributes or CSS properties.
     *
     * @param params
     *        SVG attributes or CSS to animate.
     *
     * @param options
     *        Animation options.
     *
     * @param complete
     *        Function to perform at the end of animation.
     *
     * @return Returns the SVGElement for chaining.
     */
    animate(params: SVGAttributes, options?: AnimationOptionsObject, complete?: () => void): SVGElement;
    /**
     * Apply native and custom attributes to the SVG elements.
     *
     * In order to set the rotation center for rotation, set x and y to 0 and
     * use `translateX` and `translateY` attributes to position the element
     * instead.
     *
     * Attributes frequently used in Highcharts are `fill`, `stroke`,
     * `stroke-width`.
     *
     * @param hash
     *        The native and custom SVG attributes.
     *
     * @param val
     *        If the type of the first argument is `string`, the second can be a
     *        value, which will serve as a single attribute setter. If the first
     *        argument is a string and the second is undefined, the function
     *        serves as a getter and the current value of the property is
     *        returned.
     *
     * @param complete
     *        A callback function to execute after setting the attributes. This
     *        makes the function compliant and interchangeable with the
     *        SVGElement#animate function.
     *
     * @param continueAnimation
     *        Used internally when `.attr` is called as part of an animation
     *        step. Otherwise, calling `.attr` for an attribute will stop
     *        animation for that attribute.
     *
     * @return If used as a setter, it returns the current Highcharts.SVGElement
     *         so the calls can be chained. If used as a getter, the current
     *         value of the attribute is returned.
     */
    attr(hash?: (string|SVGAttributes), val?: string, complete?: () => void, continueAnimation?: boolean): (number|string|SVGElement);
    /**
     * Apply a clipping rectangle to this element.
     *
     * @param clipRect
     *        The clipping rectangle. If skipped, the current clip is removed.
     *
     * @return Returns the SVG element to allow chaining.
     */
    clip(clipRect?: ClipRectElement): SVGElement;
    /**
     * Calculate the coordinates needed for drawing a rectangle crisply and
     * return the calculated attributes.
     *
     * @param rect
     *        Rectangle to crisp.
     *
     * @param strokeWidth
     *        The stroke width to consider when computing crisp positioning. It
     *        can also be set directly on the rect parameter.
     *
     * @return The modified rectangle arguments.
     */
    crisp(rect: RectangleObject, strokeWidth?: number): RectangleObject;
    /**
     * Set styles for the element. In addition to CSS styles supported by native
     * SVG and HTML elements, there are also some custom made for Highcharts,
     * like `width`, `ellipsis` and `textOverflow` for SVG text elements.
     *
     * @param styles
     *        The new CSS styles.
     *
     * @return Return the SVG element for chaining.
     */
    css(styles: CSSObject): SVGElement;
    /**
     * Destroy the element and element wrapper and clear up the DOM and event
     * hooks.
     */
    destroy(): void;
    /**
     * Fade out an element by animating its opacity down to 0, and hide it on
     * complete. Used internally for the tooltip.
     *
     * @param duration
     *        The fade duration in milliseconds.
     */
    fadeOut(duration?: number): void;
    /**
     * Get the bounding box (width, height, x and y) for the element. Generally
     * used to get rendered text size. Since this is called a lot in charts, the
     * results are cached based on text properties, in order to save DOM
     * traffic. The returned bounding box includes the rotation, so for example
     * a single text line of rotation 90 will report a greater height, and a
     * width corresponding to the line-height.
     *
     * @param reload
     *        Skip the cache and get the updated DOM bouding box.
     *
     * @param rot
     *        Override the element's rotation. This is internally used on axis
     *        labels with a value of 0 to find out what the bounding box would
     *        be have been if it were not rotated.
     *
     * @return The bounding box with `x`, `y`, `width` and `height` properties.
     */
    getBBox(reload?: boolean, rot?: number): BBoxObject;
    /**
     * Get the computed style. Only in styled mode.
     *
     * @param prop
     *        The property name to check for.
     *
     * @return The current computed value.
     */
    getStyle(prop: string): string;
    /**
     * Check if an element has the given class name.
     *
     * @param className
     *        The class name to check for.
     *
     * @return Whether the class name is found.
     */
    hasClass(className: string): boolean;
    /**
     * Hide the element, equivalent to setting the `visibility` attribute to
     * `hidden`.
     *
     * @return Returns the SVGElement for chaining.
     */
    hide(): SVGElement;
    /**
     * Initialize the SVG element. This function only exists to make the
     * initiation process overridable. It should not be called directly.
     *
     * @param renderer
     *        The SVGRenderer instance to initialize to.
     *
     * @param nodeName
     *        The SVG node name.
     */
    init(renderer: SVGRenderer, nodeName: string): void;
    /**
     * Invert a group, rotate and flip. This is used internally on inverted
     * charts, where the points and graphs are drawn as if not inverted, then
     * the series group elements are inverted.
     *
     * @param inverted
     *        Whether to invert or not. An inverted shape can be un-inverted by
     *        setting it to false.
     *
     * @return Return the SVGElement for chaining.
     */
    invert(inverted: boolean): SVGElement;
    /**
     * Add an event listener. This is a simple setter that replaces all other
     * events of the same type, opposed to the Highcharts#addEvent function.
     *
     * @param eventType
     *        The event type. If the type is `click`, Highcharts will internally
     *        translate it to a `touchstart` event on touch devices, to prevent
     *        the browser from waiting for a click event from firing.
     *
     * @param handler
     *        The handler callback.
     *
     * @return The SVGElement for chaining.
     */
    on(eventType: string, handler: () => void): SVGElement;
    /**
     * Remove a class name from the element.
     *
     * @param className
     *        The class name to remove.
     *
     * @return Returns the SVG element for chainability.
     */
    removeClass(className: (string|RegExp)): SVGElement;
    /**
     * Set the coordinates needed to draw a consistent radial gradient across a
     * shape regardless of positioning inside the chart. Used on pie slices to
     * make all the slices have the same radial reference point.
     *
     * @param coordinates
     *        The center reference. The format is `[centerX, centerY, diameter]`
     *        in pixels.
     *
     * @return Returns the SVGElement for chaining.
     */
    setRadialReference(coordinates: Array<number>): SVGElement;
    /**
     * Add a shadow to the element. Must be called after the element is added to
     * the DOM. In styled mode, this method is not used, instead use `defs` and
     * filters.
     *
     * @param shadowOptions
     *        The shadow options. If `true`, the default options are applied. If
     *        `false`, the current shadow will be removed.
     *
     * @param group
     *        The SVG group element where the shadows will be applied. The
     *        default is to add it to the same parent as the current element.
     *        Internally, this is ised for pie slices, where all the shadows are
     *        added to an element behind all the slices.
     *
     * @param cutOff
     *        Used internally for column shadows.
     *
     * @return Returns the SVGElement for chaining.
     */
    shadow(shadowOptions: (boolean|ShadowOptionsObject), group?: SVGElement, cutOff?: boolean): SVGElement;
    /**
     * Show the element after it has been hidden.
     *
     * @param inherit
     *        Set the visibility attribute to `inherit` rather than `visible`.
     *        The difference is that an element with `visibility="visible"` will
     *        be visible even if the parent is hidden.
     *
     * @return Returns the SVGElement for chaining.
     */
    show(inherit?: boolean): SVGElement;
    /**
     * Get the computed stroke width in pixel values. This is used extensively
     * when drawing shapes to ensure the shapes are rendered crisp and
     * positioned correctly relative to each other. Using `shape-rendering:
     * crispEdges` leaves us less control over positioning, for example when we
     * want to stack columns next to each other, or position things
     * pixel-perfectly within the plot box.
     *
     * The common pattern when placing a shape is:
     *
     * - Create the SVGElement and add it to the DOM. In styled mode, it will
     * now receive a stroke width from the style sheet. In classic mode we will
     * add the `stroke-width` attribute.
     *
     * - Read the computed `elem.strokeWidth()`.
     *
     * - Place it based on the stroke width.
     *
     * @return The stroke width in pixels. Even if the given stroke widtch (in
     *         CSS or by attributes) is based on `em` or other units, the pixel
     *         size is returned.
     */
    strokeWidth(): number;
    /**
     * Bring the element to the front. Alternatively, a new zIndex can be set.
     *
     * @return Returns the SVGElement for chaining.
     */
    toFront(): SVGElement;
    /**
     * Move an object and its children by x and y values.
     *
     * @param x
     *        The x value.
     *
     * @param y
     *        The y value.
     */
    translate(x: number, y: number): void;
}
/**
 * Allows direct access to the Highcharts rendering layer in order to draw
 * primitive shapes like circles, rectangles, paths or text directly on a chart,
 * or independent from any chart. The SVGRenderer represents a wrapper object
 * for SVG in modern browsers. Through the VMLRenderer, part of the `oldie.js`
 * module, it also brings vector graphics to IE <= 8.
 *
 * An existing chart's renderer can be accessed through Chart.renderer. The
 * renderer can also be used completely decoupled from a chart.
 */
export class SVGRenderer {
    /**
     * Allows direct access to the Highcharts rendering layer in order to draw
     * primitive shapes like circles, rectangles, paths or text directly on a
     * chart, or independent from any chart. The SVGRenderer represents a
     * wrapper object for SVG in modern browsers. Through the VMLRenderer, part
     * of the `oldie.js` module, it also brings vector graphics to IE <= 8.
     *
     * An existing chart's renderer can be accessed through Chart.renderer. The
     * renderer can also be used completely decoupled from a chart.
     *
     * @param container
     *        Where to put the SVG in the web page.
     *
     * @param width
     *        The width of the SVG.
     *
     * @param height
     *        The height of the SVG.
     *
     * @param forExport
     *        Whether the rendered content is intended for export.
     *
     * @param allowHTML
     *        Whether the renderer is allowed to include HTML text, which will
     *        be projected on top of the SVG.
     */
    constructor(container: HTMLDOMElement, width: number, height: number, forExport?: boolean, allowHTML?: boolean);
    /**
     * The root `svg` node of the renderer.
     */
    box: SVGDOMElement;
    /**
     * The wrapper for the root `svg` node of the renderer.
     */
    boxWrapper: SVGElement;
    /**
     * A pointer to the `defs` node of the root SVG.
     */
    defs: SVGElement;
    /**
     * A pointer to the renderer's associated Element class. The VMLRenderer
     * will have a pointer to VMLElement here.
     */
    Element: SVGElement;
    /**
     * A collection of characters mapped to HTML entities. When `useHTML` on an
     * element is true, these entities will be rendered correctly by HTML. In
     * the SVG pseudo-HTML, they need to be unescaped back to simple characters,
     * so for example `&lt;` will render as `<`.
     */
    escapes: Dictionary<string>;
    /**
     * An extendable collection of functions for defining symbol paths.
     */
    symbols: SymbolDictionary;
    /**
     * Draw and return an arc. Overloaded function that takes arguments object.
     *
     * @param attribs
     *        Initial SVG attributes.
     *
     * @return The generated wrapper element.
     */
    arc(attribs: SVGAttributes): SVGElement;
    /**
     * Draw and return an arc.
     *
     * @param x
     *        Center X position.
     *
     * @param y
     *        Center Y position.
     *
     * @param r
     *        The outer radius of the arc.
     *
     * @param innerR
     *        Inner radius like used in donut charts.
     *
     * @param start
     *        The starting angle of the arc in radians, where 0 is to the right
     *        and `-Math.PI/2` is up.
     *
     * @param end
     *        The ending angle of the arc in radians, where 0 is to the right
     *        and `-Math.PI/2` is up.
     *
     * @return The generated wrapper element.
     */
    arc(x?: number, y?: number, r?: number, innerR?: number, start?: number, end?: number): SVGElement;
    /**
     * Create a button with preset states.
     *
     * @param text
     *        The text or HTML to draw.
     *
     * @param x
     *        The x position of the button's left side.
     *
     * @param y
     *        The y position of the button's top side.
     *
     * @param callback
     *        The function to execute on button click or touch.
     *
     * @param normalState
     *        SVG attributes for the normal state.
     *
     * @param hoverState
     *        SVG attributes for the hover state.
     *
     * @param pressedState
     *        SVG attributes for the pressed state.
     *
     * @param disabledState
     *        SVG attributes for the disabled state.
     *
     * @param shape
     *        The shape type.
     *
     * @return The button element.
     */
    button(text: string, x: number, y: number, callback: () => void, normalState?: SVGAttributes, hoverState?: SVGAttributes, pressedState?: SVGAttributes, disabledState?: SVGAttributes,
shape?: SymbolKey): SVGElement;
    /**
     * Draw a circle, wraps the SVG `circle` element.
     *
     * @param attribs
     *        The initial attributes.
     *
     * @return The generated wrapper element.
     */
    circle(attribs?: SVGAttributes): SVGElement;
    /**
     * Draw a circle, wraps the SVG `circle` element.
     *
     * @param x
     *        The center x position.
     *
     * @param y
     *        The center y position.
     *
     * @param r
     *        The radius.
     *
     * @return The generated wrapper element.
     */
    circle(x?: number, y?: number, r?: number): SVGElement;
    /**
     * Define a clipping rectangle. The clipping rectangle is later applied to
     * SVGElement objects through the SVGElement#clip function.
     *
     *
     *
     *
     *
     *
     * @return A clipping rectangle.
     */
    clipRect(id: string, x: number, y: number, width: number, height: number): ClipRectElement;
    /**
     * Create a wrapper for an SVG element. Serves as a factory for SVGElement,
     * but this function is itself mostly called from primitive factories like
     * SVGRenderer#path, SVGRenderer#rect or SVGRenderer#text.
     *
     * @param nodeName
     *        The node name, for example `rect`, `g` etc.
     *
     * @return The generated SVGElement.
     */
    createElement(nodeName: string): SVGElement;
    /**
     * Make a straight line crisper by not spilling out to neighbour pixels.
     *
     * @param points
     *        The original points on the format `['M', 0, 0, 'L', 100, 0]`.
     *
     * @param width
     *        The width of the line.
     *
     * @return The original points array, but modified to render crisply.
     */
    crispLine(points: SVGPathArray, width: number): SVGPathArray;
    /**
     * General method for adding a definition to the SVG `defs` tag. Can be used
     * for gradients, fills, filters etc. Styled mode only. A hook for adding
     * general definitions to the SVG's defs tag. Definitions can be referenced
     * from the CSS by its `id`. Read more in gradients, shadows and patterns.
     * Styled mode only.
     *
     * @param def
     *        A serialized form of an SVG definition, including children.
     *
     * @return The inserted node.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.SVGRenderer#definition
     */
    definition(def: SVGDefinitionObject): SVGElement;
    /**
     * Destroys the renderer and its allocated members.
     */
    destroy(): void;
    /**
     * Dummy function for plugins, called every time the renderer is updated.
     * Prior to Highcharts 5, this was used for the canvg renderer.
     */
    draw(): void;
    /**
     * Utility to return the baseline offset and total line height from the font
     * size.
     *
     * @param fontSize
     *        The current font size to inspect. If not given, the font size will
     *        be found from the DOM element.
     *
     * @param elem
     *        The element to inspect for a current font size.
     *
     * @return The font metrics.
     */
    fontMetrics(fontSize?: string, elem?: (SVGDOMElement|SVGElement)): FontMetricsObject;
    /**
     * Create and return an svg group element. Child Highcharts.SVGElement
     * objects are added to the group by using the group as the first parameter
     * in add().
     *
     * @param name
     *        The group will be given a class name of `highcharts-{name}`. This
     *        can be used for styling and scripting.
     *
     * @return The generated wrapper element.
     */
    g(name?: string): SVGElement;
    /**
     * Returns white for dark colors and black for bright colors.
     *
     * @param rgba
     *        The color to get the contrast for.
     *
     * @return The contrast color, either `#000000` or `#FFFFFF`.
     */
    getContrast(rgba: ColorString): string;
    /**
     * Display an image.
     *
     * @param src
     *        The image source.
     *
     * @param x
     *        The X position.
     *
     * @param y
     *        The Y position.
     *
     * @param width
     *        The image width. If omitted, it defaults to the image file width.
     *
     * @param height
     *        The image height. If omitted it defaults to the image file height.
     *
     * @param onload
     *        Event handler for image load.
     *
     * @return The generated wrapper element.
     */
    image(src: string, x?: number, y?: number, width?: number, height?: number, onload?: () => void): SVGElement;
    /**
     * Initialize the SVGRenderer. Overridable initiator function that takes the
     * same parameters as the constructor.
     *
     * @param container
     *        Where to put the SVG in the web page.
     *
     * @param width
     *        The width of the SVG.
     *
     * @param height
     *        The height of the SVG.
     *
     * @param forExport
     *        Whether the rendered content is intended for export.
     *
     * @param allowHTML
     *        Whether the renderer is allowed to include HTML text, which will
     *        be projected on top of the SVG.
     *
     * @param styledMode
     *        Whether the renderer belongs to a chart that is in styled mode. If
     *        it does, it will avoid setting presentational attributes in some
     *        cases, but not when set explicitly through `.attr` and `.css` etc.
     */
    init(container: HTMLDOMElement, width: number, height: number, forExport?: boolean, allowHTML?: boolean, styledMode?: boolean): void;
    /**
     * Detect whether the renderer is hidden. This happens when one of the
     * parent elements has `display: none`. Used internally to detect when we
     * needto render preliminarily in another div to get the text bounding boxes
     * right.
     *
     * @return True if it is hidden.
     */
    isHidden(): boolean;
    /**
     * Draw a label, which is an extended text element with support for border
     * and background. Highcharts creates a `g` element with a text and a `path`
     * or `rect` inside, to make it behave somewhat like a HTML div. Border and
     * background are set through `stroke`, `stroke-width` and `fill` attributes
     * using the attr method. To update the text after render, run `label.attr({
     * text: 'New text' })`.
     *
     * @param str
     *        The initial text string or (subset) HTML to render.
     *
     * @param x
     *        The x position of the label's left side.
     *
     * @param y
     *        The y position of the label's top side or baseline, depending on
     *        the `baseline` parameter.
     *
     * @param shape
     *        The shape of the label's border/background, if any. Defaults to
     *        `rect`. Other possible values are `callout` or other shapes
     *        defined in Highcharts.SVGRenderer#symbols.
     *
     * @param anchorX
     *        In case the `shape` has a pointer, like a flag, this is the
     *        coordinates it should be pinned to.
     *
     * @param anchorY
     *        In case the `shape` has a pointer, like a flag, this is the
     *        coordinates it should be pinned to.
     *
     * @param useHTML
     *        Wether to use HTML to render the label.
     *
     * @param baseline
     *        Whether to position the label relative to the text baseline, like
     *        renderer.text, or to the upper border of the rectangle.
     *
     * @param className
     *        Class name for the group.
     *
     * @return The generated label.
     */
    label(str: string, x: number, y: number, shape?: string, anchorX?: number, anchorY?: number, useHTML?: boolean, baseline?: boolean, className?: string): SVGElement;
    /**
     * Draw a path, wraps the SVG `path` element.
     *
     * @param attribs
     *        The initial attributes.
     *
     * @return The generated wrapper element.
     */
    path(attribs?: SVGAttributes): SVGElement;
    /**
     * Draw a path, wraps the SVG `path` element.
     *
     * @param path
     *        An SVG path definition in array form.
     *
     * @return The generated wrapper element.
     */
    path(path?: SVGPathArray): SVGElement;
    /**
     * Draw and return a rectangle.
     *
     * @param attributes
     *        General SVG attributes for the rectangle.
     *
     * @return The generated wrapper element.
     */
    rect(attributes?: SVGAttributes): SVGElement;
    /**
     * Draw and return a rectangle.
     *
     * @param x
     *        Left position.
     *
     * @param y
     *        Top position.
     *
     * @param width
     *        Width of the rectangle.
     *
     * @param height
     *        Height of the rectangle.
     *
     * @param r
     *        Border corner radius.
     *
     * @param strokeWidth
     *        A stroke width can be supplied to allow crisp drawing.
     *
     * @return The generated wrapper element.
     */
    rect(x?: number, y?: number, width?: number, height?: number, r?: number, strokeWidth?: number): SVGElement;
    /**
     * Resize the SVGRenderer#box and re-align all aligned child elements.
     *
     * @param width
     *        The new pixel width.
     *
     * @param height
     *        The new pixel height.
     *
     * @param animate
     *        Whether and how to animate.
     */
    setSize(width: number, height: number, animate?: (boolean|AnimationOptionsObject)): void;
    /**
     * Apply the global style on the renderer, mixed with the default styles.
     *
     * @param style
     *        CSS to apply.
     */
    setStyle(style: CSSObject): void;
    /**
     * Draw a symbol out of pre-defined shape paths from SVGRenderer#symbols. It
     * is used in Highcharts for point makers, which cake a `symbol` option, and
     * label and button backgrounds like in the tooltip and stock flags.
     *
     * @param symbol
     *        The symbol name.
     *
     * @param x
     *        The X coordinate for the top left position.
     *
     * @param y
     *        The Y coordinate for the top left position.
     *
     * @param width
     *        The pixel width.
     *
     * @param height
     *        The pixel height.
     *
     * @param options
     *        Additional options, depending on the actual symbol drawn.
     */
    symbol(symbol: symbol, x: number, y: number, width: number, height: number, options?: SymbolOptionsObject): SVGElement;
    /**
     * Draw text. The text can contain a subset of HTML, like spans and anchors
     * and some basic text styling of these. For more advanced features like
     * border and background, use Highcharts.SVGRenderer#label instead. To
     * update the text after render, run `text.attr({ text: 'New text' })`.
     *
     * @param str
     *        The text of (subset) HTML to draw.
     *
     * @param x
     *        The x position of the text's lower left corner.
     *
     * @param y
     *        The y position of the text's lower left corner.
     *
     * @param useHTML
     *        Use HTML to render the text.
     *
     * @return The text object.
     */
    text(str: string, x: number, y: number, useHTML?: boolean): SVGElement;
}
/**
 * The Time class. Time settings are applied in general for each page using
 * `Highcharts.setOptions`, or individually for each Chart item through the time
 * options set.
 *
 * The Time object is available from Highcharts.Chart#time, which refers to
 * `Highcharts.time` if no individual time settings are applied.
 */
export class Time {
    /**
     * The Time class. Time settings are applied in general for each page using
     * `Highcharts.setOptions`, or individually for each Chart item through the
     * time options set.
     *
     * The Time object is available from Highcharts.Chart#time, which refers to
     * `Highcharts.time` if no individual time settings are applied.
     *
     * @param options
     *        Time options as defined in chart.options.time.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Time#constructor
     */
    constructor(options: TimeOptions);
    /**
     * Formats a JavaScript date timestamp (milliseconds since Jan 1st 1970)
     * into a human readable date string. The format is a subset of the formats
     * for PHP's strftime function. Additional formats can be given in the
     * Highcharts.dateFormats hook.
     *
     * @param timestamp
     *        The JavaScript timestamp.
     *
     * @param capitalize
     *        Upper case first letter in the return.
     *
     * @return The formatted date.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Time#dateFormat
     */
    dateFormat(timestamp: number, capitalize?: boolean): string;
    /**
     * Formats a JavaScript date timestamp (milliseconds since Jan 1st 1970)
     * into a human readable date string. The format is a subset of the formats
     * for PHP's strftime function. Additional formats can be given in the
     * Highcharts.dateFormats hook.
     *
     * @param format
     *        The desired format where various time representations are prefixed
     *        with %.
     *
     * @param timestamp
     *        The JavaScript timestamp.
     *
     * @param capitalize
     *        Upper case first letter in the return.
     *
     * @return The formatted date.
     *
     * @see https://api.highcharts.com/class-reference/Highcharts.Time#dateFormat
     */
    dateFormat(format: string, timestamp: number, capitalize?: boolean): string;
    /**
     * Return an array with time positions distributed on round time values
     * right and right after min and max. Used in datetime axes as well as for
     * grouping data on a datetime axis.
     *
     * @param normalizedInterval
     *        The interval in axis values (ms) and the count
     *
     * @param min
     *        The minimum in axis values
     *
     * @param max
     *        The maximum in axis values
     *
     */
    getTimeTicks(normalizedInterval: NormalizedIntervalObject, min?: number, max?: number, startOfWeek?: number): TimeTicksObject;
    /**
     * Get the time zone offset based on the current timezone information as set
     * in the global options.
     *
     * @param timestamp
     *        The JavaScript timestamp to inspect.
     *
     * @return The timezone offset in minutes compared to UTC.
     */
    getTimezoneOffset(timestamp: number): number;
    /**
     * Make a time and returns milliseconds. Interprets the inputs as UTC time,
     * local time or a specific timezone time depending on the current time
     * settings.
     *
     * @param year
     *        The year
     *
     * @param month
     *        The month. Zero-based, so January is 0.
     *
     * @param date
     *        The day of the month
     *
     * @param hours
     *        The hour of the day, 0-23.
     *
     * @param minutes
     *        The minutes
     *
     * @param seconds
     *        The seconds
     *
     * @return The time in milliseconds since January 1st 1970.
     */
    makeTime(year: number, month: number, date?: number, hours?: number, minutes?: number, seconds?: number): number;
    /**
     * Resolve legacy formats of dateTimeLabelFormats (strings and arrays) into
     * an object.
     *
     * @param f
     *        General format description
     *
     * @return The object definition
     */
    resolveDTLFormat(f: (any[]|object|string)): object;
}
/**
 * Tooltip of a chart.
 */
export class Tooltip {
    /**
     * Tooltip of a chart.
     *
     * @param chart
     *        The chart instance.
     *
     * @param options
     *        Tooltip options.
     */
    constructor(chart: Chart, options: TooltipOptions);
    /**
     * Chart of the tooltip.
     */
    chart: Chart;
    /**
     * Tooltips are initially hidden.
     */
    isHidden: boolean;
    /**
     * Used tooltip options.
     */
    options: TooltipOptions;
    /**
     * Whether to allow the tooltip to render outside the chart's SVG element
     * box. By default (false), the tooltip is rendered within the chart's SVG
     * element, which results in the tooltip being aligned inside the chart
     * area.
     */
    outside: boolean;
    /**
     * When the tooltip is shared, the entire plot area will capture mouse
     * movement or touch events.
     */
    shared: boolean;
    /**
     * True, if the tooltip is splitted into one label per series, with the
     * header close to the axis.
     */
    split: boolean;
    /**
     * Removes and destroys the tooltip and its elements.
     */
    destroy(): void;
    /**
     * Creates the Tooltip label element if it does not exist, then returns it.
     */
    getLabel(): SVGElement;
    /**
     * Hides the tooltip with a fade out animation.
     *
     * @param delay
     *        The fade out in milliseconds. If no value is provided the value of
     *        the tooltip.hideDelay option is used. A value of 0 disables the
     *        fade out animation.
     */
    hide(delay?: number): void;
    /**
     * Moves the tooltip with a soft animation to a new position.
     *
     *
     *
     *
     */
    move(x: number, y: number, anchorX: number, anchorY: number): void;
    /**
     * Refresh the tooltip's text and position.
     *
     * @param pointOrPoints
     *        Either a point or an array of points.
     *
     * @param mouseEvent
     *        Mouse event, that is responsible for the refresh and should be
     *        used for the tooltip update.
     */
    refresh(pointOrPoints: (Point|Array<Point>), mouseEvent?: Event): void;
    /**
     * Updates the tooltip with the provided tooltip options.
     *
     * @param options
     *        The tooltip options to update.
     */
    update(options: TooltipOptions): void;
}
/**
 * An array containing the current chart objects in the page. A chart's position
 * in the array is preserved throughout the page's lifetime. When a chart is
 * destroyed, the array item becomes `undefined`.
 */
export let charts: Array<Chart>;
/**
 * A hook for defining additional date format specifiers. New specifiers are
 * defined as key-value pairs by using the specifier as key, and a function
 * which takes the timestamp as value. This function returns the formatted
 * portion of the date.
 */
export let dateFormats: Dictionary<TimeFormatCallbackFunction>;
/**
 * Global default settings.
 */
export let defaultOptions: Options;
/**
 * Global `Time` object with default options. Since v6.0.5, time settings can be
 * applied individually for each chart. If no individual settings apply, this
 * `Time` object is shared by all instances.
 */
export let time: Time;
/**
 * Add an event listener.
 *
 * @param el
 *        The element or object to add a listener to. It can be a
 *        HTMLDOMElement, an SVGElement or any other object.
 *
 * @param type
 *        The event type.
 *
 * @param fn
 *        The function callback to execute when the event is fired.
 *
 * @param options
 *        Options for adding the event.
 *
 * @return A callback function to remove the added event.
 */
export function addEvent<T>(el: T, type: string, fn: EventCallbackFunction<T>, options?: EventOptionsObject): () => void;
/**
 * The global animate method, which uses Fx to create individual animators.
 *
 * @param el
 *        The element to animate.
 *
 * @param params
 *        An object containing key-value pairs of the properties to animate.
 *        Supports numeric as pixel-based CSS properties for HTML objects and
 *        attributes for SVGElements.
 *
 * @param opt
 *        Animation options.
 */
export function animate(el: (HTMLDOMElement|SVGElement), params: (HTMLAttributes|SVGAttributes), opt?: AnimationOptionsObject): void;
/**
 * Get the animation in object form, where a disabled animation is always
 * returned as `{ duration: 0 }`.
 *
 * @param animation
 *        An animation setting. Can be an object with duration, complete and
 *        easing properties, or a boolean to enable or disable.
 *
 * @return An object with at least a duration property.
 */
export function animObject(animation: (boolean|AnimationOptionsObject)): AnimationOptionsObject;
/**
 * Non-recursive method to find the lowest member of an array. `Math.max` raises
 * a maximum call stack size exceeded error in Chrome when trying to apply more
 * than 150.000 points. This method is slightly slower, but safe.
 *
 * @param data
 *        An array of numbers.
 *
 * @return The highest number.
 */
export function arrayMax(data: any[]): number;
/**
 * Non-recursive method to find the lowest member of an array. `Math.min` raises
 * a maximum call stack size exceeded error in Chrome when trying to apply more
 * than 150.000 points. This method is slightly slower, but safe.
 *
 * @param data
 *        An array of numbers.
 *
 * @return The lowest number.
 */
export function arrayMin(data: any[]): number;
/**
 * Set or get an attribute or an object of attributes. To use as a setter, pass
 * a key and a value, or let the second argument be a collection of keys and
 * values. To use as a getter, pass only a string as the second argument.
 *
 * @param elem
 *        The DOM element to receive the attribute(s).
 *
 * @param prop
 *        The property or an object of key-value pairs.
 *
 * @param value
 *        The value if a single property is set.
 *
 * @return When used as a getter, return the value.
 */
export function attr(elem: (HTMLDOMElement|SVGDOMElement), prop?: (string|HTMLAttributes|SVGAttributes), value?: string): any;
/**
 * Factory function for basic charts.
 *
 * @param options
 *        The chart options structure.
 *
 * @param callback
 *        Function to run when the chart has loaded and and all external images
 *        are loaded. Defining a chart.event.load handler is equivalent.
 *
 * @return Returns the Chart object.
 *
 * @see https://api.highcharts.com/class-reference/Highcharts#chart
 */
export function chart(options: Options, callback?: ChartCallbackFunction): Chart;
/**
 * Factory function for basic charts.
 *
 * @param renderTo
 *        The DOM element to render to, or its id.
 *
 * @param options
 *        The chart options structure.
 *
 * @param callback
 *        Function to run when the chart has loaded and and all external images
 *        are loaded. Defining a chart.event.load handler is equivalent.
 *
 * @return Returns the Chart object.
 *
 * @see https://api.highcharts.com/class-reference/Highcharts#chart
 */
export function chart(renderTo: (string|HTMLDOMElement), options: Options, callback?: ChartCallbackFunction): Chart;
/**
 * Internal clear timeout. The function checks that the `id` was not removed
 * (e.g. by `chart.destroy()`). For the details see issue .7901.
 *
 * @param id
 *        Id of a timeout.
 *
 * @see https://api.highcharts.com/class-reference/Highcharts#clearTimeout
 */
export function clearTimeout(id: number): void;
/**
 * Fix JS round off float errors.
 *
 * @param num
 *        A float number to fix.
 *
 * @param prec
 *        The precision.
 *
 * @return The corrected float number.
 */
export function correctFloat(num: number, prec?: number): number;
/**
 * Utility function to create an HTML element with attributes and styles.
 *
 * @param tag
 *        The HTML tag.
 *
 * @param attribs
 *        Attributes as an object of key-value pairs.
 *
 * @param styles
 *        Styles as an object of key-value pairs.
 *
 * @param parent
 *        The parent HTML object.
 *
 * @param nopad
 *        If true, remove all padding, border and margin.
 *
 * @return The created DOM element.
 */
export function createElement(tag: string, attribs?: HTMLAttributes, styles?: CSSObject, parent?: HTMLDOMElement, nopad?: boolean): HTMLDOMElement;
/**
 * Set CSS on a given element.
 *
 * @param el
 *        An HTML DOM element.
 *
 * @param styles
 *        Style object with camel case property names.
 */
export function css(el: HTMLDOMElement, styles: CSSObject): void;
/**
 * Formats a JavaScript date timestamp (milliseconds since Jan 1st 1970) into a
 * human readable date string. The format is a subset of the formats for PHP's
 * strftime function. Additional formats can be given in the
 * Highcharts.dateFormats hook.
 *
 * Since v6.0.5, all internal dates are formatted through the
 * Highcharts.Chart#time instance to respect chart-level time settings. The
 * `Highcharts.dateFormat` function only reflects global time settings set with
 * `setOptions`.
 *
 * @param format
 *        The desired format where various time representations are prefixed
 *        with `%`.
 *
 * @param timestamp
 *        The JavaScript timestamp.
 *
 * @param capitalize
 *        Upper case first letter in the return.
 *
 * @return The formatted date.
 *
 * @see https://api.highcharts.com/class-reference/Highcharts#dateFormat
 */
export function dateFormat(format: string, timestamp: number, capitalize?: boolean): string;
/**
 * Recursively converts all Date properties to timestamps.
 *
 * @param object
 *        any object to convert properties of
 */
export function datePropsToTimestamps(object: object): void;
/**
 * Check if an object is null or undefined.
 *
 * @param obj
 *        The object to check.
 *
 * @return False if the object is null or undefined, otherwise true.
 */
export function defined(obj: any): boolean;
/**
 * Utility method that destroys any SVGElement instances that are properties on
 * the given object. It loops all properties and invokes destroy if there is a
 * destroy method. The property is then delete.
 *
 * @param obj
 *        The object to destroy properties on.
 *
 * @param except
 *        Exception, do not destroy this property, only delete it.
 */
export function destroyObjectProperties(obj: any, except?: any): void;
/**
 * Discard a HTML element by moving it to the bin and delete.
 *
 * @param element
 *        The HTML node to discard.
 */
export function discardElement(element: HTMLDOMElement): void;
/**
 * Iterate over an array.
 *
 * @param arr
 *        The array to iterate over.
 *
 * @param fn
 *        The iterator callback. It passes three arguments:
 *
 *        - `item`: The array item.
 *
 *        - `index`: The item's index in the array.
 *
 *        - `arr`: The array that each is being applied to.
 *
 * @param ctx
 *        The context.
 */
export function each(arr: Array<any>, fn: () => void, ctx?: any): void;
/**
 * Remove the last occurence of an item from an array.
 *
 * @param arr
 *        The array.
 *
 * @param item
 *        The item to remove.
 */
export function erase(arr: any[], item: any): void;
/**
 * Provide error messages for debugging, with links to online explanation. This
 * function can be overridden to provide custom error handling.
 *
 * @param code
 *        The error code. See errors.xml for available codes. If it is a string,
 *        the error message is printed directly in the console.
 *
 * @param stop
 *        Whether to throw an error or just log a warning in the console.
 *
 * @see https://api.highcharts.com/class-reference/Highcharts#error
 */
export function error(code: (number|string), stop?: boolean): void;
/**
 * Utility function to extend an object with the members of another.
 *
 * @param a
 *        The object to be extended.
 *
 * @param b
 *        The object to add to the first one.
 *
 * @return Object a, the original object.
 */
export function extend(a: Dictionary<any>, b: Dictionary<any>): Dictionary<any>;
/**
 * Extend a prototyped class by new members.
 *
 * @param parent
 *        The parent prototype to inherit.
 *
 * @param members
 *        A collection of prototype members to add or override compared to the
 *        parent prototype.
 *
 * @return A new prototype.
 */
export function extendClass(parent: any, members: Dictionary<any>): any;
/**
 * Return the value of the first element in the array that satisfies the
 * provided testing function.
 *
 * @param arr
 *        The array to test.
 *
 * @param callback
 *        The callback function. The function receives the item as the first
 *        argument. Return `true` if this item satisfies the condition.
 *
 * @return The value of the element.
 */
export function find(arr: any[], callback: () => void): any;
/**
 * Fire an event that was registered with Highcharts#addEvent.
 *
 * @param el
 *        The object to fire the event on. It can be a HTMLDOMElement, an
 *        SVGElement or any other object.
 *
 * @param type
 *        The type of event.
 *
 * @param eventArguments
 *        Custom event arguments that are passed on as an argument to the event
 *        handler.
 *
 * @param defaultFunction
 *        The default function to execute if the other listeners haven't
 *        returned false.
 */
export function fireEvent(el: any, type: string, eventArguments?: Dictionary<any>, defaultFunction?: () => void): void;
/**
 * Format a string according to a subset of the rules of Python's String.format
 * method.
 *
 * @param str
 *        The string to format.
 *
 * @param ctx
 *        The context, a collection of key-value pairs where each key is
 *        replaced by its value.
 *
 * @param time
 *        A `Time` instance that determines the date formatting, for example for
 *        applying time zone corrections to the formatted date.
 *
 * @return The formatted string.
 */
export function format(str: string, ctx: any, time?: Time): string;
/**
 * Format a single variable. Similar to sprintf, without the % prefix.
 *
 * @param format
 *        The format string.
 *
 * @param val
 *        The value.
 *
 * @param time
 *        A `Time` instance that determines the date formatting, for example for
 *        applying time zone corrections to the formatted date.
 *
 * @return The formatted representation of the value.
 */
export function formatSingle(format: string, val: any, time?: Time): string;
/**
 * Get the magnitude of a number.
 *
 * @param number
 *        The number.
 *
 * @return The magnitude, where 1-9 are magnitude 1, 10-99 magnitude 2 etc.
 */
export function getMagnitude(number: number): number;
/**
 * Get the updated default options. Until 3.0.7, merely exposing defaultOptions
 * for outside modules wasn't enough because the setOptions method created a new
 * object.
 */
export function getOptions(): Options;
/**
 * Get the computed CSS value for given element and property, only for numerical
 * properties. For width and height, the dimension of the inner box (excluding
 * padding) is returned. Used for fitting the chart within the container.
 *
 * @param el
 *        An HTML element.
 *
 * @param prop
 *        The property name.
 *
 * @param toInt
 *        Parse to integer.
 *
 * @return The numeric value.
 */
export function getStyle(el: HTMLDOMElement, prop: string, toInt?: boolean): number;
/**
 * Filter an array by a callback.
 *
 * @param arr
 *        The array to filter.
 *
 * @param callback
 *        The callback function. The function receives the item as the first
 *        argument. Return `true` if the item is to be preserved.
 *
 * @return A new, filtered array.
 */
export function grep(arr: Array<any>, callback: () => void): Array<any>;
/**
 * Search for an item in an array.
 *
 * @param item
 *        The item to search for.
 *
 * @param arr
 *        The array or node collection to search in.
 *
 * @param fromIndex
 *        The index to start searching from.
 *
 * @return The index within the array, or -1 if not found.
 */
export function inArray(item: any, arr: any[], fromIndex?: number): number;
/**
 * Utility function to check if an item is an array.
 *
 * @param obj
 *        The item to check.
 *
 * @return True if the argument is an array.
 */
export function isArray(obj: any): boolean;
/**
 * Utility function to check if an Object is an class.
 *
 * @param obj
 *        The item to check.
 *
 * @return True if the argument is an class.
 */
export function isClass(obj: any): boolean;
/**
 * Utility function to check if an Object is a HTML Element.
 *
 * @param obj
 *        The item to check.
 *
 * @return True if the argument is a HTML Element.
 */
export function isDOMElement(obj: any): boolean;
/**
 * Utility function to check if an item is a number and it is finite (not NaN,
 * Infinity or -Infinity).
 *
 * @param n
 *        The item to check.
 *
 * @return True if the item is a finite number
 */
export function isNumber(n: any): boolean;
/**
 * Utility function to check if an item is of type object.
 *
 * @param obj
 *        The item to check.
 *
 * @param strict
 *        Also checks that the object is not an array.
 *
 * @return True if the argument is an object.
 */
export function isObject(obj: any, strict?: boolean): boolean;
/**
 * Utility function to check for string type.
 *
 * @param s
 *        The item to check.
 *
 * @return True if the argument is a string.
 */
export function isString(s: any): boolean;
/**
 * Returns an array of a given object's own properties.
 *
 * @param obj
 *        The object of which the properties are to be returned.
 *
 * @return An array of strings that represents all the properties.
 */
export function keys(obj: any): Array<string>;
/**
 * Map an array by a callback.
 *
 * @param arr
 *        The array to map.
 *
 * @param fn
 *        The callback function. Return the new value for the new array.
 *
 * @return A new array item with modified items.
 */
export function map(arr: Array<any>, fn: () => void): Array<any>;
/**
 * Utility function to deep merge two or more objects and return a third object.
 * The merge function can also be used with a single object argument to create a
 * deep copy of an object.
 *
 * @param a
 *        The first object to extend. When only this is given, the function
 *        returns a deep copy.
 *
 * @param n
 *        An object to merge into the previous one.
 *
 * @return The merged object. If the first argument is true, the return is the
 *         same as the second argument.
 */
export function merge(a: any, n?: any): any;
/**
 * Utility function to deep merge two or more objects and return a third object.
 * If the first argument is true, the contents of the second object is copied
 * into the first object. The merge function can also be used with a single
 * object argument to create a deep copy of an object.
 *
 * @param extend
 *        Whether to extend the left-side object (a) or return a whole new
 *        object.
 *
 * @param a
 *        The first object to extend. When only this is given, the function
 *        returns a deep copy.
 *
 * @param n
 *        An object to merge into the previous one.
 *
 * @return The merged object. If the first argument is true, the return is the
 *         same as the second argument.
 */
export function merge(extend: boolean, a: any, n?: any): any;
/**
 * Take an interval and normalize it to multiples of round numbers.
 *
 * @param interval
 *        The raw, un-rounded interval.
 *
 * @param multiples
 *        Allowed multiples.
 *
 * @param magnitude
 *        The magnitude of the number.
 *
 * @param allowDecimals
 *        Whether to allow decimals.
 *
 * @param hasTickAmount
 *        If it has tickAmount, avoid landing on tick intervals lower than
 *        original.
 *
 * @return The normalized interval.
 */
export function normalizeTickInterval(interval: number, multiples?: any[], magnitude?: number, allowDecimals?: boolean, hasTickAmount?: boolean): number;
/**
 * Format a number and return a string based on input settings.
 *
 * @param number
 *        The input number to format.
 *
 * @param decimals
 *        The amount of decimals. A value of -1 preserves the amount in the
 *        input number.
 *
 * @param decimalPoint
 *        The decimal point, defaults to the one given in the lang options, or a
 *        dot.
 *
 * @param thousandsSep
 *        The thousands separator, defaults to the one given in the lang
 *        options, or a space character.
 *
 * @return The formatted number.
 */
export function numberFormat(number: number, decimals: number, decimalPoint?: string, thousandsSep?: string): string;
/**
 * Iterate over object key pairs in an object.
 *
 * @param obj
 *        The object to iterate over.
 *
 * @param fn
 *        The iterator callback. It passes three arguments:
 *
 *        * value - The property value.
 *
 *        * key - The property key.
 *
 *        * obj - The object that objectEach is being applied to.
 *
 * @param ctx
 *        The context.
 */
export function objectEach(obj: any, fn: ObjectEachCallbackFunction, ctx?: any): void;
/**
 * Get the element's offset position, corrected for `overflow: auto`.
 *
 * @param el
 *        The HTML element.
 *
 * @return An object containing `left` and `top` properties for the position in
 *         the page.
 */
export function offset(el: HTMLDOMElement): OffsetObject;
/**
 * Left-pad a string to a given length by adding a character repetetively.
 *
 * @param number
 *        The input string or number.
 *
 * @param length
 *        The desired string length.
 *
 * @param padder
 *        The character to pad with.
 *
 * @return The padded string.
 */
export function pad(number: number, length: number, padder?: string): string;
/**
 * Return the first value that is not null or undefined.
 *
 * @param items
 *        Variable number of arguments to inspect.
 *
 * @return The value of the first argument that is not null or undefined.
 */
export function pick(items: any): any;
/**
 * Reduce an array to a single value.
 *
 * @param arr
 *        The array to reduce.
 *
 * @param fn
 *        The callback function. Return the reduced value. Receives 4 arguments:
 *        Accumulated/reduced value, current value, current array index, and the
 *        array.
 *
 * @param initialValue
 *        The initial value of the accumulator.
 *
 * @return The reduced value.
 */
export function reduce(arr: any[], fn: () => void, initialValue: any): any;
/**
 * Return a length based on either the integer value, or a percentage of a base.
 *
 * @param value
 *        A percentage string or a number.
 *
 * @param base
 *        The full length that represents 100%.
 *
 * @param offset
 *        A pixel offset to apply for percentage values. Used internally in axis
 *        positioning.
 *
 * @return The computed length.
 */
export function relativeLength(value: RelativeSize, base: number, offset?: number): number;
/**
 * Remove an event that was added with Highcharts#addEvent.
 *
 * @param el
 *        The element to remove events on.
 *
 * @param type
 *        The type of events to remove. If undefined, all events are removed
 *        from the element.
 *
 * @param fn
 *        The specific callback to remove. If undefined, all events that match
 *        the element and optionally the type are removed.
 */
export function removeEvent<T>(el: T, type?: string, fn?: EventCallbackFunction<T>): void;
/**
 * Factory to create new series prototypes.
 *
 * @param type
 *        The series type name.
 *
 * @param parent
 *        The parent series type name. Use `line` to inherit from the basic
 *        Series object.
 *
 * @param options
 *        The additional default options that is merged with the parent's
 *        options.
 *
 * @param props
 *        The properties (functions and primitives) to set on the new prototype.
 *
 * @param pointProps
 *        Members for a series-specific extension of the Point prototype if
 *        needed.
 *
 * @return The newly created prototype as extended from Series or its
 *         derivatives.
 */
export function seriesType(type: string, parent: string, options: any, props: any, pointProps?: any): Series;
/**
 * Set the global animation to either a given value, or fall back to the given
 * chart's animation option.
 *
 * @param animation
 *        The animation object.
 *
 * @param chart
 *        The chart instance.
 */
export function setAnimation(animation: (boolean|AnimationOptionsObject), chart: Chart): void;
/**
 * Merge the default options with custom options and return the new options
 * structure. Commonly used for defining reusable templates.
 *
 * @param options
 *        The new custom chart options.
 *
 * @return Updated options.
 */
export function setOptions(options: Options): Options;
/**
 * Test whether at least one element in the array passes the test implemented by
 * the provided function.
 *
 * @param arr
 *        The array to test
 *
 * @param fn
 *        The function to run on each item. Return truty to pass the test.
 *        Receives arguments `currentValue`, `index` and `array`.
 *
 * @param ctx
 *        The context.
 */
export function some(arr: Array<any>, fn: () => void, ctx: any): boolean;
/**
 * Check if an element is an array, and if not, make it into an array.
 *
 * @param obj
 *        The object to splat.
 *
 * @return The produced or original array.
 */
export function splat(obj: any): any[];
/**
 * Sort an object array and keep the order of equal items. The ECMAScript
 * standard does not specify the behaviour when items are equal.
 *
 * @param arr
 *        The array to sort.
 *
 * @param sortFunction
 *        The function to sort it with, like with regular Array.prototype.sort.
 */
export function stableSort(arr: any[], sortFunction: () => void): void;
/**
 * Stop running animation.
 *
 * @param el
 *        The SVGElement to stop animation on.
 *
 * @param prop
 *        The property to stop animating. If given, the stop method will stop a
 *        single property from animating, while others continue.
 */
export function stop(el: SVGElement, prop?: string): void;
/**
 * Set a timeout if the delay is given, otherwise perform the function
 * synchronously.
 *
 * @param fn
 *        The function callback.
 *
 * @param delay
 *        Delay in milliseconds.
 *
 * @param context
 *        The context.
 *
 * @return An identifier for the timeout that can later be cleared with
 *         Highcharts.clearTimeout.
 */
export function syncTimeout(fn: () => void, delay: number, context?: any): number;
/**
 * Get a unique key for using in internal element id's and pointers. The key is
 * composed of a random hash specific to this Highcharts instance, and a
 * counter.
 *
 * @return A unique key.
 */
export function uniqueKey(): string;
/**
 * Wrap a method with extended functionality, preserving the original function.
 *
 * @param obj
 *        The context object that the method belongs to. In real cases, this is
 *        often a prototype.
 *
 * @param method
 *        The name of the method to extend.
 *
 * @param func
 *        A wrapper function callback. This function is called with the same
 *        arguments as the original function, except that the original function
 *        is unshifted and passed as the first argument.
 */
export function wrap(obj: any, method: string, func: () => void): void;
declare global {
    /**
     * Highcharts-extended JQuery.
     */
    interface JQuery {
        /**
         * Helper function to return the chart of the current JQuery selector
         * element.
         *
         * @param className
         *        Name of the factory class in the Highcharts namespace.
         *
         * @param options
         *        The chart options structure.
         *
         * @param callback
         *        Function to run when the chart has loaded and and all external
         *        images are loaded. Defining a chart.event.load handler is
         *        equivalent.
         *
         * @return The current JQuery selector.
         *
         * @see https://api.highcharts.com/class-reference/external-JQuery#highcharts
         */
        highcharts(className?: ("Chart"|"Map"|"StockChart"|string), options?: Options, callback?: ChartCallbackFunction): JQuery;
    }
}
export as namespace Highcharts;
